(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    907274,      25466]*)
(*NotebookOutlinePosition[    963938,      27553]*)
(*  CellTagsIndexPosition[    962452,      27516]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Correlation and regression in contingency tables", "Title"],

Cell["\<\
A measure of association or correlation in nominal data (contingency tables), \
using determinants\
\>", "Subtitle"],

Cell["\<\
Thomas Colignatus, June 5 2007
http://www.dataweb.nl/~cool
(c) Thomas Cool\
\>", "Text"],

Cell["\<\
I thank anonymous referee(s) for their comments, a good friend at Leiden \
University who does a bit in statistics and who made an important remark, and \
a sympathetic mind in California who wondered about the relation to logistic \
regression.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Summary", "Subsection"],

Cell[TextData[{
  "Nominal data currently lack a correlation coefficient, such as has already \
been defined for real data. A measure can be designed using the determinant, \
with the useful interpretation that the determinant gives the ratio between \
volumes. With ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "a ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table with ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[GreaterEqual] ",
  StyleBox["n, ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["A",
    FontSlant->"Italic"],
  " = Normalized[",
  StyleBox["M",
    FontSlant->"Italic"],
  "], then ",
  StyleBox["A'A",
    FontSlant->"Italic"],
  " is a square ",
  StyleBox["n",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " matrix and the suggested measure is ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "= Sqrt[Det[",
  StyleBox["A'A",
    FontSlant->"Italic"],
  "]]. With ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "an ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " contingency matrix, then pairwise correlations can be collected in a ",
  StyleBox["k",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["k",
    FontSlant->"Italic"],
  " matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  ". A matrix of such pairwise correlations is called an association matrix. \
If that matrix is also positive semi-definite (PSD) then it is a proper \
correlation matrix. The overall correlation then is ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] where ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "can be chosen to impose PSD-ness. An option is to use ",
  StyleBox["R = ",
    FontSlant->"Italic"],
  "Sqrt[1 - Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "]]. However, for both nominal and cardinal data the advisable choice is to \
take the maximal multiple correlation within ",
  StyleBox["R",
    FontWeight->"Bold"],
  ". The resulting measure of \[OpenCurlyDoubleQuote]nominal correlation\
\[CloseCurlyDoubleQuote] measures the distance between a main diagonal and \
the off-diagonal elements, and thus is a measure of strong correlation. \
Cramer\[CloseCurlyQuote]s V measure for pairwise correlation can be \
generalized in this manner too. It measures the distance between all \
diagonals (including cross-diagonals and subdiagonals) and statistical \
independence, and thus is a measure of weaker correlation. Finally, when also \
variances are defined then regression coefficients can be determined from the \
variance-covariance matrix. The volume ratio measure can be related to the \
regression coefficients, not of the variables, but of the categories in the \
contingency matrix, using the conditional probabilities given the row and \
column sums."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Section"],

Cell[BoxData[
    \(Needs["\<Economics`Pack`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell["ResetAll", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(TraditionalForm\`{"Utilities`CleanSlate`", "Economics`Pack`", 
      "Cool`Declare`", "Cool`Context`", "Cool`Common`", "Cool`Inequality`", 
      "Cool`Graphics`", "Cool`Tool`", "Cool`List`", "Cool`Manager`", 
      "Statistics`Common`DistributionsCommon`", 
      "Algebra`AlgebraicInequalities`", "Algebra`InequalitySolve`", 
      "Graphics`Arrow`", "LinearAlgebra`MatrixManipulation`", 
      "Utilities`FilterOptions`", "Global`", "System`"}\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[Plot, \ 
      TextStyle\  \[Rule] \ {FontSize\  \[Rule] \ 11}]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"AspectRatio", "\[Rule]", 
            FractionBox["1", 
              TagBox["\[Phi]",
                Function[ {}, GoldenRatio]]]}], 
          ",", \(Axes \[Rule] Automatic\), ",", \(AxesLabel \[Rule] None\), 
          ",", \(AxesOrigin \[Rule] Automatic\), 
          ",", \(AxesStyle \[Rule] Automatic\), 
          ",", \(Background \[Rule] Automatic\), 
          ",", \(ColorOutput \[Rule] Automatic\), 
          ",", \(Compiled \[Rule] True\), 
          ",", \(DefaultColor \[Rule] Automatic\), 
          ",", \(DefaultFont \[RuleDelayed] $DefaultFont\), 
          ",", \(DisplayFunction \[RuleDelayed] $DisplayFunction\), 
          ",", \(Epilog \[Rule] {}\), 
          ",", \(FormatType \[RuleDelayed] $FormatType\), 
          ",", \(Frame \[Rule] False\), ",", \(FrameLabel \[Rule] None\), 
          ",", \(FrameStyle \[Rule] Automatic\), 
          ",", \(FrameTicks \[Rule] Automatic\), 
          ",", \(GridLines \[Rule] None\), 
          ",", \(ImageSize \[Rule] Automatic\), ",", \(MaxBend \[Rule] 10.`\),
           ",", \(PlotDivision \[Rule] 30.`\), 
          ",", \(PlotLabel \[Rule] None\), ",", \(PlotPoints \[Rule] 25\), 
          ",", \(PlotRange \[Rule] Automatic\), 
          ",", \(PlotRegion \[Rule] Automatic\), 
          ",", \(PlotStyle \[Rule] Automatic\), ",", \(Prolog \[Rule] {}\), 
          ",", \(RotateLabel \[Rule] True\), 
          ",", \(TextStyle \[Rule] {FontSize \[Rule] 11}\), 
          ",", \(Ticks \[Rule] Automatic\)}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[BoxData[
    \(Off[Get::"\<notencode\>"]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Needs["\<Statistics`MultiDescriptiveStatistics`\>"]\)], "Input",
  CellLabel->"In[5]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Causality]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    FormBox[
      RowBox[{\(Protect::"locked"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`\[ImaginaryI]\\) is locked. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Protect::locked\\\"]\\)\"\>"}], 
      TraditionalForm]], "Message",
  CellLabel->"From In[6]:="],

Cell[BoxData[
    \("CausalityPackages[] gives an overview of the packages in \
causality"\)], "Print",
  CellTags->"Info3389988121-2727535"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Statistics`Contingency]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Statistics`Contingency`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["CT",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1497787", 
                    "Cool`Statistics`Contingency`CT"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Contingency`"], 
                ButtonBox[
                  StyleBox["dbCT",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1497787", 
                    "Cool`Statistics`Contingency`dbCT"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Contingency`"], 
                ButtonBox[
                  StyleBox["OddsTable22",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1497787", 
                    "Cool`Statistics`Contingency`OddsTable22"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Contingency`"], 
                ButtonBox[
                  StyleBox["OddsTable222",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1497787", 
                    "Cool`Statistics`Contingency`OddsTable222"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Contingency`"], 
                ButtonBox[
                  StyleBox["Options$CT",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1497787", 
                    "Cool`Statistics`Contingency`Options$CT"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Contingency`"], ""}
              },
            RowMinHeight->1.05]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Estimate]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Estimate`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AdjustedR2Density",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`AdjustedR2Density"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["NonlinearFitOld",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`NonlinearFitOld"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["RSquaredDensity",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`RSquaredDensity"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["AdjustedR2Expectation",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`AdjustedR2Expectation"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["NumberOfEquations",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`NumberOfEquations"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["RSquaredExpectation",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`RSquaredExpectation"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["AdjustedRSquaredCI",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`AdjustedRSquaredCI"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["Options$Estimate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`Options$Estimate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["SetR2Plots",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`SetR2Plots"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["CorrelationDensity",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`CorrelationDensity"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["ParametersToE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`ParametersToE"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["SSE",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988122-8204364", "Cool`Estimate`SSE"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["DensitySigma",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`DensitySigma"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["Phi",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988122-8204364", "Cool`Estimate`Phi"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["SSR",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988122-8204364", "Cool`Estimate`SSR"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["ErrorsInVariable",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`ErrorsInVariable"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["PlotExpectedR2s",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`PlotExpectedR2s"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["SSRAdj",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`SSRAdj"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["Estats",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`Estats"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["QuadraticRegress",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`QuadraticRegress"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["SST",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988122-8204364", "Cool`Estimate`SST"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["Estimate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`Estimate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["ReducedFormQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`ReducedFormQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["TErrorToNormal",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`TErrorToNormal"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"]},
              {
                ButtonBox[
                  StyleBox["InverseHessian",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`InverseHessian"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["Rho2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`Rho2"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], ""},
              {
                ButtonBox[
                  StyleBox["ModelY",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`ModelY"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], 
                ButtonBox[
                  StyleBox["RSquaredCI",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-8204364", 
                    "Cool`Estimate`RSquaredCI"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Estimate`"], ""}
              },
            RowMinHeight->{1, 1, 1, 1, 1, 1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Matrix]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Matrix`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["BlockDiagonal",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`BlockDiagonal"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["DiagMatDiag",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`DiagMatDiag"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["SuccBorderedMinors",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`SuccBorderedMinors"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"]},
              {
                ButtonBox[
                  StyleBox["Border",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`Border"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["EigenChop",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`EigenChop"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["SuccPrincipalMinors",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`SuccPrincipalMinors"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"]},
              {
                ButtonBox[
                  StyleBox["BorderedDefiniteness",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`BorderedDefiniteness"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["FromBorderedMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`FromBorderedMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["SymmetricMatrixQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`SymmetricMatrixQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"]},
              {
                ButtonBox[
                  StyleBox["BorderMatrices",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`BorderMatrices"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["MatrixSquareRoot",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`MatrixSquareRoot"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["TabledBorderMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`TabledBorderMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"]},
              {
                ButtonBox[
                  StyleBox["BorderMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`BorderMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["NormalizedMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`NormalizedMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["ToBorderedMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`ToBorderedMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"]},
              {
                ButtonBox[
                  StyleBox["CoFactor",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`CoFactor"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["Options$Definiteness",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`Options$Definiteness"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["ToPSDMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`ToPSDMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"]},
              {
                ButtonBox[
                  StyleBox["Definiteness",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`Definiteness"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["StripMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`StripMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"], 
                ButtonBox[
                  StyleBox["UnitDiagonalMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-9117084", 
                    "Cool`Matrix`UnitDiagonalMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Matrix`"]}
              },
            RowMinHeight->{1, 1, 1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Statistics`Correlation]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Statistics`Correlation`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AssociationMatrixQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`AssociationMatrixQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"], 
                ButtonBox[
                  StyleBox["CorrelationSolve",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`CorrelationSolve"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"], 
                ButtonBox[
                  StyleBox["SolveDetIn0To1",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`SolveDetIn0To1"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"]},
              {
                ButtonBox[
                  StyleBox["CORAMatrixQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`CORAMatrixQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"], 
                ButtonBox[
                  StyleBox["MultipleRSquared",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`MultipleRSquared"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"], 
                ButtonBox[
                  StyleBox["ToPSDCorrelationMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`ToPSDCorrelationMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"]},
              {
                ButtonBox[
                  StyleBox["CorrelationMatrixQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`CorrelationMatrixQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"], 
                ButtonBox[
                  StyleBox["OverallCorrelation",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988122-1120032", 
                    "Cool`Statistics`Correlation`OverallCorrelation"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Correlation`"], ""}
              },
            RowMinHeight->{1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Statistics`Nominal]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Statistics`Nominal`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["BordersOrAll",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`BordersOrAll"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["NominalStatistics",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`NominalStatistics"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["SquareMatrixNormedDet",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`SquareMatrixNormedDet"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"]},
              {
                ButtonBox[
                  StyleBox["CorrelationPr2By2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`CorrelationPr2By2"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["NominalVariance",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`NominalVariance"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["UsedPairwiseMeasure",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`UsedPairwiseMeasure"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"]},
              {
                ButtonBox[
                  StyleBox["CramersV",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`CramersV"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["Options$NominalVariance",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`Options$NominalVariance"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["VariancePr2By2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`VariancePr2By2"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"]},
              {
                ButtonBox[
                  StyleBox["ForceSign",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`ForceSign"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["PairwiseMeasure",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`PairwiseMeasure"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["VolumeRatio",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`VolumeRatio"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"]},
              {
                ButtonBox[
                  StyleBox["Move1FromRow1To2In3D",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`Move1FromRow1To2In3D"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["PairwiseMeasureMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`PairwiseMeasureMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["VolumeRatioMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`VolumeRatioMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"]},
              {
                ButtonBox[
                  StyleBox["NominalCorrelation",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`NominalCorrelation"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["PairwiseSign",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`PairwiseSign"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["VolumeRatioMethod",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`VolumeRatioMethod"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"]},
              {
                ButtonBox[
                  StyleBox["NominalCorrelationMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`NominalCorrelationMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["PearsonVariance",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`PearsonVariance"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["VolumeRatioReview",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`VolumeRatioReview"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"]},
              {
                ButtonBox[
                  StyleBox["NominalCorrelationReview",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`NominalCorrelationReview"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], 
                ButtonBox[
                  StyleBox["SplitAggregator",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-1676018", 
                    "Cool`Statistics`Nominal`SplitAggregator"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Statistics`Nominal`"], ""}
              },
            RowMinHeight->{1, 1, 1, 1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Chi2]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Chi2`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["BorderSums",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-3330068", 
                    "Cool`Chi2`BorderSums"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["InverseChi2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-3330068", 
                    "Cool`Chi2`InverseChi2"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["Pearson",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`Pearson"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["xLogX",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`xLogX"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"]},
              {
                ButtonBox[
                  StyleBox["Chi2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`Chi2"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["LogLikelihoodRatio",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-3330068", 
                    "Cool`Chi2`LogLikelihoodRatio"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["PrEst",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`PrEst"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["xPowerX",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`xPowerX"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"]},
              {
                ButtonBox[
                  StyleBox["Chi2CriticalValue",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", 
                    "Cool`Chi2`Chi2CriticalValue"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["MLEstimate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-3330068", 
                    "Cool`Chi2`MLEstimate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["SumLog",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`SumLog"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["$KBChi2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`$KBChi2"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"]},
              {
                ButtonBox[
                  StyleBox["Chi2PValue",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-3330068", 
                    "Cool`Chi2`Chi2PValue"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["Options$Chi2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-3330068", 
                    "Cool`Chi2`Options$Chi2"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], 
                ButtonBox[
                  StyleBox["xLogP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988123-3330068", "Cool`Chi2`xLogP"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Chi2`"], ""}
              },
            RowMinHeight->{1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[CrossTable]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`CrossTable`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["BorderWeight",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`BorderWeight"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["CrossTable",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`CrossTable"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["LLRStatisticsOut",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`LLRStatisticsOut"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["ShowCT",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`ShowCT"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"]},
              {
                ButtonBox[
                  StyleBox["CrossEntries",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`CrossEntries"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["CrossWeight",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`CrossWeight"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["Make",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`Make"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["$KBCrossTable",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`$KBCrossTable"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"]},
              {
                ButtonBox[
                  StyleBox["CrossEntriesQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`CrossEntriesQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["FIDLLRStatistic",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`FIDLLRStatistic"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["MakeAndSave",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`MakeAndSave"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], ""},
              {
                ButtonBox[
                  StyleBox["CrossOutliers",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`CrossOutliers"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["LLRStatistics",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`LLRStatistics"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], 
                ButtonBox[
                  StyleBox["QuickTest",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988123-4021655", 
                    "Cool`CrossTable`QuickTest"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`CrossTable`"], ""}
              },
            RowMinHeight->{1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Survival]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \("SurvivalPackages[] gives an overview of the packages in survival \
statistics and epidemiology.\nThese packages aren't supported with palettes \
yet.\nMathematica's I is the imaginary number (complex operator), but the \
String \"I\" may be used for Incidence"\)], "Print",
  CellTags->"Info3389988124-3165832"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SurvivalPackages[]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(TraditionalForm\`"The following packages concern the area of survival \
statistics and epidemiology: \n     Survival`CEA`: cost-effectiveness \
analysis in epidemiology \n     Survival`Common`: key terms for the life \
table and its functions \n     Survival`BioStatistics`: calculate m or q from \
observations \n     Survival`Criteria`: life gain, time trade off, patient \
cost \n     Survival`Data`: see ??DataSymbols \n     Survival`Disease`: \
survival in health or disease state \n     Survival`Epidemiology`: test \
statistics \n     Survival`Graphics`: plotting routines \n     \
Survival`JointTest`: test that consists of two other tests \n     \
Survival`LifeTable`: life table construction and listing \n     \
Survival`LifeTableByChiang`: idem, method Chiang \n     \
Survival`MetaAnalysis`: pooled Relative Risk \n     Survival`Screening`: \
detection phases and lead times \n     Survival`TreatmentControl`: a.k.a. \
case-control studies \n     Survival`BMI`: body mass index example "\)], \
"Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Survival`TreatmentControl]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Survival`TreatmentControl`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["CaseControlMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`CaseControlMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["IT",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`IT"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["Control",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`Control"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["NoEffect",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`NoEffect"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["ControlIneffectivenessRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`\
ControlIneffectivenessRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["NumberNeededToTreat",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`NumberNeededToTreat"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["ControlRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`ControlRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["OddsRatioTrTCM",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`OddsRatioTrTCM"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["Cornfield",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`Cornfield"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["Options$ToCornfieldMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`Options$\
ToCornfieldMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["CornfieldConfounder",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`CornfieldConfounder"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["RiskDiffTCM",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`RiskDiffTCM"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["EC",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`EC"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["RoundSeemingTable",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`RoundSeemingTable"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["EffectiveControl",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`EffectiveControl"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["RRiskTCM",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`RRiskTCM"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["EffectiveTreatment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`EffectiveTreatment"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["StudyGroup",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`StudyGroup"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["ET",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`ET"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["ToCornfieldMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`ToCornfieldMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["ExplainTreatmentControl",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`ExplainTreatmentControl"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["Treatment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`Treatment"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["FromCornfieldMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`FromCornfieldMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["TreatmentControlMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`TreatmentControlMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["IC",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`IC"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["TreatmentEffectRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`TreatmentEffectRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["IneffectiveControl",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`IneffectiveControl"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["TreatmentRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`TreatmentRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]},
              {
                ButtonBox[
                  StyleBox["IneffectiveTreatment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`IneffectiveTreatment"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"], 
                ButtonBox[
                  StyleBox["WeighedEffectRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-7530491", 
                    "Cool`Survival`TreatmentControl`WeighedEffectRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`TreatmentControl`"]}
              },
            RowMinHeight->{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Survival`Epidemiology]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Survival`Epidemiology`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["DeathTestMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DeathTestMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["Move1FromRow2To1",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Move1FromRow2To1"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["RiskDiff",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`RiskDiff"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DetectionRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DetectionRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["NegativePredictiveValue",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`NegativePredictiveValue"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["RRisk",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`RRisk"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DetectionRatios",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DetectionRatios"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["NegLR",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`NegLR"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["RRiskRelation",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`RRiskRelation"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiagnosisRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiagnosisRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["NoDisease",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`NoDisease"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["RSafety",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`RSafety"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiagnosticAccuracy",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiagnosticAccuracy"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["NPV",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`NPV"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["Se",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Se"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["Disease",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Disease"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["NSeSpD",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`NSeSpD"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["Sensitivity",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Sensitivity"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiseaseTestMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiseaseTestMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["NSeSpPPVNPV",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`NSeSpPPVNPV"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["Sp",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Sp"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiseaseTestOdds",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiseaseTestOdds"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["NumberNeededToTest",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`NumberNeededToTest"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["Specificity",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Specificity"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiseaseTestRatios",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiseaseTestRatios"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["OddsRatio",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`OddsRatio"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TestEfficiency",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TestEfficiency"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiseaseTestResults",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiseaseTestResults"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["OverDetectionRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`OverDetectionRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TestNegative",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TestNegative"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiseaseTMFromDeathTM",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiseaseTMFromDeathTM"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["OverDiagnosisQuote",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`OverDiagnosisQuote"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TestNegativeRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TestNegativeRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["DiseaseTransitionMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`DiseaseTransitionMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["PositivePredictiveValue",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`PositivePredictiveValue"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TestPopulation",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TestPopulation"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["Explain2DMatrices",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Explain2DMatrices"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["PosLR",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`PosLR"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TestPositive",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TestPositive"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["ExplainRates",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`ExplainRates"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["PostTestOdds",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`PostTestOdds"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TestPositiveRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TestPositiveRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["FalseNegative",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`FalseNegative"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["PPV",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`PPV"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TestPrevalenceRatio",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TestPrevalenceRatio"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["FalsePositive",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`FalsePositive"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["PreTestOdds",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`PreTestOdds"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TN",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TN"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["FalsePositiveRate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`FalsePositiveRate"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["PrevalenceMultiplier",
                    "Hyperlink"],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`PrevalenceMultiplier"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TP"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["FN",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`FN"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["ProperNumberNeededToTest",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`ProperNumberNeededToTest"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TrueNegative",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TrueNegative"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["FP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`FP"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["RandomDTMatrix",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`RandomDTMatrix"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["TruePositive",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`TruePositive"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]},
              {
                ButtonBox[
                  StyleBox["Move1FromRow1To2",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Move1FromRow1To2"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["Reliability",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`Reliability"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"], 
                ButtonBox[
                  StyleBox["YoudenJ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988124-4498559", 
                    "Cool`Survival`Epidemiology`YoudenJ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Survival`Epidemiology`"]}
              },
            
            RowMinHeight->{
              1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
                1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Logic]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    FormBox[
      RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(TraditionalForm\\`Logic\\)\\\" is similar to \
existing symbol \\\"\\!\\(TraditionalForm\\`Logit\\)\\\". \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}], 
      TraditionalForm]], "Message",
  CellLabel->"From In[18]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Logic`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["Agreement",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Agreement"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Imp",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Imp"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Propositions",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Propositions"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Analyse",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Analyse"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Implications",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Implications"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["PropVariableList",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`PropVariableList"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["AnalysePrint",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`AnalysePrint"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["JoinStatements",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`JoinStatements"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["RemarkOnParentheses",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`RemarkOnParentheses"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["AndOrEnhance",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`AndOrEnhance"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Liar",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Liar"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["SeaBattle",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`SeaBattle"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["AndOrEnhanced",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`AndOrEnhanced"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["LocateThen",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`LocateThen"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Sentences",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Sentences"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["AndOrRules",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`AndOrRules"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["LogicalVariables",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`LogicalVariables"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["SquareTruthTable",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`SquareTruthTable"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["AndQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`AndQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["LogicLab",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`LogicLab"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Statements",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Statements"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["ArrowTestQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ArrowTestQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["LogicState",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`LogicState"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["SubstituteQuantors",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`SubstituteQuantors"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Belongs",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Belongs"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["MatrixDNForm",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`MatrixDNForm"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["TertiumNonDatur",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`TertiumNonDatur"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["BinaryTruthTables",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`BinaryTruthTables"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NandQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`NandQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ThreeValuedLogic",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ThreeValuedLogic"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Choose",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Choose"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Negate",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Negate"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ThreeValuedRules",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ThreeValuedRules"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["ChooseP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ChooseP"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NonSequitur",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`NonSequitur"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Thus",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Thus"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["ChoosePrint",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ChoosePrint"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NorQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`NorQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ToAlgebra",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ToAlgebra"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Conclude",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Conclude"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NorToAnd",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`NorToAnd"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ToAndOrNot",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ToAndOrNot"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Conclusion",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Conclusion"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NotAtAll",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`NotAtAll"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ToBelongs",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ToBelongs"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Conclusions",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Conclusions"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NoteElement",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`NoteElement"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ToDNForm",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ToDNForm"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Decide",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Decide"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NotNot",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`NotNot"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ToEquationRule",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ToEquationRule"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Deduce",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Deduce"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["NotpOrq",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`NotpOrq"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ToLogic",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ToLogic"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["DefinitionOfTruth",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`DefinitionOfTruth"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["P",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`P"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ToPropositionalLogic",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ToPropositionalLogic"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Equivalence",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Equivalence"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Paragraph",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Paragraph"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["TruthQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`TruthQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Equivalent",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`Equivalent"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["PredicatesQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`PredicatesQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["TruthTable",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`TruthTable"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Ergo",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Ergo"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["ProperSentence",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`ProperSentence"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["TruthTableForm",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`TruthTableForm"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["Ergo2D",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Ergo2D"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["PropositionalForm",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`PropositionalForm"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["TruthTableRule",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`TruthTableRule"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["FindP",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`FindP"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["PropositionalLogicQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`PropositionalLogicQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["TruthValue",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`TruthValue"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["FromBelongs",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`FromBelongs"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["PropositionalOperatorQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`PropositionalOperatorQ"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["Unless",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389988125-1502612", "Cool`Logic`Unless"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"]},
              {
                ButtonBox[
                  StyleBox["FromEquationRule",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`FromEquationRule"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], 
                ButtonBox[
                  StyleBox["PropositionMeaningRule",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389988125-1502612", 
                    "Cool`Logic`PropositionMeaningRule"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Logic`"], ""}
              },
            
            RowMinHeight->{
              1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
                1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    FormBox[
      RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(TraditionalForm\\`mat\\)\\\" is similar to \
existing symbol \\\"\\!\\(TraditionalForm\\`Mat\\)\\\". \\!\\(\\*ButtonBox[\\\
\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}], 
      TraditionalForm]], "Message",
  CellLabel->"From In[19]:="],

Cell[BoxData[
    \(TraditionalForm\`mat\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[BoxData[
    \(On[Get::"\<notencode\>"]\)], "Input",
  CellLabel->"In[20]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?dbCT\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \("dbCT is a Databank object, that collects crosstables with Label, \
Dimensions, Data, and Source. Dimensions and Data are put in Hold because \
Databank recognizes only one level. At Startup dbCT is the default db for \
SetDatabank; however, since other packages might be loaded: check \
Options[SetDatabank]. Useful commands are for example: \nDatabank[Query, \
Label] reviews the available labels \nShowData[Transpose] shows the contents \
in TableForm \ndbCT[Data] shows the contents in a list \n\
Explain[dbCT[Data][[1]]] // ReleaseHold explains the first element"\)], \
"Print",
  CellTags->"Info3389988126-2902430"]
}, Open  ]],

Cell[BoxData[
    \(\(SetOptions[SetDatabank, \ Databank\  \[Rule] \ dbCT];\)\)], "Input",
  CellLabel->"In[22]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Databank[Query, \ Label]\)\(\ \)\)\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Hat shops\"\>"},
            {"\<\"Arthritis-Original\"\>"},
            {"\<\"Arthritis2\"\>"},
            {"\<\"Arthritis\"\>"},
            {"\<\"Email study\"\>"},
            {"\<\"Uebersax (2000)\"\>"},
            {"\<\"Cornfield\"\>"},
            {"\<\"Fisher Male Twins\"\>"},
            {"\<\"Fisher Female Twins\"\>"},
            {"\<\"Fisher Twins\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ 4]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Active\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Placebo\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Some\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "21"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"13"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"None\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "6"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"19"},
                  {"10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{21, 7}, {13, 1}}, {{6, 7}, {19, 10}}}, 
          TableHeadings -> {{"Some", "None"}, {"Active", "Placebo"}, {"F", 
          "M"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[24]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ Default, \ "\<Hat shops\>"]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "5"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"8"},
                  {"2"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "2"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "8"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"5"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{5, 1}, {8, 2}}, {{2, 8}, {1, 5}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[25]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat\  = \ CT[Data]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({5, 1}\), \({8, 2}\)},
            {\({2, 8}\), \({1, 5}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[26]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Table of contents", "Section",
  PageBreakAbove->True],

Cell["Summary", "Outline3"],

Cell["Introduction", "Outline2"],

Cell["Nominal versus cardinal data", "Outline3"],

Cell["The new suggestion", "Outline3"],

Cell["Analysis of the hat shop example", "Outline3"],

Cell["What nominal correlation stands for", "Outline3"],

Cell["The key result of this paper", "Outline2"],

Cell["Leading ideas", "Outline2"],

Cell["The volume ratio idea", "Outline3"],

Cell["Existing options", "Outline3"],

Cell["Strength of association", "Outline3"],

Cell["The notion of overall correlation", "Outline3"],

Cell["Two uses of the determinant", "Outline3"],

Cell["Association and correlation", "Outline3"],

Cell["Warranting positive semi-definiteness", "Outline3"],

Cell["Overall versus multiple correlation", "Outline3"],

Cell["Regression coefficients", "Outline3"],

Cell["What the correlation coefficient is useful for", "Outline3"],

Cell["The 2 \[Times] 2 case", "Outline2"],

Cell["The layout", "Outline3"],

Cell["An insight: diagram of the 2 \[Times] 2 case", "Outline3"],

Cell["Statistical independence means zero correlation", "Outline3"],

Cell["Next step: square matrices", "Outline2"],

Cell[TextData[{
  "Next step: ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "matrices",
  " "
}], "Outline2"],

Cell["Theory", "Outline3"],

Cell["Implementation", "Outline3"],

Cell["The examples above", "Outline4"],

Cell["Consistency with the 2 \[Times] 2 case", "Outline4"],

Cell["The sign of the correlation", "Outline4"],

Cell[TextData[{
  "Finally ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]]
}], "Outline2"],

Cell["In general", "Outline3"],

Cell["Using bordersums", "Outline3"],

Cell["Using inner submatrices", "Outline3"],

Cell["Review", "Outline3"],

Cell["The default", "Outline3"],

Cell["Conclusion", "Outline2"],

Cell["\<\
Appendix A: Measures of association mentioned by common resources\
\>", "Outline2"],

Cell[TextData[{
  "Appendix B: Relation to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " measure"
}], "Outline2"],

Cell["In general", "Outline3"],

Cell["The 2 \[Times] 2 case", "Outline3"],

Cell["A 3 \[Times] 3 case", "Outline3"],

Cell["The general principle", "Outline3"],

Cell["The key point", "Outline4"],

Cell["Cross diagonals", "Outline4"],

Cell["Triangular matrices", "Outline4"],

Cell["Aggregation", "Outline4"],

Cell["Zero diagonal", "Outline4"],

Cell["What next", "Outline4"],

Cell["A parametric 3 \[Times] 3 case", "Outline3"],

Cell["A higher dimensional case", "Outline3"],

Cell["Generalizing Cramer\[CloseCurlyQuote]s V", "Outline3"],

Cell["Appendix C: Overall correlation between real variables", "Outline2"],

Cell["The notion of overall correlation", "Outline3"],

Cell["Derivation of 0 \[LessEqual] Det[R] \[LessEqual] 1 ", "Outline3"],

Cell["Matrices with theoretical values", "Outline3"],

Cell[TextData[{
  "PSD for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3"
}], "Outline3"],

Cell["Numerical example: Klein I model", "Outline3"],

Cell["Appendix D: Other relations for the 2 \[Times] 2 case", "Outline2"],

Cell[" An analytical stepping stone", "Outline3"],

Cell["1. Just recall", "Outline3"],

Cell["2. Epidemiology - pooled test", "Outline3"],

Cell["3. Epidemiology - Matthew", "Outline3"],

Cell["4. Assigning values {0, 1} or {-1, 1} or {i, j}", "Outline3"],

Cell["Appendix E: An example in a higher dimension", "Outline2"],

Cell["Appendix F: A note on the Frobenius theorems", "Outline2"],

Cell["Appendix G: On inference and causality", "Outline2"],

Cell["\<\
Appendix H: Positive semidefiniteness for nominal correlation\
\>", "Outline2"],

Cell["On the sign", "Outline3"],

Cell["In general", "Outline3"],

Cell["Formally", "Outline3"],

Cell["PM. Additional notes", "Outline4"],

Cell[TextData[{
  "A symbolic approach for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3 "
}], "Outline3"],

Cell[TextData[{
  "Simulation for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3"
}], "Outline3"],

Cell["Introduction", "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Automatic"
}], "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Min"
}], "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Max"
}], "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] BorderMatrices"
}], "Outline4"],

Cell["Review", "Outline4"],

Cell["A stronger measure", "Outline3"],

Cell[TextData[{
  "Simulation for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, using the stronger measure for the volume ratio"
}], "Outline3"],

Cell["Introduction", "Outline4"],

Cell["Introduction as before", "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Automatic"
}], "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Min"
}], "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Max"
}], "Outline4"],

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] BorderMatrices"
}], "Outline4"],

Cell["Review", "Outline4"],

Cell["Be sure to reset", "Outline3"],

Cell["Appendix I: Overview of variants", "Outline2"],

Cell["Introduction", "Outline3"],

Cell["1. The example from the introduction", "Outline3"],

Cell["2. A case of conditional independence", "Outline3"],

Cell["3. An example where Det[R] is not in the required range", "Outline3"],

Cell["4. Another example where Det[R] is not in the required range", \
"Outline3"],

Cell["Conclusion", "Outline3"],

Cell["Appendix J: Finding the closest PSD correlation matrix", "Outline2"],

Cell["Introduction", "Outline3"],

Cell[" Higham (1989)", "Outline3"],

Cell["Nonnegative eigenvalues", "Outline3"],

Cell["A numerical approach", "Outline3"],

Cell["Review", "Outline3"],

Cell["Appendix K: Variances and regression coefficients", "Outline2"],

Cell["Introduction", "Outline3"],

Cell["Variance for for a single category", "Outline3"],

Cell["Variance for nominal variables", "Outline3"],

Cell["VariancePr", "Outline3"],

Cell["PearsonVariance", "Outline3"],

Cell["PM. Multinomial", "Outline3"],

Cell["Appendix L: Two more practical examples", "Outline2"],

Cell["Appendix M: Manipulating a contingency table", "Outline2"],

Cell["Appendix N: Routines", "Outline2"],

Cell["Introduction", "Outline3"],

Cell["For real or nominal data", "Outline3"],

Cell["For nominal data", "Outline3"],

Cell["Literature", "Outline2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell["Nominal versus cardinal data", "Subsection"],

Cell["\<\
Real-valued (cardinal) data are a researcher\[CloseCurlyQuote]s paradise \
since you can do almost anything with them. For example, when we have data on \
temperatures {-2.4, 4.3, 10.5, 21.5, 29.9} in degrees Celsius and associated \
sales of icecream {10.5, 11.3, 8.7, 50.4, 70.8} in kilo\[CloseCurlyQuote]s \
then it is easy to express the degree of association in a single number. A \
correlation value generally lies between -1 and +1 and in this case we find \
that temperature and icecream sales are highly and positively correlated, so \
that we are motivated to determine the true model that captures their \
relationship.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Needs["\<Statistics`MultiDescriptiveStatistics`\>"]\
\[IndentingNewLine]
    Correlation[{\(-2.4\), 4.3, 10.5, 21.5, 29.9}, {10.5, 11.3, 8.7, 50.4, 
        70.8}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(TraditionalForm\`0.928300918763579`\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
The situation is entirely different for nominal data. This kind of data only \
gives categories, such as Male versus Female, or Democrat versus Republican, \
that are just labels and aren\[CloseCurlyQuote]t numbers, making it difficult \
to apply the Pearson formula for correlation and to find some \
\[OpenCurlyDoubleQuote]average value\[CloseCurlyDoubleQuote] and to square \
them. The following numerical example from Kleinbaum et al. (2003:277) will \
be used more often in the discussion below. Let there be two shops selling \
both blue and green hats, and a customer visiting both shops. The customer \
tries all hats and scores them as \[OpenCurlyDoubleQuote]fit\
\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]no fit\
\[CloseCurlyDoubleQuote]. The resulting data are nominal since they only \
count the cases and there isn\[CloseCurlyQuote]t an \
\[OpenCurlyDoubleQuote]average shop\[CloseCurlyDoubleQuote] or \
\[OpenCurlyDoubleQuote]average colour\[CloseCurlyDoubleQuote] or \
\[OpenCurlyDoubleQuote]average fit\[CloseCurlyDoubleQuote]. There are \
nevertheless the same kind of questions of association, e.g. whether we can \
use colour to select a fitting hat or whether it is the shop that matters. \
\>", "Text"],

Cell["We can retrieve a contingency table from a databank.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ Default, \ "\<Hat shops\>"]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "5"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"8"},
                  {"2"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "2"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "8"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"5"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{5, 1}, {8, 2}}, {{2, 8}, {1, 5}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[27]//TableForm="]
}, Open  ]],

Cell["\<\
To determine associations, the nominal data are collected in tables, called \
contingency tables or crosstables. When we want to analyze these data and \
read the statistical reference guides for help, we discover that nominal data \
and in particular these contingency tables lack a standard coefficient of \
correlation. It is also interesting to observe that a common notion in \
statistics is that \[OpenCurlyDoubleQuote]correlation \
doesn\[CloseCurlyQuote]t mean causation\[CloseCurlyDoubleQuote] and it is a \
bit paradoxical that this notion has no numerical expression for nominal data \
since there is no standard measure of correlation. The contingency table is \
meant to analyze association, and the data lie there on the disection table \
right in front of us, but we cannot express simple correlation, to great \
frustration. Instead of giving us a simple standard, the reference guides \
point to various alternatives that quickly become complex, increasing our \
frustration from being expelled from the paradise of those real-valued \
data.\
\>", "Text"],

Cell[TextData[{
  "Contingency tables are much used in psychology, epidemiology or \
experimental economics, and the frustration that we feel with respect to \
above table is just a small example of what these researchers must experience \
every day. Their statistical analyses quickly proceed with more complex \
approaches like the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  "test on statistical independence, which tests are not only more complex \
but also require levels of statistical significance that tend to say little \
about the strength of association. When we collect sufficiently large numbers \
of data then a low association may still become statistically significant. \
The most dubious research outcome is when we start out with small numbers and \
a suggestion of high association that motivates us to collect more numbers, \
but with the result that we find a low association that however differs \
statistically significantly from independence: what to make of that ? This is \
not to say that the concept of statistical significance \
isn\[CloseCurlyQuote]t useful, merely that it is not sufficient. In the case \
just referred to, the true test question there likely is to see whether the \
result also differs significantly from a specific higher association that \
would be relevant for some theory. But to discuss higher degrees of \
association other than mere independence we are served with a measure of \
association. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The new suggestion", "Subsection"],

Cell[TextData[{
  "This paper presents a new proposal for correlation in contingency tables. \
We will develop this measure below, starting with a 2 \[Times] 2 table, \
generalize this to a ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " table,",
  StyleBox[" ",
    FontSlant->"Italic"],
  "then ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n, ",
    FontSlant->"Italic"],
  "and finally ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  ". In this paper the term \[OpenCurlyDoubleQuote]nominal correlation\
\[CloseCurlyDoubleQuote] will be used to indicate the intended application. \
It should be understood that this term is intended for this paper only. The \
term thus should be read as \[OpenCurlyDoubleQuote]what happens if we apply \
this measure for the purpose of expressing association ?\
\[CloseCurlyDoubleQuote] and not as \[OpenCurlyDoubleQuote]this is an \
established statistical practice firmly grounded in statistical theory\
\[CloseCurlyDoubleQuote]. The first draft of the discussion used the neutral \
label \[OpenCurlyDoubleQuote]volume ratio measure\[CloseCurlyDoubleQuote] but \
it appeared that this destroyed much of the added value of asking that key \
question, and it distracted the mind with irrelevant questions on what shops, \
hats and fits have to do with \[OpenCurlyDoubleQuote]volume\
\[CloseCurlyDoubleQuote]. As the measure seems promising we can only conclude \
and advise that future papers investigate that promise, both in theory and \
with tests in practice, and readers are warned not to merely and uncritically \
apply the measure. It must be mentioned as well that the author has limited \
time and resources. He has used the literature in the list of references but \
there obviously exists more literature. Thus, since the suggested measure is \
new and has not been tested in years of statistical practice, it is hoped \
that theorists of linear algebra and statisticians working with nominal data \
look into the potential value of this suggested measure. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analysis of the hat shops example", "Subsection"],

Cell["\<\
For the hat shops contingency table above we find the following number for \
the overall association. For the reader this currently is just a meaningless \
number between 0 and 1, and hence the objective of the discussion below is to \
explain what it means. A key question is whether ranges of values can be \
compared to ranges of values of the Pearson correlation coefficient for \
real-valued data.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[mat\ \  = \ CT[Data]]\  // \ N\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(TraditionalForm\`0.6658507727534974`\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
Though we don\[CloseCurlyQuote]t know what the number means, let us see what \
happens when we interprete it like a Pearson correlation coefficient. Since \
0.67 is closer to 1 than to 0, we conclude that there is quite some \
association in these data. If we would select a statistical significance \
level then we could decide on statistical independence. But given this amount \
of correlation we certainly become more interested in what the relation \
between these variables is.\
\>", "Text"],

Cell["\<\
The example of the hat shops has been taken since it is an example of the \
Simpson paradox. In each separate shop the green hats fit relatively better, \
but for both shops combined the blue hats fit relatively better. For Shop 1 \
the fit / no-fit odds for green hats are 5/1 and for blue hats 8/2, thus the \
odds ratio (5/1) / (8/2) = 5/4. For Shop 2 we find the fit / no-fit odds \
ratio (1/4) / (1/5) = 5/4 too. For the two shops separately the odds ratio is \
above 1 but for the total (7/9 versus 9/7) it is below 1. The dispersion over \
the two shops is a confounder. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OddsRatio\  /@ \ \ Append[mat, \ Plus\  @@ \ mat]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(TraditionalForm\`{5\/4, 5\/4, 49\/81}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
As the tables only concern the problem of fitting hats then it makes sense to \
eliminate the confounder, add the two tables, and find a small association, \
but of a reverse sign.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[Plus\  @@ \ mat]\  // \ N\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(TraditionalForm\`\(-0.125`\)\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
Note that the analysis depends upon the case at hand. When these data tables \
don\[CloseCurlyQuote]t concern hat shops but represent another kind of \
problem, then it might not be sensible to merely add the subtables. In that \
case the difference between -0.125 and 0.67 helps us to consider that there \
indeed is some relation, and, if the problem is serious enough, we might grow \
convinced that it could be worth while to find the true model. For example, \
we might do a meta-analysis on the findings of the separate shops, \
aggregating the problem in such a way that the overall direction reflects the \
individual ones. Or, for example in voting theory, there can also be \
paradoxes but on close inspection with an acceptable explanation, such that \
it would neither make sense to simply add the subtables. Indeed, in the \
current example, if Shop1 has better quality control then one would buy a \
blue hat from Shop1 and be happy that the shops are not aggregated. To be \
sure, though, one has to check whether there is cause for a systematic \
difference.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["What nominal correlation stands for", "Subsection"],

Cell["\<\
Thus, this example shows that the notion of nominal correlation coefficient \
might help in the analysis. In this introductory discussion, we have been \
interpreting the number just like a Pearson coefficient of correlation. Can \
we really do so ? What is behind this number ? This question brings us to \
some leading ideas. But before looking into those leading ideas, we better \
present the key result of this paper, so that it is clear what the focus is \
on.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The key result of this paper", "Section"],

Cell[CellGroupData[{

Cell["In a nutshell", "Subsubsection"],

Cell["\<\
The key result of this paper is that correlation and regression coefficients \
are made available, based upon a determinant or volume ratio measure of \
association. Regression coefficients follow from both the correlation matrix \
and the variances. Regression coefficients derive their interpretation from a \
positive or negative direction. Though the nominal data have no order, there \
is an order of presentation. For these tables, \[OpenCurlyDoubleQuote]getting \
a higher shop number\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]becoming \
blue\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]losing fit\
\[CloseCurlyDoubleQuote] are positive steps in the right direction. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Subsubsection"],

Cell[TextData[{
  "Correlation and regression for real-valued data have some properties that \
we retain for nominal data. A measure of correlation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(x, y\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(y, x\)\)]],
  " expresses how much the variables ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "are associated on a scale of -1 to 1. The regression coefficient of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " in a pairwise regression on ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(y, x\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(x, y\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_y\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_x\)]],
  ". By consequence, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rho]\_\(x, y\)\)\(\ \)\)\^2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(y, x\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(x, y\)\)]],
  ". In multiple regression, the regression coefficients would be derived as \
cofactors of the matrix of pairwise correlations. The interpretation of the \
regression coefficient is that it gives the contribution of one unit change \
of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " to both ",
  Cell[BoxData[
      \(TraditionalForm\`y\&^\)]],
  " and ",
  StyleBox["y. ",
    FontSlant->"Italic"],
  "The squared multiple correlation coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " is the squared correlation between ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`y\&^\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Consider a ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "contingency table, thus with",
  " two nominal variables,",
  StyleBox[" x ",
    FontSlant->"Italic"],
  "with ",
  StyleBox["n",
    FontSlant->"Italic"],
  " categories put in the columns and ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "with ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "categories put in the rows. When counting occurrences of the variables \
there is a time-dependence since both variables are scored within the same \
time frame. The result of the counts is the contingency table ",
  Cell[BoxData[
      \(TraditionalForm\`C\_t\)]],
  " with ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "the time index, e.g. for dichotomous variables {{",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(11  t\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(12  t\)\)]],
  "}, {{",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(21  t\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(22  t\)\)]],
  "}}. The data can be aggregated over a period so that ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "would rather stand not for an individual observation but for a period \
total. A summation over a category can be denoted with a \
\[OpenCurlyDoubleQuote]+\[CloseCurlyDoubleQuote] so that ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(1 + t\)\)]],
  " is the summation of the first row for period ",
  StyleBox["t. ",
    FontSlant->"Italic"],
  "The counts can be expressed as probabilities ",
  Cell[BoxData[
      \(TraditionalForm\`p\_ijt\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`n\_ijt\)]],
  "/ ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(++t\)\)]],
  " and for the marginal probabilities we can write ",
  Cell[BoxData[
      \(TraditionalForm\`p\_jt\)]],
  " for ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`q\_it\)]],
  " for ",
  StyleBox["y.",
    FontSlant->"Italic"],
  " Probabilities look like real-valued data though for nominal data the only \
order is the order of presentation. "
}], "Text"],

Cell[TextData[{
  "When the difference over time has meaning then we can do a regression over \
time, for example as ",
  Cell[BoxData[
      \(TraditionalForm\`n\_ijt\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_ij\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_ij\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+jt\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_ijt\)]],
  " which would give an estimate of the ",
  StyleBox["i,j",
    FontSlant->"Italic"],
  " cell consisting of a base value and a marginal contribution dependent \
upon the column sum. A vector format of regression is ",
  Cell[BoxData[
      \(TraditionalForm\`y\_t\)]],
  " = \[Alpha] + \[Beta] ",
  Cell[BoxData[
      \(TraditionalForm\`x\_t\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_t\)]],
  ", where the variables are seen as vectors with the data in the order of \
presentation, and in particular ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " now are interpreted as vectors containing the border sums (marginals), \
and \[Alpha] and \[Beta] would be matrices collecting those cell \
coefficients. "
}], "Text"],

Cell[TextData[{
  "It may also be that the distinction between time periods is less \
informative or even disinformative so that the true result is ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_+\)\)]],
  " only. In that case a regression over time ceases to be relevant and even \
becomes impossible. It is still possible to calculate the conditional \
probabilities ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(i, j\)\)]],
  " = P[",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(i, j\)\)]],
  " | ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "] =  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  " that can be seen as regression coefficients. Then by definition \[Alpha] \
= 0. The example of the regression over time helps us to recognize that those \
conditional probabilities are regression coefficients indeed. In that case ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rho]\_\(xj, yi\)\)\(\ \)\)\^2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(yi, xj\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(xj, \ yi\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\_\(i, j\)\)\(\ \)\)\^2\)]],
  " / (",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(\(i\)\(+\)\)\)]],
  "). The matrix that contains the square roots of those values can be \
denoted as ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)]],
  ", ",
  "and will be called in this paper the \[OpenCurlyDoubleQuote]normalized \
matrix\[CloseCurlyDoubleQuote] of the ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NormalizedMatrix[{{a, \ b, \ c}, \ {d, \ e, \ f}}]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(a\/\(\@\(a + b + c\)\ \@\(a + d\)\)\), \(b\/\(\@\(a + b + c\)\ \
\@\(b + e\)\)\), \(c\/\(\@\(a + b + c\)\ \@\(c + f\)\)\)},
            {\(d\/\(\@\(a + d\)\ \@\(d + e + f\)\)\), \(e\/\(\@\(b + e\)\ \
\@\(d + e + f\)\)\), \(f\/\(\@\(c + f\)\ \@\(d + e + f\)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[TextData[{
  "PM 1. We might also determine standard deviations of the marginal \
probabilities ",
  Cell[BoxData[
      \(TraditionalForm\`p\_j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\_i\)]],
  StyleBox[".",
    FontSlant->"Italic"],
  " Correlation coefficients then follow from the reverse of the above as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i, j\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(yi, xj\)\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(yi, xj\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_xj\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_yi\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(i, j\)\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_xj\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_yi\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  " *  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_xj\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_yi\)]],
  ". The earlier approach however already gives correlation coefficients \
without requiring those standard deviations for the categories. The transform \
is useful, though, to note that the standard deviations of ",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " would be related by the square roots of the numbers of observations.  "
}], "Text"],

Cell[TextData[{
  "PM 2. Above correlations will all be nonnegative, since ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " \[GreaterEqual] 0. Possibly, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(yi, xj\)\)]],
  " should not be defined as the conditional probability P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "] but thus rather as ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(i, j\)\)\&_\)]],
  " = P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "] - P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| Not[",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]]. This pairwise regression coefficient keeps the total",
  StyleBox[" N",
    FontSlant->"Italic"],
  " constant. It comes about by ",
  "using #[",
  "Not[ ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]",
  "] = ",
  StyleBox["N - ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  " and considering that ",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "= ",
  "P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  " + P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| Not[ ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]]",
  " #[",
  "Not[ ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]",
  "] = ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(i, j\)\)\&_\)]],
  " ",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  " + P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| Not[ ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]] ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". In this pairwise regression between the categories, P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| Not[ ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]] ",
  StyleBox["N ",
    FontSlant->"Italic"],
  "is ithe fixed constant and ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(i, j\)\)\&_\)]],
  " the marginal contribution of one unit of the column sum, keeping the \
total constant. In that case the regression coefficients conceivably can have \
negative values too. This approach creates a linear dependence in the matrix \
of pairwise (adjusted) correlation coefficients, as one can verify with the \
example of a 2 \[Times] 2 table. It is not obvious how to proceed with that. \
The point that one wishes some constraint on the overall effect may be \
handled in a different way too, see the next."
}], "Text"],

Cell[TextData[{
  "Writing the regression in vector notation also comes with a shift in \
focus, away from the single cells and towards targetting the variables. We \
started out with the variables but the measurement created cells that called \
all attention towards themselves. Refocussing, we wonder whether there might \
not be a \[OpenCurlyDoubleQuote]pairwise correlation\[CloseCurlyDoubleQuote] \
between ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["y.",
    FontSlant->"Italic"],
  " This refocus may come along with an imposition of overall conditions. For \
example, while the impact of a ",
  StyleBox["category ",
    FontSlant->"Italic"],
  "is measured by ",
  StyleBox["adding ",
    FontSlant->"Italic"],
  "one unit, the impact of a ",
  StyleBox["variable",
    FontSlant->"Italic"],
  " might be measured by ",
  StyleBox["moving ",
    FontSlant->"Italic"],
  "a unit, either keeping the marginal constant (a move down the column) or \
keeping the marginal sum constant (substracting somewhere and adding \
somewhere else). Such conditions can be stated in terms of the regressions on \
the cells but derive their meaning from the interpretation in terms of the \
variables."
}], "Text"],

Cell["There is an important distinction here:", "Text"],

Cell[TextData[{
  "  ",
  StyleBox["1.",
    FontWeight->"Bold"],
  "  For real valued data, a correlation matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  ", that contains the pairwise correlations between ",
  StyleBox["k",
    FontSlant->"Italic"],
  " variables, allows a measure of \[OpenCurlyDoubleQuote]overall correlation\
\[CloseCurlyDoubleQuote] as ",
  Cell[BoxData[
      \(TraditionalForm\`R\_O\)]],
  " = ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{"1", " ", "-", " ", 
            RowBox[{"Det", "[", 
              StyleBox["R",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["]",
                FontWeight->"Plain"]}]}]], TraditionalForm]]],
  ". For example, when all off-diagonal pairwise correlations are zero so \
that only the diagonal of 1 of the correlations of the variables with \
themselves remains, then the block of data shows no overall correlation and \
",
  Cell[BoxData[
      \(TraditionalForm\`R\_O\)]],
  " = 0. Alternatively, when the data are multicollinear then there is full \
overall correlation and ",
  Cell[BoxData[
      \(TraditionalForm\`R\_O\)]],
  " = 1. This ",
  StyleBox["R",
    FontWeight->"Bold"],
  " concern variables and is square and symmetric."
}], "ItemizedText"],

Cell[TextData[{
  "  ",
  StyleBox["2.",
    FontWeight->"Bold"],
  "  The matrix ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)]],
  " contains correlation coefficients but differs from such an ",
  StyleBox["R",
    FontWeight->"Bold"],
  ". ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)]],
  " concerns categories, has size ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n, ",
    FontSlant->"Italic"],
  "and if it would be square then it would not necessarily be symmetric. If \
",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)]],
  " would happen to be filled with zeros except for something that looks like \
a diagonal of 1 (as far as is possible in a rectangle), then we would say \
that the ",
  StyleBox["variables",
    FontSlant->"Italic"],
  " ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "are highly correlated since the categories of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " directly translate into those of ",
  StyleBox["y. ",
    FontSlant->"Italic"]
}], "ItemizedText"],

Cell[TextData[{
  "The proposed measure for nominal correlation between variables uses the ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)]],
  " on the categories to determine a pairwise correlation between ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["y",
    FontSlant->"Italic"],
  ". The measure first determines the symmetric square ",
  Cell[BoxData[
      \(TraditionalForm\`\(C'\)\_\[Rho]\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)]],
  " (assuming ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[GreaterEqual] n) and then applies the determinant to aggregate the \
information, thereby also imposing the condition that a total does not \
change. The taking of the determinant reminds of overall correlation ",
  Cell[BoxData[
      \(TraditionalForm\`R\_O\)]],
  ". However, in this case there is no overall correlation but just pairwise \
correlation between two variables. The dimensions of the rows and columns \
would differ. The procedure stops at taking the determinant and there is no \
substraction from 1, since there still is the difference between points 1 and \
2 above."
}], "Text"],

Cell[TextData[{
  "The procedure perfectly follows the geometry of volume ratio\
\[CloseCurlyQuote]s, and this may help to see the difference between points 1 \
and 2. The notion of the volume ratio only applies for the transformation of \
",
  Cell[BoxData[
      \(TraditionalForm\`C\_\[Rho]\)]],
  " for the categories into the pairwise correlation of variables ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["y. ",
    FontSlant->"Italic"],
  "The other aspects have all their own other reasons."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The numerical example", "Subsubsection"],

Cell[TextData[{
  "For the hat shops example we find that the border totals are all {16, 16}. \
Since the nominal variances are defined on the border totals, they are all \
the same (and they are 1, see the discussion on nominal variance and its \
scale in ",
  StyleBox["Appendix K",
    FontWeight->"Bold"],
  "). Points to note are: (1) the nominal correlation matrix does not depend \
upon the variance but instead the variance-covariance matrix is created with \
it (in reverse order as for real data), (2) for the regression coefficients \
the variances drop from the expressions when they are all equal."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalStatistics[mat]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(ContingencyTableQ \[Rule] True\), 
          ",", \(OverallCorrelation \[Rule] 0.6658507727534974`\), 
          ",", \(Length \[Rule] {2, 2, 2}\), 
          ",", \(EffectiveNumberOfCategories \[Rule] {2.`, 2.`, 2.`}\), 
          ",", \(Variance \[Rule] {1.`, 1.`, 1.`}\), ",", 
          RowBox[{"BorderTotals", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"16", "16"},
                  {"16", "16"},
                  {"16", "16"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"BorderMatrices", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{\({1, 2}\), "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"6", "10"},
                        {"10", "6"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{\({1, 3}\), "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"13", "3"},
                        {"3", "13"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{\({2, 3}\), "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"7", "9"},
                        {"9", "7"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{"NominalCorrelationMatrix", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.`", \(-0.22191676197856086`\), "0.6180700462007376`"},
                  {\(-0.22191676197856086`\), "1.`", "0.04134491152973615`"},
                  {"0.6180700462007376`", "0.04134491152973615`", "1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarMat", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.`", \(-0.22191676197856086`\), "0.6180700462007376`"},
                  {\(-0.22191676197856086`\), "1.`", "0.04134491152973615`"},
                  {"0.6180700462007376`", "0.04134491152973615`", "1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarRegress", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0.`", \(-0.24789456475064645`\), "0.6283192250490557`"},
                  {\(-0.4004450661356596`\), "0.`", "0.28884801205706073`"},
                  {"0.6597351863015085`", "0.1877512078370895`", "0.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[{
  "The main result of this output is the matrix ",
  StyleBox["C ",
    FontSlant->"Italic"],
  "with regression coefficients. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalStatistics[Results, \ CovarRegress, \ CT[Variables]]\)], "Input",\

  CellLabel->"In[28]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Shop\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Colour\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Fitness\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop\"\>",
                "TraditionalForm"], "0.`", \(-0.24789456475064645`\), 
              "0.6283192250490557`"},
            {
              FormBox["\<\"Colour\"\>",
                "TraditionalForm"], \(-0.4004450661356596`\), "0.`", 
              "0.28884801205706073`"},
            {
              FormBox["\<\"Fitness\"\>",
                "TraditionalForm"], "0.6597351863015085`", 
              "0.1877512078370895`", "0.`"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{"Shop", "Colour", "Fitness"}, {
            "Shop", "Colour", "Fitness"}}]]], TraditionalForm]], "Output",
  CellLabel->"Out[28]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "For the matrix ",
  StyleBox["C",
    FontSlant->"Italic"],
  " and variables ",
  StyleBox["x = ",
    FontSlant->"Italic"],
  "{",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\)]],
  "}, the relation is ",
  StyleBox["x == C x",
    FontSlant->"Italic"],
  " + \[Epsilon]",
  ". The variable that is explained has a zero coefficient. The matrix ",
  StyleBox["C ",
    FontSlant->"Italic"],
  "of regression coefficients (\[OpenCurlyDoubleQuote]CovarRegress\
\[CloseCurlyDoubleQuote])",
  StyleBox[" ",
    FontSlant->"Italic"],
  "is not symmetric since it matters in regression what the explained \
variable is. CovarRegress takes the pairwise correlations and then uses the \
cofactors to determine the multiple regression coefficients. "
}], "Text"],

Cell["\<\
For these data, some of the conclusions are as follows. Take Fit as the \
explained variable. The data are in the order Shop, Colour, Fit, so we take \
the third row.  Fit and Shop number have a correlation coefficient of 62%, \
and if one hat in the study were replaced from Shop1 to Shop2 then the fit \
would move 0.66 (the {3, 1} cell) from fit to no-fit. Fit and colour have a \
correlation coefficient of 4%. If the Blue score were raised by 1 then the \
number of not-fitting hats would rise by 0.2 (the {3, 2} cell). \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Comparison to the risk difference in treatment control studies\
\>", "Subsubsection"],

Cell["\<\
Regression coefficients can be interpreted by the effect of adding a unit \
(allow the total to be raised) or by moving a unit (keeping the same total). \
Let us focus on one regression coefficient, for example the relation between \
shops and fitness. Let us sum out the colour to get the 2 \[Times] 2 data. \
The structure that we get is that of a treatment control study, where shop 1 \
is the treatment, shop 2 the control, and the fit is the effect measure. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Sum, \ "\<Colour\>"]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Fit\"\>",
                "TraditionalForm"], 
              FormBox["\<\"No fit\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], "13", "3"},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], "3", "13"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{"Shop1", "Shop2"}, {"Fit", 
            "No fit"}}]]], TraditionalForm]], "Output",
  CellLabel->"Out[32]//TableForm="]
}, Open  ]],

Cell["\<\
We find a nominal correlation that is lower than the one found above, and \
there is a difference since this neglects the effect of submatrices.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[%]\  // \ N\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(TraditionalForm\`0.625`\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
Let us move one hat from shop 1 to shop 2. The special requirement is that \
this hat is typical of shop 1 when it is taken from shop 1, but suddenly \
becomes typical of shop 2 when it is put into shop 2. In other words, the \
rates of fitness per shop are kept constant. In this example it so happens \
that the two rates of fitness (per shop) are opposites. Their difference, \
called the risk difference, turns up as above correlation measure. Since the \
variances are 1 there is no difference between the correlation and regression \
coefficient.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Move1FromRow1To2[matsf = \ %%]\ \  // \ N\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\(Mat(In)\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"13.`", "3.`", "16.`"},
                  {"3.`", "13.`", "16.`"},
                  {"16.`", "16.`", "32.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\(Mat(Out)\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"12.1875`", "2.8125`", "15.`"},
                  {"3.1875`", "13.8125`", "17.`"},
                  {"15.375`", "16.625`", "32.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
          ",", \(Row[1.`] \[Rule] {\(-0.8125`\), \(-0.1875`\)}\), 
          ",", \(Row[2.`] \[Rule] {0.1875`, 0.8125`}\), 
          ",", \(Dif \[Rule] {\(-0.625`\), 0.625`}\)}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["\<\
To get rid of the symmetries in this example, let us consider a random \
example. Here we find a difference between correlation and regression \
coefficient, and the regression coefficient is equal to the differences in \
probabilities.\
\>", "Text"],

Cell[BoxData[
    \(\(matran\  = \ 
        Table[Random[Integer, \ {0, \ 10}], \ {i, \ 2}, \ {j, \ 
            2}];\)\)], "Input",
  CellLabel->"In[40]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Move1FromRow1To2[matran]\ ~Join~\ NominalStatistics[matran]\  // 
      N\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\(Mat(In)\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"4.`", "6.`", "10.`"},
                  {"1.`", "8.`", "9.`"},
                  {"5.`", "14.`", "19.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\(Mat(Out)\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"3.6`", "5.4`", "9.`"},
                  {"1.1111111111111112`", "8.88888888888889`", "10.`"},
                  {"4.711111111111111`", "14.28888888888889`", "19.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
          ",", \(Row[1.`] \[Rule] {\(-0.4`\), \(-0.6`\)}\), 
          ",", \(Row[2.`] \[Rule] {0.1111111111111111`, 
              0.8888888888888888`}\), 
          ",", \(Dif \[Rule] {\(-0.28888888888888886`\), 
              0.28888888888888886`}\), 
          ",", \(ContingencyTableQ \[Rule] True\), 
          ",", \(OverallCorrelation \[Rule] 0.3275692099413303`\), 
          ",", \(Length \[Rule] {2.`, 2.`}\), 
          ",", \(EffectiveNumberOfCategories \[Rule] {1.9944751381215469`, 
              1.6334841628959276`}\), 
          ",", \(Variance \[Rule] {0.997229916897507`, 0.775623268698061`}\), 
          ",", 
          RowBox[{"BorderTotals", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"10.`", "9.`"},
                  {"5.`", "14.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"BorderMatrices", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\({1.`, 2.`}\), "\[Rule]", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"4.`", "6.`"},
                      {"1.`", "8.`"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], "}"}]}],
           ",", 
          RowBox[{"NominalCorrelationMatrix", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.`", "0.3275692099413303`"},
                  {"0.3275692099413303`", "1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarMat", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0.997229916897507`", "0.28808864265927986`"},
                  {"0.28808864265927986`", "0.775623268698061`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarRegress", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0.`", "0.37142857142857155`"},
                  {"0.28888888888888886`", "0.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[43]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A formal explanation for the treatment control matrix", "Subsubsection"],

Cell[TextData[{
  "The reasoning is as follows. It will be easiest when we take the context \
of a treatment-control study. Let ",
  StyleBox["S",
    FontSlant->"Italic"],
  " be the total number of participants in the study, ",
  StyleBox["T ",
    FontSlant->"Italic"],
  "the number treated, ",
  StyleBox["C",
    FontSlant->"Italic"],
  " the controls,",
  StyleBox[" E",
    FontSlant->"Italic"],
  " the number with a (positive) effect, and ",
  StyleBox["E",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`E\_T\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`E\_C\)]],
  " with the respective subgroups, such that ",
  Cell[BoxData[
      \(TraditionalForm\`p\_T\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`E\_T\)]],
  " / ",
  StyleBox["T ",
    FontSlant->"Italic"],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_C\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`E\_C\)]],
  " / ",
  StyleBox["C ",
    FontSlant->"Italic"],
  "are the respective effect probabilities so that ",
  StyleBox["E = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`p\_T\)]],
  " ",
  StyleBox["T",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`p\_C\)]],
  "  ",
  StyleBox["C.",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TreatmentControlMatrix[Table, \ 0, \ Set]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Effective\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Ineffective\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Total\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Treatment\"\>",
                "TraditionalForm"], "ET", "IT", \(ET + IT\)},
            {
              FormBox["\<\"Controls\"\>",
                "TraditionalForm"], "EC", "IC", \(EC + IC\)},
            {
              FormBox["\<\"Sum\"\>",
                "TraditionalForm"], \(EC + ET\), \(IC + IT\), \(EC + ET + 
                IC + IT\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{"Treatment", "Controls", "Sum"}, {
            "Effective", "Ineffective", "Total"}}]]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[41]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "In terms of our earlier discussion, moving one hat from shop 1 to shop 2, \
we increase the control group, and thus we would calculate the influence on \
the ineffectiveness. For this kind of study it makes more sense to consider \
the opposite, which gives the same regression coefficient. The regression \
coefficient for the effect of an increase of treatment ",
  StyleBox["T ",
    FontSlant->"Italic"],
  "on the total effect ",
  StyleBox["E ",
    FontSlant->"Italic"],
  "can be found as:"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["d",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontSlant->"Plain"], "E"}], TraditionalForm]]],
  " / ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["d",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontSlant->"Plain"], "T"}], TraditionalForm]]],
  " = (",
  Cell[BoxData[
      \(TraditionalForm\`p\_T\)]],
  " (",
  StyleBox["T +",
    FontSlant->"Italic"],
  " d",
  StyleBox["T",
    FontSlant->"Italic"],
  ") + ",
  Cell[BoxData[
      \(TraditionalForm\`p\_C\)]],
  " (",
  StyleBox["C",
    FontSlant->"Italic"],
  " - d",
  StyleBox["T",
    FontSlant->"Italic"],
  ") - ",
  StyleBox["E",
    FontSlant->"Italic"],
  ") / d",
  StyleBox["T",
    FontSlant->"Italic"],
  " "
}], "Text",
  TextAlignment->-0.5],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["d",
              FontSlant->"Plain"], "T"], " ", "E"}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`p\_T\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`p\_C\)]],
  "  taking  d",
  StyleBox["T",
    FontSlant->"Italic"],
  " = 1 "
}], "Text",
  TextAlignment->-0.5],

Cell[TextData[{
  "Note that ",
  StyleBox["T* = ",
    FontSlant->"Italic"],
  "1 / (",
  Cell[BoxData[
      \(TraditionalForm\`p\_T\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`p\_C\)]],
  ") is also called the \[OpenCurlyDoubleQuote]number needed to treat\
\[CloseCurlyDoubleQuote], i.e. the number needed to have one single success \
above the control outcome."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The influence of more variables", "Subsubsection"],

Cell[TextData[{
  "For the 2 \[Times] 2 case just considered, we already had the \
\[OpenCurlyDoubleQuote]risk difference\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]number needed to treat\[CloseCurlyDoubleQuote] \
measures to express what we wished to express. Now, however, we can proceed \
with larger matrices and more dimensions. For example, the regression \
coefficient for the influence of shops on fitness was 0.625, but when we \
consider the 2 \[Times] 2 \[Times] 2 model then it rises to 0.66. Replacing a \
\[OpenCurlyDoubleQuote]typical hat\[CloseCurlyDoubleQuote] now requires us to \
keep colour constant too and this has some influence. More dramatically, the \
relation between colour and fitness in the 2 \[Times] 2 \[Times] 2 case \
correlation matrix has a value of 0.04 but it changes to -0.125 when we \
aggregate the data and remove the influence of the shops. In general, using \
larger sizes and dimensions will move us further from the agreeable notion of \
the risk difference. It is an option indeed to define regression coefficients \
using only those condensed 2 \[Times] 2 tables, and neglect the interaction \
effects. One would have to specify though how a ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "matrix would be aggregated into a 2 \[Times] 2 matrix. All in all, having \
a general expression might be more practical in the end. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Restatement of what the new results are", "Subsubsection"],

Cell["\<\
Up to now there was no straightforward way to express these notions for \
nominal data for larger sizes and dimensions. The discussion below develops \
the suggested new approach. Comparison is made to existing methods for \
association and correlation. Given the number of pages already created, a \
comparison to current existing approaches to regression, like logistic \
regression, is postponed to another paper. \
\>", "Text"],

Cell["\<\
In itself, the following is useful to observe. Given the link between \
correlation and regression one might surmise that this very link also exists \
in the literature, so that e.g. Cramer\[CloseCurlyQuote]s V on association \
also has a pendant in some notion of regression, or that e.g. logistic \
regression has a pendant in correlation, but it appears in practice that one \
lacks such clear developments. In this line, this paper emphasizes \
association and correlation, and, while we have indicated the link to \
regression and included this in the computer routine output, a longer \
discussion on the comparison with regression methods like logistic regression \
thus is postponed to another discussion.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Leading ideas", "Section"],

Cell[CellGroupData[{

Cell["The volume ratio idea", "Subsection"],

Cell["\<\
The general idea is that the determinant of a matrix measures the change in \
volume when mapping a body from one space to another. We can also find a \
specific determinant that lies between 0 and 1. The value 1 means that the \
contingency table has a diagonal and that all off-diagonal terms are zero. \
Information on one variable is equivalent to information on the other \
variable. The value 0 means that the data are evenly spread across all cells. \
Information on one variable tells us nothing about the other one. Values \
between 0 and 1 arise when the data move from statistical independence to \
full structure. Thus we have a normalized volume ratio that can be \
interpreted as correlation. Note that the correlation coefficient for real \
data has the geometric interpretation of the cosine of the angle between the \
vectors. For nominal data we thus don\[CloseCurlyQuote]t find a cosine but \
the important point remains that there is a meaningful interpretation. \
Perhaps the true position should be the other way around that the standard is \
a volume ratio and that real data don\[CloseCurlyQuote]t quite follow that \
standard but use a cosine instead. Perhaps there is a way that the volume \
ratio can be translated into a cosine interpretation. For now it suffices \
that we consider volumes only. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Existing options", "Subsection"],

Cell[TextData[{
  "With respect to the statistical reference guides - and see in particular \
the accessible sources on the internet Becker (1999), Garson (2007) and Losh \
(2004) - it must be observed that we find that there are actually various \
possible measures of association for contingency tables. This is another way \
of saying that there is no standard. The multitude of measures does not \
present paradise but rather a tropical forest or maze. We find Phi, (Pearson\
\[CloseCurlyQuote]s) Contingency Coefficient, Tschuprow\[CloseCurlyQuote]s T, \
Cramer\[CloseCurlyQuote]s V, Lambda, (Theil\[CloseCurlyQuote]s) Uncertainty \
Coefficient and some tetrachoric correlation. ",
  StyleBox["Appendix A ",
    FontWeight->"Bold"],
  "reviews these measures and rejects them for various reasons. A key point \
is that some measures are not symmetric. Another key point is that the most \
promising measures Phi, (Pearson\[CloseCurlyQuote]s) Contingency Coefficient \
and Cramer\[CloseCurlyQuote]s V all depend upon the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  "statistic that is not elementary and requires quite a bit of statistical \
theory. Cramer\[CloseCurlyQuote]s V is the most promising measure but is \
limited to the ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " case, and thus cannot handle the ",
  "hat shops example",
  " above. However, it appears that the proposed measure for nominal \
correlation is equal to Cramer\[CloseCurlyQuote]s V for the 2 \[Times] 2 \
case. We might start with that case and develop the story from there. \
However, it is better to develop the new measure by its own logic, and once \
we have done so, it appears that the volume ratio measure and Cramer\
\[CloseCurlyQuote]s V have different philosophies and different outcomes. ",
  StyleBox["Appendix B ",
    FontWeight->"Bold"],
  "discusses the use of Cramer\[CloseCurlyQuote]s V in relation to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  "test and shows its complexity. The determinant measure and Cramer\
\[CloseCurlyQuote]s V both range from 0 to 1 but their scores have a \
different meaning and gradient so that the numbers cannot be translated \
directly. Readers who are versed in statistics and want to start on familiar \
grounds might consider starting there. The key distinction is that the volume \
ratio measures the closeness to ",
  StyleBox["a",
    FontSlant->"Italic"],
  " diagonal while the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " allows for ",
  StyleBox["any ",
    FontSlant->"Italic"],
  "diagonal, also cross-diagonals and subdiagonals. While starting to use the \
term \[OpenCurlyDoubleQuote]nominal correlation\[CloseCurlyDoubleQuote], we \
thus can say that nominal correlation is stronger than the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " measure or Cramer\[CloseCurlyQuote]s V. Note that it is always useful to \
have more measures. When we have a contingency table say of size 5 \[Times] 3 \
\[Times] 7 then this block of 105 counts can usefully be summarized, not \
really in only one, but likely some more index numbers. One number for each \
separate aspect. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strength of association", "Subsection"],

Cell[TextData[{
  "If one holds that Cramer\[CloseCurlyQuote]s V is correlation, then one \
must accept this also for the determinant / volume ratio measure, since it is \
only stronger correlation. As said, the determinant measure tests on ",
  StyleBox["a",
    FontSlant->"Italic"],
  " diagonal (and not more) and Cramer\[CloseCurlyQuote]s V tests on ",
  StyleBox["any",
    FontSlant->"Italic"],
  " diagonal. The determinant measure might be called strong correlation and \
Cramer\[CloseCurlyQuote]s V weak correlation, given that the first has \
stricter conditions (\[OpenCurlyDoubleQuote]and\[CloseCurlyDoubleQuote]) than \
the latter (\[OpenCurlyDoubleQuote]or\[CloseCurlyDoubleQuote]). Having ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "diagonal within the determinant measure is a sufficient condition for \
Cramer\[CloseCurlyQuote]s V but not conversely. We may also note that \
statistical independence destroys the weak condition and henceforth the \
strong condition."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SquareTruthTable[StrongCondition\  \[Implies] \ WeakCondition]\  // \ 
      Transpose\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\((StrongCondition\ \(\(\[Implies]\)\(\ \)\) 
        WeakCondition)\)\)], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"\"\>", "StrongCondition", \(\[Not] StrongCondition\)},
            {"WeakCondition", "True", "True"},
            {\(\[Not] WeakCondition\), "False", "True"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
It might be a good research strategy to first test whether there is any \
association and if so then proceed with checking whether this concerns a main \
diagonal or not. If no association is found then one can save the trouble of \
checking for a main diagonal. One might also work conversely, check whether \
there is a main diagonal, and if not, proceed with a weaker condition. In \
practice, one would run both routines, just to be sure, anyhow.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The notion of overall correlation", "Subsection"],

Cell[TextData[{
  "It is useful to take real-valued data as our point of reference. Consider \
a block of data ",
  StyleBox["X ",
    FontSlant->"Italic"],
  "= {",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", ...., ",
  Cell[BoxData[
      \(TraditionalForm\`x\_k\)]],
  "} and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " \[Element] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^n\)]],
  " real data vectors, ",
  StyleBox["i",
    FontSlant->"Italic"],
  " = 1, ..., ",
  StyleBox["k. ",
    FontSlant->"Italic"],
  "Let the correlation matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  " contain the pairwise correlations between ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  ". Let \[ScriptCapitalR] = Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] the determinant of ",
  StyleBox["R",
    FontWeight->"Bold"],
  " and let ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(i, j\)\)]],
  " be that specific co-factor. Overall correlation is defined in squared \
form as ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - \[ScriptCapitalR] or rather non-squared as ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1\  - \ \[ScriptCapitalR]\)\)]],
  ",  we require 0 \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " \[LessEqual] 1 and thus require that 0 \[LessEqual] \[ScriptCapitalR] \
\[LessEqual] 1. From this we can also derive that ",
  StyleBox["R",
    FontWeight->"Bold"],
  " must be a positive semi-definite (PSD) matrix. The coefficient of \
determination or the squared multiple correlation coefficient for the OLS \
regression of the first variable on the others is ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_\(1.2,  .. , k\)\)]],
  " = 1 - \[ScriptCapitalR] / ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(1, 1\)\)]],
  ", see Johnston (1972:134). ",
  StyleBox["Appendix C ",
    FontWeight->"Bold"],
  "contains some supporting notions for real data, including the proof that 0 \
\[LessEqual] \[ScriptCapitalR] \[LessEqual] 1 for such a PSD correlation \
matrix. For example, when all variables are uncorrelated then the \
off-diagonal elements in ",
  StyleBox["R",
    FontWeight->"Bold"],
  " are zero and Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] = 1, and then we see an overall correlation of ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " = 0. Similarly, for two variables and ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "the pairwise correlation then ",
  StyleBox["R",
    FontWeight->"Bold"],
  " = {{1, ",
  StyleBox["r",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["r",
    FontSlant->"Italic"],
  ", 1}} and then we find ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] = 1 - (1 - ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " as it should be. "
}], "Text"],

Cell[TextData[{
  "NB. For ease of notation, this paper uses ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " for squared overall correlation and ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_\(1.2,  .. , k\)\)]],
  " for the squared coefficient for multiple correlation, or the coefficient \
of determination, \[OpenCurlyDoubleQuote]R-Squared\[CloseCurlyDoubleQuote]. \
In general though, the notation for \[OpenCurlyDoubleQuote]R-Squared\
\[CloseCurlyDoubleQuote] must be maintained, and thus ",
  Cell[BoxData[
      \(TraditionalForm\`R\_O\)]],
  " is the better notation for overall correlation outside of this paper."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two uses of the determinant", "Subsection"],

Cell[TextData[{
  "There is a key distinction here. In matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  " a linear dependence causes a zero determinant, as for example would \
happen with two equal rows (and henceforth two columns, given symmetry). When \
two variables have the same correlation pattern then they probably are \
correlated themselves too. In that case we want overall correlation ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1\  - \ \[ScriptCapitalR]\)\)]],
  "to express that ",
  StyleBox["R",
    FontWeight->"Bold"],
  " contains a strong correlation between (some of) the data indeed. Thus \
algebraic dependence in ",
  StyleBox["R",
    FontWeight->"Bold"],
  " gives overall correlation of 1 indeed. This is a bit different for \
contingency tables. In the square contingency table ",
  StyleBox["M",
    FontSlant->"Italic"],
  " a linear dependence causes a zero determinant as well, yet in this case \
the algebraic dependence means statistical independence. In that case we want \
to express that, with its categories, the data are not correlated. Hence \
there are two distinct realms where we use the determinant, not to be \
confused. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Association and correlation", "Subsection"],

Cell[TextData[{
  "Apparently, real data are such a paradise for analysis that the question \
about an overall correlation is not urgent and has slipped from much \
discussion. The issue is more urgent for nominal data since one quickly gets \
higher order contingency tables, and those tables frequently come as a block \
of data without obvious order. One of the key questions is also that we might \
have \[OpenCurlyDoubleQuote]correlation matrices\[CloseCurlyDoubleQuote] that \
are ",
  StyleBox["not ",
    FontSlant->"Italic"],
  "PSD to start with and can only be approximated by an associated PSD matrix \
that is \[OpenCurlyDoubleQuote]close\[CloseCurlyDoubleQuote] to it. This \
issue requires some sharp definitions. Suppose that we define a measure of \
\[OpenCurlyDoubleQuote]correlation\[CloseCurlyDoubleQuote] between two \
nominal data in a contingency matrix, and make sure that pairwise \
correlations are -1 \[LessEqual] ",
  StyleBox["r",
    FontSlant->"Italic"],
  " \[LessEqual] 1. Suppose that we have ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "such variables and collect the pairwise \
\[OpenCurlyDoubleQuote]correlations\[CloseCurlyDoubleQuote] in a matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  ". Are we allowed to call this matrix a \[OpenCurlyDoubleQuote]correlation \
matrix\[CloseCurlyDoubleQuote] ? Students from the school of real data \
analysis (one part of the brain of the author) will say \
\[OpenCurlyDoubleQuote]no\[CloseCurlyDoubleQuote] since there is no proof \
that this matrix will be PSD. Students from the school of nominal data \
analysis (another part of the brain of the author) wil say \
\[OpenCurlyDoubleQuote]why not ?\[CloseCurlyDoubleQuote], meaning that we \
generalize the concept and allow a matrix to contain pairwise correlations, \
subsequently impose 0 \[LessEqual] \[ScriptCapitalR] \[LessEqual] 1 and thus \
approximate PSD-ness if the need may arise. The issue can be resolved by \
using the sharp definition that a collection of pairwise correlation is \
called an \[OpenCurlyDoubleQuote]association matrix\[CloseCurlyDoubleQuote] \
and is only accepted as a \[OpenCurlyDoubleQuote]correlation matrix\
\[CloseCurlyDoubleQuote] if it is also PSD. A consequence is that the \
\[OpenCurlyDoubleQuote]pairwise correlation\[CloseCurlyDoubleQuote] has two \
values, the original one and the one in the PSD approximation. This may still \
be close to blasphemy for the school of real data analysis yet there is \
nothing to it since those values are well-defined now. They only must be \
properly used and practice makes perfect. "
}], "Text"],

Cell[TextData[{
  "The situation for both real and nominal data can be summarized in the \
general point of the choice of some ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "such that overall correlation within the data is ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] with ",
  StyleBox["R ",
    FontWeight->"Bold"],
  "now defined on pairwise correlations only."
}], "Text"],

Cell[TextData[{
  "Once the sharp distinction between association and correlation in above \
technical sense is clear and has been accepted, it appears in practice that \
this sharpness only is relevant for actual calculations and interpretations \
of the data. For general discussion the terms still can be and must be used \
interchangeably. To say for example that hat fitness and hat colour are \
associated but not correlated strains the use of the English language. Texts \
need to be lively and it helps when there are more terms to express one\
\[CloseCurlyQuote]s thoughts. It would be pedantic to use the symbol ",
  StyleBox["A",
    FontWeight->"Bold"],
  " for the association matrix and ",
  StyleBox["R",
    FontWeight->"Bold"],
  " for the correlation matrix, except of course when we sit down for the \
formulas in order to specify the approximation algorithm for the computer. \
Also given the general scarcity of symbols we still can use ",
  StyleBox["R",
    FontWeight->"Bold"],
  " for general use while it is kept in mind how we handle issues \
technically."
}], "Text"],

Cell[TextData[{
  "This generalization procedure on putting pairwise correlations in ",
  StyleBox["R",
    FontWeight->"Bold"],
  " has also been implemented for Cramer\[CloseCurlyQuote]s V, generalizing \
its use from",
  StyleBox[" m",
    FontSlant->"Italic"],
  " \[Times]",
  StyleBox[" n",
    FontSlant->"Italic"],
  " to the higher dimensions. It needs to be seen how this relates to a more \
straightforward adjustment of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " for multidimensional tables."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warranting positive semi-definiteness", "Subsection"],

Cell[TextData[{
  "For the volume ratio measure for contingency data there is some internal \
dependency such that a volume ratio in one dimension restricts ratios in \
other dimensions. ",
  StyleBox["Appendix H",
    FontWeight->"Bold"],
  " contains a simulation where cell values can differ from 1 to a million, \
and we find that 90% of the volume ratio scores are between 0 and 1. If we \
neglect the inner variation of the table and base the pairwise correlations \
only on the border sum matrices then 100% of the cases are between 0 and 1. \
This is only indicative since there is no mathematical proof yet that those \
outcomes will always be like that. The simulation doesn\[CloseCurlyQuote]t \
use zero entries yet to keep issues simple. These results nevertheless give \
some indication that the new proposed measure might be of some practical use. \
The latter will be enhanced when we find an acceptable method to approximate \
PSD-ness - which is complex way of saying that we make sure that 0 \
\[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " \[LessEqual] 1 and by implication that 0 \[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. Notably, when ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "B"], TraditionalForm]]],
  " is the association matrix containing the pairwise correlations using the \
border matrices only and when ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "A"], TraditionalForm]]],
  " is the association matrix containing the pairwise correlations that uses \
all inner variation, then we can maximize \[Lambda] such that 0 \[LessEqual] \
\[Lambda] \[LessEqual] 1 and  0 \[LessEqual] Det[",
  StyleBox["R =",
    FontWeight->"Bold"],
  " (1 - \[Lambda]) ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "B"], TraditionalForm]]],
  "  + \[Lambda] ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "A"], TraditionalForm]]],
  " ] \[LessEqual] 1. A statistical report would not only mention ",
  StyleBox["R",
    FontWeight->"Bold"],
  " but also \[Lambda]. This gives just one example of the possibilities for \
adjustment. When it would appear that it is not guaranteed that 0 \
\[LessEqual] Det[",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "B"], TraditionalForm]]],
  "] \[LessEqual] 1 and that such a \[Lambda] can be found then also \
technical approximations are possible. See ",
  StyleBox["Appendix J",
    FontWeight->"Bold"],
  " for such technical methods of PSD approximation. Higham (1989) presents \
the minimum of a Frobenius distance (Euclidean norm), we can also work \
directly on the eigenvalues, and there are also straightforward numerical \
methods that try to preserve some \[OpenCurlyDoubleQuote]grid\
\[CloseCurlyDoubleQuote]."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overall versus multiple correlation", "Subsection"],

Cell[TextData[{
  "We are used to think in terms of multiple correlations. Since statistical \
practice on real data doesn\[CloseCurlyQuote]t make much use of overall \
correlation ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - \[ScriptCapitalR] we have less experience with this notion. A score \
might be less informative when we are not used to interpreting such values. \
Given that we are most accustomed to the (squared) multiple correlation \
coefficient, an alternative measure of overall correlation is to consider the \
whole series ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_i\)]],
  " and take the maximal value. When it holds for one ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(i, \ i\)\)]],
  "  = 1 then this again collapses to 1 - \[ScriptCapitalR].",
  StyleBox[" ",
    FontSlant->"Italic"],
  "It seems to make most sense for current practice to say that the overall \
correlation within a block of data is given by the maximal value that we can \
find in it. Of course, we might consider a normal or geometric average too. \
Considering all the options it seems that using ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - \[ScriptCapitalR] or such averages lose out against simply taking \
the maximal value of all multiple correlations. For both types of data, it is \
thus suggested that the default ",
  StyleBox["f",
    FontSlant->"Italic"],
  " just selects the highest value of any multiple correlation in the data. "
}], "Text"],

Cell["\<\
PM 1. The routine OverallCorrelation allows one the choice and multiple \
correlation is only the default. The notion of OverallCorrelation thus is not \
to be confused with NominalCorrelation. NominalCorrelation only calls \
OverallCorrelation when the input is either an association or correlation \
matrix or a higher dimensional block of data that can be reduced to such. PM \
2. We may also think about separating data into subsets. Once the set of data \
with that maximal correlation has been located, it can be separated from the \
other data, that may contain another maximum. This reminds of canonical \
correlation methods, but is not the same. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Regression coefficients", "Subsection"],

Cell[TextData[{
  "Once we have a correlation matrix for contingency tables, it is \
straightforward to define a measure of variance as well, and then determine \
regression coefficients as we already can do for real data (Johnston \
(1972:133)). The main problem is that one requires a bit of care in \
interpreting these regression coefficients. ",
  StyleBox["Appendix K",
    FontWeight->"Bold"],
  " contains the discussion."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["What the correlation coefficient is useful for", "Subsection"],

Cell["\<\
A correlation coefficient only gives some rough indication of association. \
For the specific kind of association one would design a model and perform a \
test. However, the correlation coefficient has some psychological value for \
research on real data and undoubtedly will have the same effect for nominal \
data as well. A strong association for example might cause more curiosity as \
to what the true model is.\
\>", "Text"],

Cell[TextData[{
  "To understand the measure, let us start with the 2 \[Times] 2 case. Note \
that ",
  StyleBox["Appendix D ",
    FontWeight->"Bold"],
  "discusses conventional approaches to the 2 \[Times] 2 case while we now \
proceed with the volume ratio, interpreted as nominal correlation."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The 2 \[Times] 2 case", "Section"],

Cell[CellGroupData[{

Cell["The layout", "Subsection"],

Cell[TextData[{
  "The 2 \[Times] 2 case is much discussed in epidemiology. Contingency \
tables generally are presented with table-headings and border-sums. \
Calculations are normally done with the inner matrix. The following is an \
example where men and women are dieting or not. Observed frequencies are ",
  StyleBox["a",
    FontSlant->"Italic"],
  " to ",
  StyleBox["d",
    FontSlant->"Italic"],
  ". We wonder whether the behaviour of the groups differs."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(DiseaseTestMatrix[]\), " ", "=", " ", 
        RowBox[{"mat2", " ", "=", " ", 
          RowBox[{"Bordered2DPrSolve", "[", GridBox[{
                {"a", "b", "\[Placeholder]"},
                {"c", "d", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]"}
                }], "   ", "]"}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DiseaseTestMatrix[
      Table, \ "\<men\>", \ "\<dieting\>"]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"men\"\>",
                "TraditionalForm"], 
              FormBox[\(\[Not] "men"\),
                "TraditionalForm"], 
              FormBox["\<\"Tested\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"dieting\"\>",
                "TraditionalForm"], "a", "b", \(a + b\)},
            {
              FormBox[\(\[Not] "dieting"\),
                "TraditionalForm"], "c", "d", \(c + d\)},
            {
              FormBox["\<\"Sum\"\>",
                "TraditionalForm"], \(a + c\), \(b + d\), \(a + b + c + d\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$, TableHeadings -> {{"dieting", 
            Not[ "dieting"], "Sum"}, {"men", 
            Not[ "men"], "Tested"}}]]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["For analysis, we rely on the inner matrix only.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat3\  = \ StripMatrix[mat2]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"a", "b"},
            {"c", "d"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["An insight: diagram of the 2 \[Times] 2 case", "Subsection"],

Cell[TextData[{
  "The 2 \[Times] 2 matrix {{",
  StyleBox["a, b",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["c, d",
    FontSlant->"Italic"],
  "}} contains two row vectors {",
  StyleBox["a, b",
    FontSlant->"Italic"],
  "} and {",
  StyleBox["c, d",
    FontSlant->"Italic"],
  "} that together span a parallelepiped. When we draw a diagram of this, we \
find that the parallelepiped is contained in a rectangle with sides (",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["c",
    FontSlant->"Italic"],
  ") and (",
  StyleBox["b",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d",
    FontSlant->"Italic"],
  ") which are the column sums of the matrix. The following gives a numerical \
example (a routine defined for this). Recall that we discuss nonnegative \
matrices."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowDet[{{11, \ 3}, \ {4, \ 9}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.0147151 0.0490503 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
.97619 .60332 L
.02381 .60332 L
.02381 .01472 L
s
.02381 .45617 m
.27778 .45617 L
.27778 .60332 L
s
.72222 .01472 m
.72222 .16187 L
.97619 .16187 L
s
.02381 .01472 m
.72222 .16187 L
s
% Start of user PostScript
0. 0. 11. 3. MAarrowhead1
% End of user PostScript
.72222 .16187 m
.97619 .60332 L
s
% Start of user PostScript
11. 3. 15. 12. MAarrowhead1
% End of user PostScript
.02381 .01472 m
.27778 .45617 L
s
% Start of user PostScript
0. 0. 4. 9. MAarrowhead1
% End of user PostScript
.27778 .45617 m
.97619 .60332 L
s
% Start of user PostScript
4. 9. 15. 12. MAarrowhead1
% End of user PostScript
gsave
.72222 .16187 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.875 moveto
(8) show
69.563 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
82.688 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.750 13.875 moveto
(<) show
1.000 setlinewidth
grestore
gsave
.27778 .45617 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.875 moveto
(8) show
69.563 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
76.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
86.625 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.188 13.875 moveto
(<) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{226.813, 140.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003R0000S2000`400?l00000o`00003ohP3oool0
0>80oooo003R0?ooo`00hP3oool000D0oooof00000050?ooo`001@3oool2000000030?ooo`000000
000000<00000U@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo00050?oo
o`8000001P3oool400000940oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?oo
o`001@3oool00`000000oooo000000090?ooo`D00000S03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0000000h0oooo1@0000270?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool00000
4P3oool500000880oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`001@3o
ool010000000oooo0?ooo`00000G0?ooo`@00000OP3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00<0oooo00050?ooo`050000003oool0oooo0?ooo`0000006P3oool5000007T0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01`0oooo1@00001d0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q
0?ooo`D00000K`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo00050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool4000006/0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02T0oooo1@00001V0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool00`3oool000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`D00000
H@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0<P3oool5000005`0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo03H0oooo1000001H0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0i0?ooo`D00000D`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0?P3oool5000004h0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0480oooo
1@0000190?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool000D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`170?ooo`D00000A03oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0B`3oool400000400oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`03
0?ooo`001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04h0oooo1@00000k0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1C0?ooo`D00000=P3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
E`3oool500000340oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`001@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05`0oooo1000000]0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1O0?ooo`D00000:03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00<0oooo00050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0I03oool50000
02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo06P0oooo1@00000N0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1/0?ooo`@000006P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0L03oool5000000/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo0005
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0M03oool5000000H0oooo0`000007
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1i0?ooo`D0000000<0oooo0000000000000`0000050?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1m0?ooo`P000000`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
O@3oool:000000030?ooo`000000oooo03P0oooo00<000000?ooo`3oool00`3oool000D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1l0?ooodH000001@3oool000D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`270?ooo`050000003oool0oooo0?ooo`0000004@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool000D0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`270?ooo`040000003oool0oooo0000
0180oooo0P00000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool000D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`270?ooo`030000003oool0000000@0
oooo1@0000020?ooo`D000000`3oool2000000P0oooo0`0000040?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`280?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`001@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo0P0000040?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo08H0oooo0P000005
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`001@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool00P3oool2
000000D0oooo0P00000?0?ooo`<000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00<0
oooo00050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo0005
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00050?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00<0oooo00050?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00<0oooo00050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo
00050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo00050?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00<0oooo00050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0
oooo00050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo0005
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00050?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00<0oooo00050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00<0oooo00050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo
00050?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00050?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<0oooo00050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0
oooo00050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0300oooo00@0
00000?ooo`3oool00000QP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo
00050?ooo`030000003oool0oooo0300oooo100000270?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0;`3oool6000008H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0^0?oo
o`L00000Q`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00050?ooo`03
0000003oool0oooo02l0oooo1P0000280?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool00`3oool000D0oooo00<000000?ooo`3oool0<03oool5000008P0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0a0?ooo`D00000R03o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0
oooo0380oooo100000280?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool0<`3oool3000008T0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0d0?ooo`800000R@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo03D0oooo
0P0000290?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool000D0oooo?000
00280?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool000D0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`05000008<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00D0oooo100000200?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool000D0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo1P00000A0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool5000000h0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`<000000`3oool200000080oooo2000
00060?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`D00000103oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?oo
o`3oool0=P3oool01@000000oooo0?ooo`3oool0000000D0oooo1@00000@0?ooo`D0000000<0oooo
0000003oool0J03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00050?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000h0oooo100000040?ooo`D00000IP3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000d0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo1@00001R0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P00000=0?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`D00000GP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo0`0000040?oo
o`030000003oool0oooo00d0oooo1@00001I0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool000D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0e0?ooo`@0
0000EP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00050?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0>@3oool500000540oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo03h0oooo1@00001=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`130?ooo`D00000B03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0B03oool4000004D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04`0
oooo1@0000110?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1A0?ooo`D00000?03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0EP3oool5000003P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05/0oooo1@00000c
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`1P0?ooo`@00000<03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0I03oool5000002`0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`00
1@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06T0oooo1@00000W0?ooo`<00000
0`3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo06h0oooo1@00000Q0?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`001@3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo07<0oooo1@00000K0?ooo`H000000P3oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
07P0oooo1000000H0?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo07`0oooo1@00000D0?ooo`D0000000<0oooo0000003o
ool0103oool000D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`210?ooo`D00000
2P3oool2000000@0oooo100000000`3oool000000?ooo`040?ooo`001@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo08H0oooo1@0000050?ooo`@000000`3oool5000000D0oooo0005
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0R`3oool;00000080oooo10000005
0?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo08l0oooo2@000000103o
ool000000000000000050?ooo`001@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
08l0oooo3@0000050?ooo`001@3ooooH000000D0oooo003@0?ooo`L000002`3oool00>80oooo003R
0?ooo`00\
\>"],
  ImageRangeCache->{{{179, 404.813}, {362.688, 223.5}} -> {-12.9144, 19.9324, \
0.0699349, 0.0905257}}]
}, Open  ]],

Cell[TextData[{
  "The total area of the rectangle is given by (",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["c",
    FontSlant->"Italic"],
  ")(",
  StyleBox["b",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d",
    FontSlant->"Italic"],
  ") while the area of the parallelepiped can be found by subtraction of the \
small rectangles and triangles, thus (",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["c",
    FontSlant->"Italic"],
  ")(",
  StyleBox["b",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d",
    FontSlant->"Italic"],
  ") - 2 ",
  StyleBox["bc",
    FontSlant->"Italic"],
  " - 2 * (",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  StyleBox["ab",
    FontSlant->"Italic"],
  ") - 2 * (",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  StyleBox["cd",
    FontSlant->"Italic"],
  ") = ",
  StyleBox["ad - bc. ",
    FontSlant->"Italic"],
  "This latter value is the determinant of the matrix."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox["a",
                FontSlant->"Italic"], "+", 
              StyleBox["c",
                FontSlant->"Italic"]}], ")"}], 
          RowBox[{"(", 
            RowBox[{
              StyleBox["b",
                FontSlant->"Italic"], "+", 
              StyleBox["d",
                FontSlant->"Italic"]}], ")"}]}], "-", 
        RowBox[{"2", 
          StyleBox["b",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], 
          StyleBox["c",
            FontSlant->"Italic"]}], "-", 
        RowBox[{"2", 
          RowBox[{"(", 
            RowBox[{
              FormBox[\(1\/2\),
                "TraditionalForm"], 
              StyleBox["a",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["b",
                FontSlant->"Italic"]}], ")"}]}], "-", 
        RowBox[{"2", 
          RowBox[{"(", 
            RowBox[{
              FormBox[\(1\/2\),
                "TraditionalForm"], 
              StyleBox["c",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["d",
                FontSlant->"Italic"]}], ")"}]}]}], " ", "//", " ", 
      "Simplify"}]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\ d - b\ c\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Det", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            StyleBox[\(a, \ b\),
              FontSlant->"Italic"], "}"}], ",", 
          RowBox[{"{", 
            StyleBox[\(c, \ d\),
              FontSlant->"Italic"], "}"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\ d - b\ c\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "When we take the ratio of the areas ",
  StyleBox["cr",
    FontSlant->"Italic"],
  " = (",
  StyleBox["ad - bc",
    FontSlant->"Italic"],
  ") / ((",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["c",
    FontSlant->"Italic"],
  ")(",
  StyleBox["b",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d",
    FontSlant->"Italic"],
  ")) then we find a number between -1 and 1. "
}], "Text"],

Cell[TextData[{
  "Note that the determinant ",
  StyleBox["ad - bc",
    FontSlant->"Italic"],
  " also holds for the dual (transposed) matrix, giving a ratio ",
  StyleBox["rr. ",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "Since there are two ways of looking at the matrix a more robust measure is \
the geometric average ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            StyleBox["cr",
              FontSlant->"Italic"], " ", "*", " ", 
            StyleBox["rr",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". The numerator remains ",
  StyleBox["ad - bc",
    FontSlant->"Italic"],
  " but the denominator becomes  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\@\ \)\)]],
  "((",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["c",
    FontSlant->"Italic"],
  ")(",
  StyleBox["b",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d",
    FontSlant->"Italic"],
  ")(",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["b",
    FontSlant->"Italic"],
  ")(",
  StyleBox["c",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d",
    FontSlant->"Italic"],
  ")). This gives us a \[OpenCurlyDoubleQuote]standardized volume ratio\
\[CloseCurlyDoubleQuote]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[CorrelationPr2By2[mat2], \ 
      Assumptions\  \[Rule] \ {a\  \[GreaterEqual] \ 0, \ 
          b\  \[GreaterEqual] \ 0, \ c\  \[GreaterEqual] \ 0, \ 
          d\  \[GreaterEqual] \ 0}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(a\ d - b\ c\)\/\@\(\((a + b)\)\ \((a + c)\)\ \((b + \
d)\)\ \((c + d)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can easily check that a diagonal matrix with ",
  StyleBox["b",
    FontSlant->"Italic"],
  " = ",
  StyleBox["c ",
    FontSlant->"Italic"],
  "= 0 gives outcome +1 and with ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = ",
  StyleBox["d ",
    FontSlant->"Italic"],
  "= 0 gives outcome -1. Nominal data have no natural order, but one cannot \
avoid an order of presentation and the sign of the correlation in this case \
reflects that."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Statistical independence means zero correlation", "Subsection"],

Cell[TextData[{
  "As might already have been obvious from the properties of determinants, \
algebraic dependence means that this measure shows zero association. The \
following routine constructs a matrix by multiplying the marginals. We can \
multiply with the total number of observations ",
  StyleBox["N",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat4\  = \ PrTable[t, \ p]\ \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(N\ p\ t\), \(N\ \((1 - p)\)\ t\)},
            {\(N\ p\ \((1 - t)\)\), \(N\ \((1 - p)\)\ \((1 - t)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[CorrelationPr2By2[mat4], \ 
      Assumptions\  \[Rule] \ {t\  \[GreaterEqual] \ 0, \ 
          p\  \[GreaterEqual] \ 0}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Next step: square matrices", "Section"],

Cell[TextData[{
  "The 2 \[Times] 2 case can easily be extended to the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "case. The determinant is only defined for square matrices. We directly get \
a measure if we apply the paradigm that we put the determinant in the \
numerator and the square root of the products of the border sums in the \
denominator."
}], "Text"],

Cell[TextData[{
  "In normalizing a matrix with the products of sums of columns and rows, it \
may be noted that the latter relate to determinants of diagonal matrices. Let \
",
  StyleBox["A",
    FontSlant->"Italic"],
  " be any square matrix. Let Detr(",
  StyleBox["A",
    FontSlant->"Italic"],
  ") = Det(diag(",
  StyleBox["A ",
    FontSlant->"Italic"],
  "1)) and Detc(",
  StyleBox["A",
    FontSlant->"Italic"],
  ") = Det(diag(",
  StyleBox["A' ",
    FontSlant->"Italic"],
  "1)).",
  StyleBox[" ",
    FontSlant->"Italic"],
  "Detr and Detc are just the products of the diagonals but there may be an \
advantage to write them in this manner. The determinant of a normalized \
matrix can be resolved in subterms using the properties of the determinant \
with respect to multiplications of rows and columns. The suggested measure \
for square matrice ",
  StyleBox["M",
    FontSlant->"Italic"],
  " then gives Det(",
  StyleBox["M",
    FontSlant->"Italic"],
  ")",
  StyleBox[" ",
    FontWeight->"Bold"],
  " / ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            RowBox[{"Detr", "(", 
              StyleBox["M",
                FontSlant->"Italic"], ")"}], "  ", 
            RowBox[{"Detc", "(", 
              StyleBox["M",
                FontSlant->"Italic"], ")"}]}]], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "The case ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "= 3 is already a big deviation from ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = 2. The following example is from Mood & Graybill (1963:325). Given the \
categories, and possibly an implied order related to the way of presentation, \
or perhaps even some true ordinality, one might interprete the negative \
association as \[OpenCurlyDoubleQuote]the more capable the less poorly \
clothed\[CloseCurlyDoubleQuote]. The correlation measure shows little ",
  StyleBox["overall",
    FontSlant->"Italic"],
  " association though (note the emphasis on \[OpenCurlyDoubleQuote]overall\
\[CloseCurlyDoubleQuote])."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"mat5", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {" ", "\"\<Dull\>\"", "\"\<Intelligent\>\"", 
                "\"\<Very Capable\>\""},
              {"\"\<Very well clothed\>\"", "81", "322", "233"},
              {"\"\<Well clothed\>\"", "141", "457", "153"},
              {"\"\<Poorly clothed\>\"", "127", "163", "48"}
              }], ")"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SquareMatrixNormedDet[Take[mat5, \ \(-3\), \ \(-3\)]]\  // \ 
      N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-0.028554822192004045`\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The low overall association does not preclude that there might be more \
association when we aggregate over subgroups. However, in that case we need a \
theory that can handle ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "matrices."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat6\  = \ 
      mat5\  . \ 
        Transpose[{{1, \ 0, \ 0, \ 0}, \ {0, \ 1, \ 1, \ 0}, \ \ {\ 0, \ 0, \ 
              0, \ 1}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"Null", \("Dull" + "Intelligent"\), "\<\"Very Capable\"\>"},
            {"\<\"Very well clothed\"\>", "403", "233"},
            {"\<\"Well clothed\"\>", "598", "153"},
            {"\<\"Poorly clothed\"\>", "290", "48"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SquareMatrixNormedDet[Take[mat6, \ \(-3\), \ \(-2\)]]\  // \ 
      N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(SquareMatrixNormedDet::"dim"\), \(\(:\)\(\ \)\), "\<\"Must be \
a n by n matrix \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::dim\\\"]\\)\"\>"}], TraditionalForm]], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Next step: ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "matrices",
  " "
}], "Section"],

Cell[CellGroupData[{

Cell["Theory", "Subsection"],

Cell[TextData[{
  "Take an arbitrary ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table, say ",
  StyleBox["A",
    FontSlant->"Italic"],
  " \[Element] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^\(m, n\)\)]],
  ", not necessarily integers. With ",
  StyleBox["f",
    FontSlant->"Italic"],
  "[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] = ",
  StyleBox["A x",
    FontSlant->"Italic"],
  ", we have ",
  StyleBox["f",
    FontSlant->"Italic"],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^n\)]],
  " \[Rule] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^m\)]],
  ". A property in linear algebra is that if ",
  StyleBox["S ",
    FontSlant->"Italic"],
  "is a subset of ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^n\)]],
  " with Volume[",
  StyleBox["S",
    FontSlant->"Italic"],
  "] then Volume[",
  StyleBox["f",
    FontSlant->"Italic"],
  "[",
  StyleBox["S",
    FontSlant->"Italic"],
  "]] = Sqrt[Det[",
  StyleBox["A'.A",
    FontSlant->"Italic"],
  "]] Volume[",
  StyleBox["S",
    FontSlant->"Italic"],
  "]. Hence Sqrt[",
  "Det[",
  StyleBox["A'.A",
    FontSlant->"Italic"],
  "]] gives a volume ratio. For a problem like the hat shops, one can \
interprete ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "as taking combinations of the nominal categories, where a combination is \
not quite an addition (though it is in linear algebra). Thus there is an \
interpretation that makes the volume ratio an interpretable summary of \
association. Note that there is also a dimensionality adjustment, since a 2D \
surface has zero 3D volume; however, each space has a unit metric, e.g. as 1 \
",
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  " or 1 ",
  Cell[BoxData[
      \(TraditionalForm\`m\^3\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "To make the measure robust we include the following: (1) ",
  StyleBox["A ",
    FontSlant->"Italic"],
  "is normalized by dividing column-wise and row-wise by the square roots of \
the sums of the columns and rows respectively, (2) of ",
  StyleBox["A'.A ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["A.A'  ",
    FontSlant->"Italic"],
  "we take the one with lower size, since the larger one will give a zero \
determinant. It makes sense to consider only the smaller matrix since all \
variation in the higher dimension is only relevant with respect to the \
smaller dimension. (3) While the above causes the loss of the sign of the \
association, we recover this by letting ",
  StyleBox["s",
    FontSlant->"Italic"],
  "[",
  StyleBox["A",
    FontSlant->"Italic"],
  "] be the sign of the association in the matrix. "
}], "Text"],

Cell[TextData[{
  "Hence: let ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "be the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table and ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[GreaterEqual] ",
  StyleBox["n",
    FontSlant->"Italic"],
  ". The suggested pairwise VolumeRatio or NominalCorrelation measure is:"
}], "Text"],

Cell[TextData[{
  StyleBox["r ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["s",
    FontSlant->"Italic"],
  "[",
  StyleBox["M",
    FontSlant->"Italic"],
  "]",
  " Sqrt[Det[",
  StyleBox["A'A",
    FontSlant->"Italic"],
  "]] with ",
  StyleBox["A",
    FontSlant->"Italic"],
  " = Normalized[",
  StyleBox["M",
    FontSlant->"Italic"],
  "]"
}], "Text",
  TextAlignment->-0.5,
  TextJustification->0],

Cell[TextData[{
  "PM 1. For normalization, let ",
  StyleBox["dr ",
    FontSlant->"Italic"],
  "= diag[",
  StyleBox["M.",
    FontSlant->"Italic"],
  "1] and ",
  StyleBox["dc",
    FontSlant->"Italic"],
  " = diag[1'.",
  StyleBox["M",
    FontSlant->"Italic"],
  "] with diag[...] the diagonal matrix. Then ",
  StyleBox["A = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["dr",
            FontSlant->"Italic"], \(-\(1\/2\)\)], TraditionalForm]]],
  " ",
  StyleBox["M ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["dc",
            FontSlant->"Italic"], \(-\(1\/2\)\)], TraditionalForm]]],
  ". We can check that if ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "is square, then the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " measure reduces to the measure already defined for square measures, with \
the only loss of the sign (due to the square root of the squares). PM 2. Note \
that this is a special kind of normalization. Repeated application results \
into different values. PM 3. Given that we are still considering nonnegative \
matrices, the only condition for the division would seem to be that every row \
or column contains at least one non-zero element. A row or column with only \
zero\[CloseCurlyQuote]s would cause the determinant to be zero too so that \
division can be left out of consideration. It might be too simple to merely \
drop such a row or column. PM 4. For a calculation procedure, it seems most \
efficient to first check the diagonal. Only for zero elements on the diagonal \
it is necessary to check whether also the row or column are all zero. PM 5. \
In OLS the coefficient of determination relates to the correlation between \
explained variable ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "and explanation ",
  Cell[BoxData[
      \(TraditionalForm\`y\&^\)]],
  ". In this present case for nominal data we consider an overall \
correlation. See ",
  StyleBox["Appendix C",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection"],

Cell[CellGroupData[{

Cell["The examples above", "Subsubsection"],

Cell["\<\
We now can tackle above case. We first check that we reproduce the proper \
value of the square example that we could calculate above, and then produce \
the value for the case that we could not calculate before.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[Take[mat5, \ \(-3\), \ \(-3\)]]\  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-0.028554822192004045`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[Take[mat6, \ \(-3\), \ \(-2\)]]\  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-0.20875859177176337`\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Consistency with the 2 \[Times] 2 case", "Subsubsection"],

Cell["\<\
It may be noted that the measure is consistent with the 2 \[Times] 2 case. We \
lose the sign because of the quadratic term so that it has to be added \
explicitly.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[{{a, \ b}, \ {c, \ d}}]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a + c)\)\ \
\((b + d)\)\ \((c + d)\)\)\)\ \(sgn(a\ d - b\ c)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The sign of the correlation", "Subsubsection"],

Cell[TextData[{
  "Obviously, the sign matters a great deal, for example for the overall \
correlation and for the regression coefficients. For a ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table, the routine PairwiseSign determines the direction of \
the association."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(exmp\)\(\ \)\(=\)\(\ \)\(Table[
        Random[Integer, \ {0, \ 10}], \ {i, \ 4}, \ {j, \ 
          9}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"7", "2", "5", "6", "9", "5", "7", "2", "5"},
            {"2", "10", "8", "7", "1", "5", "8", "5", "8"},
            {"8", "9", "7", "10", "6", "4", "8", "2", "3"},
            {"3", "9", "1", "2", "9", "2", "5", "8", "9"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PairwiseSign[exmp]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-1\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that there is no clear universal algorithm yet to determine the \
direction of association within a  ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table. The current implementation takes the pragmatic \
approach of splitting the rows and columns down the middle and aggregating \
the matrix into a 2 \[Times] 2 matrix and then use that sign. If some \
diagonal dominates some cross-diagonal then this property would seem to be \
preserved by such aggregation. If aggregation creates a diagonal where none \
existed before then this changes the sign from 0 to 1, and this would have no \
effect on a correlation of zero."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({forRows\  = \ SplitAggregator[4], \ 
        forCols\  = \ SplitAggregator[9]}\ \  // \ Transpose\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 1, 0, 0}\), \({1, 1, 1, 1, 1, 0, 0, 0, 0}\)},
            {\({0, 0, 1, 1}\), \({0, 0, 0, 0, 0, 1, 1, 1, 1}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(forRows\  . \ exmp\  . \ Transpose[forCols]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"57", "45"},
            {"64", "41"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sign[Det[%]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-1\)\)], "Output"]
}, Open  ]],

Cell["\<\
If this method is considered too pragmatic then one might set the option \
ForceSign \[Rule] 1 so that all sign considerations are removed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PairwiseSign[exmp, \ ForceSign\  \[Rule] \ 1]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Finally ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]]
}], "Section"],

Cell[CellGroupData[{

Cell["In general", "Subsection"],

Cell[TextData[{
  "Let us take ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " as nominal data, ",
  StyleBox["i",
    FontSlant->"Italic"],
  " = 1, ..., ",
  StyleBox["k",
    FontSlant->"Italic"],
  ", and let ",
  Cell[BoxData[
      \(TraditionalForm\`n\_i\)]],
  " be the number of nominal categories in the ",
  Cell[BoxData[
      \(TraditionalForm\`i\^th\)]],
  " variable, then a contingency matrix ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "is of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  ". When we can define an association measure ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(i, j\)\)]],
  " between two variables then we can collect all of those in a ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "\[Times]",
  StyleBox[" k",
    FontSlant->"Italic"],
  " correlation (association) matrix ",
  StyleBox["R. ",
    FontWeight->"Bold"],
  "Subsequently, we can define an overal correlation as ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "[",
  StyleBox["R",
    FontWeight->"Bold"],
  "]. For this ",
  StyleBox["f, ",
    FontSlant->"Italic"],
  "a default approach is to take the highest value of any multiple \
correlation in the data."
}], "Text"],

Cell[TextData[{
  "For nominal data, the crux is to find a good ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(i, j\)\)]],
  ". The relation between two variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " can be considered in two ways. (1) One way is to sum out all other \
variables, giving ",
  StyleBox["B = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`M\_\(i, j\)\)]],
  ", the border matrix of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  ". It may well be that some third variable in some category has most \
influence on the correlation score, but when we consider only two variables \
then the influence of the other variables and the manner of influence might \
be considered to no longer apply. (2) The other approach is to hold that all \
variation in the submatrices that generate the border matrix is important \
too. Consider all matrices ",
  Cell[BoxData[
      \(TraditionalForm\`B\_p\)]],
  " =",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(M\_\(i, j\)\)(p)\)\)\)]],
  " used in the summing procedure to create ",
  StyleBox["B",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(i, j\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(p = 1\)\%\(n[i, j]\)\(M\_\(i, j\)\)(
          p)\)]],
  " and note that ",
  StyleBox["p ",
    FontSlant->"Italic"],
  "= 1, ...., ",
  StyleBox["n",
    FontSlant->"Italic"],
  "[",
  StyleBox["i, j",
    FontSlant->"Italic"],
  "] = ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " / (",
  Cell[BoxData[
      \(TraditionalForm\`n\_i\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_j\)]],
  "). With our measure ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " on an arbitrary ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table, we determine the ",
  Cell[BoxData[
      \(TraditionalForm\`r\_p\)]],
  " for each ",
  Cell[BoxData[
      \(TraditionalForm\`B\_p\)]],
  ", and determine a weighted average ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_\_p\)]],
  ", using the total number of observations in ",
  Cell[BoxData[
      \(TraditionalForm\`B\_p\)]],
  " as the weight. "
}], "Text"],

Cell[TextData[{
  "The overall method thus contains two steps that should not be confused (a) \
aggregating correlations for the same two variables given a total border sum \
(for which we might take the weighted average) and (b) aggregating \
correlations for ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "variables (for which we take the maximal value of any multiple \
correlation). Each step has its own reason. But with the distinctions and \
categories we get various combinations that we can look into, see also ",
  StyleBox["Appendix I",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell["\<\
As said, we should be strict about association and correlation when this is \
relevant. The routine VolumeRatioMatrix produces the matrix of pairwise \
correlations based upon the volume ratio. The routine \
NominalCorrelationMatrix uses that as input and checks upon positive \
semi-definiteness. When there is a problem then it first determines the \
\[Lambda] between the border sum result and the inner matrices result. When a \
problem remains then it uses a PSD approximator, by default setting negative \
eigenvalues to zero.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using bordersums", "Subsection"],

Cell["\<\
Reconsider the shop case, its dimensions (1) Shop, (2) Colour and (3) \
Fitness, and its border matrices. For example, the border matrix for Shop \
versus Colour (the first two dimensions) is created by summing over Fitness \
(the third dimension).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      mat\  = \ {{{5, \ 1}, \ {8, \ 2}}, \ {{2, \ 8}, \ {1, \ 5}}}, \ 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "5"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"8"},
                  {"2"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "2"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "8"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"5"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{5, 1}, {8, 2}}, {{2, 8}, {1, 5}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[30]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BorderMatrices[mat]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\({1, 2}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"6", "10"},
                  {"10", "6"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({1, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"13", "3"},
                  {"3", "13"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({2, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"7", "9"},
                  {"9", "7"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["\<\
When we use only these border matrices to determine the association between \
the variables then we neglect the variation that is in the submatrices. \
Application of the NominalCorrelation measure to these bordermatrices gives \
the elements of the total correlation matrix. \
\>", "Text"],

Cell[BoxData[
    \(\(case\  = \ BorderMatrices;\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[case, \ Mat]\  = \ 
      NominalCorrelationMatrix[mat, \ 
        BordersOrAll\  \[Rule] \ BorderMatrices]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(-\(1\/4\)\), \(5\/8\)},
            {\(-\(1\/4\)\), "1", \(-\(1\/8\)\)},
            {\(5\/8\), \(-\(1\/8\)\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
There are no messages and thus this volume ratio matrix is directly PSD of \
itself. Since we used the bordermatrices as the method, the value of \
\[Lambda] should be 0. We can recover it from the Results.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor\  /. \ 
      Results[NominalCorrelationMatrix, \ BorderMatrices, \ True]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]],

Cell["\<\
Having produced the correlation matrix, we now can consider the measures for \
overall correlation. By default, OverallCorrelation[mat] only considers the \
maximal multiple correlation in this correlation matrix.\
\>", "Text"],

Cell[BoxData[
    \(\(mrsq\  = \ MultipleRSquared;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[mrsq, \ 
        case]\  = \ {Correlation\  \[Rule] \ \ \((OverallCorrelation[
                nc[case, \ Mat]]\ \  // \ N)\)}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Correlation \[Rule] 0.6485637367560112`}\)], "Output"]
}, Open  ]],

Cell["\<\
An alternative is to take the arithmetic average of all multiple \
correlations. One may experiment with such functions but it will be noted \
quickly that a single high correlation within a block of data might be \
sufficient to say that there is high correlation within that data. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(OverallCorrelation[nc[case, \ Mat], \ 
        Function\  \[Rule] \ 
          Average]\)\(\ \)\(//\)\(\ \)\(N\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.5404948816915078`\)], "Output"]
}, Open  ]],

Cell["\<\
OverallCorrelation[nc[bordmat, Mat], Mode \[Rule] Det] would use the \
determinant measure. We can also calculate this directly.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[Det, \ 
        case]\  = \ {Correlation\  \[Rule] \ \ \((\(\((1\  - \ 
                    Det[nc[case, \ Mat]])\)\  // \ Sqrt\)\  // \ 
              N)\)}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Correlation \[Rule] 0.6555055301063447`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using inner submatrices", "Subsection"],

Cell[TextData[{
  "When we want to account for the variation in the inner submatrices, then \
we can determine all submatrices that are used in the sum for a pairwise \
border matrix, determine each separate VolumeRatio, and then add these \
outcomes. It will be sensible in this addition to use the weights given by \
the numbers of observations in each submatrix. Note that there is an element \
of arbitrariness in using the weighted sum. We might also weigh e.g. the ",
  StyleBox["squared ",
    FontSlant->"Italic"],
  "measures of association, or use a geometric average, or take the maximal \
value, and so on. For the time being, the simple weighted average seems wise. \
It will also be instructive to see how the procedure works. In the following, \
the \[OpenCurlyDoubleQuote]VR\[CloseCurlyDoubleQuote] stands for the \
VolumeRatio measure, i.e. the NominalCorrelation, and the \
\[OpenCurlyDoubleQuote]Add\[CloseCurlyDoubleQuote] stands for taking the \
weighted sum."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[mat, \ 
      BordersOrAll\  \[Rule] \ Show]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"5", "8"},
                            {"2", "1"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}], ",", 
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"1", "2"},
                            {"8", "5"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}]}], "}"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"5", "1"},
                            {"2", "8"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}], ",", 
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"8", "2"},
                            {"1", "5"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}]}], "}"}], "]"}]},
            {
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"5", "8"},
                            {"2", "1"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}], ",", 
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"1", "2"},
                            {"8", "5"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}]}], "}"}], "]"}], "1", 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"5", "1"},
                            {"8", "2"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}], ",", 
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"2", "8"},
                            {"1", "5"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}]}], "}"}], "]"}]},
            {
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"5", "1"},
                            {"2", "8"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}], ",", 
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"8", "2"},
                            {"1", "5"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}]}], "}"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"5", "1"},
                            {"8", "2"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}], ",", 
                    RowBox[{"\<\"VR\"\>", "[", 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {"2", "8"},
                            {"1", "5"}
                            },
                          RowSpacings->1,
                          ColumnSpacings->1,
                          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                      "]"}]}], "}"}], "]"}], "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Actually doing the calculation gives this correlation matrix.\
\>", "Text"],

Cell[BoxData[
    \(\(case\  = \ All;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[case, \ 
        Mat]\  = \ \(\(NominalCorrelationMatrix[mat, \ 
          BordersOrAll\  \[Rule] \ 
            All]\)\(\ \ \ \)\(//\)\(\ \)\(N\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", \(-0.22191676197856086`\), "0.6180700462007376`"},
            {\(-0.22191676197856086`\), "1.`", "0.04134491152973615`"},
            {"0.6180700462007376`", "0.04134491152973615`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
In this numerical example, using all variation in the submatrices, the total \
measure (maximal multiple correlation) appears to be a bit different from the \
one using only the border matrices (in particular due to some of the signs of \
the correlations).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[mrsq, \ 
        case]\  = \ {Correlation\  \[Rule] \ \ \((OverallCorrelation[
                nc[case, \ Mat]]\ \  // \ N)\)}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Correlation \[Rule] 0.6658507727534974`}\)], "Output"]
}, Open  ]],

Cell["Using the determinant measure of overall correlation. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[Det, \ 
        case]\  = \ {Correlation\  \[Rule] \ \ \((\(\((1\  - \ 
                    Det[nc[case, \ Mat]])\)\  // \ Sqrt\)\  // \ 
              N)\)}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Correlation \[Rule] 0.6665649087989187`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Review", "Subsection"],

Cell["\<\
We calculated the nominal correlations using both the border matrices or all \
submatrices, and using only the maximal multiple RSquared or the determinant \
measure. The following table collects these results. \
\>", "Text"],

Cell["\<\
heading = TableHeadings \[Rule] {{mrsq, Det}, {BorderMatrices, All}};\
\>", "Input"],

Cell["InsideTable[Set, nc, heading] ", "Input"],

Cell[CellGroupData[{

Cell["InsideTable[Show, Correlation]", "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["BorderMatrices",
                "TraditionalForm"], 
              FormBox["All",
                "TraditionalForm"]},
            {
              FormBox["MultipleRSquared",
                "TraditionalForm"], "0.6485637367560112`", 
              "0.6658507727534974`"},
            {
              FormBox["Det",
                "TraditionalForm"], "0.6555055301063447`", 
              "0.6665649087989187`"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{MultipleRSquared, Det}, {
            BorderMatrices, All}}]]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
There are no general conclusions yet since all this is a result of this \
particular numerical example.\
\>", "Text"],

Cell["The difference between the correlation matrices is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(nc[All, \ Mat]\)\(\ \)\(-\)\(\ \)\(nc[BorderMatrices, \ 
        Mat]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.`", "0.02808323802143914`", \(-0.006929953799262423`\)},
            {"0.02808323802143914`", "0.`", "0.16634491152973616`"},
            {\(-0.006929953799262423`\), "0.16634491152973616`", "0.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The default", "Subsection"],

Cell["\<\
As already shown above, the default definition uses the inner submatrices and \
the maximal multiple RSquared. In that case we can directly call \
NominalCorrelation, that is smart enough to recognize that the input is a \
multidimensional contingency table so that it produces the underlying matrix \
itself.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[mat]\  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.6658507727534974`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "See ",
  StyleBox["Appendix E",
    FontWeight->"Bold"],
  " for an example in higher dimensions. See ",
  StyleBox["Appendix F",
    FontWeight->"Bold"],
  " for a note on the Frobenius theorems on nonnegative (contingency) \
matrices. See ",
  StyleBox["Appendix G",
    FontWeight->"Bold"],
  " for a note on causality, and how this paper originated. See ",
  StyleBox["Appendix H",
    FontWeight->"Bold"],
  " for a formal definition that the nominal correlation matrix is positive \
semidefinite. See ",
  StyleBox["Appendix I",
    FontWeight->"Bold"],
  " for an overview of the variants for the measure: {border matrices versus \
all submatrices}, {overall correlation versus multiple correlation}, {PSD \
adjustment or not}. See ",
  StyleBox["Appendix J",
    FontWeight->"Bold"],
  " for methods of PSD approximation. As said, ",
  StyleBox["Appendix K",
    FontWeight->"Bold"],
  " discusses regression, though focusses on the selection of the variance \
and leaves a comparison with logistic regression for another paper. See ",
  StyleBox["Appendix L",
    FontWeight->"Bold"],
  " for an application to two more practical examples. See ",
  StyleBox["Appendix M",
    FontWeight->"Bold"],
  " for an explanation of a routine used to handle contingency tables. See ",
  StyleBox["Appendix N",
    FontWeight->"Bold"],
  " for a list of the other routines used here."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Section"],

Cell[TextData[{
  "The crux in this development lies in the ",
  StyleBox["m \[Times] n ",
    FontSlant->"Italic"],
  "case. It covers the lower orders, and it forms the core for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " generalization. Since the ",
  StyleBox["m \[Times] n ",
    FontSlant->"Italic"],
  "case has a sound interpretation, the overall interpretation is sound. \
There is an element of arbitrariness in the methods of aggregation in the \
upward generalization. Namely, (i) there is the use of a weighted average for \
submatrices of pairwise correlations, (ii) the use of the maximal value of \
multiple correlations in the total correlation matrix, and (iii) the method \
to warrant positive semi-definiteness. Though arbitrary as this seems, each \
step has merit, and as a standard it is well defined. "
}], "Text"],

Cell[TextData[{
  "The suggested measure has a useful interpretation as the volume ratio, \
with values between 0 and 1. The meaning of the index can be translated \
conceptually as measuring the distance from ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "diagonal (anywhere but unique). The main comparison to existing measures \
is to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " measure in general and Cramer\[CloseCurlyQuote]s V in the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " case, see ",
  StyleBox["Appendix B",
    FontWeight->"Bold"],
  ". Compared to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " scores and tests currently in use, the suggested measure has the added \
value of indicating the overall strength of association. That a deviation \
from independence is statistically significant or not, at some level of \
significance, need not be the most meaningful message when researching an \
issue. Compared to Cramer\[CloseCurlyQuote]s V, it must be observed that the \
two indices measure different aspects of a contingency table and thus derive \
their usefulness from these two different angles. Cramer\[CloseCurlyQuote]s V \
measures the distance to ",
  StyleBox["any",
    FontSlant->"Italic"],
  " diagonal (more at the same time, cross-diagonals and subdiagonals). This \
is weaker than the suggested measure for overall correlation."
}], "Text"],

Cell["\<\
Considering all aspects, it makes sense to call the determinant measure \
\[OpenCurlyDoubleQuote]nominal correlation\[CloseCurlyDoubleQuote]. As said, \
this is a suggestion only, and only applies for the scope of this paper. The \
measure has been implemented as such in The Economics Pack and can be used to \
generate more experience.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Appendix A: Measures of association mentioned by common resources\
\>", "Section",
  PageBreakAbove->True],

Cell[TextData[{
  "There seems to be no standard and satisfactory measure of association for \
nominal data. Apart from the official books mentioned in the list of \
references, like Mood & Graybill (1963) and Kleinbaum et al. (2003), also the \
resources on the internet mentioned there, notably Becker (1999), Garson \
(2007) and Losh (2004), have been used to find measures for the association \
in nominal data. See Cool, Th. (1999, 2001), \[OpenCurlyDoubleQuote]The \
Economics Pack, Applications for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyDoubleQuote], and the website update, for an implementation of \
the LLR and Pearson tests, in the CrossTable package, and for some \
implementations in the Life Sciences packages (all created in 1993-2004). The \
following measures have been found."
}], "Text"],

Cell["\<\
(1) Fisher\[CloseCurlyQuote]s exact test does a test and does not provide a \
measure of association. Similarly for the likelihood ratio test and the \
Pearson approximation. The measure then is yes/no with respect to passing the \
test.\
\>", "Text"],

Cell["\<\
(2) The Odds Ratio depends upon direction (column-wise versus row-wise) and \
it is unknown whether this is generalizable. For the 2 by 2 table, taking the \
default column direction:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OddsRatio[]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(a\ d\)\/\(b\ c\)\)], "Output"]
}, Open  ]],

Cell["\<\
(3) \[OpenCurlyDoubleQuote]The tetrachoric correlation coefficient is \
essentially the Pearson product-moment correlation coefficient between the \
row and column variables, their values for each observation being taken as 0 \
or 1 depending on the category it falls into\[CloseCurlyDoubleQuote] \
\>", "Text"],

Cell["\<\
(4) Phi (Cramer\[CloseCurlyQuote]s V in non-square tables): \
\[OpenCurlyDoubleQuote]Also in 2-by-2 tables, phi is identical to the \
correlation coefficient. In larger tables, where phi may be greater than 1.0, \
there is no simple intuitive interpretation, which is a reason why phi is \
often used only for 2-by-2 tables.\[CloseCurlyDoubleQuote] (Garson (2007))\
\>", "Text"],

Cell["\<\
PM 4.1. The statement \[OpenCurlyDoubleQuote]Also in 2-by-2 tables, phi is \
identical to the correlation coefficient\[CloseCurlyDoubleQuote] is confusing \
since that correlation coefficient is not clearly defined for nominal data. \
As with the \"tetrachoric\" measure, one takes {1, 0} assignments to the \
nominal values, but are these also the values for Phi ? \
\>", "Text"],

Cell[TextData[{
  "PM 4.2. There are different ways to determine a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " value. The Pearson test statistic is ",
  Cell[BoxData[
      \(\((o\  - \ t)\)\^2\)]],
  "/ ",
  StyleBox["t, ",
    FontSlant->"Italic"],
  "with ",
  StyleBox["o",
    FontSlant->"Italic"],
  " the observed and ",
  StyleBox["t",
    FontSlant->"Italic"],
  " the theoretical frequency. For a 2 by 2 table the theoretical frequency \
might come from the hypothesis of independence. But other hypotheses are \
possible too."
}], "Text"],

Cell[TextData[{
  "PM 4.3 Cramer\[CloseCurlyQuote]s V is the most useful of all these \
possible measures. Yet its interpretation is the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " from the hypothesis of statistical independence, and one wonders whether \
this captures the intuition of correlation as given by the real variables. "
}], "Text"],

Cell[TextData[{
  "Cramer\[CloseCurlyQuote]s V, defined for a ",
  StyleBox["m \[Times] n ",
    FontSlant->"Italic"],
  "matrix, is the square root of the Pearson ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " value divided by the sample size ",
  StyleBox["p",
    FontSlant->"Italic"],
  " times ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["q",
    FontSlant->"Italic"],
  " is the smaller of (",
  StyleBox["m",
    FontSlant->"Italic"],
  " - 1) and (",
  StyleBox["n",
    FontSlant->"Italic"],
  " - 1). Thus V = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Chi]\^2\ /\ \((p\ q)\)\)\)]],
  ". For a 2 \[Times] 2 case we find ",
  StyleBox["q ",
    FontSlant->"Italic"],
  "=",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1, and then V reduces to Phi (that always takes ",
  StyleBox["q ",
    FontSlant->"Italic"],
  "= 1)."
}], "Text"],

Cell[TextData[{
  "PM 4.4. Since the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Chi]\^2\)\(\ \)\)\)]],
  "measure can be extended in higher dimensions (see the CrossTable package), \
one feels that this might be possible with this V too. (The CrossTable \
package might be used to check upon value 1 for all diagonals.)"
}], "Text"],

Cell[TextData[{
  "See ",
  StyleBox["Appendix B",
    FontWeight->"Bold"],
  " for a longer discussion."
}], "Text"],

Cell[TextData[{
  "(5) The Contingency Coefficient, Pearson\[CloseCurlyQuote]s C = SQRT[",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " + n)].  \[OpenCurlyDoubleQuote]There is no easily intuited interpretation \
of C or C*, though C* may be viewed as the association between two variables \
as a percentage of their maximum possible variation. Pearson viewed C as a \
nominal approximation of Pearsonian correlation r.\[CloseCurlyDoubleQuote]  \
(Garson (2007))"
}], "Text"],

Cell["\<\
(6) The Uncertainty Coefficient, UC or Theil\[CloseCurlyQuote]s U - an \
asymmetric measure.\
\>", "Text"],

Cell["\<\
(7) Hoeffding\[CloseCurlyQuote]s Dependence Coefficients - not looked into.\
\>", "Text"],

Cell["\<\
(8) Eta is an asymmetric correlation coefficient, and its dependent variable \
would be interval scaled.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Appendix B: Relation to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " measure"
}], "Section"],

Cell[CellGroupData[{

Cell["In general", "Subsection"],

Cell[TextData[{
  "A standard procedure in the analysis of contingency tables is to perform \
the Pearson test on independence, which is an approximation of the \
log-likelihood ratio test. Independence arises when the cells in the matrix \
are mere products of the marginals, given in the border sums. With ",
  StyleBox["o",
    FontSlant->"Italic"],
  " the observed data and ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "the theoretical frequencies, derived from those products given by the \
hypothesis of independence, the Pearson test statistic is \[CapitalSigma] ",
  Cell[BoxData[
      \(TraditionalForm\`\((o\  - \ t)\)\^2\ /\ t\)]],
  ". When we introduce additional assumptions on the distribution then we can \
perform a test. A possible assumption is a multinomial distribution and for \
larger numbers this gets closer to the multivariate normal, such that the \
Pearson test statistic would have a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  "distribution. Mood & Graybill (1963:314) clarify the procedure: \
\[OpenCurlyDoubleQuote]In casting about a test which may be used when the \
sample is not large, we may inquire how it is that a test criterion comes to \
have a unique distribution for large samples when the distribution actually \
depends on unknown parameters which may have any values in certain ranges. \
The answer is that the parameters are not really unknown; they can be \
estimated, and their estimates approach their true values as the sample size \
increases.\[CloseCurlyDoubleQuote] "
}], "Text"],

Cell[TextData[{
  "The most useful existing measure for association in crosstables is Cramer\
\[CloseCurlyQuote]s V, defined for a ",
  StyleBox["m \[Times] n ",
    FontSlant->"Italic"],
  "matrix, as the square root of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " value divided by the sample size ",
  StyleBox["p",
    FontSlant->"Italic"],
  " times ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["q",
    FontSlant->"Italic"],
  " is the smaller of (",
  StyleBox["m",
    FontSlant->"Italic"],
  " - 1) and (",
  StyleBox["n",
    FontSlant->"Italic"],
  " - 1). Thus V = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Chi]\^2\ /\ \((p\ q)\)\)\)]],
  ". For a 2 \[Times] 2 case we find ",
  StyleBox["q ",
    FontSlant->"Italic"],
  "=",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1, and then V reduces to Phi (that always takes ",
  StyleBox["q ",
    FontSlant->"Italic"],
  "= 1)."
}], "Text"],

Cell[TextData[{
  "Thinking about association within a table along this route is not simple \
and plunges us into the deep waters of statistical hypothesis testing. We can \
recognize that the 2 \[Times] 2 case has the same form for Cramer\
\[CloseCurlyQuote]s V as the suggested determinant measure for Nominal \
Correlation, yet, the reasoning behind it is quite different. To understand \
the relation between these two measures we must refresh our understanding of \
the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " test on statistical independence. Their behaviour with respect to \
diagonals appears to be key. Some illuminating cases are cross diagonals and \
triangular matrices. We can also consider aggregating a higher order matrix \
and check the consistency or change of the values. "
}], "Text"],

Cell["\<\
In the discussion below we will consider the 2 \[Times] 2 case, the 3 \
\[Times] 3 case and some higher dimensions where we focus on the role of \
diagonals. In this discussion symmetric matrices are used, just for \
simplicity, without affecting the generality of the conclusion.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The 2 \[Times] 2 case", "Subsection"],

Cell[TextData[{
  "The routine Test does the Pearson ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " test of ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  "\[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " contingency tables. The routine was written in 1993 - 1995 and has been \
in The Economics Pack since. We find fruitful employment for it again in this \
discussion, also using its feature that it can explain the various \
intermediate steps. In output, the rule ",
  StyleBox["Do \[Rule] Accept | Reject ",
    FontWeight->"Bold"],
  "expresses whether the hypothesis of independence is accepted or rejected \
at the stated significance level. The routine normally uses N[.] to prevent \
long expressions yet in this case we want to Rationalize[.] again. We \
presently consider the 2 \[Times] 2 case."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(test\  = \ 
      Test[Chi2, \ 
            Pearson, \ {{a, \ b}, \ {c, \ d}}]\  /. \ \ \ x_?
              NumberQ\  \[RuleDelayed] \ Rationalize[x] // \ 
        Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Observed"\)], "Print"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {"a", "b"},
            {"c", "d"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$]]], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"Theoretical"\)], "Print"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {\(\(\((a + b)\)\ \((a + c)\)\)\/\(a + b + c + 
                    d\)\), \(\(\((a + b)\)\ \((b + d)\)\)\/\(a + b + c + 
                    d\)\)},
            {\(\(\((a + c)\)\ \((c + d)\)\)\/\(a + b + c + 
                    d\)\), \(\(\((b + d)\)\ \((c + d)\)\)\/\(a + b + c + 
                    d\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$]]], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"Pearson (o - t)^2 / t"\)], "Print"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {\(\(\((a + b + c + 
                        d)\)\ \((a - \(1.`\ \((a + b)\)\ \((a + c)\)\)\/\(a + \
b + c + d\))\)\^2\)\/\(\((a + b)\)\ \((a + c)\)\)\), \(\(\((a + b + c + 
                        d)\)\ \((b - \(1.`\ \((a + b)\)\ \((b + d)\)\)\/\(a + \
b + c + d\))\)\^2\)\/\(\((a + b)\)\ \((b + d)\)\)\)},
            {\(\(\((a + b + c + 
                        d)\)\ \((c - \(1.`\ \((a + c)\)\ \((c + d)\)\)\/\(a + \
b + c + d\))\)\^2\)\/\(\((a + c)\)\ \((c + d)\)\)\), \(\(\((a + b + c + 
                        d)\)\ \((d - \(1.`\ \((b + d)\)\ \((c + d)\)\)\/\(a + \
b + c + d\))\)\^2\)\/\(\((b + d)\)\ \((c + d)\)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$]]], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(ArrayDepth \[Rule] 2\), ",", 
          RowBox[{"BorderSums", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(a + b\), \(c + d\)},
                  {\(a + c\), \(b + d\)}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"Chi2PValue", "\[Rule]", 
            RowBox[{"1", "-", 
              RowBox[{
                InterpretationBox["Q",
                  GammaRegularized,
                  Editable->False,
                  Selectable->False], "(", \(1\/2, 
                0, \(\((a + b + c + d)\)\ \((b\ c - a\ d)\)\^2\)\/\(2\ \((a + \
b)\)\ \((a + c)\)\ \((b + d)\)\ \((c + d)\)\)\), ")"}]}]}], 
          ",", \(DegreesOfFreedom \[Rule] 1\), 
          ",", \(Dimensions \[Rule] {2, 2}\), ",", 
          RowBox[{"Do", "\[Rule]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"20", " ", 
                    RowBox[{
                      InterpretationBox["Q",
                        GammaRegularized,
                        Editable->False,
                        Selectable->False], "(", \(1\/2, 
                      0, \(\((a + b + c + d)\)\ \((b\ c - a\ d)\)\^2\)\/\(2\ \
\((a + b)\)\ \((a + c)\)\ \((b + d)\)\ \((c + d)\)\)\), ")"}]}], 
                  "\[GreaterEqual]", "19"}], ",", "Reject", ",", "Accept"}], 
              "]"}]}], 
          ",", \(MarginalPr \[Rule] {MarginalPr(
                  1) \[Rule] {\(a + b\)\/\(a + b + c + d\), \(c + d\)\/\(a + \
b + c + d\)}, 
              MarginalPr(
                  2) \[Rule] {\(a + c\)\/\(a + b + c + d\), \(b + d\)\/\(a + \
b + c + d\)}}\), ",", \(NumberOfObservations \[Rule] a + b + c + d\), 
          ",", \(Partition \[Rule] {1, 2}\), ",", 
          RowBox[{"ProbabilityMatrix", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(\(\((a + b)\)\ \((a + 
                              c)\)\)\/\((a + b + c + d)\)\^2\), \(\(\((a + 
                              b)\)\ \((b + d)\)\)\/\((a + b + c + d)\)\^2\)},
                  {\(\(\((a + c)\)\ \((c + 
                              d)\)\)\/\((a + b + c + d)\)\^2\), \(\(\((b + 
                              d)\)\ \((c + d)\)\)\/\((a + b + c + d)\)\^2\)}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
          ",", \(SignificanceLevel \[Rule] 1\/20\), 
          ",", \(Test \[Rule] Pearson\), 
          ",", \(TestStatistic \[Rule] \(\((a + b + c + d)\)\ \((b\ c - a\ d)\
\)\^2\)\/\(\((a + b)\)\ \((a + c)\)\ \((b + d)\)\ \((c + d)\)\)\)}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The object of interest is the test statistic. We can select it from above \
output and give it a name that expresses its distribution under the null \
hypothesis of independence.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(chi2\)\(\ \)\(=\)\(\ \)\((TestStatistic\  /. \ 
          test)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\((a + b + c + d)\)\ \((b\ c - a\ d)\)\^2\)\/\(\((a \
+ b)\)\ \((a + c)\)\ \((b + d)\)\ \((c + d)\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Cramer\[CloseCurlyQuote]s V then is (for the 2 \[Times] 2 case):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt[chi2\ /\ \((NumberOfObservations\  /. \ test)\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a + c)\)\ \
\((b + d)\)\ \((c + d)\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note too, that, in general, it seems that one would be more interested in \
the measure of association and its confidence interval rather than the test \
on independence. Given that the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " value and its distribution have been given and Cramer\[CloseCurlyQuote]s \
V differs only by a constant, it should not be too difficult to determine \
these."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A 3 \[Times] 3 case", "Subsection"],

Cell["\<\
With respect to above 3 \[Times] 3 case, Cramer\[CloseCurlyQuote]s V suggests \
some modest association. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CramersV[Take[mat5, \ \(-3\), \ \(-3\)]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.19758354043576704`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We find that the hypothesis of independence would be rejected at the \
standard 5% significance level. Note that this test result actually derives \
from the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " test procedure in the background that is used to construct the Cramer\
\[CloseCurlyQuote]s V measure."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do\  /. \ Results[CramersV]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`Reject\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note however this crucial observation, Cool (1995, 2001:368) discussing \
some other examples: \[OpenCurlyDoubleQuote]The ",
  Cell[BoxData[
      \(\[Chi]\^2\)]],
  " test is sensitive to the number of observations per degree of freedom. \
(... When ...) there are more observations per degree of freedom, (...) the \
test is stronger. (In the same manner, by increasing the sample size, \
acceptance tends to turn into rejection, and by reducing the size, rejection \
can turn into acceptance.)\[CloseCurlyDoubleQuote] Thus a statistically \
significant deviation from independence in a ",
  Cell[BoxData[
      \(\[Chi]\^2\)]],
  " test does not imply that there would be much of an association."
}], "Text"],

Cell[TextData[{
  "The Cramer V outcome of 0.197584 differs importantly from the outcome of \
Nominal Correlation of 0.0285548. At this point there seems little to be said \
about this. Different measures, different results. But one cannot evade the \
impression that Cramer\[CloseCurlyQuote]s V is sensitive to the quirks of ",
  Cell[BoxData[
      \(\[Chi]\^2\)]],
  " testing. The point that Cramer\[CloseCurlyQuote]s V is equal to the \
volume ratio measure for the 2 \[Times] 2 case saves it though, and we need \
to embark upon the longer discussion below."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The general principle", "Subsection"],

Cell[CellGroupData[{

Cell["The key point", "Subsubsection"],

Cell[TextData[{
  "The determinant measure NominalCorrelation looks at the degree of \
dominance of ",
  StyleBox["a",
    FontSlant->"Italic"],
  " diagonal of the matrix (and not more), for any arbitrary permutation. \
Cramer\[CloseCurlyQuote]s V looks at ",
  StyleBox["any ",
    FontSlant->"Italic"],
  "diagonal, also subdiagonals or cross-diagonals. In the following we shall \
be using square matrices for simplicity. To emphasize neutrality and \
technicality we use the routine SquareMatrixNormedDet rather than VolumeRatio \
or NominalCorrelation (though they are technically similar). The determinant \
measure arrives at 1 or -1 and Cramer\[CloseCurlyQuote]s V arrives at 1 when \
the categories in the dimensions can be sorted such that there appears a neat \
diagonal. In this respect the measures are similar. The key point is that \
they differ when the diagonal is less important."
}], "Text"],

Cell[BoxData[
    \(\(perms\  = \ 
        Permutations[
          DiagonalMatrix[
            Table[Random[Integer, \ {1, \ 10}], \ {i, \ 4}]]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SquareMatrixNormedDet\  /@ \ perms\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, \(-1\), \(-1\), 1, 1, \(-1\), \(-1\), 1, 
      1, \(-1\), \(-1\), 1, 1, \(-1\), \(-1\), 1, 1, \(-1\), \(-1\), 1, 
      1, \(-1\), \(-1\), 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CramersV\  /@ \ perms\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0.9999999999999998`, 0.9999999999999999`, 
      0.9999999999999998`, 0.9999999999999998`, 0.9999999999999999`, 
      0.9999999999999998`, 0.9999999999999998`, 0.9999999999999999`, 
      0.9999999999999998`, 1.`, 0.9999999999999999`, 1.`, 
      0.9999999999999998`, 0.9999999999999998`, 0.9999999999999998`, 
      0.9999999999999999`, 0.9999999999999999`, 1.`, 0.9999999999999999`, 
      0.9999999999999998`, 0.9999999999999999`, 0.9999999999999999`, 
      0.9999999999999998`, 0.9999999999999999`}\)], "Output"]
}, Open  ]],

Cell["\<\
The measures differ however with respect to subdiagonals and cross diagonals. \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cross diagonals", "Subsubsection"],

Cell["\<\
Illuminating are the cross diagonal matrices, where a score in one dimension \
only allows some limited (and diverging, in the order of presentation) \
possibilities in the other dimension. The determinant measure concludes that \
these dimensions are not correlated (the cross-diagonal destroys the \
diagonal) yet Cramer\[CloseCurlyQuote]s V picks up a pattern.\
\>", "Text"],

Cell[BoxData[
    \(\(crossdiag[n_]\  := \ 
        Table[If[i\  == \ j\ \  || \ i\  \[Equal] \ n\  - \ j\  + \ 1, \ 1, \ 
            0], \ {i, \ n}, \ {j, n}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((crossdiagonal\  = \ {{crossdiag[2], \ crossdiag[3], \ 
              crossdiag[4], \ crossdiag[5], \ 
              crossdiag[6]}\[IndentingNewLine]})\)\ \  // 
      TableForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"1", "1"},
                  {"1", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1", "0", "1"},
                  {"0", "1", "0"},
                  {"1", "0", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1", "0", "0", "1"},
                  {"0", "1", "1", "0"},
                  {"0", "1", "1", "0"},
                  {"1", "0", "0", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1", "0", "0", "0", "1"},
                  {"0", "1", "0", "1", "0"},
                  {"0", "0", "1", "0", "0"},
                  {"0", "1", "0", "1", "0"},
                  {"1", "0", "0", "0", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1", "0", "0", "0", "0", "1"},
                  {"0", "1", "0", "0", "1", "0"},
                  {"0", "0", "1", "1", "0", "0"},
                  {"0", "0", "1", "1", "0", "0"},
                  {"0", "1", "0", "0", "1", "0"},
                  {"1", "0", "0", "0", "0", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{{1, 1}, {1, 1}}, {{1, 0, 1}, {0, 1, 0}, {1, 0, 1}}, {{1,
           0, 0, 1}, {0, 1, 1, 0}, {0, 1, 1, 0}, {1, 0, 0, 1}}, {{1, 0, 0, 0, 
          1}, {0, 1, 0, 1, 0}, {0, 0, 1, 0, 0}, {0, 1, 0, 1, 0}, {1, 0, 0, 0, 
          1}}, {{1, 0, 0, 0, 0, 1}, {0, 1, 0, 0, 1, 0}, {0, 0, 1, 1, 0, 0}, {
          0, 0, 1, 1, 0, 0}, {0, 1, 0, 0, 1, 0}, {1, 0, 0, 0, 0, 1}}}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[\(({SquareMatrixNormedDet[#], \ CramersV[#]}\  // \ N\ )\) &\ , \ 
      crossdiagonal, \ {2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0.`, 0.`}\), \({0.`, 0.7071067811865475`}\), \({0.`, 
                0.5773502691896257`}\), \({0.`, 
                0.7071067811865474`}\), \({0.`, 0.6324555320336757`}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Triangular matrices", "Subsubsection"],

Cell["\<\
Another illuminating case is triangularity. The case of a triangular \
contingency table is intriguing.  When we can rearrange a table so that it \
shows a triangle then we know that with an \[OpenCurlyDoubleQuote]increasing\
\[CloseCurlyDoubleQuote] score in one dimension we have more certainty in the \
sense of less (and also \[OpenCurlyDoubleQuote]increasing\
\[CloseCurlyDoubleQuote]) categories in the other dimension. This is a \
specific kind of regularity and association but not necessarily \
\[OpenCurlyDoubleQuote]correlation\[CloseCurlyDoubleQuote] when we take the \
latter in the (strong) sense that a main diagonal in some symmetric manner \
wins out over the off-diagonal elements.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((triangular\  = \ {{Table[
                If[i\  \[GreaterEqual] \ j, \ 1, \ 0], \ {i, \ 4}, \ {j, \ 
                  4}], \ \[IndentingNewLine]Table[
                Which[\ i\  \[Equal] \ j, \ 1, \ i\  \[GreaterEqual] \ j, \ 
                  Random[Integer, \ {0, \ 10}], \ True, \ 0], \ {i, \ 
                  4}, \ {j, \ 4}], 
              Table[If[i\  \[GreaterEqual] \ j, \ 
                  Random[Integer, \ {0, \ 10}], \ 0], \ {i, \ 4}, \ {j, \ 
                  4}]}\[IndentingNewLine]})\)\ \  // TableForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"1", "0", "0", "0"},
                  {"1", "1", "0", "0"},
                  {"1", "1", "1", "0"},
                  {"1", "1", "1", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1", "0", "0", "0"},
                  {"5", "1", "0", "0"},
                  {"4", "4", "1", "0"},
                  {"7", "0", "10", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"6", "0", "0", "0"},
                  {"2", "8", "0", "0"},
                  {"7", "2", "9", "0"},
                  {"8", "6", "10", "10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{{1, 0, 0, 0}, {1, 1, 0, 0}, {1, 1, 1, 0}, {1, 1, 1, 
          1}}, {{1, 0, 0, 0}, {5, 1, 0, 0}, {4, 4, 1, 0}, {7, 0, 10, 1}}, {{6,
           0, 0, 0}, {2, 8, 0, 0}, {7, 2, 9, 0}, {8, 6, 10, 10}}}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(res1\  = \ 
      Map[\(({SquareMatrixNormedDet[#], \ CramersV[#]}\  // \ 
              N\ )\) &\ , \ \ triangular, \ {2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0.041666666666666664`, 
                0.3757708127352411`}\), \({0.0010489651556241123`, 
                0.4196122855590828`}\), \({0.08525732469838632`, 
                0.4634233712715258`}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aggregation", "Subsubsection"],

Cell[TextData[{
  "When we aggregate nominal categories from a ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "case to a 2 \[Times] 2 level then the most important effect is that the \
diagonal increases in value. What first was off-diagonal now becomes \
diagonal. Precisely for this reason the value for the determinant measure \
rises strongly. Cramer\[CloseCurlyQuote]s V maintains a more stable value, \
since it already took this effect into account but taking along the \
subdiagonals. PM. For simplicity the following aggregation is symmetric but \
this does not have to be so. PM. Having the 2 \[Times] 2 case, the measures \
of course use the same formula. We do the operation to show the differential \
effect due to aggregation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(agg\  = \ {{1, \ 1, \ 1, \ 0}, \ {0, \ 0, \ 0, \ 
            1}};\)\), "\[IndentingNewLine]", 
    \(TableForm[\((triangular\  /. \ \((x_?SquareMatrixQ\  \[RuleDelayed] \ 
              agg\  . \ x\  . \ Transpose[agg])\))\)]\)}], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"6", "0"},
                  {"3", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"16", "0"},
                  {"17", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"34", "0"},
                  {"24", "10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{{6, 0}, {3, 1}}, {{16, 0}, {17, 1}}, {{34, 0}, {24, 
          10}}}}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(res2\  = \ 
      Map[\(({SquareMatrixNormedDet[#], \ CramersV[#]}\  // \ 
              N\ )\) &\ , \ %, \ {2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0.408248290463863`, 
                0.40824829046386296`}\), \({0.16412198797244365`, 
                0.16412198797244365`}\), \({0.41522739926869984`, 
                0.41522739926869984`}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(res2\  - \ res1\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0.36658162379719633`, 
                0.03247747772862186`}\), \({0.16307302281681954`, \
\(-0.25549029758663916`\)}\), \({0.3299700745703135`, \(-0.04819597200282594`\
\)}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zero diagonal", "Subsubsection"],

Cell["\<\
What is important in the example above is that the diagonals are not zero. \
With a zero diagonal, the determinant measure is indeterminate while Cramer\
\[CloseCurlyQuote]s V still produces a value. Cramer\[CloseCurlyQuote]s V \
namely looks at subdiagonals, which means that some aggregation can produce \
diagonal elements. We can check this by setting the diagonals of above \
matrices to zero and performing the relevant aggregation. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[\((triangular\  /. \ \((x_?
                  SquareMatrixQ\  \[RuleDelayed] \ \ x\  - \ 
                  10\ IdentityMatrix[4])\))\) /. \ \((y_?
              NumberQ\ )\)\  \[RuleDelayed] \ 
          If[y\  < \ 0, \ 0, \ y]]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"0", "0", "0", "0"},
                  {"1", "0", "0", "0"},
                  {"1", "1", "0", "0"},
                  {"1", "1", "1", "0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"0", "0", "0", "0"},
                  {"5", "0", "0", "0"},
                  {"4", "4", "0", "0"},
                  {"7", "0", "10", "0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"0", "0", "0", "0"},
                  {"2", "0", "0", "0"},
                  {"7", "2", "0", "0"},
                  {"8", "6", "10", "0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{{0, 0, 0, 0}, {1, 0, 0, 0}, {1, 1, 0, 0}, {1, 1, 1, 
          0}}, {{0, 0, 0, 0}, {5, 0, 0, 0}, {4, 4, 0, 0}, {7, 0, 10, 0}}, {{0,
           0, 0, 0}, {2, 0, 0, 0}, {7, 2, 0, 0}, {8, 6, 10, 0}}}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[\(({SquareMatrixNormedDet[#], \ CramersV[#]}\  // \ 
            N\ )\) &\ , \ %, \ {2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({Indeterminate, 0.3469443332443554`}\), \({Indeterminate, 
                0.485071250072666`}\), \({Indeterminate, 
                0.2912578834711532`}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
And this is a possible aggregation of the categories such that diagonal \
elements arise. Yet, while the determinant measure recovers, Cramer\
\[CloseCurlyQuote]s V collapses, meeting on the common ground of the 2 \
\[Times] 2 case again. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(agg\  = \ {{1, \ 1, \ 0, \ 0}, \ {0, \ 0, \ 1, \ 
            1}};\)\), "\[IndentingNewLine]", 
    \(TableForm[\((%%% /. \ \((x_?SquareMatrixQ\  \[RuleDelayed] \ 
              agg\  . \ x\  . \ Transpose[agg])\))\)]\)}], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"1", "0"},
                  {"4", "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"5", "0"},
                  {"15", "10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"2", "0"},
                  {"23", "10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{{1, 0}, {4, 1}}, {{5, 0}, {15, 10}}, {{2, 0}, {23, 
          10}}}}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[\(({SquareMatrixNormedDet[#], \ CramersV[#]}\  // \ 
            N\ )\) &\ , \ %, \ {2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0.2`, 0.19999999999999998`}\), \({0.31622776601683794`, 
                0.31622776601683794`}\), \({0.1556997888323046`, 
                0.15569978883230462`}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["What next", "Subsubsection"],

Cell["\<\
By way of arriving at a sub-conclusion, we see the impact both of the \
diagonals and the confounding by the 2 \[Times] 2 case. In the latter case \
the two philosophies meet but the room is too small to let them bloom in \
full. This brings us at the next subsection, where we replace numerics with \
analytics.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A parametric 3 \[Times] 3 case", "Subsection"],

Cell[TextData[{
  "To get more grip on the problem we can consider a parametric example. The \
following case has some theoretical value. (1) We use the fact that both \
measures are insensitive to the total number of observations ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". Thus we can normalize, say, and also taking a bit more flexibility, to \
one row with unit values. (2) We can reduce the size of the problem by taking \
a subblock of zeros such that the determinant of the 3 \[Times] 3 case is the \
same as the determinant of the lower 2 \[Times] 2 submatrix."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(matpar\  = \ {{a, \ b, \ 0}, \ {c, \ d, \ 0}, \ {1, \ 1, \ 
          1}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"a", "b", "0"},
            {"c", "d", "0"},
            {"1", "1", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We find that the denominators of the two measures have the same products of \
the border sums. But they differ strongly in their numerators. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(dt\)\(\ \)\(=\)\(\ \)\(SquareMatrixNormedDet[
        matpar]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(a\ d - b\ c\)\/\(\@3\ \@\(\((a + b)\)\ \((a + c + 1)\
\)\ \((b + d + 1)\)\ \((c + d)\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(cv\  = \ 
        CramersV[matpar]\  /. \ 
            x_?NumericQ\  \[RuleDelayed] \ Rationalize[x]\  // \ 
          Simplify\ ;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Denominator[\(cv\  // PowerExpand\)\  // \ 
        Simplify]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`6\ \@\(a + b\)\ \@\(a + c + 1\)\ \@\(b + d + 1\)\ \
\@\(c + d\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Numerator[\(cv // PowerExpand\)\  // \ 
        Simplify]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@6\ \[Sqrt]\((\((c\ \((b + d + 2)\) + 
                  d\ \((b + 4\ d + 2)\))\)\ a\^2 + \((\((c + 
                        d)\)\ b\^2 + \((c\^2 - 
                        2\ \((2\ d + 1)\)\ c + \((d - 2)\)\ d)\)\ b + 
                  2\ d\^2 + c\ \((d - 2)\)\ d + c\^2\ \((d + 2)\))\)\ a + 
            b\ \((\((d + 2)\)\ c\^2 + \((d - 2)\)\ d\ c + 2\ d\^2 + 
                  b\ \((4\ c\^2 + \((d + 2)\)\ c + 2\ d)\))\))\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For reference, we may also look at what happens in the 2 \[Times] 2 \
sub-case and include it in the list of our formulas. Also, it appears to be \
most illuminating to consider the case that ",
  StyleBox["c ",
    FontSlant->"Italic"],
  "= 0.  The determinant measure then appears to be a decreasing function of \
",
  StyleBox["b",
    FontSlant->"Italic"],
  " only, with a limit of 0. Cramer\[CloseCurlyQuote]s V first has a dip but \
then is an increasing function with limit 1/2. We can show the formulas, a \
table of values, and a plot."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(measures[
        b_]\  = \ {CorrelationPr2By2[{{a, \ b}, \ {c, \ d}}]\ , \ dt, \ 
            cv}\  /. \ {a\  \[Rule] \ 1, \ c\  \[Rule] \ 0, \ 
            d\  \[Rule] \ 1}\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1\/\@\((b + 1)\)\^2, 
      1\/\(\@6\ \@\(\((b + 1)\)\ \((b + 2)\)\)\), 
      1\/2\ \@\(\(3\ b\^2 + 2\ b + 8\)\/\(3\ b\^2 + 9\ b + 6\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[\(measures\  /@ \ {0, \ 1, \ 10, \ \ 10^10}\  // \ N\)\  // \ 
        Chop, \ TableHeadings\  \[Rule] \ {{0, \ 1, \ 
            10, \ \ Infinity}, \ {"\<2 \[Times] 2 subcase\>", \ Det, \ 
            CramersV}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"2 \[Times] 2 subcase\"\>",
                "TraditionalForm"], 
              FormBox["Det",
                "TraditionalForm"], 
              FormBox["CramersV",
                "TraditionalForm"]},
            {
              FormBox["0",
                "TraditionalForm"], "1.`", "0.28867513459481287`", 
              "0.5773502691896257`"},
            {
              FormBox["1",
                "TraditionalForm"], "0.5`", "0.16666666666666666`", 
              "0.4249182927993987`"},
            {
              FormBox["10",
                "TraditionalForm"], "0.09090909090909091`", 
              "0.03553345272593507`", "0.4550502247782183`"},
            {
              FormBox["\[Infinity]",
                "TraditionalForm"], "0", "0", "0.49999999994166666`"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$, TableHeadings -> {{0, 1, 10, 
            DirectedInfinity[ 1]}, {"2 \[Times] 2 subcase", Det, 
            CramersV}}]]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[measures[b]], \ {b, \ 0, \ 10}, \ 
        AxesLabel\  \[Rule] \ {b, \ "\<Association\>"}\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -5.28125 -13.875 ]
[.21429 .00222 5.28125 0 ]
[.40476 .00222 -5.28125 -13.875 ]
[.40476 .00222 5.28125 0 ]
[.59524 .00222 -5.28125 -13.875 ]
[.59524 .00222 5.28125 0 ]
[.78571 .00222 -5.28125 -13.875 ]
[.78571 .00222 5.28125 0 ]
[.97619 .00222 -8.5625 -13.875 ]
[.97619 .00222 8.5625 0 ]
[1.025 .01472 0 -6.9375 ]
[1.025 .01472 10.5625 6.9375 ]
[.01131 .13244 -23.6875 -6.9375 ]
[.01131 .13244 0 6.9375 ]
[.01131 .25016 -23.6875 -6.9375 ]
[.01131 .25016 0 6.9375 ]
[.01131 .36788 -23.6875 -6.9375 ]
[.01131 .36788 0 6.9375 ]
[.01131 .4856 -23.6875 -6.9375 ]
[.01131 .4856 0 6.9375 ]
[.01131 .60332 -10.5625 -6.9375 ]
[.01131 .60332 0 6.9375 ]
[.02381 .64303 -38.0938 0 ]
[.02381 .64303 38.0938 13.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -69.5625 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -71.5625 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -99.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Association) show
135.188 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .50625 L
.06244 .43345 L
.08255 .37877 L
.10458 .33321 L
.12579 .29896 L
.14509 .27362 L
.18408 .23411 L
.22401 .20446 L
.26243 .18263 L
.30329 .16431 L
.34264 .1501 L
.38048 .13876 L
.42077 .12861 L
.45954 .12029 L
.50076 .11269 L
.54047 .10633 L
.57866 .10095 L
.61931 .09587 L
.65844 .09152 L
.70002 .08738 L
.74009 .08379 L
.77864 .08066 L
.81964 .07763 L
.85913 .07496 L
.8971 .07259 L
.93752 .07028 L
.97619 .06822 L
s
.02381 .18463 m
.04262 .16285 L
.06244 .14539 L
.08255 .13154 L
.10458 .11945 L
.14509 .1028 L
.18408 .09116 L
.22553 .08177 L
.26546 .0747 L
.30387 .06917 L
.34474 .06432 L
.38409 .06041 L
.42192 .05718 L
.46221 .05422 L
.50098 .05173 L
.54221 .04941 L
.58192 .04744 L
.62011 .04574 L
.66075 .04412 L
.69988 .04271 L
.74147 .04135 L
.78153 .04016 L
.82008 .03912 L
.86109 .03809 L
.90057 .03718 L
.93855 .03638 L
.97619 .03563 L
s
.02381 .35455 m
.03279 .33643 L
.04262 .32031 L
.06244 .29657 L
.07298 .28748 L
.08426 .27974 L
.10458 .26971 L
.1148 .2661 L
.12589 .26301 L
.13636 .26074 L
.14603 .25909 L
.15569 .25781 L
.16475 .25689 L
.17469 .25613 L
.18027 .25581 L
.18538 .25557 L
.19014 .25539 L
.19522 .25524 L
.19769 .25518 L
.20002 .25513 L
.20209 .2551 L
.20436 .25507 L
.20688 .25504 L
.20826 .25503 L
.20955 .25502 L
.21075 .25502 L
.21185 .25502 L
.21312 .25501 L
.21432 .25501 L
.21562 .25501 L
.21627 .25501 L
.217 .25502 L
.21827 .25502 L
.21947 .25503 L
.22217 .25504 L
.22508 .25507 L
.23004 .25514 L
.23466 .25521 L
.24513 .25545 L
.26622 .25612 L
.30527 .25779 L
.34677 .25987 L
.38675 .26196 L
.42522 .26394 L
.46613 .26596 L
.50554 .26781 L
.54343 .26948 L
.58376 .27115 L
.62259 .27265 L
.66387 .27413 L
Mistroke
.70363 .27547 L
.74187 .27667 L
.78257 .27786 L
.82175 .27893 L
.86339 .28 L
.9035 .28096 L
.94211 .28183 L
.97619 .28256 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00DP3oool5
000002X0oooo0`00000X0?ooo`<00000:@3oool3000002D0oooo1@0000030?ooo`<000005@3oool0
0580oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo
0?ooo`0000009`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000001@0oooo001C0?ooo`030000003oool0oooo02T0oooo1@00
000W0?ooo`050000003oool0oooo0?ooo`0000009`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001@0oooo001D0?ooo`03
0000003oool0oooo02P0oooo00@000000?ooo`3oool00000:03oool4000002T0oooo0`00000W0?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000D0?ooo`00E@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool0:@3oool01@00
0000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000001@0oooo001B0?ooo`050000003oool0oooo0?ooo`000000:P3oool2000002T0oooo00<0
00000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000001@0oooo001C0?ooo`<00000;03oool00`000000oooo
0?ooo`0X0?ooo`<00000:03oool3000002H0oooo0P0000050?ooo`<000005@3oool00?l0oooo8@3o
ool002P0oooo00<000000?ooo`3oool0m@3oool002P0oooo00<000000?ooo`3oool0j03oool50000
00P0oooo000X0?ooo`030000003oool0oooo0>T0oooo00D000000?ooo`3oool0oooo000000070?oo
o`008`3ooooY000000P0oooo00D000000?ooo`3oool0oooo000000070?ooo`00:03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool200000080
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`0000000000203oool002P0oooo
00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`090?ooo`00:03oool00`000000oooo0?oo
o`3X0?ooo`8000002`3oool002P0oooo00<000000?ooo`3oool0cP3oool>000001T0oooo000X0?oo
o`030000003oool0oooo0:X0oooo9000000W0?ooo`00:03oool2000008l0oooo7000001;0?ooo`00
:03oool00`000000oooo0?ooo`1b0?oooa`00000I`3oool002P0oooo00<000000?ooo`3oool0J03o
ool:000008<0oooo000X0?ooo`030000003oool0oooo05H0oooo4P00002=0?ooo`00:03oool00`00
0000oooo0?ooo`1=0?ooo`T00000W`3oool002P0oooo00<000000?ooo`3oool0A03oool900000:P0
oooo000X0?ooo`030000003oool0oooo03X0oooo2P00002:0?ooo`h000006@3oool002P0oooo0P00
000d0?ooo`L00000PP3ooolB000002L0oooo000X0?ooo`030000003oool0oooo02l0oooo10000020
0?ooo`T00000>@3oool002P0oooo00<000000?ooo`3oool0:P3oool500000740oooo4`0000120?oo
o`00:03oool00`000000oooo0?ooo`0V0?ooo`@00000K@3oool9000005D0oooo000X0?ooo`030000
003oool0oooo0280oooo1000001W0?ooo`X00000GP3oool002P0oooo00<000000?ooo`3oool07`3o
ool300000680oooo2@00001X0?ooo`00:03oool00`000000oooo0?ooo`0K0?ooo`@00000GP3oool7
00000740oooo000X0?ooo`8000006@3oool3000005h0oooo1000001h0?ooo`00:03oool00`000000
oooo0?ooo`0F0?ooo`800000FP3oool7000007`0oooo000X0?ooo`030000003oool0oooo01@0oooo
0P00001D0?ooo`P00000P`3oool002P0oooo00<000000?ooo`3oool04P3oool200000580oooo1000
002;0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`800000C`3oool5000008l0oooo000B0?oo
o`<00000103oool2000000@0oooo1@0000040?ooo`030000003oool0oooo00h0oooo0P00001=0?oo
o`@00000U03oool00140oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0303oool2000004X0oooo1@00002H0?ooo`004@3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool01@3oool3000000/0oooo00<000000?oo
o`3oool0A@3oool5000009d0oooo000A0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo0P0000140?ooo`@00000XP3oool00140
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool2000004<0oooo0`00002V0?ooo`004@3oool01@000000oooo0?ooo`3oool00000
00T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0@03oool300000:T0oooo000B0?ooo`<000002`3oool3000000D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0n0?ooo`<00000[03oool002P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0l0?ooo`<00000[`3oool002P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0j0?ooo`<00000/P3oool002P0oooo0P0000030?ooo`030000003o
ool0oooo03P0oooo0`00002e0?ooo`00:03oool01@000000oooo0?ooo`3oool0000003T0oooo0P00
002h0?ooo`00:03oool010000000oooo0?ooo`00000h0?ooo`800000^P3oool002P0oooo00<00000
0?ooo`000000=`3oool200000;`0oooo000X0?ooo`800000=P3oool200000;h0oooo000X0?ooo`03
0000003oool0oooo03<0oooo0P0000300?ooo`00:03oool2000003<0oooo00<000000?ooo`3oool0
`03oool002P0oooo00<000000?ooo`3oool0<03oool200000<<0oooo000X0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0``3oool002P0oooo00<000000?ooo`3oool0;@3oool20000
0<H0oooo000X0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0aP3oool002P0oooo
00<000000?ooo`3oool0:P3oool200000<T0oooo000X0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0b@3oool002P0oooo0P00000X0?ooo`800000c03oool002P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`3<0?ooo`00:03oool00`000000oooo0?ooo`0T0?ooo`80
0000c`3oool002P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3?0?ooo`00:03o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0=00oooo000B0?ooo`<00000103oool2
000000H0oooo0`0000040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0d@3oool0
0140oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`3B0?ooo`004@3oool01@000000oooo0?ooo`3oool0
000000T0oooo1@0000040?ooo`<000007`3oool00`000000oooo0?ooo`3C0?ooo`004@3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`0N0?ooo`040000003oool0oooo0?oooa800000`@3oool00140oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool06@3oool900000180oooo
6@00002X0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000/0oooo0P0000050?ooo`030000
003oool0oooo01@0oooo1@0000030?ooo`030000003oool0oooo02h0oooo4`00002E0?ooo`004P3o
ool3000000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`8000001`3o
ool00`000000oooo0?ooo`120?oooa800000P`3oool002P0oooo00<000000?ooo`3oool03`3oool3
000000P0oooo00<000000?ooo`3oool0E@3ooolL000006L0oooo000X0?ooo`030000003oool0oooo
00d0oooo0P00000:0?ooo`030000003oool0oooo0780oooo6`00001<0?ooo`00:03oool2000000`0
oooo0P00000;0?ooo`030000003oool0oooo08h0oooo9P00000V0?ooo`00:03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0]03oool=000001T0oooo
000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3K0?ooo`00:03oool00`000000oooo0?ooo`070?ooo`8000003@3oool00`000000oooo0?ooo`3L
0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0g03oool002P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0=d0oooo000X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3N0?ooo`00:03oool2000000D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`3N0?ooo`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0g`3oool002P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0>00oooo000X0?ooo`050000003oool0oooo0?oo
o`0000003`3oool00`000000oooo0?ooo`3Q0?ooo`00:03oool010000000oooo0?ooo`00000@0?oo
o`030000003oool0oooo0>40oooo000X0?ooo`040000003oool0oooo000000l0oooo00<000000?oo
o`3oool0hP3oool002P0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`3R0?ooo`00
:03oool200000100oooo00<000000?ooo`3oool0h`3oool002P0oooo0P00000@0?ooo`030000003o
ool0oooo0><0oooo000X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0i03oool0
02P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3T0?ooo`00:03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0>D0oooo000B0?ooo`<00000103oool2000000D0oooo
0`0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0i@3oool00140oooo00D0
00000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0>H0oooo000A0?ooo`050000003oool0oooo0?ooo`00
00002@3oool01@000000oooo0?ooo`3oool0000000@0oooo0`00000<0?ooo`030000003oool0oooo
0>H0oooo000A0?ooo`050000003oool0oooo0?ooo`0000002@3oool4000000D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`3W0?ooo`004@3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0>L0oooo000A0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0i`3oool00180oooo0`00000<0?ooo`<0
0000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0>P0oooo000X0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0j03oool002P0oooo0P00000:0?ooo`030000003o
ool0oooo0>T0oooo000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0j@3oool0
02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3Y0?ooo`00:03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0>X0oooo000X0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0jP3oool002P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3Z0?ooo`00:03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>/0oooo000X0?oo
o`800000203oool00`000000oooo0?ooo`3[0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0>`0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
k03oool002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3/0?ooo`00:03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0>`0oooo000X0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0k@3oool002P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3]0?ooo`00:03oool2000000H0oooo00<000000?ooo`3oool0k@3oool002P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3]0?ooo`00:03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0>h0oooo000X0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0kP3oool002P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3^0?ooo`00
4P3oool3000000@0oooo0P0000050?ooo`<000001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0>h0oooo000A0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3_0?ooo`00
4@3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000040?oo
o`<000000`3oool00`000000oooo0?ooo`3_0?ooo`004@3oool01@000000oooo0?ooo`3oool00000
00X0oooo0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0k`3oool00140
oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0>l0oooo000A0?ooo`050000003oool0oooo
0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3`0?ooo`004P3oool3000000/0oooo0`0000050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0l03oool002P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3`0?ooo`00:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?00
oooo000X0?ooo`8000000`3oool00`000000oooo0?ooo`3`0?ooo`00:03oool01@000000oooo0?oo
o`3oool000000?<0oooo000X0?ooo`050000003oool0oooo0?ooo`000000l`3oool002P0oooo00D0
00000?ooo`3oool0oooo0000003c0?ooo`00:03oool01@000000oooo0?ooo`3oool000000?<0oooo
000X0?ooo`040000003oool0oooo00000?@0oooo000X0?ooo`040000003oool0oooo00000?@0oooo
000X0?ooo`80000000<0oooo0000003oool0l`3oool002P0oooo00@000000?ooo`3oool00000m03o
ool002P0oooo00<000000?ooo`000000m@3oool002P0oooo00<000000?ooo`000000m@3oool002P0
oooo00<000000?ooo`000000m@3oool002P0oooo00<000000?ooo`000000m@3oool002P0oooo00<0
00000?ooo`000000m@3oool002P0oooo0P00003f0?ooo`00:03oool200000?H0oooo000X0?ooo`80
0000mP3oool002P0oooo0P00003f0?ooo`007P3oool5000000D0oooo00<000000?ooo`3oool0m@3o
ool00200oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3e0?ooo`00803oool00`00
0000oooo0?ooo`050?ooo`<00000m@3oool00200oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3e0?ooo`00803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?D0oooo
000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0m@3oool001l0oooo0P000007
0?ooo`030000003oool0oooo0?D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo00040?ooo`<0000000D0oooo00000000000000000?ooo`04
000000<0oooo100000040?ooo`<00000103oool400000080oooo1@0000020?ooo`H000000P3oool3
000000<0oooo1@0000030?ooo`<000000P3oool3000000040?ooo`000000000000000<l0oooo0005
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
0000003@0?ooo`001P3oool3000000@0oooo0`0000040?ooo`<000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`@00000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000020?ooo`050000003oool0oooo0?ooo`000000d03oool000H0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool00`000000oooo
0?ooo`3>0?ooo`001P3oool00`000000oooo000000040?ooo`@000000`3oool4000000<0oooo0`00
00040?ooo`@000000P3oool3000000D0oooo0`0000020?ooo`D000000`3oool3000000D0oooo0`00
00020?ooo`80000000<0oooo000000000000d@3oool000L0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`3W0?ooo`001P3oool200000280oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3N0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{179, 466}, {267.438, 90.5}} -> {-9.90981, 0.537942, \
0.0451014, 0.00729757}}]
}, Open  ]],

Cell[TextData[{
  "Given that we might multiply the matrix with ",
  StyleBox["N, ",
    FontSlant->"Italic"],
  "the change in scores from 0 to 1 is important. For the 2 \[Times] 2 \
reference case all measures have the same formula and {{1, 0}, {",
  StyleBox["b",
    FontSlant->"Italic"],
  ", 1}} generates the correlation of 50% for ",
  StyleBox["b ",
    FontSlant->"Italic"],
  " = 1. For the 3 \[Times] 3 case the Cramer\[CloseCurlyQuote]s V 15 \
percentage points drop between 0 and 1 can best be interpreted as an \
approximation of the change from 58% at 0 to the limit value of 50%. The \
basic analysis is that Cramer\[CloseCurlyQuote]s V gives a score of about 50% \
to a triangular matrix, give or take some percentage points around it. The \
Det measure on the other hand behaves the same for 2 \[Times] 2 and 3 \
\[Times] 3. As the weight in the lower triangular matrix rises in comparison \
to the diagonal, the correlation drops. It is not quite right to consider \
{{1, 0}, {",
  StyleBox["b",
    FontSlant->"Italic"],
  ", 1}} as a lower triangular matrix since ",
  StyleBox["b",
    FontSlant->"Italic"],
  " is just a cell, yet from this angle it makes some sense."
}], "Text"],

Cell["\<\
A question might be whether we want the correlation score for triangular \
matrices to fall with their weight or to be stable and consistently around \
50% ? This question might be a bit misleading as we might usefully employ \
both measures, yet it is a good question to clarify what the measures do. The \
best way to answer this question seems to be to consider the 2 \[Times] 2 \
reference case and in particular the matrix {(1, 0}, {1, 1}}. Though the \
determinant measure and Cramer\[CloseCurlyQuote]s V have the same formula, \
they still have entirely different philosophies. Cramer\[CloseCurlyQuote]s V \
assigns a value of 50% because the diagonal gets a score of 1 but the \
cross-diagonal gets 0, thus the average is 50%. (When there are two \
diagonals, then there are also two columns and two rows, and then the result \
is 0%.) The determinant measure assigns 50% because the main diagonal is \
offset by off-diagonal elements. \
\>", "Text"],

Cell[TextData[{
  "PM 1. We may also say that the result of the volume ratio measure is \
merely from the effect that the formula works that way. The formula gives the \
ratio of the areas created by the vectors, and 1 in that cell is just one \
value in the range between 0 and infinity. Since the determinant measure has \
such an interpretation it is easier to understand what the score expresses. \
To say something like that is less feasible with the Pearson statistic. It is \
a formula too but less tractable. PM 2. One might possibly argue that Cramer\
\[CloseCurlyQuote]s V is inconsistent in that it does not assign 50% to the \
lower diagonal of {{1, 0}, {",
  StyleBox["b",
    FontSlant->"Italic"],
  ", 1}} for any ",
  StyleBox["b",
    FontSlant->"Italic"],
  " \[NotEqual] 0. However, a cell is not a lower triangular matrix if it \
comes to that, whatever said before, and thus the major issue are the (main, \
sub or cross) diagonals. The 2 \[Times] 2 case may just be a sandbox that \
allows too many philosophies and we need the perspective of more variables."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A higher dimensional case", "Subsection"],

Cell[TextData[{
  "Cramer\[CloseCurlyQuote]s V is only defined for ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times]",
  StyleBox[" n ",
    FontSlant->"Italic"],
  "matrices. But the ",
  Cell[BoxData[
      \(\[Chi]\^2\)]],
  " test can handle higher dimensions. We can run the test on the ",
  "hat shops",
  " case, for some level of significance and some ",
  StyleBox["p",
    FontSlant->"Italic"],
  "-value. The hypothesis of independence is rejected at the 5% significance \
level. And then ? This rejection tells us little about the amount of \
association. The ",
  Cell[BoxData[
      \(\[Chi]\^2\)]],
  " ",
  StyleBox["p",
    FontSlant->"Italic"],
  "-value does not impress as a good measure for association either."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(test\)\(\ \)\(=\)\(\ \)\(Test[Chi2, \ Pearson, \ 
        mat]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Observed"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"5"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"8"},
                  {"2"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {GridBox[{
                  {"2"},
                  {"8"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"5"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{5, 1}, {8, 2}}, {{2, 8}, {1, 5}}}]], 
      TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"Theoretical"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"4.`"},
                  {"4.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"4.`"},
                  {"4.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {GridBox[{
                  {"4.`"},
                  {"4.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"4.`"},
                  {"4.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{4.0, 4.0}, {4.0, 4.0}}, {{4.0, 4.0}, {4.0, 4.0}}}]], 
      TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"Pearson (o - t)^2 / t"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {"0.25`"},
                  {"2.25`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"4.`"},
                  {"1.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {GridBox[{
                  {"1.`"},
                  {"4.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"2.25`"},
                  {"0.25`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{{.25, 2.25}, {4.0, 1.0}}, {{1.0, 4.0}, {2.25, .25}}}]], 
      TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(ArrayDepth \[Rule] 3\), ",", 
          RowBox[{"BorderSums", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"16", "16"},
                  {"16", "16"},
                  {"16", "16"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
          ",", \(Chi2PValue \[Rule] 0.00010751117672946897`\), 
          ",", \(DegreesOfFreedom \[Rule] 1\), 
          ",", \(Dimensions \[Rule] {2, 2, 2}\), ",", \(Do \[Rule] Reject\), 
          ",", \(MarginalPr \[Rule] {MarginalPr(1) \[Rule] {0.5`, 0.5`}, 
              MarginalPr(2) \[Rule] {0.5`, 0.5`}, 
              MarginalPr(3) \[Rule] {0.5`, 0.5`}}\), 
          ",", \(NumberOfObservations \[Rule] 32\), 
          ",", \(Partition \[Rule] {1, 2, 3}\), ",", 
          RowBox[{"ProbabilityMatrix", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\({0.125`, 0.125`}\), \({0.125`, 0.125`}\)},
                  {\({0.125`, 0.125`}\), \({0.125`, 0.125`}\)}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
          ",", \(SignificanceLevel \[Rule] 0.05`\), 
          ",", \(Test \[Rule] Pearson\), 
          ",", \(TestStatistic \[Rule] 15.`\)}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generalizing Cramer\[CloseCurlyQuote]s V", "Subsection"],

Cell[TextData[{
  "There are two ways to generalize Cramer\[CloseCurlyQuote]s V to the higher \
",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  "\[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  " dimensions: (1) to adjust the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " score for those higher dimensions, (2) to follow the scheme as designed \
for the volume ratio, i.e. collect the pairwise results into an association \
or correlation matrix and then summarize that matrix in an overall \
correlation. Let us just do the latter. For the ",
  "hat shops example",
  " (that is 2 \[Times] 2 \[Times] 2) this procedure generates the same \
result for Cramer\[CloseCurlyQuote]s V as for the volume ratio, since the 2 \
\[Times] 2 formulas are the same, except for the sign of course. PM 1. We \
thus use a generalized PairwiseMeasureMatrix routine, that recognizes a \
PairwiseMeasure, either VolumeRatio or CramerV. PM 2. Rourtinewise speaking, \
it is not smart to allow just any pairwise measure, since it might be \
ill-defined, and generate a lot of intractable output. Thus it is useful to \
have a test on routines that are recognized. PM 3. This paragraph neglects \
the technical issue of the difference between \
\[OpenCurlyDoubleQuote]association\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]correlation\[CloseCurlyDoubleQuote]. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
TableForm[{{N[PairwiseMeasureMatrix[mat, PairwiseMeasure \[Rule] \
VolumeRatio]], 
    N[PairwiseMeasureMatrix[mat, PairwiseMeasure \[Rule] CramersV]]}}, \
TableHeadings -> {{}, {VolumeRatio, CramersV}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["VolumeRatio",
                "TraditionalForm"], 
              FormBox["CramersV",
                "TraditionalForm"]},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], GridBox[{
                  {"1.`", \(-0.22191676197856086`\), "0.6180700462007376`"},
                  {\(-0.22191676197856086`\), "1.`", "0.04134491152973615`"},
                  {"0.6180700462007376`", "0.04134491152973615`", "1.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1.`", "0.2219167619785609`", "0.6180700462007377`"},
                  {"0.2219167619785609`", "1.`", "0.04134491152973615`"},
                  {"0.6180700462007377`", "0.04134491152973615`", "1.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{{
          1.0, -.22191676197856086, .61807004620073758}, {-.22191676197856086,
           1.0, .041344911529736149}, {.61807004620073758, \
.041344911529736149, 1.0}}, {{
          1.0, .22191676197856089, .61807004620073769}, {.22191676197856089, 
          1.0, .041344911529736149}, {.61807004620073769, .041344911529736149,
           1.0}}}}, TableHeadings -> {{}, {VolumeRatio, CramersV}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Differences arise for the higher dimensions. When we use the triangular \
matrices above then it appears that these contain some zero columns so that \
pairwise volume ratios are indeterminate, while Cramer\[CloseCurlyQuote]s V \
still produces values.\
\>", "Text"],

Cell[BoxData[
    \(\(mattr\  = \ triangular[\([1]\)];\)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
TableForm[{{N[PairwiseMeasureMatrix[mattr, PairwiseMeasure \[Rule] \
VolumeRatio]], 
    N[PairwiseMeasureMatrix[mattr, PairwiseMeasure \[Rule] CramersV]]}}, \
TableHeadings -> {{}, {VolumeRatio, CramersV}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["VolumeRatio",
                "TraditionalForm"], 
              FormBox["CramersV",
                "TraditionalForm"]},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], GridBox[{
                  {"1.`", "Indeterminate", "Indeterminate"},
                  {"Indeterminate", "1.`", "0.055802049655787105`"},
                  {"Indeterminate", "0.055802049655787105`", "1.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1.`", "0.2644019660554452`", "0.29680007734815406`"},
                  {"0.2644019660554452`", "1.`", "0.4422974560966516`"},
                  {"0.29680007734815406`", "0.4422974560966516`", "1.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{{1.0, Indeterminate, Indeterminate}, {Indeterminate, 
          1.0, .055802049655787105}, {Indeterminate, .055802049655787105, 
          1.0}}, {{
          1.0, .26440196605544519, .29680007734815406}, {.26440196605544519, 
          1.0, .44229745609665161}, {.29680007734815406, .44229745609665161, 
          1.0}}}}, TableHeadings -> {{}, {VolumeRatio, CramersV}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The above result of course depends upon the parameters of the selected \
(default) methods. When we restrict our attention to the border matrices then \
we get non-indeterminate results (in this case).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bm\  = \ BorderMatrices[mattr]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\({1, 2}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"1", "6", "9", "18"},
                  {"6", "10", "18", "34"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({1, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"4", "3", "2", "1"},
                  {"17", "5", "11", "1"},
                  {"23", "16", "19", "10"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({2, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"8", "0", "0", "0"},
                  {"8", "10", "0", "0"},
                  {"12", "7", "11", "0"},
                  {"16", "7", "21", "12"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TableForm[{{N[PairwiseMeasureMatrix[mattr, PairwiseMeasure \[Rule] \
VolumeRatio, BordersOrAll \[Rule]  BorderMatrices]], \
N[PairwiseMeasureMatrix[mattr, PairwiseMeasure \[Rule] CramersV, BordersOrAll \
\[Rule]  BorderMatrices]]}}, TableHeadings -> {{}, {VolumeRatio, \
CramersV}}]\
\>", "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["VolumeRatio",
                "TraditionalForm"], 
              FormBox["CramersV",
                "TraditionalForm"]},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], GridBox[{
                  {"1.`", \(-0.006299407883487121`\), 
                    "0.01609507285172727`"},
                  {\(-0.006299407883487121`\), "1.`", 
                    "0.033715566404695294`"},
                  {"0.01609507285172727`", "0.033715566404695294`", "1.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1.`", "0.08844279988524004`", "0.16476888556588554`"},
                  {"0.08844279988524004`", "1.`", "0.36424798189147045`"},
                  {"0.16476888556588554`", "0.36424798189147045`", "1.`"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{{
          1.0, -.0062994078834871211, .016095072851727271}, \
{-.0062994078834871211, 
          1.0, .033715566404695294}, {.016095072851727271, \
.033715566404695294, 1.0}}, {{
          1.0, .088442799885240037, .16476888556588554}, {.088442799885240037,
           1.0, .36424798189147045}, {.16476888556588554, .36424798189147045, 
          1.0}}}}, TableHeadings -> {{}, {VolumeRatio, CramersV}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The transformation of a matrix of such correlation coefficients into a PSD \
correlation matrix is another issue. This is discussed in this paper \
elsewhere in the context of the volume ratio. The routine \
NominalCorrelationMatrix has been implemented such that this applies the \
volume ratios and constructs a PSD correlation matrix. This might be \
generalized for Cramer\[CloseCurlyQuote]s V as well, yet, this can best be \
done in relation to theory (approach (1)), which has not been implemented at \
this moment of writing.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix C: Overall correlation between real variables", "Section"],

Cell[CellGroupData[{

Cell["The notion of overall correlation", "Subsection"],

Cell[TextData[{
  "Consider a block of data ",
  StyleBox["X ",
    FontSlant->"Italic"],
  "= {",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", ...., ",
  Cell[BoxData[
      \(TraditionalForm\`x\_k\)]],
  "} and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " \[Element] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^n\)]],
  " real data vectors, ",
  StyleBox["i",
    FontSlant->"Italic"],
  " = 1, ..., ",
  StyleBox["k. ",
    FontSlant->"Italic"],
  "Let the correlation matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  " contain the pairwise correlations between ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  ". The correlation matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  " is by definition a symmetric matrix with 1 on its diagonal and 0 \
\[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. It is only a secondary issue that it is positive \
semi-definite (PSD) and that the method of OLS creates such a matrix. "
}], "Text"],

Cell[TextData[{
  "It is not customary of statistical textbooks and reference guides to \
discuss \[OpenCurlyDoubleQuote]overall correlation\[CloseCurlyDoubleQuote].  \
The books and guides concentrate on both the pairwise correlations and the \
multiple correlation coefficient, where the latter arises when a particular \
",
  StyleBox["y ",
    FontSlant->"Italic"],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " for some ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "is selected as the dependent variable so that the others are the \
explanatory variables. It appears that it is not common for real data to \
summarize that correlation matrix into one single number. The textbooks and \
guides will, at some point in the discussion, express that this ",
  StyleBox["R",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is a positive semi-definite (PSD) matrix. For a PSD matrix it holds that \
for any vector ",
  StyleBox["v ",
    FontSlant->"Italic"],
  "\[NotEqual] 0, ",
  StyleBox["v'",
    FontSlant->"Italic"],
  " ",
  StyleBox["R",
    FontWeight->"Bold"],
  " ",
  StyleBox["v",
    FontSlant->"Italic"],
  " \[GreaterEqual] 0. This may seem mysterious at first. With OLS expression \
",
  StyleBox["y = X ",
    FontSlant->"Italic"],
  "\[Beta], then the variance-coveriance matrix is based upon ",
  StyleBox["X'X",
    FontSlant->"Italic"],
  ", which is a PSD matrix since \[Beta]",
  StyleBox["' X' X ",
    FontSlant->"Italic"],
  "\[Beta]",
  StyleBox[" = y' y",
    FontSlant->"Italic"],
  " is a sum of squares. The latter also holds when the dependent variable ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "is included in the data ",
  StyleBox["X, ",
    FontSlant->"Italic"],
  "and we define some arbitrary ",
  StyleBox["z = X b. ",
    FontSlant->"Italic"],
  "Let \[ScriptCapitalR] = Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] the determinant of ",
  StyleBox["R",
    FontWeight->"Bold"],
  " and let ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(i, j\)\)]],
  " be that specific co-factor. The multiple correlation coefficient for the \
OLS regression of the first variable on the others is ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_\(1.2,  .. , k\)\)]],
  " = 1 - \[ScriptCapitalR] / ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(1, 1\)\)]],
  ", see Johnston (1972:134). This is where statistical textbooks and \
reference guides tend to stop. It is not customary for statistical textbooks \
and reference guides to state that 0 \[LessEqual] \[ScriptCapitalR] \
\[LessEqual] 1. At least, this holds before March 15 2007, and perhaps \
developments on the internet are fast and the situation has changed by the \
time that you read this. An improvement with respect to March 15 2007 would \
be: (i) to discuss overall association or correlation between a set of \
variables irrespective of order, (ii) define overall correlation as ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - \[ScriptCapitalR] or ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1\  - \ \[ScriptCapitalR]\)\)]],
  ", require 0 \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " \[LessEqual] 1 and deduce that 0 \[LessEqual] \[ScriptCapitalR] \
\[LessEqual] 1, (iii) only then derive that ",
  StyleBox["R",
    FontWeight->"Bold"],
  " must be PSD for the latter to be true. Note the shift in presentation \
content and order. The condition of PSD-ness is just a consequence of \
requiring that 0 \[LessEqual] \[ScriptCapitalR] \[LessEqual] 1. We only \
impose that condition since it is useful for something. The key point why it \
is useful is overall correlation and the possibility to derive arbitrary ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_i\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_\(i  .2,  .. , k\)\)]],
  " = 1 - \[ScriptCapitalR] / ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(i, \ i\)\)]],
  ", ",
  StyleBox["i",
    FontSlant->"Italic"],
  " = 1, ..., ",
  StyleBox["k. ",
    FontSlant->"Italic"],
  "The fact that we can estimate the correlation matrix with ",
  StyleBox["X' X ",
    FontSlant->"Italic"],
  "is only secondary to these considerations, since if we would not be able \
to use that estimator then we would design another estimator. Precisely since \
it follows from 0 \[LessEqual] \[ScriptCapitalR] \[LessEqual] 1 that ",
  StyleBox["R",
    FontWeight->"Bold"],
  " must be PSD brings us to using ",
  StyleBox["X' X ",
    FontSlant->"Italic"],
  "since it is PSD. The current practice in the textbooks and guides to slip \
in PSD-ness without much justification and with neglect of the concept of \
overall correlation turns the true argument upside down and deletes important \
information. "
}], "Text"],

Cell[TextData[{
  "For nominal data, the steps (i) to (iii) above should be extended with: \
(iv) show for nominal data that PSD-ness may require an approximation. In \
that way (i) to (iv) make for a logical structure that is transparant in its \
simplicity. The situation for both real and nominal data can be summarized in \
the general point of the choice of some ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "such that overall correlation within the data is ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] with ",
  StyleBox["R ",
    FontWeight->"Bold"],
  "now defined on pairwise correlations only."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivation of 0 \[LessEqual] Det[R] \[LessEqual] 1 ", "Subsection"],

Cell[TextData[{
  "With proper theory, we impose 0 \[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1 (next to -1 \[LessEqual] ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(i, j\)], TraditionalForm]]],
  " \[LessEqual] 1 and the unit diagonal) and then derive PSD-ness. However, \
in current practice PSD-ness is imposed and now we need to derive that 0 \
\[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1."
}], "Text"],

Cell[TextData[{
  "As said, a possible measure for overall correlation is ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - \[ScriptCapitalR] where \[ScriptCapitalR] = Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "]. Whatever we said about taking the maximal multiple correlation as the \
superior measure, there can still be value in just this determinant measure. \
The measure is valid if we can show that 0 \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - \[ScriptCapitalR] \[LessEqual] 1 or 0 \[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. From the PSD property already Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[GreaterEqual] 0. For the proof on the upper bound, such that ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "= 1 - \[ScriptCapitalR] \[GreaterEqual] 0 or Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1, we now use the property that we have 1 on the diagonal, \
so that the trace is ",
  StyleBox["k",
    FontSlant->"Italic"],
  ". (PM. The diagonal is 1 since the correlation of a variable with itself \
is 1.  It might suffice that the trace is ",
  StyleBox["k, ",
    FontSlant->"Italic"],
  "allowing other values on the diagonal, but we also want to take \
submatrices, so the only consistent overall appearance is 1 on the \
diagonal.)"
}], "Text"],

Cell[TextData[{
  "We can look at ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "= 2 and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " > 2. Since ",
  StyleBox["R ",
    FontWeight->"Bold"],
  "is a symmetric and positive semi-definite matrix, its determinant is given \
by the product of all its (nonnegative) eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_i\)]],
  ", while the sum of those is also given by the trace of the diagonal, i.e. \
the dimension, see Johnston (1972:105-109). Thus we have Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "... ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_k\)]],
  " while ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "+ ... + ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_i\)]],
  " \[GreaterEqual] 0. For singular ",
  StyleBox["R ",
    FontWeight->"Bold"],
  "we trivially have \[ScriptCapitalR] = 0. For regular ",
  StyleBox["R",
    FontWeight->"Bold"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 2 we trivially have 0 \[LessEqual] \[ScriptCapitalR] \[LessEqual] 1. \
Namely, for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 2, we know that the correlation ",
  StyleBox["r",
    FontSlant->"Italic"],
  " between two variables satisfies -1 \[LessEqual] ",
  StyleBox["r",
    FontSlant->"Italic"],
  " \[LessEqual] 1 and the determinant is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[{{1, \ r}, \ {r, \ 1}}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1 - r\^2\)], "Output"]
}, Open  ]],

Cell["\<\
Using the overall correlation destroys information about the direction of the \
correlation:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OverallCorrelation[{{1, \ r}, \ {r, \ 1}}, \ 
      Mode\  \[Rule] \ Det]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@r\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "At issue remains only regular ",
  StyleBox["R",
    FontWeight->"Bold"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " > 2. A step in the proof is that the maximal determinant is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_i\)]],
  " = \[Lambda] for all ",
  StyleBox["i",
    FontSlant->"Italic"],
  ". We might show this by calculus, maximizing \[ScriptCapitalR] subject to \
the given constraints, but it is simpler to assume that all eigenvalues are \
at their maximal value except for the first two. Then we get \
\[ScriptCapitalR]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^\(k - 2\)\)]],
  ". Since the sum is given, the difference between \[Lambda] and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "is reflected in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_2\)]],
  ", thus \[ScriptCapitalR]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "= (\[Lambda] - ",
  StyleBox["x",
    FontSlant->"Italic"],
  ") (\[Lambda] + ",
  StyleBox["x",
    FontSlant->"Italic"],
  ") ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^\(k - 2\)\)]],
  " = (",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  ") ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^\(k - 2\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^k\)]],
  " - ",
  StyleBox["X, ",
    FontSlant->"Italic"],
  "where ",
  StyleBox["X",
    FontSlant->"Italic"],
  " is a nonnegative amount. Thus the determinant is maximal when ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "= 0, and then all ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_i\)]],
  " = \[Lambda]. Then also ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = ",
  StyleBox["k",
    FontSlant->"Italic"],
  " \[Lambda], or \[Lambda] = 1, and \[ScriptCapitalR] = 1. This proof can be \
supported by a drawing in the 2D plane where 2 = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_2\)]],
  " and their product finds a maximum in  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_2\)]],
  " = 1, meaning that ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "= 0."
}], "Text"],

Cell[TextData[{
  "Hence, an option for overall correlation is to use ",
  StyleBox["R = ",
    FontSlant->"Italic"],
  "Sqrt[1 - Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "]]. Yet its usefulness must show in practice. PM 1. Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] is also used in tests on (multi-) collinearity (Farrar-Glauber). PM 2. \
Testing that all correlations are zero gives a test statistic - ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "Log[Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "]]. PM 3. It can also be mentioned that there are other measures for \
overall correlation, notably in the area of entropy. This however seems to \
lead too far from the correlation paradigm."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrices with theoretical values", "Subsection"],

Cell["\<\
In theoretical exercises one may be tempted to fill in arbitrary parameters \
that however violate some key assumptions. The following is an example when \
we assume arbitrary values and set one correlation to -1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rmat\  = \ {{1, a, \ b}, {a, 1, \ c}, \ \ {b, \ c, \ 1}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "a", "b"},
            {"a", "1", "c"},
            {"b", "c", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
In the standard definition, the overall correlation takes the maximum of the \
multiple correlation coefficients.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(oc\  = \ OverallCorrelation[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(Max(1 - \(\(-a\^2\) + 2\ b\ c\ a - b\^2 - c\^2 + 1\
\)\/\(1 - a\^2\), 1 - \(\(-a\^2\) + 2\ b\ c\ a - b\^2 - c\^2 + 1\)\/\(1 - \
b\^2\), 1 - \(\(-a\^2\) + 2\ b\ c\ a - b\^2 - c\^2 + 1\)\/\(1 - c\^2\))\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "Arbitrarily setting ",
  StyleBox["a",
    FontSlant->"Italic"],
  " to -1 generates error messages."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ a\  \[Rule] \ \(-1\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(TraditionalForm\\`1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Max::"nord"\), \(\(:\)\(\ \)\), "\<\"Invalid comparison with \
\\!\\(TraditionalForm\\`ComplexInfinity\\) attempted. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::nord\\\"]\\)\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`\@\(Max(1 - \(\(-b\^2\) - 2\ c\ b - c\^2\)\/\(1 - b\^2\
\), 1 - \(\(-b\^2\) - 2\ c\ b - c\^2\)\/\(1 - c\^2\), ComplexInfinity)\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "The point to note is that the correlations are mutually dependent. If we \
set ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "to -1 then this has consequences for ",
  StyleBox["b",
    FontSlant->"Italic"],
  " and ",
  StyleBox["c",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InequalitySolve[{\(-1\)\  \[LessEqual] \ b\  \[LessEqual] \ 
          1, \ \(-1\)\  \[LessEqual] \ c\  \[LessEqual] \ 1, \ 
        Det[rmat\  /. \ a\  \[Rule] \ \(-1\)]\  \[GreaterEqual] \ 0}, \ {b, \ 
        c}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-1\) \[LessEqual] b \[LessEqual] 1 \[And] 
      c \[LongEqual] \(-b\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(oc /. \ c\  \[Rule] \ \(-b\)\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(Max(\(-\(\(2\ b\^2\)\/\(a - 1\)\)\), \(a\^2 + 2\ b\
\^2\ a + b\^2\)\/\(1 - b\^2\))\)\)], "Output"]
}, Open  ]],

Cell["\<\
Only now it is proper to set a to its value, so that we \
don\[CloseCurlyQuote]t get error messages.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ a\  \[Rule] \ \(-1\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(Max(1, b\^2)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Working with theoretical matrices, the determinant approach is more robust, \
while the PSD condition is included in the condition that the outcome must \
between 0 and 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OverallCorrelation[rmat, \ Mode\  \[Rule] \ Det]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(a\^2 - 2\ b\ c\ a + b\^2 + c\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "PSD for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[TextData[{
  "The interdependence depends upon the PSD-ness of the matrix and less upon \
the data that are behind it. These data generate PSD-ness, but once it has \
been set, PSD-ness takes over control. The following gives a more general \
solution for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3. Consider the situation that 0 < ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "< 1 is the correlation of Y and Z and that a new variable X is introduced. \
Instead of arbitray numbers ",
  StyleBox["a, b ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["c",
    FontSlant->"Italic"],
  " we might prefer to express that we are using correlations that satisfy \
PSD-ness."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rmat\  = \ {{1, \ r\_\(x, y\), \ r\_\(x, z\)}, \ {r\_\(x, y\), \ 1, \ 
          r}, \ {r\_\(x, z\)\ , r, \ 1}}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(r\_\(x, y\)\), \(r\_\(x, z\)\)},
            {\(r\_\(x, y\)\), "1", "r"},
            {\(r\_\(x, z\)\), "r", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cond\  = \ {0\  < r\  < 1, \ 
        0\  \[LessEqual] \ r\_\(x, y\)\  \[LessEqual] \ 1, \ 
        0\  \[LessEqual] \ r\_\(x, z\) \[LessEqual] \ 1, \ 
        Det[rmat]\  \[GreaterEqual] \ 0}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0 < r < 1, 0 \[LessEqual] r\_\(x, y\) \[LessEqual] 1, 
      0 \[LessEqual] r\_\(x, z\) \[LessEqual] 
        1, \(-r\^2\) + 2\ r\_\(x, y\)\ r\_\(x, z\)\ r - r\_\(x, y\)\%2 - 
          r\_\(x, z\)\%2 + 1 \[GreaterEqual] 0}\)], "Output"]
}, Open  ]],

Cell["\<\
An overall solution can be found as follows (that apparently requires a trick \
of replacing variables). This generates a rather long expression so it is \
simpler to take a particular numerical example.\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(\(rul\  = \ {r\_\(x, y\)\ \  \[Rule] \ rxy, \ 
          r\_\(x, z\)\  \[Rule] \ rxz};\)\[IndentingNewLine]
    \(Solution[]\  = \ \(InequalitySolve[
              cond\  /. \ rul, \ {rxy, \ rxz, \ r}]\ \  /. \ 
            eluR[rul]\)\  /. \ \ Inequality[0, Less, r, Less, 1]\  \[Rule] \ 
            True;\)\)\)\)], "Input"],

Cell[BoxData[{
    \(\(rul\  = \ {r\_\(x, y\)\ \  \[Rule] \ rxy, \ 
          r\_\(x, z\)\  \[Rule] \ rxz};\)\), "\[IndentingNewLine]", 
    \(\(\(\(cond\  /. \ rul\)\  /. \ r\  \[Rule] \ 3/10\)\  /. \ \ eluR[
          rul];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(res\  = \ 
      InequalitySolve[%, \ {\ r\_\(x, y\), \ r\_\(x, z\)}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\((0 \[LessEqual] 
            r\_\(x, y\) \[LessEqual] \@91\/10 \[And] 
          0 \[LessEqual] 
            r\_\(x, z\) \[LessEqual] \(3\ r\_\(x, y\)\)\/10 + 
              1\/10\ \@91\ \@\(1 - r\_\(x, y\)\%2\))\) \[Or] \((\@91\/10 < 
            r\_\(x, y\) < 
            1 \[And] \(3\ r\_\(x, y\)\)\/10 - 
              1\/10\ \@91\ \@\(1 - r\_\(x, y\)\%2\) \[LessEqual] 
            r\_\(x, z\) \[LessEqual] \(3\ r\_\(x, y\)\)\/10 + 
              1\/10\ \@91\ \@\(1 - r\_\(x, y\)\%2\))\) \[Or] \((r\_\(x, y\) \
\[LongEqual] 1 \[And] r\_\(x, z\) \[LongEqual] 3\/10)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Setting to values e.g. ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["r",
            FontSlant->"Italic"], \(x, y\)], " "}]]],
  " = 90%"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(res\  /. \ r\_\(x, y\)\ \  \[Rule] \ 9/10\  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.` \[LessEqual] r\_\(x, z\) \[LessEqual] 
      0.6858124577258358`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical example: Klein I model", "Subsection"],

Cell["\<\
It can be useful to support this discussion with a numerical example of \
correlation in real data. The Klein I model is a good example, see Theil \
(1971:432). Data and regressions can be found at UCLA ATS (2007). \
\>", "Text"],

Cell[BoxData[
    \(\(lis = Partition[TextToMatrix["\<
1920 39.8 12.7 28.8 2.7 180.1 44.9 2.2 2.4 3.4
1921 41.9 12.4 25.5-0.2 182.8 45.6 2.7 3.9 7.7
1922 45.0 16.9 29.3 1.9 182.6 50.1 2.9 3.2 3.9
1923 49.2 18.4 34.1 5.2 184.5 57.2 2.9 2.8 4.7
1924 50.6 19.4 33.9 3.0 189.7 57.1 3.1 3.5 3.8
1925 52.6 20.1 35.4 5.1 192.7 61.0 3.2 3.3 5.5
1926 55.1 19.6 37.4 5.6 197.8 64.0 3.3 3.3 7.0
1927 56.2 19.8 37.9 4.2 203.4 64.4 3.6 4.0 6.7
1928 57.3 21.1 39.2 3.0 207.6 64.5 3.7 4.2 4.2
1929 57.8 21.7 41.3 5.1 210.6 67.0 4.0 4.1 4.0
1930 55.0 15.6 37.9 1.0 215.7 61.2 4.2 5.2 7.7
1931 50.9 11.4 34.5-3.4 216.7 53.4 4.8 5.9 7.5
1932 45.6 7.0 29.0-6.2 213.3 44.3 5.3 4.9 8.3
1933 46.5 11.2 28.5-5.1 207.1 45.1 5.6 3.7 5.4
1934 48.7 12.3 30.6-3.0 202.0 49.7 6.0 4.0 6.8
1935 51.3 14.0 33.2-1.3 199.0 54.4 6.1 4.4 7.2
1936 57.7 17.6 36.8 2.1 197.7 62.7 7.4 2.9 8.3
1937 58.7 17.3 41.0 2.0 199.8 65.0 6.7 4.3 6.7
1938 57.5 15.3 38.2-1.9 201.8 60.9 7.7 5.3 7.4
1939 61.6 19.0 41.6 1.3 199.9 69.5 7.8 6.6 8.9
1940 65.0 21.1 45.0 3.3 201.2 75.7 8.0 7.4 9.6
1941 69.7 23.5 53.3 4.9 204.5 88.4 8.5 13.8 11.6\>", \ Number], \ 
          10];\)\)], "Input",
  FontSize->9],

Cell[BoxData[
    \(\({year, \ \ cons, \ profit, \ wpriv, \ invest, \ \ klag, \ xprod, \ 
          wgov, \ govt, \ taxes}\  = \ Transpose[lis]\ ;\)\)], "Input"],

Cell["\<\
Currently, we just take the example of the regression of consumption on \
profits, lagged profits and the total wage sum (in the reference: table \
16.4). According to the references, the OLS estimate gives an R-Squared of \
0.9810. We can verify this as follows:\
\>", "Text"],

Cell[BoxData[
    \(\(dat\  = \ \({cons, \ profit, \ Lag[profit], \ 
              wpriv\  + \ wgov}\  // \ Transpose\)\  // \ Rest;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cm\  = \ CorrelationMatrix[dat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.0000000000000002`", "0.7153380578561573`", "0.6520495467386`",
               "0.9827033115478695`"},
            {"0.7153380578561573`", "1.0000000000000002`", 
              "0.7691278354514303`", "0.6341559947713056`"},
            {"0.6520495467386`", "0.7691278354514303`", "1.`", 
              "0.5793321650298436`"},
            {"0.9827033115478695`", "0.6341559947713056`", 
              "0.5793321650298436`", "1.0000000000000002`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The routine MultipleRSquared[",
  StyleBox["R",
    FontWeight->"Bold"],
  ", i] calculates RSquared[i] = 1 - \[ScriptCapitalR] / ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(i, \ i\)\)]],
  ". Taking ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "= 1 gives us the squared multiple correlation coefficient of the OLS \
regression of the first variable, consumption, on the other three variables \
including a constant. The value we get fits the one reported in the \
literature."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultipleRSquared[cm, \ 1]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9810081920648895`\)], "Output"]
}, Open  ]],

Cell["\<\
If we want to summarize the correlation matrix into one number, we might \
consider 1 - Det[cm]. Note that the following still is a squared value.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1\  - \ Det[cm]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9955217720928227`\)], "Output"]
}, Open  ]],

Cell["\<\
However, since we are more used to consider multiple correlations, we might \
better work with these. The routine OverallCorrelation[mat] has two options: \
Mode to select either Det or MultipleRSquared (default), and in the latter \
mode the option Function to select the function (default Max). Note that we \
now have a Sqrt[RSquared] outcome. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OverallCorrelation[cm]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9904585766526985`\)], "Output"]
}, Open  ]],

Cell["\<\
After this evaluation, the Results[...] allow us to identify the dependent \
variable in the multiple correlation that has been selected.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Results[OverallCorrelation]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Mode \[Rule] MultipleRSquared\), 
          ",", \(Function \[Rule] Max\), 
          ",", \(List \[Rule] {0.9810081920648895`, 0.7190329385834728`, 
              0.6271522600782691`, 0.9763135460665437`}\), 
          ",", \(Take \[Rule] 0.9810081920648895`\), ",", 
          RowBox[{"Position", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
          ",", \(Out \[Rule] 0.9904585766526985`\)}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix D: Other relations for the 2 \[Times] 2 case", "Section"],

Cell[CellGroupData[{

Cell[" An analytical stepping stone", "Subsection"],

Cell["\<\
The 2 \[Times] 2 case is a crucial stepping stone. One can arrive at various \
measures using different philosophies, test the adequacy, and if that test is \
passed, see whether it can be generalized. Sometimes different philosophies \
give the same result for the simplest case, which provides a base for \
agreement and a source for confusion. The following lists 5 approaches that \
generate the same correlation measure for the 2 \[Times] 2 contingency table, \
using different approaches. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. Just recall", "Subsection"],

Cell["\<\
This is just to recall that the 2 \[Times] 2 case is generated both by the \
Volume Ratio measure and Cramer\[CloseCurlyQuote]s V.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Epidemiology - pooled test", "Subsection"],

Cell[TextData[{
  "However, in epidemiology, the following approach is possible for the risk \
ratio or risk difference. Let ",
  Cell[BoxData[
      \(TraditionalForm\`p\_0\)]],
  " = ",
  StyleBox["a",
    FontSlant->"Italic"],
  " / (",
  StyleBox["a",
    FontSlant->"Italic"],
  " + ",
  StyleBox["c",
    FontSlant->"Italic"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`p\_1\)]],
  " = ",
  StyleBox["b",
    FontSlant->"Italic"],
  " / (",
  StyleBox["b",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["p ",
    FontSlant->"Italic"],
  "the pooled probability found in the sum column. Then a test statistic for \
",
  Cell[BoxData[
      \(TraditionalForm\`p\_0\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`p\_1\)]],
  " differs from the VolumeRatio measure only in ",
  Cell[BoxData[
      \(TraditionalForm\`\@N\)]],
  "with ",
  StyleBox["N ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["a + b + c + d",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(p0\  - \ p1\)\/\@\(p\ \((1\  - \ p)\)\ \((1\/\(a\ \  + \ \ c\)\  + \
\ 1\/\(b\  + \ d\))\)\)\  /. \ {p0\  \[Rule] \ a/\((a + c)\), \ 
          p1\ \  \[Rule] \ b/\((b + d)\), \ 
          p\  \[Rule] \ \((a + b)\)/\((a + b + c + d)\)}\ ;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[%, \ 
      Assumptions\  \[Rule] \ {a\  \[GreaterEqual] \ 0, \ 
          b\  \[GreaterEqual] \ 0, \ c\  \[GreaterEqual] \ 0, \ 
          d\  \[GreaterEqual] \ 0}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(a\ d - b\ c\)\/\@\(\(\((a + b)\)\ \((a + c)\)\ \((b \
+ d)\)\ \((c + d)\)\)\/\(a + b + c + d\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Epidemiology - Matthew and Mantel-Haenszel", "Subsection"],

Cell["\<\
The literature contains a reference to a Matthew 1975 measure of correlation \
for disease test matrices, which appears to be the same formula as the Volume \
Ratio measure and Cramer\[CloseCurlyQuote]s V. \
\>", "Text"],

Cell["\<\
The Mantel-Haenszel test (Kleinbaum et al. (2003:348)) also contains the \
determinant expression, a large sample approximation of Fisher\
\[CloseCurlyQuote]s exact test.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Assigning values {0, 1} or {-1, 1} or {i, j}", "Subsection"],

Cell[TextData[{
  "For a 2 \[Times] 2 table, we can assign values {0, 1} as in logic, see \
Colignatus (2007a), and then calculate the Pearson coefficient of correlation \
for real-valued data. In fact, let us assign arbitrary values {i, j}. It \
appears that all values drop out, as long as ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "\[NotEqual] ",
  StyleBox["j",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[CorrelationPr2By2[Definition, {{a, b}, {c, d}}, {i, j}], 
      Assumptions \[Rule] {Thread[{a, b, c, d} \[GreaterEqual] 
              0]}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\((a\ d - b\ c)\)\ \((i - j)\)\^2\)\/\@\(\((a + b)\)\
\ \((a + c)\)\ \((b + d)\)\ \((c + d)\)\ \((i - j)\)\^4\)\)], "Output"]
}, Open  ]],

Cell["\<\
(i) Originally, this author assigned the values {1, -1} rather than {1, 0} or \
True | False as in logic. A reason to avoid zero is that it might needlessly \
destroy information. A reason to use 1 versus -1 is that equal numbers of \
observations might be thought to balance each other, with an average outcome \
of zero. But above general rule shows that it does not matter.\
\>", "Text"],

Cell[TextData[{
  "(ii) The data points {1, 1}, {1, -1}, {-1, 1}, {-1, -1} generate ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "= {1, 1, -1, -1} and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = {1, -1, 1, -1} with frequencies {",
  StyleBox["a, c, b, d",
    FontSlant->"Italic"],
  "}.  Indeed, we might as well give ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "lists of {1, 1}, ",
  StyleBox["b ",
    FontSlant->"Italic"],
  "lists of {1, -1} etcetera."
}], "Text"],

Cell[TextData[{
  "(iii) Thus we get the normal correlation between ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "= {1, 1, -1, -1} and  ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = {1, -1, 1, -1}with frequencies {",
  StyleBox["a, c, b, d",
    FontSlant->"Italic"],
  "}."
}], "Text"],

Cell[TextData[{
  "(iv) Using formal parameters {",
  StyleBox["a, c, b, d",
    FontSlant->"Italic"],
  "} and simplification shows that the determinant is used in the numerator \
and the row sums and column sums in the denominator. The values 1 and -1 \
assigned to the nominal data do not occur any more."
}], "Text"],

Cell[TextData[{
  "It may be mentioned that it was this relation that caused the author to \
investigate the issue into the direction that resulted into the general \
measure suggested above. This case was generalized first to ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n, ",
    FontSlant->"Italic"],
  "then ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n, ",
    FontSlant->"Italic"],
  "then  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " \[Times] ... \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`n\_k\)]],
  ". The latter was done first for bordermatrices and then for the inner \
submatrices. Subsequently, PSD-ness and the comparison with the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " measure were included."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix E: An example in a higher dimension", "Section"],

Cell["\<\
The following shows an example of the Nominal Correlation measure in a higher \
dimension. The example shows that the algorithm is straightforward. It also \
indicates that, especially considering higher dimensions, a weighted average \
is a sensible choice.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat2\  = \ 
      Table[i\  + \ 10\ j\  + \ 100\ k\  + \ 1000\ m, \ {i, \ 2}, \ {j, \ 
          3}, \ {k, \ 4}, \ {m, \ 2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1111", "2111"},
                    {"1211", "2211"},
                    {"1311", "2311"},
                    {"1411", "2411"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1121", "2121"},
                    {"1221", "2221"},
                    {"1321", "2321"},
                    {"1421", "2421"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1131", "2131"},
                    {"1231", "2231"},
                    {"1331", "2331"},
                    {"1431", "2431"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1112", "2112"},
                    {"1212", "2212"},
                    {"1312", "2312"},
                    {"1412", "2412"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1122", "2122"},
                    {"1222", "2222"},
                    {"1322", "2322"},
                    {"1422", "2422"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1132", "2132"},
                    {"1232", "2232"},
                    {"1332", "2332"},
                    {"1432", "2432"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is the border matrix for dimension 3 and 4 (that should have sizes ",
  StyleBox["m",
    FontSlant->"Italic"],
  " = ",
  "4 and ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "=",
  " 2)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BorderMatrix[mat2, \ {3, \ 4}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"6729", "12729"},
            {"7329", "13329"},
            {"7929", "13929"},
            {"8529", "14529"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
These are the 4 by 2 submatrices used in the summation of the border \
matrix.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TabledBorderMatrix[mat2, \ {3, \ 4}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"Mat", "(", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1111", "2111"},
                      {"1211", "2211"},
                      {"1311", "2311"},
                      {"1411", "2411"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], ")"}], 
              RowBox[{"Mat", "(", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1121", "2121"},
                      {"1221", "2221"},
                      {"1321", "2321"},
                      {"1421", "2421"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], ")"}]},
            {
              RowBox[{"Mat", "(", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1131", "2131"},
                      {"1231", "2231"},
                      {"1331", "2331"},
                      {"1431", "2431"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], ")"}], 
              RowBox[{"Mat", "(", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1112", "2112"},
                      {"1212", "2212"},
                      {"1312", "2312"},
                      {"1412", "2412"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], ")"}]},
            {
              RowBox[{"Mat", "(", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1122", "2122"},
                      {"1222", "2222"},
                      {"1322", "2322"},
                      {"1422", "2422"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], ")"}], 
              RowBox[{"Mat", "(", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1132", "2132"},
                      {"1232", "2232"},
                      {"1332", "2332"},
                      {"1432", "2432"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], ")"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["Check that it fits.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((%\  // \ Add)\)\  /. \ Mat\  \[Rule] \ Identity\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"6729", "12729"},
            {"7329", "13329"},
            {"7929", "13929"},
            {"8529", "14529"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["These are all the submatrices.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VolumeRatioMatrix[mat2, \ BordersOrAll\  \[Rule] \ Show]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "1121", "1131"},
                                {"1112", "1122", "1132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2111", "2121", "2131"},
                                {"2112", "2122", "2132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1211", "1221", "1231"},
                                {"1212", "1222", "1232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2211", "2221", "2231"},
                                {"2212", "2222", "2232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1311", "1321", "1331"},
                                {"1312", "1322", "1332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2311", "2321", "2331"},
                                {"2312", "2322", "2332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1411", "1421", "1431"},
                                {"1412", "1422", "1432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2411", "2421", "2431"},
                                {"2412", "2422", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "1211", "1311", "1411"},
                                {"1112", "1212", "1312", "1412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2111", "2211", "2311", "2411"},
                                {"2112", "2212", "2312", "2412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1121", "1221", "1321", "1421"},
                                {"1122", "1222", "1322", "1422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2121", "2221", "2321", "2421"},
                                {"2122", "2222", "2322", "2422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1131", "1231", "1331", "1431"},
                                {"1132", "1232", "1332", "1432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2131", "2231", "2331", "2431"},
                                {"2132", "2232", "2332", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "2111"},
                                {"1112", "2112"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1211", "2211"},
                                {"1212", "2212"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1311", "2311"},
                                {"1312", "2312"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1411", "2411"},
                                {"1412", "2412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1121", "2121"},
                                {"1122", "2122"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1221", "2221"},
                                {"1222", "2222"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1321", "2321"},
                                {"1322", "2322"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1421", "2421"},
                                {"1422", "2422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1131", "2131"},
                                {"1132", "2132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1231", "2231"},
                                {"1232", "2232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1331", "2331"},
                                {"1332", "2332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1431", "2431"},
                                {"1432", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}]},
            {
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "1121", "1131"},
                                {"1112", "1122", "1132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2111", "2121", "2131"},
                                {"2112", "2122", "2132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1211", "1221", "1231"},
                                {"1212", "1222", "1232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2211", "2221", "2231"},
                                {"2212", "2222", "2232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1311", "1321", "1331"},
                                {"1312", "1322", "1332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2311", "2321", "2331"},
                                {"2312", "2322", "2332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1411", "1421", "1431"},
                                {"1412", "1422", "1432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2411", "2421", "2431"},
                                {"2412", "2422", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              "1", 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "1211", "1311", "1411"},
                                {"1121", "1221", "1321", "1421"},
                                {"1131", "1231", "1331", "1431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2111", "2211", "2311", "2411"},
                                {"2121", "2221", "2321", "2421"},
                                {"2131", "2231", "2331", "2431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1112", "1212", "1312", "1412"},
                                {"1122", "1222", "1322", "1422"},
                                {"1132", "1232", "1332", "1432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2112", "2212", "2312", "2412"},
                                {"2122", "2222", "2322", "2422"},
                                {"2132", "2232", "2332", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "2111"},
                                {"1121", "2121"},
                                {"1131", "2131"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1211", "2211"},
                                {"1221", "2221"},
                                {"1231", "2231"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1311", "2311"},
                                {"1321", "2321"},
                                {"1331", "2331"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1411", "2411"},
                                {"1421", "2421"},
                                {"1431", "2431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1112", "2112"},
                                {"1122", "2122"},
                                {"1132", "2132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1212", "2212"},
                                {"1222", "2222"},
                                {"1232", "2232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1312", "2312"},
                                {"1322", "2322"},
                                {"1332", "2332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1412", "2412"},
                                {"1422", "2422"},
                                {"1432", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}]},
            {
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "1211", "1311", "1411"},
                                {"1112", "1212", "1312", "1412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2111", "2211", "2311", "2411"},
                                {"2112", "2212", "2312", "2412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1121", "1221", "1321", "1421"},
                                {"1122", "1222", "1322", "1422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2121", "2221", "2321", "2421"},
                                {"2122", "2222", "2322", "2422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1131", "1231", "1331", "1431"},
                                {"1132", "1232", "1332", "1432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2131", "2231", "2331", "2431"},
                                {"2132", "2232", "2332", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "1211", "1311", "1411"},
                                {"1121", "1221", "1321", "1421"},
                                {"1131", "1231", "1331", "1431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2111", "2211", "2311", "2411"},
                                {"2121", "2221", "2321", "2421"},
                                {"2131", "2231", "2331", "2431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1112", "1212", "1312", "1412"},
                                {"1122", "1222", "1322", "1422"},
                                {"1132", "1232", "1332", "1432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"2112", "2212", "2312", "2412"},
                                {"2122", "2222", "2322", "2422"},
                                {"2132", "2232", "2332", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              "1", 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "2111"},
                                {"1211", "2211"},
                                {"1311", "2311"},
                                {"1411", "2411"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1121", "2121"},
                                {"1221", "2221"},
                                {"1321", "2321"},
                                {"1421", "2421"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1131", "2131"},
                                {"1231", "2231"},
                                {"1331", "2331"},
                                {"1431", "2431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1112", "2112"},
                                {"1212", "2212"},
                                {"1312", "2312"},
                                {"1412", "2412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1122", "2122"},
                                {"1222", "2222"},
                                {"1322", "2322"},
                                {"1422", "2422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1132", "2132"},
                                {"1232", "2232"},
                                {"1332", "2332"},
                                {"1432", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}]},
            {
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "2111"},
                                {"1112", "2112"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1211", "2211"},
                                {"1212", "2212"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1311", "2311"},
                                {"1312", "2312"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1411", "2411"},
                                {"1412", "2412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1121", "2121"},
                                {"1122", "2122"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1221", "2221"},
                                {"1222", "2222"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1321", "2321"},
                                {"1322", "2322"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1421", "2421"},
                                {"1422", "2422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1131", "2131"},
                                {"1132", "2132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1231", "2231"},
                                {"1232", "2232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1331", "2331"},
                                {"1332", "2332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1431", "2431"},
                                {"1432", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "2111"},
                                {"1121", "2121"},
                                {"1131", "2131"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1211", "2211"},
                                {"1221", "2221"},
                                {"1231", "2231"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1311", "2311"},
                                {"1321", "2321"},
                                {"1331", "2331"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1411", "2411"},
                                {"1421", "2421"},
                                {"1431", "2431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1112", "2112"},
                                {"1122", "2122"},
                                {"1132", "2132"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1212", "2212"},
                                {"1222", "2222"},
                                {"1232", "2232"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1312", "2312"},
                                {"1322", "2322"},
                                {"1332", "2332"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1412", "2412"},
                                {"1422", "2422"},
                                {"1432", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"\<\"Add\"\>", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1111", "2111"},
                                {"1211", "2211"},
                                {"1311", "2311"},
                                {"1411", "2411"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1121", "2121"},
                                {"1221", "2221"},
                                {"1321", "2321"},
                                {"1421", "2421"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1131", "2131"},
                                {"1231", "2231"},
                                {"1331", "2331"},
                                {"1431", "2431"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1112", "2112"},
                                {"1212", "2212"},
                                {"1312", "2312"},
                                {"1412", "2412"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]},
                      {
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1122", "2122"},
                                {"1222", "2222"},
                                {"1322", "2322"},
                                {"1422", "2422"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}], 
                        RowBox[{"\<\"VR\"\>", "[", 
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"1132", "2132"},
                                {"1232", "2232"},
                                {"1332", "2332"},
                                {"1432", "2432"}
                                },
                              RowSpacings->1,
                              ColumnSpacings->1,
                              ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                          "]"}]}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[mat2]\  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1.`", \(-1.4218632985979396`*^-6\), \(-0.00001944910712241935`\
\), \(-0.00008345149439101066`\)},
            {\(-1.4218632985979396`*^-6\), "1.`", 
              "0.`", \(-0.0013627428571016994`\)},
            {\(-0.00001944910712241935`\), "0.`", 
              "1.`", \(-0.018629653215884834`\)},
            {\(-0.00008345149439101066`\), \(-0.0013627428571016994`\), \
\(-0.018629653215884834`\), "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
And the total measure of association can be applied again to this correlation \
matrix.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OverallCorrelation[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.018679616487511257`\)], "Output"]
}, Open  ]],

Cell["Or directly:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[mat2]\  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.018679616487514226`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix F: A note on the Frobenius theorems", "Section"],

Cell["\<\
These are just some notes, reflecting an angle for future prospection.\
\>", "Text"],

Cell[TextData[{
  "A contingency matrix is a nonnegative matrix, so that the Frobenius \
theorems apply. It is not quite clear how the eigenvectors come into play. \
There might be a relation here. The Frobenius eigenvalue \[Lambda] \
\[GreaterEqual] 0 is a real value that is at least as large as the absolute \
value of any other (possibly complex) eigenvalue. (Takayama (1974: 375)). \
Thus det(",
  StyleBox["A",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "... ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  " \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^n\)]],
  " and thus, if \[Lambda] > 0 (which is definitely the case when ",
  StyleBox["A",
    FontSlant->"Italic"],
  " is indecomposable) then the implied Frobenius ratio measure is \
FrobRatio(",
  StyleBox["A",
    FontSlant->"Italic"],
  ") = det(",
  StyleBox["A",
    FontSlant->"Italic"],
  ")",
  StyleBox[" / ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^n\)]],
  " \[LessEqual] 1. It is not clear however how this relates to the notion of \
the volume ratio."
}], "Text"],

Cell[TextData[{
  "With square matrix ",
  StyleBox["A",
    FontSlant->"Italic"],
  ", if ",
  StyleBox["A x",
    FontSlant->"Italic"],
  " = \[Lambda] ",
  StyleBox["x",
    FontSlant->"Italic"],
  " for vector ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "\[NotEqual] 0 ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "and scalar \[Lambda], then we say that \[Lambda] is an eigenvalue and ",
  StyleBox["x",
    FontSlant->"Italic"],
  " its eigenvector. Let ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["A ",
    FontSlant->"Italic"],
  "1 the row sums and ",
  StyleBox["c = ",
    FontSlant->"Italic"],
  " 1' ",
  StyleBox["A ",
    FontSlant->"Italic"],
  "the column sums. Then 1' ",
  StyleBox["A x",
    FontSlant->"Italic"],
  " = \[Lambda] 1' ",
  StyleBox["x",
    FontSlant->"Italic"],
  " or \[Lambda] = ",
  StyleBox["c",
    FontSlant->"Italic"],
  "'",
  StyleBox["x ",
    FontSlant->"Italic"],
  "/ 1'",
  StyleBox["x = ",
    FontSlant->"Italic"],
  StyleBox["c'x",
    FontSlant->"Italic"],
  "*",
  StyleBox[", ",
    FontSlant->"Italic"],
  "when 1' ",
  StyleBox["x",
    FontSlant->"Italic"],
  " \[NotEqual] 0, and ",
  StyleBox["x",
    FontSlant->"Italic"],
  "* = ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "/ 1'",
  StyleBox["x ",
    FontSlant->"Italic"],
  "a normalized vector. Since ",
  StyleBox["A",
    FontSlant->"Italic"],
  " and ",
  StyleBox["A",
    FontSlant->"Italic"],
  "' have the same eigenvalues, there is also a ",
  StyleBox["y' A",
    FontSlant->"Italic"],
  " = \[Lambda] ",
  StyleBox["y",
    FontSlant->"Italic"],
  "' or \[Lambda] = ",
  StyleBox["y",
    FontSlant->"Italic"],
  "'",
  StyleBox["r ",
    FontSlant->"Italic"],
  "/ ",
  StyleBox["y",
    FontSlant->"Italic"],
  "' 1. When ",
  StyleBox["x \[NotEqual] ",
    FontSlant->"Italic"],
  " 0 (everywhere) and in particular ",
  StyleBox["x",
    FontSlant->"Italic"],
  " > 0 then there is also the possibility of a change in dimensions such \
that ",
  Cell[BoxData[
      \(TraditionalForm\`D\^\(-1\)\)]],
  "= diag(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") and B = D A ",
  Cell[BoxData[
      \(TraditionalForm\`D\^\(-1\)\)]],
  " such that B 1 = \[Lambda] 1."
}], "Text"],

Cell[TextData[{
  "In general det(",
  StyleBox["A",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "... ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  ". Collecting all eigenvalues on the diagonal in \[CapitalLambda], zero \
everywhere else, and all eigenvectors in ",
  StyleBox["X ",
    FontSlant->"Italic"],
  "(also using spanning vectors for higher multiplicity) then ",
  StyleBox["A X ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["X",
    FontSlant->"Italic"],
  " \[CapitalLambda]. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix G: On inference and causality", "Section"],

Cell["\<\
This discussion originated from considering the links between logic \
(Colignatus (2007a)) and causality (Pearl (2000)). Suppose that rain is a \
cause and wetness of streets is an effect. Is the observation that the \
streets are wet a good predictor of what was the cause ?\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"mat", " ", "=", " ", GridBox[{
            {"\"\<Observation count\>\"", "\"\<It rains\>\"", 
              "\"\<It doesn't rain\>\"", "\"\<Total\>\""},
            {"\"\<The streets are wet\>\"", "25", "3", "\[Placeholder]"},
            {"\"\<The streets are not wet\>\"", "0", "\[Placeholder]", 
              "\[Placeholder]"},
            {"\"\<Total\>\"", "\[Placeholder]", "\[Placeholder]", "100"}
            }]}], "  ", ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat = \ Headed2DTableSolve[mat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Observation count\"\>", "\<\"It rains\"\>", "\<\"It doesn't \
rain\"\>", "\<\"Total\"\>"},
            {"\<\"The streets are wet\"\>", "25", "3", "28"},
            {"\<\"The streets are not wet\"\>", "0", "72", "72"},
            {"\<\"Total\"\>", "25", "75", "100"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Instead of remembering all these 100 cases either individually or by \
frequency distribution, the memory processing unit might save on storage and \
retrieval costs by adopting a general rule (induction) that \
\[OpenCurlyDoubleQuote]If it rains then the streets are wet\
\[CloseCurlyDoubleQuote]. This can become a general rule for which we can use \
a truthtable. The truthtable tests the condition whether the frequency is \
zero or non-zero, with entries True or False in the table.\
\>", "Text"],

Cell["\<\
In the course of considering these issues, the author noted that the common \
notion \[OpenCurlyDoubleQuote]correlation doesn\[CloseCurlyQuote]t mean \
causation\[CloseCurlyDoubleQuote] has little use for such nominal data - \
since there is no standard measure of correlation. But now there is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CorrelationPr2By2[Take[mat, \ \(-3\), \ \(-3\)]]\  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9258200997725514`\)], "Output"]
}, Open  ]],

Cell["\<\
Given this measure of correlation, we must say (and we can do it now, with \
some relief that we can do so) that the normal caveats apply, i.e. that \
correlation is no causation, and that correlation itself doesn\
\[CloseCurlyQuote]t say much about the actual model.\
\>", "Text"],

Cell[TextData[{
  "PM 1. The author may now continue considering the links between logic and \
causality. His hypothesis is that causality cannot be inferred from common \
statistics and has to do with the model and the order of calculation (time\
\[CloseCurlyQuote]s arrow). In logic, there is a difference between \
implication \[Implies] and inference \[RightTee]. In causal models, there is \
a difference between equality \[Equal] and assignment = (using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s notation; other notations use = for equality and := for assignment). \
What causality is in Nature, inference is in the Mind. The overall umbrella \
would be the difference between statics and dynamics. "
}], "Text"],

Cell[TextData[{
  "PM 2. A result of this continued work is Colignatus (2007f). A useful link \
there is that if ",
  StyleBox["s",
    FontSlant->"Italic"],
  " is the marginal probability of a success, ",
  StyleBox["c",
    FontSlant->"Italic"],
  " the marginal probability of the cause, ",
  StyleBox["R",
    FontSlant->"Italic"],
  " the risk of a success (e.g. death) and ",
  StyleBox["B",
    FontSlant->"Italic"],
  " background risk, then ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["R c ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["B ",
    FontSlant->"Italic"],
  "(1 - ",
  StyleBox["c",
    FontSlant->"Italic"],
  ") = ",
  StyleBox["B ",
    FontSlant->"Italic"],
  "+",
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  StyleBox["R - B",
    FontSlant->"Italic"],
  ") ",
  StyleBox["c, ",
    FontSlant->"Italic"],
  "where ",
  StyleBox["B",
    FontSlant->"Italic"],
  " can be seen as the constant in a regression and ",
  StyleBox["R - B ",
    FontSlant->"Italic"],
  "gives the regression coefficient for the cause. But ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "would also be a conditional probability P[",
  StyleBox["S, C",
    FontSlant->"Italic"],
  "] / P[",
  StyleBox["C",
    FontSlant->"Italic"],
  "]. This might be a paradigmatic example that conditional probabilities \
could be seen as regression coefficients (or differences of them)."
}], "Text"],

Cell[TextData[{
  "As said, the pairwise correlations of nominal variables are based upon the \
volume ratio measure, which is based upon using ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rho]\_\(x, y\)\)\(\ \)\)\^2\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(y, x\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(x, \ y\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\_\(i, j\)\)\(\ \)\)\^2\)]],
  " / (",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(\(i\)\(+\)\)\)]],
  "). Possibly, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(yi, xj\)\)]],
  " should not be defined as the conditional probability P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "] but thus rather as P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]  - P[",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "| Not[",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "]], like above paradigmatic example. This kind of regression coefficient \
keeps the total",
  StyleBox[" N",
    FontSlant->"Italic"],
  " constant. However, as it looks now, the use of the determinant on the \
normalized matrix is sufficient to handle that overall condition. The \
definition of the coefficients for the categories would depend upon the use \
that one would make of those categories."
}], "Text"],

Cell[TextData[{
  "PM 3. ",
  StyleBox["Appendix K",
    FontWeight->"Bold"],
  " on the variances below discusses the variances of the variables. This \
differs from the variances of a category, say column ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " in a ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "contingency matrix. We have no need for these variances since we used the \
conditional probabilities to directly move to correlation. Only if one would \
use a different approach then the selection of such variance could enter the \
discussion."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Appendix H: Positive semidefiniteness for nominal correlation\
\>", "Section"],

Cell[CellGroupData[{

Cell["On the sign", "Subsection"],

Cell["\<\
This appendix uses no signs for the associations and correlations, to \
eliminate a possible arbitrariness from the implementation of its \
determination. For now, we simulate only 2 \[Times] 2 \[Times] 2 matrices so \
that the sign would be unambiguous, but it is useful to mention the issue \
here for the case of larger sizes. Note though that disregarding the sign may \
also negatively affect the results.\
\>", "Text"],

Cell[BoxData[
    \(\(SetOptions[PairwiseSign, \ ForceSign\  \[Rule] \ 1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["In general", "Subsection"],

Cell[TextData[{
  StyleBox["Appendix C",
    FontWeight->"Bold"],
  " discussed positive semidefiniteness (PSD) in the context of real data. \
For nominal data and the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "contingency table we have allowed pairwise correlations -1 \[LessEqual] ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1, where the negative values arise from the order of presentation. The \
square matrix however is less general and hence we proceed with the more \
general case. For the more general ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "case, we take the measure of pairwise nominal correlation ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "as the square root of an expression of squares, neglect the sign, thus \
with 0 \[LessEqual] ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1. For the most general case of ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "dimensions, the matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  " is created from these pairwise correlations, thus with 0 \[LessEqual] ",
  StyleBox["R",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1.1'. This matrix is only an \[OpenCurlyDoubleQuote]association matrix\
\[CloseCurlyDoubleQuote] since we don\[CloseCurlyQuote]t know yet that the \
overall correlation is in the proper range between 0 and 1. For proper \
overall correlation we require that 0 \[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. This can be translated into the equivalent condition of \
positive semidefiniteness (PSD), i.e. that for any ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "\[NotEqual] 0 that ",
  StyleBox["x'.",
    FontSlant->"Italic"],
  StyleBox["R",
    FontWeight->"Bold"],
  StyleBox[".x",
    FontSlant->"Italic"],
  " \[GreaterEqual] 0. Outcomes outside of those ranges however cannot yet be \
excluded on a priori grounds. Thus let us see what we can say about that \
analytically."
}], "Text"],

Cell[TextData[{
  "Note the issue of terminology. We collected the outcomes of the pairwise \
\[OpenCurlyDoubleQuote]nominal correlations\[CloseCurlyDoubleQuote] into ",
  StyleBox["R",
    FontWeight->"Bold"],
  ", call it an \[OpenCurlyDoubleQuote]assocation matrix\
\[CloseCurlyDoubleQuote] and ",
  "sometimes call it a \[OpenCurlyDoubleQuote]correlation matrix\
\[CloseCurlyDoubleQuote]. We can only do the latter for the cases when 0 \
\[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. The key questions are: (a) is this always the case, (b) \
is this mostly the case, (c) or are these situations infrequent, (d) and what \
to do when it is not true ? One example question to ask: with VR[",
  StyleBox["x, y",
    FontSlant->"Italic"],
  "] the volume ratio between ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", how does VR[",
  StyleBox["x, y",
    FontSlant->"Italic"],
  "] and VR[",
  StyleBox["x, z",
    FontSlant->"Italic"],
  "] affect VR[",
  StyleBox["y, z",
    FontSlant->"Italic"],
  "] ? Given the definitions of the volume ratios there is some reason to \
expect that this works ",
  StyleBox["like",
    FontSlant->"Italic"],
  " correlations in ",
  StyleBox["many ",
    FontSlant->"Italic"],
  "cases. Yet, is there some proof that a matrix that is constructed in this \
manner is a PSD matrix ? The key questions thus might be translated as: (i) \
in what cases are symmetry, 0 \[LessEqual] ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1 and diagonal 1 sufficient for PSD, and (ii) does the Volume Ratio \
measure fall in that category ?"
}], "Text"],

Cell["\<\
Below we consider the issue formally, symbolically and by simulation. The \
first two approaches fail, given the capacities of this author, but the third \
one gives some clarity. PSD-ness tends to be assured when we take border \
matrices only and fails in 10% of the cases when we use the method of \
averaging results from inner matrices. The simulation also produced examples \
that can further be investigated in detail.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formally", "Subsection"],

Cell[TextData[{
  "For ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "= 2 we have ",
  StyleBox["R",
    FontWeight->"Bold"],
  " = {{1, ",
  StyleBox["r",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["r",
    FontSlant->"Italic"],
  ", 1}} and we know that this is PSD when 0 \[LessEqual] ",
  StyleBox["r",
    FontSlant->"Italic"],
  " \[LessEqual] 1. "
}], "Text"],

Cell[TextData[{
  "To extend ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "= 2 to higher dimensions: let ",
  StyleBox["R",
    FontWeight->"Bold"],
  " hold for ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "variables, and let ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "be the correlation vector of some ",
  StyleBox["k",
    FontSlant->"Italic"],
  "+1st variable with the other ",
  StyleBox["k. ",
    FontSlant->"Italic"],
  "The new ",
  StyleBox["R",
    FontWeight->"Bold"],
  "* is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"1", ",", 
              StyleBox[\(r'\),
                FontSlant->"Italic"]}], 
            StyleBox["}",
              FontSlant->"Italic"]}], ",", 
          RowBox[{"{", 
            RowBox[{
              StyleBox["r",
                FontSlant->"Italic"], ",", "R"}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", 
              SuperscriptBox["r", "\[Prime]",
                MultilineFunction->None]},
            {"r", "R"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "We only know 0 \[LessEqual] ",
  StyleBox["r",
    FontSlant->"Italic"],
  " \[LessEqual] 1, call this \[OpenCurlyDoubleQuote]correlation\
\[CloseCurlyDoubleQuote], but this will only be true iff 0 \[LessEqual] \
Det[",
  StyleBox["R*",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. A determinant of matrix ",
  StyleBox["A",
    FontSlant->"Italic"],
  " can be decomposed in that of its submatrices as Det[",
  StyleBox["A",
    FontSlant->"Italic"],
  "] = Det[",
  Cell[BoxData[
      \(TraditionalForm\`A\_22\)]],
  "] Det[",
  Cell[BoxData[
      \(TraditionalForm\`A\_11\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`A\_12\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`A\_22\^\(-1\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`A\_21\)]],
  "] if the inverse exists. "
}], "Text"],

Cell[TextData[{
  "(a) When ",
  StyleBox["R",
    FontWeight->"Bold"],
  " is not regular then the sufficient and necessary condition for PSD-ness \
of ",
  StyleBox["R*",
    FontWeight->"Bold"],
  " is 0 \[LessEqual] Det[",
  StyleBox["R ",
    FontWeight->"Bold"],
  "- ",
  StyleBox["r.r",
    FontSlant->"Italic"],
  "'",
  "] \[LessEqual] 1. Here the problem is on the left hand side, since ",
  StyleBox["R ",
    FontWeight->"Bold"],
  "- ",
  StyleBox["r.r",
    FontSlant->"Italic"],
  " need not be PSD. "
}], "Text"],

Cell[TextData[{
  "(b) When ",
  StyleBox["R",
    FontWeight->"Bold"],
  " is regular and thus PD then the sufficient and necessary condition for \
PSD-ness of ",
  StyleBox["R*",
    FontWeight->"Bold"],
  " is  0\[LessEqual] (",
  StyleBox["r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r",
    FontSlant->"Italic"],
  ") \[LessEqual] 1. "
}], "Text"],

Cell[TextData[{
  "Note that we can find this result also from the definition of multiple \
correlation: ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_i\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\((R\^2)\)\_\(i  .2,  .. , k\)\)]],
  " = 1 - \[ScriptCapitalR] / ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(i, \ i\)\)]],
  ". Applying this to the larger matrix, \[ScriptCapitalR] = Det[",
  StyleBox["R*",
    FontWeight->"Bold"],
  "] and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_\(1, \ 1\)\)]],
  " = Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "], thus we have (0 \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "\[LessEqual] 1) \[DoubleLeftRightArrow] (0 \[LessEqual]  1 - Det[",
  StyleBox["R*",
    FontWeight->"Bold"],
  "]  / Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1) \[DoubleLeftRightArrow] (0 \[LessEqual]  1 - Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] (1 - ",
  StyleBox["r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r",
    FontSlant->"Italic"],
  ") / Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1) \[DoubleLeftRightArrow]  (0\[LessEqual]  ",
  StyleBox["r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r",
    FontSlant->"Italic"],
  " \[LessEqual] 1) again."
}], "Text"],

Cell[TextData[{
  "The left hand side holds since ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " is also PD. It is not easy to satisfy the right hand side. The following \
gives a sufficient case but that may not be interesting. The row sums are ",
  StyleBox["s",
    FontSlant->"Italic"],
  " = ",
  StyleBox["R",
    FontWeight->"Bold"],
  " 1 = ",
  StyleBox["R",
    FontWeight->"Bold"],
  "' 1. Denote \[Mu] = Max[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] so that actually 0 \[LessEqual]  ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "\[Mu]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1 and this becomes 0 \[LessEqual] ",
  StyleBox["R ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "\[Mu]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1. Premultiplication with 1' gives  0 \[LessEqual] ",
  StyleBox["s",
    FontSlant->"Italic"],
  "'",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "\[Mu]",
  StyleBox[" k",
    FontSlant->"Italic"],
  " ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "or",
  StyleBox[" ",
    FontSlant->"Italic"],
  " 0 \[LessEqual] \[Sigma]",
  StyleBox[" / ",
    FontSlant->"Italic"],
  "\[Mu]",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1. Thus a sufficient condition for (",
  StyleBox["r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r",
    FontSlant->"Italic"],
  ") \[LessEqual] 1 is that ",
  StyleBox["r",
    FontSlant->"Italic"],
  " \[LessEqual] \[Sigma] / \[Mu] =  ",
  StyleBox["R",
    FontWeight->"Bold"],
  " 1 / (",
  StyleBox["k ",
    FontSlant->"Italic"],
  "Max[",
  StyleBox["r",
    FontSlant->"Italic"],
  "]). Thus if ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is about the the row averages then the result will be PSD. This case is \
not too interesting. ",
  "(PM. Suppose that ",
  StyleBox["R v = r",
    FontSlant->"Italic"],
  ", or ",
  StyleBox["v",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " ",
  StyleBox["r. ",
    FontSlant->"Italic"],
  "We are tempted to premultiply 0 \[LessEqual] ",
  StyleBox["R ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "\[Mu]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1 with ",
  StyleBox["v ",
    FontSlant->"Italic"],
  "but cannot do so since we don\[CloseCurlyQuote]t know its signs.)"
}], "Text"],

Cell["Presently, there seems little scope to extend on this.", "Text"],

Cell[CellGroupData[{

Cell["PM. Additional notes", "Subsubsection"],

Cell["\<\
The following are some notes on additional derivations that show no \
additional results, and it might be useful for others to see this in order to \
avoid them.\
\>", "Text"],

Cell[TextData[{
  "When we use scalar ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and vector ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "then PSD requires",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ 2 ",
  StyleBox["x",
    FontSlant->"Italic"],
  " ",
  StyleBox["r'.y ",
    FontSlant->"Italic"],
  "+",
  StyleBox[" y'.R.y ",
    FontSlant->"Italic"],
  "\[GreaterEqual] 0 with normalization ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ ",
  StyleBox["y'.y",
    FontSlant->"Italic"],
  " = 1. Using alternative normalized vector {1, ",
  StyleBox["y",
    FontSlant->"Italic"],
  "}, the condition for ",
  StyleBox["R* ",
    FontWeight->"Bold"],
  "is that for any ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "\[NotEqual] 0 that 1 + 2 ",
  StyleBox["r'.y",
    FontSlant->"Italic"],
  " + ",
  StyleBox["y'.",
    FontSlant->"Italic"],
  StyleBox["R",
    FontWeight->"Bold"],
  StyleBox[".y",
    FontSlant->"Italic"],
  " \[GreaterEqual] 0. This does not seem to lead far."
}], "Text"],

Cell[TextData[{
  "For a general proof we might use the decomposition of a PD matrix ",
  StyleBox["R",
    FontWeight->"Bold"],
  " ",
  StyleBox["= P'P",
    FontSlant->"Italic"],
  ". ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "For ",
  StyleBox["R*",
    FontWeight->"Bold"],
  " we get:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold"], "*"], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", 
                  RowBox[{
                    StyleBox["r",
                      FontSlant->"Italic"], "'"}]},
                {
                  StyleBox["r",
                    FontSlant->"Italic"], 
                  StyleBox["R",
                    FontWeight->"Bold"]}
                }], ")"}], " ", "=", "  ", 
          RowBox[{\(Q' . Q\), " ", "=", " ", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {
                      StyleBox["a",
                        FontSlant->"Italic"], 
                      StyleBox[\(b'\),
                        FontSlant->"Italic"]},
                    {
                      StyleBox["c",
                        FontSlant->"Italic"], \(S'\)}
                    }], ")"}], " ", 
              RowBox[{"(", GridBox[{
                    {
                      StyleBox["a",
                        FontSlant->"Italic"], 
                      StyleBox[\(c'\),
                        FontSlant->"Italic"]},
                    {
                      StyleBox["b",
                        FontSlant->"Italic"], "S"}
                    }], ")"}], " "}]}]}]}]]],
  " = ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {
              RowBox[{\(a\^2\), " ", "+", " ", 
                RowBox[{
                  StyleBox[\(b'\),
                    FontSlant->"Italic"], 
                  StyleBox["b",
                    FontSlant->"Italic"], " "}]}], 
              RowBox[{
                StyleBox[\(a\ c'\),
                  FontSlant->"Italic"], " ", "+", "  ", 
                RowBox[{
                  StyleBox[\(b'\),
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], 
                  StyleBox["S",
                    FontSlant->"Plain"]}]}]},
            {
              RowBox[{
                StyleBox[\(a\ c\),
                  FontSlant->"Italic"], " ", "+", " ", 
                RowBox[{\(S'\), " ", 
                  StyleBox["b",
                    FontSlant->"Italic"]}]}], 
              RowBox[{\(S' S\), " ", "+", " ", 
                RowBox[{
                  StyleBox["c",
                    FontSlant->"Italic"], ".", 
                  RowBox[{
                    StyleBox["c",
                      FontSlant->"Italic"], "'"}]}]}]}
            }], ")"}]]]
}], "Text"],

Cell["\<\
This is a bit forbidding. Let us first try the easy decomposition:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold"], "*"], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", 
                  RowBox[{
                    StyleBox["r",
                      FontSlant->"Italic"], "'"}]},
                {
                  StyleBox["r",
                    FontSlant->"Italic"], 
                  StyleBox["R",
                    FontWeight->"Bold"]}
                }], ")"}], " ", "=", "  ", 
          RowBox[{\(Q' . Q\), " ", "=", " ", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"1", "0"},
                    {
                      StyleBox["r",
                        FontSlant->"Italic"], \(S'\)}
                    }], ")"}], " ", 
              RowBox[{"(", GridBox[{
                    {"1", 
                      StyleBox[\(r'\),
                        FontSlant->"Italic"]},
                    {"0", "S"}
                    }], ")"}], " "}]}]}]}]]],
  " = ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(1\)\(\ \)\), 
              StyleBox[\(r'\),
                FontSlant->"Italic"]},
            {
              StyleBox["r",
                FontSlant->"Italic"], 
              RowBox[{\(S' S\), " ", "+", " ", 
                RowBox[{
                  StyleBox["r",
                    FontSlant->"Italic"], ".", 
                  RowBox[{
                    StyleBox["r",
                      FontSlant->"Italic"], "'"}]}]}]}
            }], ")"}]]]
}], "Text"],

Cell[TextData[{
  "So that ",
  StyleBox["R",
    FontWeight->"Bold"],
  " = ",
  StyleBox["P'P",
    FontSlant->"Italic"],
  " = ",
  StyleBox["S'.S",
    FontSlant->"Italic"],
  " + ",
  StyleBox["r.r'. ",
    FontSlant->"Italic"],
  "Note that by form",
  StyleBox[" S'.S ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["r.r' ",
    FontSlant->"Italic"],
  "are PSD. However we must keep track of the proper calculation order. We \
define ",
  StyleBox["M",
    FontSlant->"Italic"],
  " = ",
  StyleBox["R",
    FontSlant->"Italic"],
  " - ",
  StyleBox["r.r'",
    FontSlant->"Italic"],
  ", then determine when this ",
  StyleBox["M",
    FontSlant->"Italic"],
  " is PSD, only then decompose ",
  StyleBox["M = S'.S",
    FontSlant->"Italic"],
  ", and then construct ",
  StyleBox["Q",
    FontSlant->"Italic"],
  ". For ",
  StyleBox["M",
    FontSlant->"Italic"],
  " = ",
  StyleBox["R",
    FontSlant->"Italic"],
  " - ",
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " to be PSD, the necessary and sufficient condition is that for all ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "\[NotEqual] 0 that ",
  StyleBox["y'.",
    FontSlant->"Italic"],
  StyleBox["R",
    FontWeight->"Bold"],
  StyleBox[".y",
    FontSlant->"Italic"],
  " \[GreaterEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`\((r' . y)\)\^2\)]],
  ". An approach for ",
  StyleBox["R",
    FontWeight->"Bold"],
  " PD is as follows. For ",
  StyleBox["M",
    FontSlant->"Italic"],
  " we find ",
  StyleBox["M",
    FontSlant->"Italic"],
  " = ",
  StyleBox["P'P",
    FontSlant->"Italic"],
  " - ",
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " = ",
  StyleBox["P'",
    FontSlant->"Italic"],
  " (I - ",
  StyleBox["W",
    FontSlant->"Italic"],
  ") ",
  StyleBox["P, ",
    FontSlant->"Italic"],
  "where W = ",
  Cell[BoxData[
      \(TraditionalForm\`P'\^\(-1\)\)]],
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P\^\(-1\)\)]],
  ".  First, ",
  StyleBox["W",
    FontSlant->"Italic"],
  " is symmetric. Secondly, ",
  StyleBox["W' W",
    FontSlant->"Italic"],
  " = ",
  StyleBox["W W",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`P'\^\(-1\)\)]],
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P\^\(-1\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P'\^\(-1\)\)]],
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P\^\(-1\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`P'\^\(-1\)\)]],
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((P' P)\)\^\(-1\)\)]],
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P\^\(-1\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`P'\^\(-1\)\)]],
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r.r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P\^\(-1\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`P'\^\(-1\)\)]],
  StyleBox["r.",
    FontSlant->"Italic"],
  "(",
  StyleBox["r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r",
    FontSlant->"Italic"],
  ") ",
  StyleBox[".r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P\^\(-1\)\)]],
  "  where the expression in brackets \[Lambda] = (",
  StyleBox["r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r",
    FontSlant->"Italic"],
  ") \[GreaterEqual] 0 is a scalar, and nonnegative since the inverse of the \
correlation matrix is PSD too. Thus ",
  StyleBox["W W",
    FontSlant->"Italic"],
  " = \[Lambda] ",
  StyleBox["W",
    FontSlant->"Italic"],
  ".  Hence we take ",
  StyleBox["V",
    FontSlant->"Italic"],
  " =",
  StyleBox[" f",
    FontSlant->"Italic"],
  "[\[Lambda]]",
  StyleBox["W  ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["S ",
    FontSlant->"Italic"],
  "= (I - ",
  StyleBox["V",
    FontSlant->"Italic"],
  ") ",
  StyleBox["P",
    FontSlant->"Italic"],
  ", and find ",
  StyleBox["M",
    FontSlant->"Italic"],
  " = ",
  StyleBox["S'S",
    FontSlant->"Italic"],
  " = ",
  StyleBox["P",
    FontSlant->"Italic"],
  "' (I - ",
  StyleBox["V",
    FontSlant->"Italic"],
  ") (I - ",
  StyleBox["V",
    FontSlant->"Italic"],
  ") ",
  StyleBox["P",
    FontSlant->"Italic"],
  " = ",
  StyleBox["P'",
    FontSlant->"Italic"],
  " (I - ",
  StyleBox["V",
    FontSlant->"Italic"],
  " - ",
  StyleBox["V ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["V V",
    FontSlant->"Italic"],
  ") ",
  StyleBox["P",
    FontSlant->"Italic"],
  " = ",
  StyleBox["P'",
    FontSlant->"Italic"],
  " (I - 2 ",
  StyleBox["f",
    FontSlant->"Italic"],
  "[\[Lambda]] ",
  StyleBox["W ",
    FontSlant->"Italic"],
  "+ ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{
            StyleBox["f",
              FontSlant->"Italic"], "[", "\[Lambda]", "]"}], "2"], 
        TraditionalForm]]],
  StyleBox["W W ",
    FontSlant->"Italic"],
  ") ",
  StyleBox["P, ",
    FontSlant->"Italic"],
  "that reduces to ",
  StyleBox["M",
    FontSlant->"Italic"],
  " = ",
  StyleBox["P'",
    FontSlant->"Italic"],
  " (I - ",
  StyleBox["W",
    FontSlant->"Italic"],
  ") ",
  StyleBox["P ",
    FontSlant->"Italic"],
  "if and only if - 2 ",
  StyleBox["f",
    FontSlant->"Italic"],
  "[\[Lambda]] ",
  StyleBox["W ",
    FontSlant->"Italic"],
  "+ ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{
            StyleBox["f",
              FontSlant->"Italic"], "[", "\[Lambda]", "]"}], "2"], 
        TraditionalForm]]],
  "\[Lambda] ",
  StyleBox["W =",
    FontSlant->"Italic"],
  " -",
  StyleBox["W. ",
    FontSlant->"Italic"],
  "Thus:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[\(-\ 
              2\)\ f[\[Lambda]]\  + \ \[Lambda]\ f[\[Lambda]]^2\ \  \[Equal] \
\ \(-1\), \ f[\[Lambda]]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{{f(\[Lambda]) \[Rule] \(1 - \@\(1 - \[Lambda]\)\)\/\
\[Lambda]}, {f(\[Lambda]) \[Rule] \(\@\(1 - \[Lambda]\) + \
1\)\/\[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Which concludes this easy decomposition. The point to note is that the \
solution requires \[Lambda] = (",
  StyleBox["r'",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["r",
    FontSlant->"Italic"],
  ") \[LessEqual] 1 in order for the easy decomposition to be real-valued. \
This is the same as what we already knew from the determinant."
}], "Text"],

Cell[TextData[{
  "PM. Weaker properties on ",
  StyleBox["R",
    FontWeight->"Bold"],
  " follow from this. Let \[Rho] = Max[",
  StyleBox["R",
    FontWeight->"Bold"],
  " - I], thus the maximal off-diagonal element. Then ",
  StyleBox["R",
    FontWeight->"Bold"],
  " \[LessEqual] (1 - \[Rho]) I + \[Rho] 1.1' and for vector 0 \[LessEqual] \
",
  StyleBox["r ",
    FontSlant->"Italic"],
  "\[LessEqual] 1 we find ",
  StyleBox["r' ",
    FontSlant->"Italic"],
  StyleBox["R",
    FontWeight->"Bold"],
  " ",
  StyleBox["r",
    FontSlant->"Italic"],
  " \[LessEqual] (1 - \[Rho]) ",
  StyleBox["r' r ",
    FontSlant->"Italic"],
  "+ \[Rho] ",
  Cell[BoxData[
      \(TraditionalForm\`\((1'\ r)\)\^2\)]],
  " \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`\((1'\ r)\)\^2\)]],
  " since \[Rho] = 1 is the highest value. For the row sums 0 \[LessEqual] ",
  StyleBox["s",
    FontSlant->"Italic"],
  " \[LessEqual]  ((1 - \[Rho]) + \[Rho] ",
  StyleBox["k",
    FontSlant->"Italic"],
  ")",
  StyleBox[" ",
    FontSlant->"Italic"],
  "1 = (1 + (",
  StyleBox["k ",
    FontSlant->"Italic"],
  "- 1) \[Rho]) 1. "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "A symbolic approach for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3 "
}], "Subsection"],

Cell[TextData[{
  "For ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "= 3 we may take a symbolic nonnegative matrix, determine the formal \
pairwise nominal correlations, construct the matrix, take the determinant and \
determine its possible range."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      mat\  = \ {{{a, \ b}, \ {c, \ d}}, \ {{e, \ f}, \ {g, \ h}}}, \ 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "a"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "b"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"c"},
                  {"d"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "e"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "f"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"g"},
                  {"h"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{a, b}, {c, d}}, {{e, f}, {g, h}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(case\  = \ BorderMatrices;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ 
          BordersOrAll\  \[Rule] \ BorderMatrices\ ]\  // \ 
        Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`NominalCorrelationMatrix::"num" \(\(:\)\(\ \)\) 
      "No PSD test since non-numeric result"\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \
\((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + 
                            h)\)\ \((e + f + g + 
                            h)\)\)\)\), \(\@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + 
                            g)\)\ \((b + d + f + h)\)\ \((e + f + g + 
                            h)\)\)\)\)},
            {\(\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + 
                            h)\)\ \((e + f + g + h)\)\)\)\), 
              "1", \(\@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + 
                            h)\)\ \((c + d + g + h)\)\)\)\)},
            {\(\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + 
                            h)\)\ \((e + f + g + 
                            h)\)\)\)\), \(\@\(\((d\ e + h\ e - c\ f - f\ g - \
b\ \((c + g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + 
                            g)\)\ \((b + d + f + h)\)\ \((c + d + g + 
                            h)\)\)\)\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
One can imagine that this does not give an insightful result. The evaluation \
had to be aborted and the following cell thus is locked.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[dt\  = \ Det[%], \ 
      Assumptions\  \[Rule] \ 
        Thread[{a, \ b, \ c, \ d, \ e, \ f, \ g, \ h}\  \[GreaterEqual] \ 
            0]]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(TraditionalForm\`$Aborted\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We may however recall the ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3 discussion in ",
  StyleBox["Appendix C",
    FontWeight->"Bold"],
  ", where Solution[] contained the solution of the condition on the ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(i, j\)\)]],
  " (using 0 < ",
  StyleBox["r",
    FontSlant->"Italic"],
  " < 1). This evaluates easily, but gives another forbidding expression and \
thus is not shown. The subsequent simplification again is aborted and now \
locked."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol\  = \ 
      Solution[]\  /. \ {r\_\(x, y\)\  \[Rule] \ \(ncmat[case]\)\ [\([1, \ 
                2]\)], \ 
          r\_\(x, z\)\  \[Rule] \ \(ncmat[case]\)\ [\([1, \ 
                3]\)], \ \ r\  \[Rule] \ \(ncmat[case]\)\ [\([2, \ 
                3]\)]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\((\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + \
b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d \
+ g + h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] 
            0 \[And] \((\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \
\((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] 
                0 \[Or] \((0 < \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a \
+ c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + \
d + f + h)\)\ \((e + f + g + h)\)\)\) < 1 \[And] 
                  0 < \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(1 - \((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c \
+ e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\))\))\))\) \[Or] \((0 \
< \@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\
\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + \
h)\)\)\) < 
            1\/\@2 \[And] \((\((0 \[LessEqual] \@\(\((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c \
+ e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) < \@\(\((c\ \((e + \
f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\
\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) \[And] 
                  0 < \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\
\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + \
b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) + \[Sqrt]\((\(\((c\
\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + \
g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\
\)\^2\ \((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \
\((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \
\((b + d + f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\
\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\
\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\))\) \[Or] \@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] \@\(\((c\ \
\((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) \
\[Or] \((\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\
\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + \
f + g + h)\)\)\) < \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f \
+ h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\
\ \((e + f + g + h)\)\)\) \[LessEqual] \@\(1 - \((c\ \((e + f)\) + d\ \((e + \
f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + \
f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) \[And] 
                  0 < \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\
\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + \
b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) + \[Sqrt]\((\(\((c\
\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + \
g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\
\)\^2\ \((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \
\((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \
\((b + d + f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\
\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\
\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\))\) \[Or] \((\@\(1 - \((c\ \((e + f)\) + d\ \
\((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b \
+ e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) < \@\(\((b\ \((e + \
g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\
\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) < 
                    1 \[And] \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \
\((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \
\((c + d + g + h)\)\ \((e + f + g + h)\)\)\) - \[Sqrt]\((\(\((c\ \((e + f)\) \
+ d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \
\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + \
h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\) - \((a \
+ b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\) \[LessEqual] \@\(\((d\ e + h\ e - c\ f - f\ \
g - b\ \((c + g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + \
e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \
\((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\
\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\)\) + \[Sqrt]\((\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\ \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \((a + b + e + f)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\^2\) - \
\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + \
b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\) \
- \((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\) + 1)\))\) \[Or] \((\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \
\((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] 
                    1 \[And] \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + \
g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b \
+ d + f + h)\)\ \((c + d + g + h)\)\)\) \[LongEqual] \@\(\((c\ \((e + f)\) + \
d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a \
+ b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\))\))\))\) \[Or] \
\((\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \
\((e + f + g + h)\)\)\) \[LongEqual] 
            1\/\@2 \[And] \((\((0 \[LessEqual] \@\(\((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c \
+ e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) < \@\(\((c\ \((e + \
f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\
\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) \[And] 
                  0 < \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\
\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + \
b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) + \[Sqrt]\((\(\((c\
\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + \
g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\
\)\^2\ \((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \
\((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \
\((b + d + f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\
\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\
\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\))\) \[Or] \@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] \@\(\((c\ \
\((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) \
\[Or] \((\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\
\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + \
f + g + h)\)\)\) < \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f \
+ h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\
\ \((e + f + g + h)\)\)\) < 
                    1 \[And] \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \
\((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \
\((c + d + g + h)\)\ \((e + f + g + h)\)\)\) - \[Sqrt]\((\(\((c\ \((e + f)\) \
+ d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \
\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + \
h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\) - \((a \
+ b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\) \[LessEqual] \@\(\((d\ e + h\ e - c\ f - f\ \
g - b\ \((c + g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + \
e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \
\((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\
\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\)\) + \[Sqrt]\((\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\ \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \((a + b + e + f)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\^2\) - \
\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + \
b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\) \
- \((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\) + 1)\))\) \[Or] \((\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \
\((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] 
                    1 \[And] \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + \
g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b \
+ d + f + h)\)\ \((c + d + g + h)\)\)\) \[LongEqual] \@\(\((c\ \((e + f)\) + \
d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a \
+ b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\))\))\))\) \[Or] \
\((1\/\@2 < \@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \
\((e + f + g + h)\)\)\) < 
            1 \[And] \((\((0 \[LessEqual] \@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) \[LessEqual] \@\(1 - \((c\ \
\((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) \
\[And] 0 < \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \((d + \
h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \
\((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \
\((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \
\((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\ \((e \
+ f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e \
+ f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) + \[Sqrt]\((\(\((c\ \((e \
+ f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + g)\) + \
d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \
\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + \
h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\) - \((a \
+ b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\))\) \[Or] \((\@\(1 - \((c\ \((e + f)\) + d\ \
\((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b \
+ e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) < \@\(\((b\ \((e + \
g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\
\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) < \
\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \
\((e + f + g + h)\)\)\) \[And] \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a \
+ c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + \
d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\ \((e + f)\) \
- \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \
\((c + d + g + h)\)\ \((e + f + g + h)\)\)\) - \[Sqrt]\((\(\((c\ \((e + f)\) \
+ d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \
\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + \
h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\) - \((a \
+ b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\) \[LessEqual] \@\(\((d\ e + h\ e - c\ f - f\ \
g - b\ \((c + g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + \
e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \
\((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\
\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\)\) + \[Sqrt]\((\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\ \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \((a + b + e + f)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\^2\) - \
\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + \
b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\) \
- \((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\) + 1)\))\) \[Or] \((\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \
\((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] \@\(\((c\ \((e + f)\) + d\ \((e + \
f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + \
f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) \[And] \@\(\((b\ \((e + g)\
\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \
\((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \
\((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\) - \
\[Sqrt]\((\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\ \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \((a + b + e + f)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\^2\) - \
\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + \
b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\) \
- \((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\) + 1)\) \[LessEqual] \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((c + d + g + h)\)\)\) < 
                    1)\) \[Or] \((\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \
\((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \
\((c + d + g + h)\)\ \((e + f + g + h)\)\)\) < \@\(\((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c \
+ e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\) < 
                    1 \[And] \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\)\)\ \@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \
\((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \
\((c + d + g + h)\)\ \((e + f + g + h)\)\)\) - \[Sqrt]\((\(\((c\ \((e + f)\) \
+ d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\ \((b\ \((e + g)\) + d\ \
\((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \
\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + \
h)\)\ \((e + f + g + h)\)\^2\) - \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + \
c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d \
+ f + h)\)\ \((e + f + g + h)\)\) - \((c\ \((e + f)\) + d\ \((e + f)\) - \((a \
+ b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + \
d + g + h)\)\ \((e + f + g + h)\)\) + 
                            1)\) \[LessEqual] \@\(\((d\ e + h\ e - c\ f - f\ \
g - b\ \((c + g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + \
e + g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\)\) \[LessEqual] \@\(\((b\ \
\((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c \
+ d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\)\ \@\
\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\)\) + \[Sqrt]\((\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\ \((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\)\/\(\((a + b + c + d)\)\^2\ \((a + b + e + f)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\^2\) - \
\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + \
b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\) \
- \((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a \
+ b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\
\) + 1)\))\) \[Or] \((\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \
\((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((e + f + g + h)\)\)\) \[LongEqual] 
                    1 \[And] \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + \
g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b \
+ d + f + h)\)\ \((c + d + g + h)\)\)\) \[LongEqual] \@\(\((c\ \((e + f)\) + \
d\ \((e + f)\) - \((a + b)\)\ \((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a \
+ b + e + f)\)\ \((c + d + g + h)\)\ \((e + f + g + h)\)\)\))\))\))\) \[Or] \
\((\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + h)\)\ \
\((e + f + g + h)\)\)\) \[LongEqual] 1 \[And] 
          0 < \@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\
\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + h)\)\ \
\((e + f + g + h)\)\)\) < 
            1 \[And] \@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + \
h)\)\ \((c + d + g + h)\)\)\) \[LongEqual] \@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + \
g)\)\ \((b + d + f + h)\)\ \((e + f + g + h)\)\)\))\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[%, \ 
      Assumptions\  \[Rule] \ 
        Thread[{a, \ b, \ c, \ d, \ e, \ f, \ g, \ h}\  \[GreaterEqual] \ 
            0]]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(TraditionalForm\`$Aborted\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Simulation for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection"],

Cell[TextData[{
  "For ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "= 3 we may assign arbitrary numbers and determine whether 0 \[LessEqual] \
Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. There are four methods to consider, using only the \
border matrices or all inner submatrices, and for the latter using the \
standard weighted average, the minimum or the maximum of the inner \
correlations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      mat\  = \ {{{a, \ b}, \ {c, \ d}}, \ {{e, \ f}, \ {g, \ h}}}, \ 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "a"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "b"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"c"},
                  {"d"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "e"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "f"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"g"},
                  {"h"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{a, b}, {c, d}}, {{e, f}, {g, h}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We may consider cell values from 1 to a million. There will be some \
duplication in the calculations due to symmetry. Using 4 values for 8 \
variables we investigate ",
  Cell[BoxData[
      \(TraditionalForm\`4\^8\)]],
  " = 65536 matrices."
}], "Text"],

Cell[BoxData[
    \(\(possibilities\  = \ {1, \ 100, \ 10000, \ 10^6};\)\)], "Input"],

Cell[BoxData[
    \(\(tab\  = \ Table[possibilities\ , \ {i, \ 1, \ 8}];\)\)], "Input"],

Cell[BoxData[
    \(\(combi\  = \ Outer[List, Sequence\  @@ \ tab];\)\)], "Input"],

Cell["\<\
For these values, we will find that the method of using bordermatrices only \
still gives PSD correlation matrices while the method of using inner \
correlation matrices for 10% of the cases gives a determinant out off the \
range.\
\>", "Text"],

Cell["\<\
We don\[CloseCurlyQuote]t need to show the details of these simulations and \
can directly proceed to the review of the results.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Automatic"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(case\  = \ All\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`All\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ BordersOrAll\  \[Rule] \ All, \ 
          Inner\  \[Rule] \ Automatic\ ]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`NominalCorrelationMatrix::"num" \(\(:\)\(\ \)\) 
      "No PSD test since non-numeric result"\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(\(\@\(\((c\ e - a\ g)\)\^2\/\(\((a + c)\)\ \((a + e)\)\ \
\((c + g)\)\ \((e + g)\)\)\)\ \((a + c + e + g)\) + \((b + d + f + 
                          h)\)\ \@\(\((d\ f - b\ h)\)\^2\/\(\((b + d)\)\ \((b \
+ f)\)\ \((d + h)\)\ \((f + h)\)\)\)\)\/\(a + b + c + d + e + f + g + 
                    h\)\), \(\(\@\(\((b\ e - a\ f)\)\^2\/\(\((a + b)\)\ \((a \
+ e)\)\ \((b + f)\)\ \((e + f)\)\)\)\ \((a + b + e + f)\) + \((c + d + g + 
                          h)\)\ \@\(\((d\ g - c\ h)\)\^2\/\(\((c + d)\)\ \((c \
+ g)\)\ \((d + h)\)\ \((g + h)\)\)\)\)\/\(a + b + c + d + e + f + g + h\)\)},
            {\(\(\@\(\((c\ e - a\ g)\)\^2\/\(\((a + c)\)\ \((a + e)\)\ \((c + \
g)\)\ \((e + g)\)\)\)\ \((a + c + e + g)\) + \((b + d + f + 
                          h)\)\ \@\(\((d\ f - b\ h)\)\^2\/\(\((b + d)\)\ \((b \
+ f)\)\ \((d + h)\)\ \((f + h)\)\)\)\)\/\(a + b + c + d + e + f + g + h\)\), 
              "1", \(\(\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a + c)\)\ \
\((b + d)\)\ \((c + d)\)\)\)\ \((a + b + c + d)\) + \((e + f + g + 
                          h)\)\ \@\(\((f\ g - e\ h)\)\^2\/\(\((e + f)\)\ \((e \
+ g)\)\ \((f + h)\)\ \((g + h)\)\)\)\)\/\(a + b + c + d + e + f + g + h\)\)},
            {\(\(\@\(\((b\ e - a\ f)\)\^2\/\(\((a + b)\)\ \((a + e)\)\ \((b + \
f)\)\ \((e + f)\)\)\)\ \((a + b + e + f)\) + \((c + d + g + 
                          h)\)\ \@\(\((d\ g - c\ h)\)\^2\/\(\((c + d)\)\ \((c \
+ g)\)\ \((d + h)\)\ \((g + h)\)\)\)\)\/\(a + b + c + d + e + f + g + 
                    h\)\), \(\(\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a \
+ c)\)\ \((b + d)\)\ \((c + d)\)\)\)\ \((a + b + c + d)\) + \((e + f + g + 
                          h)\)\ \@\(\((f\ g - e\ h)\)\^2\/\(\((e + f)\)\ \((e \
+ g)\)\ \((f + h)\)\ \((g + h)\)\)\)\)\/\(a + b + c + d + e + f + g + h\)\), 
              "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{False, True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 6960}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 58576}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pos[False, \ \ case]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 1, 1, 3, 4, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(example\  = \ 
      Extract[combi, \ \(pos[False, \ case]\)[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 1, 1, 10000, 1000000, 100}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(matexp\  = \ \(\(mat\)\(\ \)\(/.\)\(\ \ \)\(Thread[{a, \ b, \ c, \ d, \ 
              e, \ f, \ g, \ h}\ \  \[Rule] \ \ example]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 1}\), \({1, 1}\)},
            {\({1, 10000}\), \({1000000, 100}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Note that NominalCorrelation takes the maximal multiple correlation from the \
matrix of correlations. Apparently this can go off track when the determinant \
is not in the required range. In fact, we have insulated NominalCorrelation \
from this problem, so to check we need to use the underlying non-insulated \
volume ratio measure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(matexp\  // \ VolumeRatio\)\ \  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-0.16758259827056382`\\)\\) outside [0, 1]\"\
\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`4.192789463601465`\)], "Output"]
}, Open  ]],

Cell["Checking the correlation matrices and their determinants:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VolumeRatioMatrix[matexp, \ BordersOrAll\  \[Rule] \ All]\  // 
      N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.49569167495083855`", "0.07460297827040804`"},
            {"0.49569167495083855`", "1.`", "0.9949332490867923`"},
            {"0.07460297827040804`", "0.9949332490867923`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-0.16758259827056404`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[matexp\ , \ 
        BordersOrAll\  \[Rule] \ BorderMatrices]\  // N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.009849381036843864`", "0.009799525084037888`"},
            {"0.009849381036843864`", "1.`", "0.9948377050545376`"},
            {"0.009799525084037888`", "0.9948377050545376`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.010296941594464443`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Min"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(case\  = \ AllMin\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`AllMin\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ BordersOrAll\  \[Rule] \ All, \ 
          Inner\  \[Rule] \ Min\ ]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(Min(\@\(\((c\ e - a\ g)\)\^2\/\(\((a + c)\)\ \((a + e)\)\
\ \((c + g)\)\ \((e + g)\)\)\), \@\(\((d\ f - b\ h)\)\^2\/\(\((b + d)\)\ \((b \
+ f)\)\ \((d + h)\)\ \((f + h)\)\)\))\), \(Min(\@\(\((b\ e - a\ \
f)\)\^2\/\(\((a + b)\)\ \((a + e)\)\ \((b + f)\)\ \((e + f)\)\)\), \@\(\((d\ \
g - c\ h)\)\^2\/\(\((c + d)\)\ \((c + g)\)\ \((d + h)\)\ \((g + h)\)\)\))\)},
            {\(Min(\@\(\((c\ e - a\ g)\)\^2\/\(\((a + c)\)\ \((a + e)\)\ \((c \
+ g)\)\ \((e + g)\)\)\), \@\(\((d\ f - b\ h)\)\^2\/\(\((b + d)\)\ \((b + f)\)\
\ \((d + h)\)\ \((f + h)\)\)\))\), 
              "1", \(Min(\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a + c)\)\
\ \((b + d)\)\ \((c + d)\)\)\), \@\(\((f\ g - e\ h)\)\^2\/\(\((e + f)\)\ \((e \
+ g)\)\ \((f + h)\)\ \((g + h)\)\)\))\)},
            {\(Min(\@\(\((b\ e - a\ f)\)\^2\/\(\((a + b)\)\ \((a + e)\)\ \((b \
+ f)\)\ \((e + f)\)\)\), \@\(\((d\ g - c\ h)\)\^2\/\(\((c + d)\)\ \((c + g)\)\
\ \((d + h)\)\ \((g + h)\)\)\))\), \(Min(\@\(\((b\ c - a\ d)\)\^2\/\(\((a + \
b)\)\ \((a + c)\)\ \((b + d)\)\ \((c + d)\)\)\), \@\(\((f\ g - e\ h)\)\^2\/\(\
\((e + f)\)\ \((e + g)\)\ \((f + h)\)\ \((g + h)\)\)\))\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Max"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(case\  = \ AllMax\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`AllMax\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ BordersOrAll\  \[Rule] \ All, \ 
          Inner\  \[Rule] \ Max\ ]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(Max(\@\(\((c\ e - a\ g)\)\^2\/\(\((a + c)\)\ \((a + e)\)\
\ \((c + g)\)\ \((e + g)\)\)\), \@\(\((d\ f - b\ h)\)\^2\/\(\((b + d)\)\ \((b \
+ f)\)\ \((d + h)\)\ \((f + h)\)\)\))\), \(Max(\@\(\((b\ e - a\ \
f)\)\^2\/\(\((a + b)\)\ \((a + e)\)\ \((b + f)\)\ \((e + f)\)\)\), \@\(\((d\ \
g - c\ h)\)\^2\/\(\((c + d)\)\ \((c + g)\)\ \((d + h)\)\ \((g + h)\)\)\))\)},
            {\(Max(\@\(\((c\ e - a\ g)\)\^2\/\(\((a + c)\)\ \((a + e)\)\ \((c \
+ g)\)\ \((e + g)\)\)\), \@\(\((d\ f - b\ h)\)\^2\/\(\((b + d)\)\ \((b + f)\)\
\ \((d + h)\)\ \((f + h)\)\)\))\), 
              "1", \(Max(\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a + c)\)\
\ \((b + d)\)\ \((c + d)\)\)\), \@\(\((f\ g - e\ h)\)\^2\/\(\((e + f)\)\ \((e \
+ g)\)\ \((f + h)\)\ \((g + h)\)\)\))\)},
            {\(Max(\@\(\((b\ e - a\ f)\)\^2\/\(\((a + b)\)\ \((a + e)\)\ \((b \
+ f)\)\ \((e + f)\)\)\), \@\(\((d\ g - c\ h)\)\^2\/\(\((c + d)\)\ \((c + g)\)\
\ \((d + h)\)\ \((g + h)\)\)\))\), \(Max(\@\(\((b\ c - a\ d)\)\^2\/\(\((a + \
b)\)\ \((a + c)\)\ \((b + d)\)\ \((c + d)\)\)\), \@\(\((f\ g - e\ h)\)\^2\/\(\
\((e + f)\)\ \((e + g)\)\ \((f + h)\)\ \((g + h)\)\)\))\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{False, True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 25152}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 40384}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pos[False, \ \ case]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 2, 2, 2, 2, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(example\  = \ 
      Extract[combi, \ \(pos[False, \ case]\)[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 100, 100, 100, 100, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(matexp\  = \ \(\(mat\)\(\ \)\(/.\)\(\ \ \)\(Thread[{a, \ b, \ c, \ d, \ 
              e, \ f, \ g, \ h}\ \  \[Rule] \ \ example]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 1}\), \({1, 100}\)},
            {\({100, 100}\), \({100, 1}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Note that NominalCorrelation takes the maximal multiple correlation from the \
matrix of correlations. Apparently this can go off track when the determinant \
is not in the required range.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(%\  // \ NominalCorrelation\)\ \  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.5677946026794201`\)], "Output"]
}, Open  ]],

Cell["Checking the correlation matrices and their determinants:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[matexp, \ BordersOrAll\  \[Rule] \ All, \ 
        Inner\  \[Rule] \ Max\ ]\  // N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.9801980198019802`", "0.9801980198019802`"},
            {"0.9801980198019802`", "1.`", "0.4900990099009901`"},
            {"0.9801980198019802`", "0.4900990099009901`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-0.22001070560933164`\)\)], "Output"]
}, Open  ]],

Cell["\<\
But the above used the maxima, this would be the standard weighted average.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[matexp, \ BordersOrAll\  \[Rule] \ All\ ]\  // 
      N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.4900990099009901`", "0.4900990099009901`"},
            {"0.4900990099009901`", "1.`", "0.4900990099009901`"},
            {"0.4900990099009901`", "0.4900990099009901`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.514849543968219`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[matexp\ , \ 
        BordersOrAll\  \[Rule] \ BorderMatrices]\  // N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.5622550106751559`", "0.5622550106751559`"},
            {"0.5622550106751559`", "1.`", "0.`"},
            {"0.5622550106751559`", "0.`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.3677386059413605`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] BorderMatrices"
}], "Subsubsection"],

Cell[BoxData[
    \(\(case\  = \ BorderMatrices;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ 
          BordersOrAll\  \[Rule] \ BorderMatrices\ ]\  // \ 
        Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`NominalCorrelationMatrix::"num" \(\(:\)\(\ \)\) 
      "No PSD test since non-numeric result"\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \
\((g + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + 
                            h)\)\ \((e + f + g + 
                            h)\)\)\)\), \(\@\(\((b\ \((e + g)\) + d\ \((e + \
g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + 
                            g)\)\ \((b + d + f + h)\)\ \((e + f + g + 
                            h)\)\)\)\)},
            {\(\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + b + e + f)\)\ \((c + d + g + 
                            h)\)\ \((e + f + g + h)\)\)\)\), 
              "1", \(\@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + g)\)\ \((b + d + f + 
                            h)\)\ \((c + d + g + h)\)\)\)\)},
            {\(\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\/\(\((a + b + c + d)\)\ \((a + c + e + g)\)\ \((b + d + f + 
                            h)\)\ \((e + f + g + 
                            h)\)\)\)\), \(\@\(\((d\ e + h\ e - c\ f - f\ g - \
b\ \((c + g)\) + a\ \((d + h)\))\)\^2\/\(\((a + b + e + f)\)\ \((a + c + e + 
                            g)\)\ \((b + d + f + h)\)\ \((c + d + g + 
                            h)\)\)\)\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[BoxData[
    \(\(possibilities\  = \ {1, \ 100, \ 10000, \ 10^6};\)\)], "Input"],

Cell[BoxData[
    \(\(tab\  = \ Table[possibilities\ , \ {i, \ 1, \ 8}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(combi\  = \ Outer[List, Sequence\  @@ \ tab];\)\)], "Input"],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Review", "Subsubsection"],

Cell[TextData[{
  "We checked 0 \[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1 where the ",
  StyleBox["R",
    FontWeight->"Bold"],
  " was based upon nominal correlations using either the border matrices or \
all submatrices. The following summarizes the results. This is a contingency \
table on issues pertaining to contingency tables."
}], "Text"],

Cell["\<\
heading = TableHeadings \[Rule] {{True, False, Sum}, {BorderMatrices, All, \
AllMin, AllMax}};\
\>", "Input"],

Cell["InsideTable[Set, ncposdef, heading] ", "Input"],

Cell[CellGroupData[{

Cell["InsideTable[Show, Length]", "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["BorderMatrices",
                "TraditionalForm"], 
              FormBox["All",
                "TraditionalForm"], 
              FormBox["AllMin",
                "TraditionalForm"], 
              FormBox["AllMax",
                "TraditionalForm"]},
            {
              FormBox["True",
                "TraditionalForm"], "65536", "58576", "65536", "40384"},
            {
              FormBox["False",
                "TraditionalForm"], "0", "6960", "0", "25152"},
            {
              FormBox["Sum",
                "TraditionalForm"], "65536", "65536", "65536", "65536"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{True, False, Sum}, {BorderMatrices, 
            All, AllMin, AllMax}}]]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
It appears that the measure is more sensitive to the use of the inner \
submatrices (and the weighted sums used), while it is not affected when \
correlations are based upon border matrices only or the strict Min condition. \
It is not clear whether the latter is only a result of this particular \
numerical example, where elements in the contingency table range from 1 to a \
million. For normal ranges it might be less of a problem. Another overall \
impression is that PSD-ness exists when correlations have lower values and \
comes into problem when there are some high correlations (that might \
conflict).\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A stronger measure", "Subsection"],

Cell["\<\
The definition for nominal correlation was adopted since it reduces to the \
stated result for the 2 \[Times] 2 case and since there is the relation with \
the normed determinant measure for square matrices. It may be useful to \
mention that the method is such that we first normalize and then multiply \
with the transpose. But we can also reverse this.\
\>", "Text"],

Cell[TextData[{
  "Let ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "be the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " contingency table and ",
  StyleBox["m",
    FontSlant->"Italic"],
  " \[GreaterEqual] ",
  StyleBox["n",
    FontSlant->"Italic"],
  ". A ",
  StyleBox["stronger ",
    FontWeight->"Bold"],
  "pairwise VolumeRatio or NominalCorrelation measure is:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`r\_S\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "= Sqrt[Det[Normalized[",
  StyleBox["M",
    FontSlant->"Italic"],
  StyleBox["'M",
    FontSlant->"Italic"],
  "]]]"
}], "Text",
  TextAlignment->-0.5,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelation[{{a, \ b}, \ {c, \ d}}, \ 
        VolumeRatioMethod\  \[Rule] \ "\<Strong\>"]\  // \ 
      Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(\((b\ c - a\ d)\)\^2\/\@\(\((a\^2 + c\ a + b\ \((b \
+ d)\))\)\^2\ \((c\^2 + a\ c + d\ \((b + d)\))\)\^2\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The consequence of this stronger approach is that VolumeRatio[",
  StyleBox["M",
    FontSlant->"Italic"],
  "] and SquareMatrixNormedDet[",
  StyleBox["M",
    FontSlant->"Italic"],
  "] no longer give similar outcomes for any square matrix."
}], "Text"],

Cell[TextData[{
  "To see what this means we can best consider a numerical example. We can \
standardize the diagonal to 1 and when we set ",
  StyleBox["c ",
    FontSlant->"Italic"],
  "= 0 then we are left with one variable."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mb = \ {{1, \ b}, \ {0, \ 1}}; \ {VRweak[b_]\  = \ 
        VolumeRatio[mb], \[IndentingNewLine]VRstrong[b_]\  = \ 
        VolumeRatio[mb, \ 
          VolumeRatioMethod\  \[Rule] \ \ "\<Strong\>"]\ }\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\@\(1\/\((b + 1)\)\^2\), 
      1\/\@\(\((b + 1)\)\^2\ \((b\^2 + b + 1)\)\^2\)\%4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{VRweak[b], \ VRstrong[b]}, \ {b, \ 0, \ 10}, \ 
        AxesLabel\  \[Rule] \ {c, \ VolumeRatio}\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -5.28125 -13.875 ]
[.21429 .00222 5.28125 0 ]
[.40476 .00222 -5.28125 -13.875 ]
[.40476 .00222 5.28125 0 ]
[.59524 .00222 -5.28125 -13.875 ]
[.59524 .00222 5.28125 0 ]
[.78571 .00222 -5.28125 -13.875 ]
[.78571 .00222 5.28125 0 ]
[.97619 .00222 -8.5625 -13.875 ]
[.97619 .00222 8.5625 0 ]
[1.025 .01472 0 -6.9375 ]
[1.025 .01472 10.5625 6.9375 ]
[.01131 .13244 -23.6875 -6.9375 ]
[.01131 .13244 0 6.9375 ]
[.01131 .25016 -23.6875 -6.9375 ]
[.01131 .25016 0 6.9375 ]
[.01131 .36788 -23.6875 -6.9375 ]
[.01131 .36788 0 6.9375 ]
[.01131 .4856 -23.6875 -6.9375 ]
[.01131 .4856 0 6.9375 ]
[.01131 .60332 -10.5625 -6.9375 ]
[.01131 .60332 0 6.9375 ]
[.02381 .64303 -38.0938 0 ]
[.02381 .64303 38.0938 13.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -66.2813 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -69.5625 -17.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -84.6875 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -71.5625 -10.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -99.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 11.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(VolumeRatio) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .50625 L
.06244 .43345 L
.08255 .37877 L
.10458 .33321 L
.12579 .29896 L
.14509 .27362 L
.18408 .23411 L
.22401 .20446 L
.26243 .18263 L
.30329 .16431 L
.34264 .1501 L
.38048 .13876 L
.42077 .12861 L
.45954 .12029 L
.50076 .11269 L
.54047 .10633 L
.57866 .10095 L
.61931 .09587 L
.65844 .09152 L
.70002 .08738 L
.74009 .08379 L
.77864 .08066 L
.81964 .07763 L
.85913 .07496 L
.8971 .07259 L
.93752 .07028 L
.97619 .06822 L
s
.02381 .60332 m
.04262 .49844 L
.06244 .4109 L
.08255 .34226 L
.10458 .28494 L
.12415 .24564 L
.14509 .21251 L
.16496 .18744 L
.18653 .16547 L
.22646 .135 L
.26733 .11294 L
.30668 .09731 L
.34452 .08578 L
.3848 .07616 L
.42358 .06877 L
.4648 .06239 L
.50451 .05735 L
.5427 .05328 L
.58335 .04961 L
.62248 .04659 L
.66406 .04383 L
.70413 .04153 L
.74268 .03959 L
.78368 .03776 L
.82317 .03621 L
.86114 .03487 L
.90156 .03359 L
.94047 .03248 L
.97619 .03156 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00DP3oool5
000002X0oooo0`00000X0?ooo`<00000:@3oool3000002D0oooo1@0000030?ooo`<000005@3oool0
0580oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo
0?ooo`0000009`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000001@0oooo001C0?ooo`030000003oool0oooo02T0oooo1@00
000W0?ooo`050000003oool0oooo0?ooo`0000009`3oool01@000000oooo0?ooo`3oool0000002H0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001@0oooo001D0?ooo`03
0000003oool0oooo02P0oooo00@000000?ooo`3oool00000:03oool4000002T0oooo0`00000W0?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000D0?ooo`00E@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool0:@3oool01@00
0000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000001@0oooo001B0?ooo`050000003oool0oooo0?ooo`000000:P3oool2000002T0oooo00<0
00000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000001@0oooo001C0?ooo`<00000;03oool00`000000oooo
0?ooo`0X0?ooo`<00000:03oool3000002H0oooo0P0000050?ooo`<000005@3oool00?l0oooo8@3o
ool002P0oooo00<000000?ooo`3oool0m@3oool002P0oooo00<000000?ooo`3oool0jP3oool40000
00L0oooo000X0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool02@3oool002<0oooo
j@0000080?ooo`030000003oool0oooo00T0oooo000X0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000
1`3oool002P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00`0oooo100000070?ooo`00:03oool00`000000oooo0?ooo`3e0?ooo`00:03oool00`00
0000oooo0?ooo`3?0?ooo`d000006@3oool002P0oooo00<000000?ooo`3oool0/`3ooolL000002H0
oooo000X0?ooo`030000003oool0oooo0:40oooo4P0000120?ooo`00:03oool2000008l0oooo4`00
001D0?ooo`00:03oool00`000000oooo0?ooo`1k0?oooa<00000I`3oool002P0oooo00<000000?oo
o`3oool0LP3oool9000007X0oooo000X0?ooo`030000003oool0oooo06T0oooo2@0000230?ooo`00
:03oool00`000000oooo0?ooo`1R0?ooo`L00000S03oool002P0oooo00<000000?ooo`3oool0G@3o
ool5000009<0oooo000X0?ooo`030000003oool0oooo05P0oooo1@00001a0?ooo`h000006@3oool0
02P0oooo0P00001E0?ooo`@00000I03ooolB000002L0oooo000X0?ooo`030000003oool0oooo04l0
oooo1@00001O0?ooo`T00000>@3oool002P0oooo00<000000?ooo`3oool0B`3oool400000540oooo
4`0000120?ooo`00:03oool00`000000oooo0?ooo`170?ooo`@00000C03oool9000005D0oooo000X
0?ooo`030000003oool0oooo04@0oooo0`0000160?ooo`X00000GP3oool002P0oooo00<000000?oo
o`3oool0@@3oool300000400oooo2@00001X0?ooo`00:03oool00`000000oooo0?ooo`0n0?ooo`<0
0000?03oool700000740oooo000X0?ooo`800000?03oool3000003/0oooo1000001h0?ooo`00:03o
ool00`000000oooo0?ooo`0h0?ooo`<00000=`3oool7000007`0oooo000X0?ooo`030000003oool0
oooo03H0oooo0P00000b0?ooo`P00000P`3oool002P0oooo00<000000?ooo`3oool0=03oool20000
0300oooo1000002;0?ooo`00:03oool00`000000oooo0?ooo`0b0?ooo`800000;@3oool5000008l0
oooo000B0?ooo`<00000103oool2000000@0oooo1@0000040?ooo`030000003oool0oooo0300oooo
0P00000[0?ooo`@00000U03oool00140oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool2000002P0oooo1@00002H0?ooo`004@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool01@3oool3000002`0oooo
0P00000U0?ooo`D00000W@3oool00140oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Q0?ooo`@00000
XP3oool00140oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:@3oool200000240oooo0`00002V0?ooo`004@3oool01@000000oooo0?oo
o`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool07P3oool300000:T0oooo000B0?ooo`<000002`3oool3000000D0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0L0?ooo`<00000[03oool002P0oooo00<0
00000?ooo`3oool09@3oool2000001`0oooo0`00002_0?ooo`00:03oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo01T0oooo0`00002b0?ooo`00:03oool2000002@0oooo00<000000?oo
o`3oool05`3oool300000;D0oooo000X0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool05P3oool200000;P0oooo000X0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
5@3oool200000;X0oooo000X0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0503o
ool200000;`0oooo000X0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool04P3oool2
00000;h0oooo000X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool20000
0<00oooo000X0?ooo`8000007`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0<00
oooo000X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool200000<<0oooo
000X0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`330?ooo`00:03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo0P000036
0?ooo`00:03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0aP3oool002P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`80
0000b@3oool002P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0<T0oooo000X0?ooo`8000006@3oool00`000000oooo0?ooo`0<0?ooo`800000c03o
ool002P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0<`0oooo000X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool20000
0<l0oooo000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3?0?ooo`00:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0d03oool00180oooo0`0000040?ooo`8000001P3oool3000000@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=40oooo000A
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3B0?ooo`004@3oool0
1@000000oooo0?ooo`3oool0000000T0oooo1@0000040?ooo`<00000503oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0=<0oooo000A0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3D0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0e@3oool00140oooo00D000000?ooo`3oool0oooo0000000;0?ooo`800000
1@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
eP3oool00180oooo0`00000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=L0oooo000X0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3H0?ooo`00:03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0f@3oool002P0
oooo0P00000B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0fP3oool002P0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=X0oooo
000X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3K0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0g03oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0=`0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3M0?ooo`00:03oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0gP3oool002P0oooo0P00000?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0gP3oool002P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0=l0oooo000X0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3P0?ooo`00:03oool00`000000
oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000h`3oool002P0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>40oooo000X0?ooo`030000
003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000003T0?ooo`00:03oool00`000000oooo
0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000i03oool002P0oooo0P00000<0?ooo`050000
003oool0oooo0?ooo`000000i@3oool002P0oooo00<000000?ooo`3oool02`3oool01@000000oooo
0?ooo`3oool000000>D0oooo000X0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0
0000iP3oool002P0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000>H0
oooo000X0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000i`3oool00180oooo
0`0000040?ooo`8000001@3oool3000000D0oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`00003W0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000j03oool0
0140oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000103o
ool3000000T0oooo00@000000?ooo`3oool00000j03oool00140oooo00D000000?ooo`3oool0oooo
000000090?ooo`@000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool000000>T0oooo
000A0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00@000000?ooo`3oool00000j@3oool00140oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`00003Y0?ooo`004P3oool3000000`0oooo0`0000040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`000000jP3oool002P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0000003Z0?ooo`00:03oool2000000P0oooo00<000000?ooo`000000j`3oool002P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0000003[0?ooo`00:03oool00`000000oooo0?ooo`070?oo
o`030000003oool000000>/0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000k03oool002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000003/0?ooo`00:03o
ool00`000000oooo0?ooo`060?ooo`030000003oool000000>`0oooo000X0?ooo`030000003oool0
oooo00H0oooo0P00003]0?ooo`00:03oool2000000H0oooo00<000000?ooo`000000k@3oool002P0
oooo00<000000?ooo`3oool01@3oool200000>h0oooo000X0?ooo`030000003oool0oooo00D0oooo
0P00003^0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`800000kP3oool002P0oooo00<00000
0?ooo`3oool01@3oool200000>h0oooo000X0?ooo`030000003oool0oooo00@0oooo0P00003_0?oo
o`00:03oool00`000000oooo0?ooo`040?ooo`800000k`3oool002P0oooo0P0000050?ooo`800000
k`3oool002P0oooo00<000000?ooo`3oool0103oool200000>l0oooo000X0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0kP3oool002P0oooo00<000000?ooo`3oool00`3oool20000
0?00oooo000X0?ooo`030000003oool0oooo00<0oooo0P00003`0?ooo`004P3oool3000000@0oooo
0P0000050?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`800000l03oool00140oooo00D0
00000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0>l0oooo000A0?ooo`050000003oool0oooo0?ooo`00
00002@3oool01@000000oooo0?ooo`3oool0000000@0oooo0`0000030?ooo`030000003oool0oooo
0>l0oooo000A0?ooo`050000003oool0oooo0?ooo`0000002P3oool3000000D0oooo00<000000?oo
o`3oool00P3oool200000?40oooo000A0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool200000?40oooo000A0?oo
o`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3`0?ooo`004P3oool3000000/0oooo0`000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l03oool002P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3`0?ooo`00:03oool010000000oooo0?ooo`3oool20000
0?80oooo000X0?ooo`8000000P3oool200000?80oooo000X0?ooo`050000003oool0oooo0?ooo`00
0000l`3oool002P0oooo00D000000?ooo`3oool0oooo0000003c0?ooo`00:03oool01@000000oooo
0?ooo`3oool000000?<0oooo000X0?ooo`030000003oool0oooo00800000l`3oool002P0oooo00@0
00000?ooo`3oool00000m03oool002P0oooo00@000000?ooo`3oool00000m03oool002P0oooo0P00
00000`3oool000000?ooo`3c0?ooo`00:03oool010000000oooo00000000003d0?ooo`00:03oool0
0`000000oooo0000003e0?ooo`00:03oool00`000000oooo0000003e0?ooo`00:03oool00`000000
oooo0000003e0?ooo`00:03oool00`000000oooo0000003e0?ooo`00:03oool300000?D0oooo000X
0?ooo`800000mP3oool002P0oooo0P00003f0?ooo`00:03oool200000?H0oooo000X0?ooo`800000
mP3oool001h0oooo1@0000050?ooo`030000003oool0oooo0?D0oooo000P0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0m@3oool00200oooo00<000000?ooo`3oool01@3oool30000
0?D0oooo000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0m@3oool00200oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3e0?ooo`00803oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?D0oooo000O0?ooo`8000001`3oool00`000000oooo0?ooo`3e
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`001P3oool2000000D0oooo0`0000030?ooo`D000000`3oool2000000030?ooo`0000000000
00L000000P3oool400000080oooo0`0000020?ooo`030000003oool0000000D000000P3oool30000
00<0oooo1@0000030?ooo`<00000d@3oool000H0oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
0080oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000003@0?oo
o`001P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003o
ool000000080oooo1@0000030?ooo`<00000103oool400000080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000d03oool000D0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo0000003@0?ooo`001@3oool01@000000oooo0?ooo`3oool00000
00<0oooo0`0000050?ooo`040000003oool0oooo0?ooo`8000000P3oool2000000060?ooo`000000
00000000003oool00000103oool3000000@0oooo00@000000?ooo`3oool000000`3oool300000080
oooo1@0000030?ooo`<000001@3oool300000=40oooo00050?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0h03oool000@0oooo0`000000103oool000000000000000090?ooo`8000006@3oool40000
01<0oooo00<000000?ooo`3oool0e`3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{179, 466}, {345.875, 168.938}} -> {-9.90981, 1.11034, \
0.0451014, 0.00729757}}]
}, Open  ]],

Cell[TextData[{
  "We can consider some numerical values, of which the outcome of 50% \
correlation would be of some interest. Note that this is a standardized case, \
so that all values would be multiplied with sample size ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solution[]\  = \ 
      RealRoots[Solve[VRstrong[b]\  \[Equal] \ 1/2, \ b]\ ]\ \  // \ 
        N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{{b \[Rule] 
          0.7429592021663144`}, {b \[Rule] \(-2.150911084335964`\)}}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[\(N[{#, \ VRweak[#], \ VRstrong[#]}] &\)\  /@ \ {0, \  .5, \ 
          b\  /. \ Solution[1], \ 1, \ 2, \ 10, \ Infinity}, \ 
      TableHeadings\  \[Rule] \ {{}, \ {Input, \ VRweak, \ 
            VRstrong}}\ ]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["Input",
                "TraditionalForm"], 
              FormBox["VRweak",
                "TraditionalForm"], 
              FormBox["VRstrong",
                "TraditionalForm"]},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], "0.`", "1.`", "1.`"},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], "0.5`", "0.6666666666666666`", 
              "0.6172133998483676`"},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], "0.7429592021663144`", 
              "0.5737368945624806`", "0.5000000000000002`"},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], "1.`", "0.5`", "0.408248290463863`"},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], "2.`", "0.3333333333333333`", 
              "0.2182178902359924`"},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], "10.`", "0.09090909090909091`", 
              "0.028618190351607124`"},
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], "\[Infinity]", "0.`", "0.`"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{}, {Input, VRweak, VRstrong}}]]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Whether we take the weak measure or the strong one can best be judged by \
considering multidimensional tables. Lower pairwise correlation values \
improve the possibilities for finding positive semi-definite correlation \
matrices. But if we adopt the strong measure then we lose the equality of the \
solution for the 2 \[Times] 2 case. The latter might actually be an advantage \
if we want that different measures measure different things and thus employ \
different formulas. However, when we simulate this stronger measure then it \
appears that it still allows for non-PSD matrices of association in 5% of the \
considered cases. Hence, it does not have added value and we better adapt the \
weaker measure since it collapses to the familiar outcome for the 2 \[Times] \
2 case. PM. The simulation also takes longer for this stronger measure, \
apparently given that there are more squares and square roots.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Simulation for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, using the stronger measure for the volume ratio"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection"],

Cell["\<\
We can run this simulation by simply setting another option value and redo \
the exercise from above. Note that when you evaluate this section then you \
lose stored values from the simulation of the former simulation section.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[VolumeRatio, \ 
      VolumeRatioMethod\  \[Rule] \ "\<Strong\>"]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{VolumeRatioMethod \[Rule] "Strong"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction as before", "Subsubsection"],

Cell[TextData[{
  "For ",
  StyleBox["k ",
    FontSlant->"Italic"],
  "= 3 we may assign arbitrary numbers and determine whether 0 \[LessEqual] \
Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1. There are four methods to consider, using only the \
border matrices or all inner submatrices, and for the latter using the \
standard weighted average, the minimum or the maximum of the inner \
correlations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      mat\  = \ {{{a, \ b}, \ {c, \ d}}, \ {{e, \ f}, \ {g, \ h}}}, \ 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "a"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "b"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"c"},
                  {"d"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "e"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "f"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"g"},
                  {"h"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{a, b}, {c, d}}, {{e, f}, {g, h}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We may consider cell values from 1 to a million. There will be some \
duplication in the calculations due to symmetry. Using 4 values for 8 \
variables we investigate ",
  Cell[BoxData[
      \(TraditionalForm\`4\^8\)]],
  " = 65536 matrices."
}], "Text"],

Cell[BoxData[
    \(\(possibilities\  = \ {1, \ 100, \ 10000, \ 10^6};\)\)], "Input"],

Cell[BoxData[
    \(\(tab\  = \ Table[possibilities\ , \ {i, \ 1, \ 8}];\)\)], "Input"],

Cell[BoxData[
    \(\(combi\  = \ Outer[List, Sequence\  @@ \ tab];\)\)], "Input"],

Cell["\<\
We don\[CloseCurlyQuote]t need to show the details of these simulations and \
can directly proceed to the review of the results.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Automatic"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(case\  = \ All\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`All\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ BordersOrAll\  \[Rule] \ All, \ 
          Inner\  \[Rule] \ Automatic\ ]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`NominalCorrelationMatrix::"num" \(\(:\)\(\ \)\) 
      "No PSD test since non-numeric result"\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(\(\@\(\((c\ e - a\ g)\)\^2\/\@\(\((a\^2 + e\ a + c\ \((c \
+ g)\))\)\^2\ \((e\^2 + a\ e + g\ \((c + g)\))\)\^2\)\)\ \((a + c + e + 
                          g)\) + \((b + d + f + 
                          h)\)\ \@\(\((d\ f - b\ h)\)\^2\/\@\(\((b\^2 + f\ b \
+ d\ \((d + h)\))\)\^2\ \((f\^2 + b\ f + h\ \((d + h)\))\)\^2\)\)\)\/\(a + 
                    b + c + d + e + f + g + 
                    h\)\), \(\(\@\(\((b\ e - a\ f)\)\^2\/\@\(\((a\^2 + e\ a + \
b\ \((b + f)\))\)\^2\ \((e\^2 + a\ e + f\ \((b + f)\))\)\^2\)\)\ \((a + b + 
                          e + f)\) + \((c + d + g + 
                          h)\)\ \@\(\((d\ g - c\ h)\)\^2\/\@\(\((c\^2 + g\ c \
+ d\ \((d + h)\))\)\^2\ \((g\^2 + c\ g + h\ \((d + h)\))\)\^2\)\)\)\/\(a + 
                    b + c + d + e + f + g + h\)\)},
            {\(\(\@\(\((c\ e - a\ g)\)\^2\/\@\(\((a\^2 + e\ a + c\ \((c + \
g)\))\)\^2\ \((e\^2 + a\ e + g\ \((c + g)\))\)\^2\)\)\ \((a + c + e + 
                          g)\) + \((b + d + f + 
                          h)\)\ \@\(\((d\ f - b\ h)\)\^2\/\@\(\((b\^2 + f\ b \
+ d\ \((d + h)\))\)\^2\ \((f\^2 + b\ f + h\ \((d + h)\))\)\^2\)\)\)\/\(a + 
                    b + c + d + e + f + g + h\)\), 
              "1", \(\(\@\(\((b\ c - a\ d)\)\^2\/\@\(\((a\^2 + c\ a + b\ \((b \
+ d)\))\)\^2\ \((c\^2 + a\ c + d\ \((b + d)\))\)\^2\)\)\ \((a + b + c + 
                          d)\) + \((e + f + g + 
                          h)\)\ \@\(\((f\ g - e\ h)\)\^2\/\@\(\((e\^2 + g\ e \
+ f\ \((f + h)\))\)\^2\ \((g\^2 + e\ g + h\ \((f + h)\))\)\^2\)\)\)\/\(a + 
                    b + c + d + e + f + g + h\)\)},
            {\(\(\@\(\((b\ e - a\ f)\)\^2\/\@\(\((a\^2 + e\ a + b\ \((b + \
f)\))\)\^2\ \((e\^2 + a\ e + f\ \((b + f)\))\)\^2\)\)\ \((a + b + e + 
                          f)\) + \((c + d + g + 
                          h)\)\ \@\(\((d\ g - c\ h)\)\^2\/\@\(\((c\^2 + g\ c \
+ d\ \((d + h)\))\)\^2\ \((g\^2 + c\ g + h\ \((d + h)\))\)\^2\)\)\)\/\(a + 
                    b + c + d + e + f + g + 
                    h\)\), \(\(\@\(\((b\ c - a\ d)\)\^2\/\@\(\((a\^2 + c\ a + \
b\ \((b + d)\))\)\^2\ \((c\^2 + a\ c + d\ \((b + d)\))\)\^2\)\)\ \((a + b + 
                          c + d)\) + \((e + f + g + 
                          h)\)\ \@\(\((f\ g - e\ h)\)\^2\/\@\(\((e\^2 + g\ e \
+ f\ \((f + h)\))\)\^2\ \((g\^2 + e\ g + h\ \((f + h)\))\)\^2\)\)\)\/\(a + 
                    b + c + d + e + f + g + h\)\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{False, True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 3404}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 62132}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pos[False, \ \ case]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 3, 1, 2, 3, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(example\  = \ 
      Extract[combi, \ \(pos[False, \ case]\)[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 10000, 1, 100, 10000, 100}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(matexp\  = \ \(\(mat\)\(\ \)\(/.\)\(\ \ \)\(Thread[{a, \ b, \ c, \ d, \ 
              e, \ f, \ g, \ h}\ \  \[Rule] \ \ example]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 1}\), \({1, 10000}\)},
            {\({1, 100}\), \({10000, 100}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Note that NominalCorrelation takes the maximal multiple correlation from the \
matrix of correlations. Apparently this can go off track when the determinant \
is not in the required range.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(matexp\  // \ VolumeRatio\)\  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-0.02989827797621803`\\)\\) outside [0, 1]\"\
\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`1.425262541334684`\)], "Output"]
}, Open  ]],

Cell["But we have insulated NominalCorrelation to this.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(matexp\ \  // \ NominalCorrelation\)\ \  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9999949929491114`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Min"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(case\  = \ AllMin\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`AllMin\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ BordersOrAll\  \[Rule] \ All, \ 
          Inner\  \[Rule] \ Min\ ]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`NominalCorrelationMatrix::"num" \(\(:\)\(\ \)\) 
      "No PSD test since non-numeric result"\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(Min(\@\(\((c\ e - a\ g)\)\^2\/\@\(\((a\^2 + e\ a + c\ \
\((c + g)\))\)\^2\ \((e\^2 + a\ e + g\ \((c + g)\))\)\^2\)\), \@\(\((d\ f - b\
\ h)\)\^2\/\@\(\((b\^2 + f\ b + d\ \((d + h)\))\)\^2\ \((f\^2 + b\ f + h\ \
\((d + h)\))\)\^2\)\))\), \(Min(\@\(\((b\ e - a\ f)\)\^2\/\@\(\((a\^2 + e\ a \
+ b\ \((b + f)\))\)\^2\ \((e\^2 + a\ e + f\ \((b + f)\))\)\^2\)\), \@\(\((d\ \
g - c\ h)\)\^2\/\@\(\((c\^2 + g\ c + d\ \((d + h)\))\)\^2\ \((g\^2 + c\ g + h\
\ \((d + h)\))\)\^2\)\))\)},
            {\(Min(\@\(\((c\ e - a\ g)\)\^2\/\@\(\((a\^2 + e\ a + c\ \((c + \
g)\))\)\^2\ \((e\^2 + a\ e + g\ \((c + g)\))\)\^2\)\), \@\(\((d\ f - b\ \
h)\)\^2\/\@\(\((b\^2 + f\ b + d\ \((d + h)\))\)\^2\ \((f\^2 + b\ f + h\ \((d \
+ h)\))\)\^2\)\))\), 
              "1", \(Min(\@\(\((b\ c - a\ d)\)\^2\/\@\(\((a\^2 + c\ a + b\ \
\((b + d)\))\)\^2\ \((c\^2 + a\ c + d\ \((b + d)\))\)\^2\)\), \@\(\((f\ g - e\
\ h)\)\^2\/\@\(\((e\^2 + g\ e + f\ \((f + h)\))\)\^2\ \((g\^2 + e\ g + h\ \
\((f + h)\))\)\^2\)\))\)},
            {\(Min(\@\(\((b\ e - a\ f)\)\^2\/\@\(\((a\^2 + e\ a + b\ \((b + \
f)\))\)\^2\ \((e\^2 + a\ e + f\ \((b + f)\))\)\^2\)\), \@\(\((d\ g - c\ \
h)\)\^2\/\@\(\((c\^2 + g\ c + d\ \((d + h)\))\)\^2\ \((g\^2 + c\ g + h\ \((d \
+ h)\))\)\^2\)\))\), \(Min(\@\(\((b\ c - a\ d)\)\^2\/\@\(\((a\^2 + c\ a + b\ \
\((b + d)\))\)\^2\ \((c\^2 + a\ c + d\ \((b + d)\))\)\^2\)\), \@\(\((f\ g - e\
\ h)\)\^2\/\@\(\((e\^2 + g\ e + f\ \((f + h)\))\)\^2\ \((g\^2 + e\ g + h\ \
\((f + h)\))\)\^2\)\))\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{False, True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 292}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65244}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] All, Inner \[Rule] Max"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(case\  = \ AllMax\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`AllMax\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ BordersOrAll\  \[Rule] \ All, \ 
          Inner\  \[Rule] \ Max\ ]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`NominalCorrelationMatrix::"num" \(\(:\)\(\ \)\) 
      "No PSD test since non-numeric result"\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(Max(\@\(\((c\ e - a\ g)\)\^2\/\@\(\((a\^2 + e\ a + c\ \
\((c + g)\))\)\^2\ \((e\^2 + a\ e + g\ \((c + g)\))\)\^2\)\), \@\(\((d\ f - b\
\ h)\)\^2\/\@\(\((b\^2 + f\ b + d\ \((d + h)\))\)\^2\ \((f\^2 + b\ f + h\ \
\((d + h)\))\)\^2\)\))\), \(Max(\@\(\((b\ e - a\ f)\)\^2\/\@\(\((a\^2 + e\ a \
+ b\ \((b + f)\))\)\^2\ \((e\^2 + a\ e + f\ \((b + f)\))\)\^2\)\), \@\(\((d\ \
g - c\ h)\)\^2\/\@\(\((c\^2 + g\ c + d\ \((d + h)\))\)\^2\ \((g\^2 + c\ g + h\
\ \((d + h)\))\)\^2\)\))\)},
            {\(Max(\@\(\((c\ e - a\ g)\)\^2\/\@\(\((a\^2 + e\ a + c\ \((c + \
g)\))\)\^2\ \((e\^2 + a\ e + g\ \((c + g)\))\)\^2\)\), \@\(\((d\ f - b\ \
h)\)\^2\/\@\(\((b\^2 + f\ b + d\ \((d + h)\))\)\^2\ \((f\^2 + b\ f + h\ \((d \
+ h)\))\)\^2\)\))\), 
              "1", \(Max(\@\(\((b\ c - a\ d)\)\^2\/\@\(\((a\^2 + c\ a + b\ \
\((b + d)\))\)\^2\ \((c\^2 + a\ c + d\ \((b + d)\))\)\^2\)\), \@\(\((f\ g - e\
\ h)\)\^2\/\@\(\((e\^2 + g\ e + f\ \((f + h)\))\)\^2\ \((g\^2 + e\ g + h\ \
\((f + h)\))\)\^2\)\))\)},
            {\(Max(\@\(\((b\ e - a\ f)\)\^2\/\@\(\((a\^2 + e\ a + b\ \((b + \
f)\))\)\^2\ \((e\^2 + a\ e + f\ \((b + f)\))\)\^2\)\), \@\(\((d\ g - c\ \
h)\)\^2\/\@\(\((c\^2 + g\ c + d\ \((d + h)\))\)\^2\ \((g\^2 + c\ g + h\ \((d \
+ h)\))\)\^2\)\))\), \(Max(\@\(\((b\ c - a\ d)\)\^2\/\@\(\((a\^2 + c\ a + b\ \
\((b + d)\))\)\^2\ \((c\^2 + a\ c + d\ \((b + d)\))\)\^2\)\), \@\(\((f\ g - e\
\ h)\)\^2\/\@\(\((e\^2 + g\ e + f\ \((f + h)\))\)\^2\ \((g\^2 + e\ g + h\ \
\((f + h)\))\)\^2\)\))\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{False, True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 16592}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 48944}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pos[False, \ \ case]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 2, 1, 3, 4, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(example\  = \ 
      Extract[combi, \ \(pos[False, \ case]\)[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1, 100, 1, 10000, 1000000, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(matexp\  = \ \(\(mat\)\(\ \)\(/.\)\(\ \ \)\(Thread[{a, \ b, \ c, \ d, \ 
              e, \ f, \ g, \ h}\ \  \[Rule] \ \ example]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 1}\), \({1, 100}\)},
            {\({1, 10000}\), \({1000000, 1}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Note that NominalCorrelation takes the maximal multiple correlation from the \
matrix of correlations. Apparently this can go off track when the determinant \
is not in the required range.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(%\  // \ NominalCorrelation\)\ \  // \ N\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9990137423660235`\)], "Output"]
}, Open  ]],

Cell["Checking the correlation matrices and their determinants:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[matexp, \ BordersOrAll\  \[Rule] \ All, \ 
        Inner\  \[Rule] \ Max\ ]\  // N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.2221623777449071`", "0.07113739296997229`"},
            {"0.2221623777449071`", "1.`", "0.9883384308395082`"},
            {"0.07113739296997229`", "0.9883384308395082`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.000010000000000139666`\)], "Output"]
}, Open  ]],

Cell["\<\
But the above used the maxima, this would be the standard weighted average.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[matexp, \ BordersOrAll\  \[Rule] \ All\ ]\  // 
      N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.008043576867920633`", "0.09861236437998286`"},
            {"0.008043576867920633`", "1.`", "0.9948958651848206`"},
            {"0.09861236437998286`", "0.9948958651848206`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.0019714150067464456`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationMatrix[matexp\ , \ 
        BordersOrAll\  \[Rule] \ BorderMatrices]\  // N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.00009847405897804111`", "0.0581015033685114`"},
            {"0.00009847405897804111`", "1.`", "0.985282309300314`"},
            {"0.0581015033685114`", "0.985282309300314`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.02585425115649178`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "For ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 3, method \[Rule] BorderMatrices"
}], "Subsubsection"],

Cell[BoxData[
    \(\(case\  = \ BorderMatrices;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncmat[case]\  = \ 
      NominalCorrelationMatrix[mat, \ 
          BordersOrAll\  \[Rule] \ BorderMatrices\ ]\  // \ 
        Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`NominalCorrelationMatrix::"num" \(\(:\)\(\ \)\) 
      "No PSD test since non-numeric result"\)], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \
\((g + h)\))\)\^2\/\@\(\((\((a + b)\)\^2 + \((e + f)\)\ \((a + b)\) + \((c + \
d)\)\^2 + \((c + d)\)\ \((g + h)\))\)\^2\ \((\((e + f)\)\^2 + \((a + b)\)\ \
\((e + f)\) + \((g + h)\)\^2 + \((c + d)\)\ \((g + h)\))\)\^2\)\)\), \
\(\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + h)\))\)\^2\/\@\
\(\((\((a + c)\)\^2 + \((e + g)\)\ \((a + c)\) + \((b + d)\)\^2 + \((b + d)\)\
\ \((f + h)\))\)\^2\ \((\((e + g)\)\^2 + \((a + c)\)\ \((e + g)\) + \((f + h)\
\)\^2 + \((b + d)\)\ \((f + h)\))\)\^2\)\)\)},
            {\(\@\(\((c\ \((e + f)\) + d\ \((e + f)\) - \((a + b)\)\ \((g + \
h)\))\)\^2\/\@\(\((\((a + b)\)\^2 + \((e + f)\)\ \((a + b)\) + \((c + d)\)\^2 \
+ \((c + d)\)\ \((g + h)\))\)\^2\ \((\((e + f)\)\^2 + \((a + b)\)\ \((e + \
f)\) + \((g + h)\)\^2 + \((c + d)\)\ \((g + h)\))\)\^2\)\)\), 
              "1", \(\@\(\((d\ e + h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \
\((d + h)\))\)\^2\/\@\(\((\((a + e)\)\^2 + \((c + g)\)\ \((a + e)\) + \((b + \
f)\)\^2 + \((b + f)\)\ \((d + h)\))\)\^2\ \((\((c + g)\)\^2 + \((a + e)\)\ \
\((c + g)\) + \((d + h)\)\^2 + \((b + f)\)\ \((d + h)\))\)\^2\)\)\)},
            {\(\@\(\((b\ \((e + g)\) + d\ \((e + g)\) - \((a + c)\)\ \((f + \
h)\))\)\^2\/\@\(\((\((a + c)\)\^2 + \((e + g)\)\ \((a + c)\) + \((b + d)\)\^2 \
+ \((b + d)\)\ \((f + h)\))\)\^2\ \((\((e + g)\)\^2 + \((a + c)\)\ \((e + \
g)\) + \((f + h)\)\^2 + \((b + d)\)\ \((f + h)\))\)\^2\)\)\), \(\@\(\((d\ e + \
h\ e - c\ f - f\ g - b\ \((c + g)\) + a\ \((d + h)\))\)\^2\/\@\(\((\((a + \
e)\)\^2 + \((c + g)\)\ \((a + e)\) + \((b + f)\)\^2 + \((b + f)\)\ \((d + \
h)\))\)\^2\ \((\((c + g)\)\^2 + \((a + e)\)\ \((c + g)\) + \((d + h)\)\^2 + \
\((b + f)\)\ \((d + h)\))\)\^2\)\)\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(detfun[case]\)[a_, \ b_, \ c_, \ d_, e_, \ f_, \ g_, \ h_]\  = \ 
        0\  \[LessEqual] \ Det[ncmat[case]]\  \[LessEqual] \ 1;\)\)], "Input"],

Cell[BoxData[
    \(\(possibilities\  = \ {1, \ 100, \ 10000, \ 10^6};\)\)], "Input"],

Cell[BoxData[
    \(\(tab\  = \ Table[possibilities\ , \ {i, \ 1, \ 8}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[Sum, \ 
        case]\  = \ \ {Length\  \[Rule] \ \ Length[
              possibilities\ ]^8}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 65536}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(combi\  = \ Outer[List, Sequence\  @@ \ tab];\)\)], "Input"],

Cell[BoxData[
    \(\(resdets[case]\  = \ 
        Outer[detfun[case], Sequence\  @@ \ tab];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(resdets[case]\  // \ Flatten\)\  // \ Union\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{False, True}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[False, \ case]\  = \ 
        Position[resdets[case], \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[False, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[False, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 672}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(pos[True, \ \ case] = \ Position[resdets[case], \ True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncposdef[True, \ 
        case]\  = \ \ {Length\  \[Rule] \ 
          Length[pos[True, \ case]]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Length \[Rule] 64864}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Review", "Subsubsection"],

Cell[TextData[{
  "We checked 0 \[LessEqual] Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "] \[LessEqual] 1 where the ",
  StyleBox["R",
    FontWeight->"Bold"],
  " was based upon nominal correlations using either the border matrices or \
all submatrices. The following summarizes the results. This is a contingency \
table on issues pertaining to contingency tables."
}], "Text"],

Cell["\<\
heading = TableHeadings \[Rule] {{True, False, Sum}, {BorderMatrices, All, \
AllMin, AllMax}};\
\>", "Input"],

Cell["InsideTable[Set, ncposdef, heading] ", "Input"],

Cell["\<\
Remember: this outcome now holds for the stronger measure for the volume \
ratio. \
\>", "Text"],

Cell[CellGroupData[{

Cell["InsideTable[Show, Length]", "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["BorderMatrices",
                "TraditionalForm"], 
              FormBox["All",
                "TraditionalForm"], 
              FormBox["AllMin",
                "TraditionalForm"], 
              FormBox["AllMax",
                "TraditionalForm"]},
            {
              FormBox["True",
                "TraditionalForm"], "64864", "62132", "65244", "48944"},
            {
              FormBox["False",
                "TraditionalForm"], "672", "3404", "292", "16592"},
            {
              FormBox["Sum",
                "TraditionalForm"], "65536", "65536", "65536", "65536"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{True, False, Sum}, {BorderMatrices, 
            All, AllMin, AllMax}}]]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The stronger measure indeed is stronger: instead of 10% we now only have 5% \
of the cases in the default method of nominal correlation. However, the \
border matrices that showed 0% before now show 1%. All things considered, the \
best option still seems to take the weaker measure as the default.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Be sure to reset", "Subsection"],

Cell["\<\
The last simulation used the volume ratio method Strong. This should be reset \
now to its original default value.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[VolumeRatio, \ 
      VolumeRatioMethod\  \[Rule] \ Automatic]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{VolumeRatioMethod \[Rule] Automatic}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VolumeRatio[{{a, \ b}, \ {c, \ d}}]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a + c)\)\ \
\((b + d)\)\ \((c + d)\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(SetOptions[PairwiseSign, \ ForceSign\  \[Rule] \ False];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VolumeRatio[{{a, \ b}, \ {c, \ d}}]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\@\(\((b\ c - a\ d)\)\^2\/\(\((a + b)\)\ \((a + c)\)\ \
\((b + d)\)\ \((c + d)\)\)\)\ \(sgn(a\ d - b\ c)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix I: Overview of variants", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell[TextData[{
  "We have these variants: ",
  StyleBox["mode",
    FontSlant->"Italic"],
  " {MultipleRSquared, Det}, ",
  StyleBox["method",
    FontSlant->"Italic"],
  " {",
  StyleBox["B",
    FontSlant->"Italic"],
  " = BorderMatrices, ",
  StyleBox["A",
    FontSlant->"Italic"],
  " = All inner matrices}, for the latter the ",
  StyleBox["manner",
    FontSlant->"Italic"],
  " {Automatic is the weighted average, Min, Max}, and subsequently whether \
we test for the bounds and if necessary adjust by maximizing \[Lambda] such \
that 0 \[LessEqual] \[Lambda] \[LessEqual] 1 and  0 \[LessEqual] Det[",
  StyleBox["R =",
    FontWeight->"Bold"],
  " (1 - \[Lambda]) ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "B"], TraditionalForm]]],
  "  + \[Lambda] ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "A"], TraditionalForm]]],
  " ] \[LessEqual] 1, and possibly even a PSD-approximation on top. ",
  StyleBox["Appendix H",
    FontWeight->"Bold"],
  " gave a simulation of outcomes without any such PSD-adjustment. It will be \
instructive to see concrete examples of the cases with and without \
adjustment. "
}], "Text"],

Cell["\<\
A review will present the various matrices of association and correlation. \
Since these can be equal, i.e. when there is no adjustment with some \
\[Lambda], we will include a test in the review on equality and only show \
both when there is difference. The size of the output already indicates \
whether there is a difference or not. In this review, we might consider print \
all the \[Lambda] but do this standardly only for the suggested default \
algorithm and by exception only for the case when there is value different \
from 0.\
\>", "Text"],

Cell["\<\
PM. We run these cases with the default setting that the sign of the \
correlations matter. For the submatrices considered here this would be \
unambiguous since these are 2 \[Times] 2 (square). The signs obviously are \
important for the Min and Max manners, while they also mitigate the outcome \
of averaging.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. The example from the introduction", "Subsection"],

Cell["\<\
This contingency table is innerly fully symmetric and (thus) all variants \
generate about the same outcome, with a slight difference in the mode \
MultipleRSquared or Det. The results fall into the bounds.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      mat\  = \ {{{5, \ 1}, \ {8, \ 2}}, \ {{2, \ 8}, \ {1, \ 5}}}, \ 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "5"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"8"},
                  {"2"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "2"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "8"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"5"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{5, 1}, {8, 2}}, {{2, 8}, {1, 5}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BorderMatrices[mat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\({1, 2}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"6", "10"},
                  {"10", "6"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({1, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"13", "3"},
                  {"3", "13"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({2, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"7", "9"},
                  {"9", "7"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationReview[mat]\ \  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Matrix(NominalCorrelation, Equal, 
              VolumeRatio) \[Rule] {True, True, True, True}\), ",", 
          RowBox[{\(Matrix(NominalCorrelation)\), "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"BorderMatrices", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", \(-0.25`\), "0.625`"},
                        {\(-0.25`\), "1.`", \(-0.125`\)},
                        {"0.625`", \(-0.125`\), "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Automatic", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", \(-0.22191676197856086`\), 
                          "0.6180700462007376`"},
                        {\(-0.22191676197856086`\), "1.`", 
                          "0.04134491152973615`"},
                        {"0.6180700462007376`", "0.04134491152973615`", 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Min", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", \(-0.22191676197856086`\), 
                          "0.6180700462007376`"},
                        {\(-0.22191676197856086`\), "1.`", 
                          "0.04134491152973615`"},
                        {"0.6180700462007376`", "0.04134491152973615`", 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Max", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", \(-0.22191676197856086`\), 
                          "0.6180700462007376`"},
                        {\(-0.22191676197856086`\), "1.`", 
                          "0.04134491152973615`"},
                        {"0.6180700462007376`", "0.04134491152973615`", 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{"Table", "\[Rule]", 
            TagBox[GridBox[{
                  {
                    FormBox["\<\"\"\>",
                      "TraditionalForm"], 
                    FormBox["BorderMatrices",
                      "TraditionalForm"], 
                    FormBox["Automatic",
                      "TraditionalForm"], 
                    FormBox["Min",
                      "TraditionalForm"], 
                    FormBox["Max",
                      "TraditionalForm"]},
                  {
                    FormBox[\(VolumeRatio(MultipleRSquared)\),
                      "TraditionalForm"], "0.6485637367560112`", 
                    "0.6658507727534974`", "0.6658507727534974`", 
                    "0.6658507727534974`"},
                  {
                    FormBox[\(VolumeRatio(Det)\),
                      "TraditionalForm"], "0.6555055301063447`", 
                    "0.6665649087989188`", "0.6665649087989188`", 
                    "0.6665649087989188`"},
                  {
                    FormBox[\(NominalCorrelation(MultipleRSquared)\),
                      "TraditionalForm"], "0.6485637367560112`", 
                    "0.6658507727534974`", "0.6658507727534974`", 
                    "0.6658507727534974`"},
                  {
                    FormBox[\(NominalCorrelation(Det)\),
                      "TraditionalForm"], "0.6555055301063447`", 
                    "0.6665649087989188`", "0.6665649087989188`", 
                    "0.6665649087989188`"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ BoxForm`e$, TableHeadings -> {{
                  VolumeRatio[ MultipleRSquared], 
                  VolumeRatio[ Det], 
                  NominalCorrelation[ MultipleRSquared], 
                  NominalCorrelation[ Det]}, {BorderMatrices, Automatic, Min, 
                  Max}}]]]}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor\  /. \ 
      Results[NominalCorrelationMatrix, \ {All, \ Automatic}, \ 
        True]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. A case of conditional independence", "Subsection"],

Cell["\<\
In conditional independence, the problem is essentially a 2 \[Times] 2 case \
so that all outcomes are the same.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      mat\  = \ {{{a, \ b}, \ {b, \ a}}, \ {{a, \ b}, \ {b, \ 
                a}}}\  /. \ {a\  \[Rule] \ 5, \ b\ \  \[Rule] \ 8}, \ 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "5"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "8"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"8"},
                  {"5"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "5"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "8"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"8"},
                  {"5"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{5, 8}, {8, 5}}, {{5, 8}, {8, 5}}}, TableHeadings -> {{
          "Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", "No fit"}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BorderMatrices[mat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\({1, 2}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"13", "13"},
                  {"13", "13"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({1, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"13", "13"},
                  {"13", "13"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({2, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"10", "16"},
                  {"16", "10"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationReview[mat]\  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Matrix(NominalCorrelation, Equal, 
              VolumeRatio) \[Rule] {True, True, True, True}\), ",", 
          RowBox[{\(Matrix(NominalCorrelation)\), "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"BorderMatrices", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.`", "0.`"},
                        {"0.`", "1.`", \(-0.23076923076923078`\)},
                        {"0.`", \(-0.23076923076923078`\), "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Automatic", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.`", "0.`"},
                        {"0.`", "1.`", \(-0.23076923076923078`\)},
                        {"0.`", \(-0.23076923076923078`\), "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Min", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.`", "0.`"},
                        {"0.`", "1.`", \(-0.23076923076923078`\)},
                        {"0.`", \(-0.23076923076923078`\), "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Max", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.`", "0.`"},
                        {"0.`", "1.`", \(-0.23076923076923078`\)},
                        {"0.`", \(-0.23076923076923078`\), "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{"Table", "\[Rule]", 
            TagBox[GridBox[{
                  {
                    FormBox["\<\"\"\>",
                      "TraditionalForm"], 
                    FormBox["BorderMatrices",
                      "TraditionalForm"], 
                    FormBox["Automatic",
                      "TraditionalForm"], 
                    FormBox["Min",
                      "TraditionalForm"], 
                    FormBox["Max",
                      "TraditionalForm"]},
                  {
                    FormBox[\(VolumeRatio(MultipleRSquared)\),
                      "TraditionalForm"], "0.23076923076923078`", 
                    "0.23076923076923078`", "0.23076923076923078`", 
                    "0.23076923076923078`"},
                  {
                    FormBox[\(VolumeRatio(Det)\),
                      "TraditionalForm"], "0.23076923076923078`", 
                    "0.23076923076923078`", "0.23076923076923078`", 
                    "0.23076923076923078`"},
                  {
                    FormBox[\(NominalCorrelation(MultipleRSquared)\),
                      "TraditionalForm"], "0.23076923076923078`", 
                    "0.23076923076923078`", "0.23076923076923078`", 
                    "0.23076923076923078`"},
                  {
                    FormBox[\(NominalCorrelation(Det)\),
                      "TraditionalForm"], "0.23076923076923078`", 
                    "0.23076923076923078`", "0.23076923076923078`", 
                    "0.23076923076923078`"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ BoxForm`e$, TableHeadings -> {{
                  VolumeRatio[ MultipleRSquared], 
                  VolumeRatio[ Det], 
                  NominalCorrelation[ MultipleRSquared], 
                  NominalCorrelation[ Det]}, {BorderMatrices, Automatic, Min, 
                  Max}}]]]}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor\  /. \ 
      Results[NominalCorrelationMatrix, \ {All, \ Automatic}, \ 
        True]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. An example where Det[R] is not in the required range", "Subsection"],

Cell["\<\
This example has been taken from the simulation. The suggested standard \
algorithm comes into problems but this may have to do with the wide range of \
input values. PSD-adjustment still saves the day.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[mat\  = \ {{{1, 1}, {1, 1}}, {{1, 10000}, {1000000, 100}}}\ , 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "1"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "1"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "10000"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1000000"},
                  {"100"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{1, 1}, {1, 1}}, {{1, 10000}, {1000000, 100}}}, 
          TableHeadings -> {{"Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", 
          "No fit"}}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BorderMatrices[mat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\({1, 2}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"2", "2"},
                  {"10001", "1000100"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({1, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"2", "2"},
                  {"1000001", "10100"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({2, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"2", "10001"},
                  {"1000001", "101"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The default mode uses MultipleRSquared, such that the Automatic application \
of weighted averages of inner submatrices generates a correlation that is 4. \
The cause is that the \[OpenCurlyDoubleQuote]correlation matrix\
\[CloseCurlyDoubleQuote] is not really a correlation matrix since the \
determinant is not between 0 and 1. We have to adjust to get a result within \
the bounds. Also the Min case gives a problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationReview[mat]\  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-0.17477532683115943`\\)\\) outside [0, 1]\"\
\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-0.009354485790059161`\\)\\) outside [0, \
1]\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-0.17477532683115943`\\)\\) outside [0, 1]\"\
\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(TraditionalForm\\`\\(CorrelationMatrixQ :: \\\"psd\\\"\\)\\) will be \
suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Matrix(NominalCorrelation, Equal, 
              VolumeRatio) \[Rule] {True, False, False, True}\), ",", 
          RowBox[{\(Matrix(VolumeRatio)\), "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"BorderMatrices", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", 
                          "0.009849381036843864`", \
\(-0.009799525084037888`\)},
                        {"0.009849381036843864`", 
                          "1.`", \(-0.9948377050545376`\)},
                        {\(-0.009799525084037888`\), \(-0.9948377050545376`\),
                           "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Automatic", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", 
                          "0.49430540455673744`", \(-0.0647020277751229`\)},
                        {"0.49430540455673744`", 
                          "1.`", \(-0.9949332490867923`\)},
                        {\(-0.0647020277751229`\), \(-0.9949332490867923`\), 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Min", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.06930700140731966`\), \
\(-0.07034916595088353`\)},
                        {\(-0.06930700140731966`\), 
                          "1.`", \(-0.9949371890224981`\)},
                        {\(-0.07034916595088353`\), \(-0.9949371890224981`\), 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Max", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.499999000001`", "0.4999000099990001`"},
                        {"0.499999000001`", "1.`", "0.`"},
                        {"0.4999000099990001`", "0.`", "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{\(Matrix(NominalCorrelation)\), "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"BorderMatrices", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", 
                          "0.009849381036843864`", \
\(-0.009799525084037888`\)},
                        {"0.009849381036843864`", 
                          "1.`", \(-0.9948377050545376`\)},
                        {\(-0.009799525084037888`\), \(-0.9948377050545376`\),
                           "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Automatic", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", 
                          "0.12377670613679521`", \
\(-0.022710697552164597`\)},
                        {"0.12377670613679521`", 
                          "1.`", \(-0.9948601737111249`\)},
                        {\(-0.022710697552164597`\), \(-0.9948601737111249`\),
                           "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Min", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.04731983833901832`\), \
\(-0.053530372742319206`\)},
                        {\(-0.04731983833901832`\), 
                          "1.`", \(-0.9949095554930381`\)},
                        {\(-0.053530372742319206`\), \(-0.9949095554930381`\),
                           "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Max", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.499999000001`", "0.4999000099990001`"},
                        {"0.499999000001`", "1.`", "0.`"},
                        {"0.4999000099990001`", "0.`", "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{"Table", "\[Rule]", 
            TagBox[GridBox[{
                  {
                    FormBox["\<\"\"\>",
                      "TraditionalForm"], 
                    FormBox["BorderMatrices",
                      "TraditionalForm"], 
                    FormBox["Automatic",
                      "TraditionalForm"], 
                    FormBox["Min",
                      "TraditionalForm"], 
                    FormBox["Max",
                      "TraditionalForm"]},
                  {
                    FormBox[\(VolumeRatio(MultipleRSquared)\),
                      "TraditionalForm"], "0.9948377101256987`", 
                    "4.276807591250303`", "1.3878716216112201`", 
                    "0.7070353739375423`"},
                  {
                    FormBox[\(VolumeRatio(Det)\),
                      "TraditionalForm"], "0.994838207150055`", 
                    "1.0838705304745393`", "1.0046663554583977`", 
                    "0.7070353739375423`"},
                  {
                    FormBox[\(NominalCorrelation(MultipleRSquared)\),
                      "TraditionalForm"], "0.9948377101256987`", 
                    "0.9999949974072774`", "0.9999949887664829`", 
                    "0.7070353739375423`"},
                  {
                    FormBox[\(NominalCorrelation(Det)\),
                      "TraditionalForm"], "0.994838207150055`", 
                    "0.9999949999875`", "0.9999949999875001`", 
                    "0.7070353739375423`"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ BoxForm`e$, TableHeadings -> {{
                  VolumeRatio[ MultipleRSquared], 
                  VolumeRatio[ Det], 
                  NominalCorrelation[ MultipleRSquared], 
                  NominalCorrelation[ Det]}, {BorderMatrices, Automatic, Min, 
                  Max}}]]]}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor\  /. \ 
      Results[NominalCorrelationMatrix, \ {All, \ Automatic}, \ 
        True]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.23516546305316618`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Another example where Det[R] is not in the required range", \
"Subsection"],

Cell["\<\
This example has been taken from the simulation too. Here the values range \
only between 1 and 100.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[mat\  = \ {{{1, 1}, {1, 100}}, {{100, 100}, {100, 1}}}\ , 
      TableHeadings\  \[Rule] \ {{"\<Shop1\>", \ "\<Shop2\>"}, \ \
{"\<Green\>", \ "\<Blue\>"}\ , \ {"\<Fit\>", \ "\<No fit\>"}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Green\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Blue\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Shop1\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "1"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"100"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Shop2\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Fit\"\>",
                      "TraditionalForm"], "100"},
                  {
                    FormBox["\<\"No fit\"\>",
                      "TraditionalForm"], "100"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"100"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{1, 1}, {1, 100}}, {{100, 100}, {100, 1}}}, 
          TableHeadings -> {{"Shop1", "Shop2"}, {"Green", "Blue"}, {"Fit", 
          "No fit"}}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BorderMatrices[mat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\({1, 2}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"2", "101"},
                  {"200", "101"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({1, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"2", "101"},
                  {"200", "101"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{\({2, 3}\), "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"101", "101"},
                  {"101", "101"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The default mode uses MultipleRSquared, such that the Min application on \
inner submatrices generates a correlation of 7.39. The cause is that the \
matrix of pairwise correlation coefficients is not a PSD correlation matrix \
since the determinant is not between 0 and 1. Using the function Min \
increases the absolute size of the pairwise correlations, making it more \
difficult for them to be consistent.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalCorrelationReview[mat]\ \  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-2.1035360054974226`\\)\\) outside [0, \
1]\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-2.1035360054974226`\\)\\) outside [0, \
1]\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Matrix(NominalCorrelation, Equal, 
              VolumeRatio) \[Rule] {True, True, False, True}\), ",", 
          RowBox[{\(Matrix(VolumeRatio)\), "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"BorderMatrices", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.5622550106751559`\), \
\(-0.5622550106751559`\)},
                        {\(-0.5622550106751559`\), "1.`", "0.`"},
                        {\(-0.5622550106751559`\), "0.`", "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Automatic", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.4900990099009901`\), \
\(-0.4900990099009901`\)},
                        {\(-0.4900990099009901`\), 
                          "1.`", \(-0.2401970395059308`\)},
                        {\(-0.4900990099009901`\), \(-0.2401970395059308`\), 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Min", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.9801980198019802`\), \
\(-0.9801980198019802`\)},
                        {\(-0.9801980198019802`\), 
                          "1.`", \(-0.4900990099009901`\)},
                        {\(-0.9801980198019802`\), \(-0.4900990099009901`\), 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Max", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.`", "0.`"},
                        {"0.`", "1.`", "0.4900990099009901`"},
                        {"0.`", "0.4900990099009901`", "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{\(Matrix(NominalCorrelation)\), "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"BorderMatrices", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.5622550106751559`\), \
\(-0.5622550106751559`\)},
                        {\(-0.5622550106751559`\), "1.`", "0.`"},
                        {\(-0.5622550106751559`\), "0.`", "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Automatic", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.4900990099009901`\), \
\(-0.4900990099009901`\)},
                        {\(-0.4900990099009901`\), 
                          "1.`", \(-0.2401970395059308`\)},
                        {\(-0.4900990099009901`\), \(-0.2401970395059308`\), 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Min", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {
                          "1.`", \(-0.6637095802025864`\), \
\(-0.6637095802025864`\)},
                        {\(-0.6637095802025864`\), 
                          "1.`", \(-0.1189702495065219`\)},
                        {\(-0.6637095802025864`\), \(-0.1189702495065219`\), 
                          "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{"Max", "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1.`", "0.`", "0.`"},
                        {"0.`", "1.`", "0.4900990099009901`"},
                        {"0.`", "0.4900990099009901`", "1.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{"Table", "\[Rule]", 
            TagBox[GridBox[{
                  {
                    FormBox["\<\"\"\>",
                      "TraditionalForm"], 
                    FormBox["BorderMatrices",
                      "TraditionalForm"], 
                    FormBox["Automatic",
                      "TraditionalForm"], 
                    FormBox["Min",
                      "TraditionalForm"], 
                    FormBox["Max",
                      "TraditionalForm"]},
                  {
                    FormBox[\(VolumeRatio(MultipleRSquared)\),
                      "TraditionalForm"], "0.7951486616090349`", 
                    "0.7951486616090349`", "7.392254526204981`", 
                    "0.4900990099009901`"},
                  {
                    FormBox[\(VolumeRatio(Det)\),
                      "TraditionalForm"], "0.7951486616090349`", 
                    "0.8083798193758319`", "1.7616855580657471`", 
                    "0.4900990099009901`"},
                  {
                    FormBox[\(NominalCorrelation(MultipleRSquared)\),
                      "TraditionalForm"], "0.7951486616090349`", 
                    "0.7951486616090349`", "0.9999949282014887`", 
                    "0.4900990099009901`"},
                  {
                    FormBox[\(NominalCorrelation(Det)\),
                      "TraditionalForm"], "0.7951486616090349`", 
                    "0.8083798193758319`", "0.9999949999874999`", 
                    "0.4900990099009901`"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ BoxForm`e$, TableHeadings -> {{
                  VolumeRatio[ MultipleRSquared], 
                  VolumeRatio[ Det], 
                  NominalCorrelation[ MultipleRSquared], 
                  NominalCorrelation[ Det]}, {BorderMatrices, Automatic, Min, 
                  Max}}]]]}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor\  /. \ 
      Results[NominalCorrelationMatrix, \ {All, \ Automatic}, \ 
        True]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor\  /. \ 
      Results[NominalCorrelationMatrix, \ {All, \ Min}, \ True]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.24274737778098407`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Subsection"],

Cell[TextData[{
  "This appendix considered contingency tables of higher dimensions (more \
than ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[Times] ",
  StyleBox["n",
    FontSlant->"Italic"],
  "). The suggested algorithm seems to work fairly well: (i) use the weighted \
average of the volume ratio measures of the inner matrices (the method called \
All with the manner Automatic), (ii) if this is not PSD then take the maximal \
\[Lambda] such that 0 \[LessEqual] \[Lambda] \[LessEqual] 1 and  0 \
\[LessEqual] Det[",
  StyleBox["R =",
    FontWeight->"Bold"],
  " (1 - \[Lambda]) ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "B"], TraditionalForm]]],
  "  + \[Lambda] ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "A"], TraditionalForm]]],
  " ] \[LessEqual] 1, (iii) if this still is not PSD (e.g. when ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "B"], TraditionalForm]]],
  " itself is not), take the PSD approximation (by default making the \
eigenvalues nonnegative). An adjustment was only required in case 3 \
considered above, where the range in values might be seen as extreme."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix J: Finding the closest PSD correlation matrix", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell[TextData[{
  "Consider the non-PSD association matrix (symmetric, diagonal 1, elements \
between 0 and 1) but not 0 \[LessEqual] Det[R] \[LessEqual] 1, and consider \
the question to find a closest PSD matrix. The solution of course depends \
upon the notion of \[OpenCurlyDoubleQuote]closeness\[CloseCurlyDoubleQuote]. \
Higham (1989) uses some measures of which we might use the Frobenius norm \
here, i.e. the Euclidean norm on all elements. The result that he presents \
however concerns a general PSD matrix and not one with diagonal 1. Another \
approach is to set all eigenvalues to a nonnegative value. Even when we make \
sure that the sum of these new nonnegative eigenvalues is equal to the \
dimension of matrix, we find that in practice a matrix may result that has no \
1 on the diagonal, just as a result of numerical rounding off. In both cases, \
a practical solution might be to divide rows and columns by the square root \
of the appropriate diagonal element. The latter reflects the way that a \
correlation matrix is created from a variance-covariance matrix. Next to \
these more theoretical approaches (though with the practical diagonal \
adjustment) there are also the straightforward numerical approaches by \
adjusting the off-diagonal elements in some uniform manner. These approaches \
have little theory but do have the advantage of working directly with the \
elements and not with some hidden matrices or eigenvalues. In that manner one \
can aspire at some adjustment that maintains some \[OpenCurlyDoubleQuote]grid\
\[CloseCurlyDoubleQuote]. A very attractive approach is, for off-diagonal \
element ",
  StyleBox["r,",
    FontSlant->"Italic"],
  " to take the adjusted value ",
  Cell[BoxData[
      \(TraditionalForm\`r\^\(\(\ \)\(x\)\)\)]],
  StyleBox["x  ",
    FontSlant->"Italic"],
  "for 0 < ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "< 1, so that one includes both a proportional effect and a power effect. "
}], "Text"],

Cell["\<\
These issues can be clarified with the following examples (taken from the \
simulations).\
\>", "Text"],

Cell[BoxData[
    \(\(mat\  = \ {{{1, 1}, {1, 1}}, {{1, 10000}, {1000000, 
              100}}}\ ;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(associationMat = \ VolumeRatioMatrix[mat]\ \  // \ N\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.49430540455673744`", \(-0.0647020277751229`\)},
            {"0.49430540455673744`", "1.`", \(-0.9949332490867923`\)},
            {\(-0.0647020277751229`\), \(-0.9949332490867923`\), "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CorrelationMatrixQ[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(CorrelationMatrixQ::"psd"\), \(\(:\)\(\ \)\), "\<\"Not PSD, \
Det = \\!\\(TraditionalForm\\`\\(-0.1747753268311596`\\)\\) outside [0, \
1]\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`False\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Higham (1989)", "Subsection"],

Cell["\<\
Higham\[CloseCurlyQuote]s solution for the Frobenius norm generates a \
positive semi definite matrix yet the diagonal may not be unity.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hf\  = \ ToPSDMatrix["\<HighamF\>", \ associationMat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.007114917689008`", 
              "0.476604066153134`", \(-0.08049224586529413`\)},
            {"0.476604066153134`", 
              "1.0440394948999856`", \(-0.9556484665920293`\)},
            {\(-0.08049224586529413`\), \(-0.9556484665920293`\), 
              "1.0350434113553226`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Definiteness[hf]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Positive, Semi, Definiteness}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CorrelationMatrixQ[hf]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`CorrelationMatrixQ::"diag" \(\(:\)\(\ \)\) 
      "Matrix doesn't have a diagonal of 1"\)], "Message"],

Cell[BoxData[
    \(TraditionalForm\`False\)], "Output"]
}, Open  ]],

Cell["\<\
However, when we divide by the diagonal elements then we find a proper PSD \
correlation matrix, and the differences from the original input are not too \
large.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newnc\  = \ 
      ToPSDCorrelationMatrix[associationMat, \ 
        Do\  \[Rule] \ {"\<HighamF\>", \ UnitDiagonalMatrix}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.0000000000000002`", 
              "0.4647931991330347`", \(-0.07883793640707268`\)},
            {"0.4647931991330347`", "1.`", \(-0.919306690364672`\)},
            {\(-0.07883793640707268`\), \(-0.919306690364672`\), 
              "0.9999999999999998`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(difhf\  = \ newnc\  - \ associationMat\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "2.220446049250313`*^-16", \(-0.029512205423702753`\), \
\(-0.014135908631949773`\)},
            {\(-0.029512205423702753`\), "0.`", "0.07562655872212021`"},
            {\(-0.014135908631949773`\), 
              "0.07562655872212021`", \(-2.220446049250313`*^-16\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FrobeniusDistance\  \[Rule] \ Sqrt[Add[%^2]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`FrobeniusDistance \[Rule] 
      0.11653472071423142`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nonnegative eigenvalues", "Subsection"],

Cell["\<\
Setting the eigenvalues to nonnegative values doesn\[CloseCurlyQuote]t \
guarantee a proper diagonal. But the test might already break down due to \
symmetry problems due to numerical precision. We neglect that issue just for \
now.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nonnegev\  = \ ToPSDMatrix["\<NonnegEV\>", \ associationMat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9789860940299651`", 
              "0.46329246536504615`", \(-0.07824408912558395`\)},
            {"0.46329246536504615`", 
              "1.0148793639861209`", \(-0.928957106227231`\)},
            {\(-0.07824408912558395`\), \(-0.928957106227231`\), 
              "1.0061345419839145`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Definiteness[nonnegev\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Positive, Semi, Definiteness}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CorrelationMatrixQ[nonnegev\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`CorrelationMatrixQ::"diag" \(\(:\)\(\ \)\) 
      "Matrix doesn't have a diagonal of 1"\)], "Message"],

Cell[BoxData[
    \(TraditionalForm\`False\)], "Output"]
}, Open  ]],

Cell["\<\
When we re-diagonalize then we find a proper PSD correlation matrix, and the \
differences from the original input are not too large. (Neglecting possibly \
symmetry issues due to numerical precision.)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newnc\  = \ 
      ToPSDCorrelationMatrix[associationMat, \ 
        Do\  \[Rule] \ {"\<NonnegEV\>", \ UnitDiagonalMatrix}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.4647931991330348`", \(-0.07883793640707264`\)},
            {"0.4647931991330348`", 
              "1.0000000000000002`", \(-0.9193066903646724`\)},
            {\(-0.07883793640707264`\), \(-0.9193066903646724`\), 
              "0.9999999999999999`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The problems of the diagonal and symmetry are solved to an error of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-15\)\)]],
  ". The differences between the original non-PSD correlations and the \
approximated PSD correlations are not too large."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newnc\  - \ associationMat\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.`", \(-0.029512205423702642`\), \(-0.014135908631949731`\)},
            {\(-0.029512205423702642`\), "2.220446049250313`*^-16", 
              "0.07562655872211987`"},
            {\(-0.014135908631949731`\), 
              "0.07562655872211987`", \(-1.1102230246251565`*^-16\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
In fact, the differences are the same as the earlier solution with Higham\
\[CloseCurlyQuote]s Frobenius norm. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(difhf\  - \ %\  // \ Chop\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A numerical approach", "Subsection"],

Cell[TextData[{
  "A plain non-theoretical but numerical approach is to gradually adjust the \
off-diagonal correlations till the determinant is in the appropriate range. \
The following is a general expression, using parameters \[Alpha] and \[Beta], \
while minimizing Det[",
  StyleBox["R",
    FontWeight->"Bold"],
  "[",
  StyleBox["x; \[Alpha]",
    FontSlant->"Italic"],
  ", \[Beta]]] over ",
  StyleBox["x. ",
    FontSlant->"Italic"],
  "Only parameter values 0 or 1 have been programmed. An attractive method \
with \[Alpha] = \[Beta] = 1 can be called \[OpenCurlyDoubleQuote]gradual\
\[CloseCurlyDoubleQuote]. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(res\  = \ 
      ToPSDCorrelationMatrix[{\[Alpha], \ \[Beta], \ x}, \ 
        associationMat]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(0.49430540455673744`\^\(x\ \[Alpha] - \[Alpha] + 1\)\ \
\((x\ \[Beta] - \[Beta] + 
                    1)\)\), \(\(-0.0647020277751229`\^\(x\ \[Alpha] - \
\[Alpha] + 1\)\)\ \((x\ \[Beta] - \[Beta] + 1)\)\)},
            {\(0.49430540455673744`\^\(x\ \[Alpha] - \[Alpha] + 1\)\ \((x\ \
\[Beta] - \[Beta] + 1)\)\), 
              "1", \(\(-0.9949332490867923`\^\(x\ \[Alpha] - \[Alpha] + 1\)\)\
\ \((x\ \[Beta] - \[Beta] + 1)\)\)},
            {\(\(-0.0647020277751229`\^\(x\ \[Alpha] - \[Alpha] + 1\)\)\ \((x\
\ \[Beta] - \[Beta] + 
                    1)\)\), \(\(-0.9949332490867923`\^\(x\ \[Alpha] - \
\[Alpha] + 1\)\)\ \((x\ \[Beta] - \[Beta] + 1)\)\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ {\[Alpha]\  \[Rule] \ 1, \ \[Beta]\  \[Rule] \ 1}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "1", \(0.49430540455673744`\^x\ x\), \
\(\(-0.0647020277751229`\^x\)\ x\)},
            {\(0.49430540455673744`\^x\ x\), 
              "1", \(\(-0.9949332490867923`\^x\)\ x\)},
            {\(\(-0.0647020277751229`\^x\)\ x\), \
\(\(-0.9949332490867923`\^x\)\ x\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Since the original determinant is negative we solve for the lower value close \
to zero.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveDetIn0To1[\(-1\), \ %, \ x, \ 1]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0.48017554046525734`", \(-0.07473508459208686`\)},
            {"0.48017554046525734`", "1", \(-0.9105995810964195`\)},
            {\(-0.07473508459208686`\), \(-0.9105995810964195`\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Results[SolveDetIn0To1]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{x \[Rule] 0.9148410343365942`}\)], "Output"]
}, Open  ]],

Cell["The following routine combines these steps.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newnc\  = \ 
      ToPSDCorrelationMatrix[associationMat, \ 
        Do\  \[Rule] \ "\<Gradual\>"]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0.48017554046525734`", \(-0.07473508459208686`\)},
            {"0.48017554046525734`", "1", \(-0.9105995810964195`\)},
            {\(-0.07473508459208686`\), \(-0.9105995810964195`\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CorrelationMatrixQ[newnc]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In this general routine the output value of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is available as a text variable (since we didn\[CloseCurlyQuote]t provide \
a symbolic variable)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \("\<x\>"\  /. \ Results[ToPSDCorrelationMatrix, \ {1, \ 1}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9148410343365942`\)], "Output"]
}, Open  ]],

Cell["\<\
The differences between the original non-PSD correlations and the \
approximated PSD correlations are small. The Frobenius distance is a bit \
larger than the theoretical distance yet the distribution over the cells is \
different. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newnc\  - \ associationMat\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.`", \(-0.014129864091480093`\), \(-0.010033056816963953`\)},
            {\(-0.014129864091480093`\), "0.`", "0.08433366799037278`"},
            {\(-0.010033056816963953`\), "0.08433366799037278`", "0.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FrobeniusDistance\  \[Rule] \ Sqrt[Add[%^2]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`FrobeniusDistance \[Rule] 
      0.121757815724877`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(difhf\  - \ %%\  // \ Chop\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", \(-0.01538234133222266`\), \(-0.0041028518149858195`\)},
            {\(-0.01538234133222266`\), "0", \(-0.008707109268252577`\)},
            {\(-0.0041028518149858195`\), \(-0.008707109268252577`\), "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Review", "Subsection"],

Cell["\<\
When programming these routines, the method of nonnegative eigenvalues was \
selected as the default, since this both has a theoretical base and is \
relatively easy to understand and program. Precisely this method might still \
have problems due to numerical rounding off. In that case one might use the \
routine EigenChop and reapply the procedure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(associationMat\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.49430540455673744`", \(-0.0647020277751229`\)},
            {"0.49430540455673744`", "1.`", \(-0.9949332490867923`\)},
            {\(-0.0647020277751229`\), \(-0.9949332490867923`\), "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToPSDCorrelationMatrix[associationMat, \ 
      Do\  \[Rule] \ {"\<HighamF\>", \ UnitDiagonalMatrix}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.0000000000000002`", 
              "0.4647931991330347`", \(-0.07883793640707268`\)},
            {"0.4647931991330347`", "1.`", \(-0.919306690364672`\)},
            {\(-0.07883793640707268`\), \(-0.919306690364672`\), 
              "0.9999999999999998`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(newnc\  = \ 
      ToPSDCorrelationMatrix[associationMat, \ 
        Do\  \[Rule] \ {"\<NonnegEV\>", \ UnitDiagonalMatrix}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.4647931991330348`", \(-0.07883793640707264`\)},
            {"0.4647931991330348`", 
              "1.0000000000000002`", \(-0.9193066903646724`\)},
            {\(-0.07883793640707264`\), \(-0.9193066903646724`\), 
              "0.9999999999999999`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToPSDCorrelationMatrix[associationMat, \ 
      Do\  \[Rule] \ "\<Gradual\>"]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0.48017554046525734`", \(-0.07473508459208686`\)},
            {"0.48017554046525734`", "1", \(-0.9105995810964195`\)},
            {\(-0.07473508459208686`\), \(-0.9105995810964195`\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Note that these adjustment approaches have been developed just for \
\[OpenCurlyDoubleQuote]back up\[CloseCurlyDoubleQuote]. When we determine a \
nominal correlation matrix such that we make sure from the outset that it is \
PSD then there is no need to approximate PSD-ness. For the volume ratio \
measure we apparently can first see of a choice of some \[Lambda] is \
sufficient.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix K: Variances and regression coefficients", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell[TextData[{
  "With ",
  StyleBox["R",
    FontWeight->"Bold"],
  " a correlation matrix containing the pairwise simple regressions, for \
either real or nominal data, then the multiple regression coefficients can be \
found by the cofactors of ",
  StyleBox["R",
    FontWeight->"Bold"],
  " and the standard deviations of the variables. The \
\[OpenCurlyDoubleQuote]variance-covariance-regression matrix\
\[CloseCurlyDoubleQuote] ",
  StyleBox["C",
    FontSlant->"Italic"],
  " contains on each row a different explained variable, indicated by 0, and \
the relevant regression coefficients of the other variables, such that ",
  StyleBox["x == C x",
    FontSlant->"Italic"],
  " + \[Epsilon]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CovarRegress[All, \ {s1, \ s2, \ s3}]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0", \(-\(\(s1\ "R"[1, 2]\)\/\(s2\ "R"[1, 
                        1]\)\)\), \(-\(\(s1\ "R"[1, 3]\)\/\(s3\ "R"[1, 
                        1]\)\)\)},
            {\(-\(\(s2\ "R"[2, 1]\)\/\(s1\ "R"[2, 2]\)\)\), 
              "0", \(-\(\(s2\ "R"[2, 3]\)\/\(s3\ "R"[2, 2]\)\)\)},
            {\(-\(\(s3\ "R"[3, 1]\)\/\(s1\ "R"[3, 3]\)\)\), \(-\(\(s3\ "R"[3, 
                        2]\)\/\(s2\ "R"[3, 3]\)\)\), "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  "To apply above scheme for nominal data, we already have a correlation \
matrix. We only need to define variance to get regression coefficients. \
Variance is usefully defined on the border sum totals of a contingency \
matrix. For a single variable we thus get a list of frequencies per category, \
",
  StyleBox["f",
    FontSlant->"Italic"],
  " =",
  " {",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  "}. The discussion below will discuss the choice of a variance measure for \
such a list."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Variance for a single category", "Subsection"],

Cell[TextData[{
  "Since this subject has a certain complexity, it might be useful to state \
what this appendix is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " about. This appendix is about variables that have frequencies over \
categories, and this appendix is not about a single category itself. This \
distinction can best be expressed in a short manner so that one sees the \
difference. In the introductory pages we expressed that a correlation between \
categories might be expressed as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(yi, xj\)\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  " *  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_xj\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_yi\)]],
  " and thus some idea about those variances of the category elements might \
be useful."
}], "Text"],

Cell[TextData[{
  "When we assume a distribution for variable ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " then the distribution of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " is an element in that, and ",
  "the distribution of ",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "follows from ",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  " ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  " is the row of conditional probabilities. Instead of thinking of ",
  StyleBox["y",
    FontSlant->"Italic"],
  " as a weighted sum it may also help to remember that ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "is only a re-allocation of the outcomes of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", via the individual observations in the ",
  Cell[BoxData[
      \(TraditionalForm\`C\_t\)]],
  " matrix. ",
  "There are two obvious candidates for distributions for ",
  StyleBox["x, ",
    FontSlant->"Italic"],
  "with consequences for",
  " the standard deviations: "
}], "Text"],

Cell[TextData[{
  "  ",
  StyleBox["1.",
    FontWeight->"Bold"],
  "  When ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is multinomial, then ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " may be taken as binomial, and ",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  " is a weighted sum of binomials that might be approximated again with a \
binomial. With the bernoulli distribution we get ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(p\_j\ \((1 - p\_j)\)\)\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(q\_i\ \((1 - q\_i)\)\)\)]],
  " and for the binomial we get an influence of ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\_++\)\)]],
  " that however drops out of the ratio. Then ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(yi, xj\)\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(+j\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(n\_\(+j\)\ \((\(n\_++\) - n\_\(+j\))\)\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(n\_\(\(i\)\(+\)\)\ \((\(n\_++\) - \
n\_\(\(i\)\(+\)\))\)\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(n\_\(+j\)\ \ n\_\(\(i\)\(+\)\)\)\)]],
  " * ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            RowBox[{"(", 
              FormBox[\(\(n\_++\) - n\_\(+j\)\),
                "TraditionalForm"], ")"}], "/", 
            RowBox[{"(", 
              FormBox[\(\(n\_++\) - n\_\(\(i\)\(+\)\)\),
                "TraditionalForm"], ")"}]}]], TraditionalForm]]],
  ". Then also ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(xj, \ yi\)\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(\(i\)\(+\)\)\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(n\_\(\(i\)\(+\)\)\ \((\(n\_++\) - \
n\_\(\(i\)\(+\)\))\)\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(n\_\(+j\)\ \((\(n\_++\) - n\_\(+j\))\)\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(n\_\(+j\)\ \ n\_\(\(i\)\(+\)\)\)\)]],
  " * ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            RowBox[{"(", 
              FormBox[\(\(n\_++\) - n\_\(\(i\)\(+\)\)\),
                "TraditionalForm"], ")"}], "/", 
            RowBox[{"(", 
              FormBox[\(\(n\_++\) - n\_\(+j\)\),
                "TraditionalForm"], ")"}]}]], TraditionalForm]]],
  ". For symmetry the bigger square roots ought to be the same. Since they \
are not, one either takes a geometric average of these correlation \
coefficients and forgets about the standard deviations, or adopts the \
following model."
}], "ItemizedText"],

Cell[TextData[{
  "  ",
  StyleBox["2.",
    FontWeight->"Bold"],
  "  Alternatively, ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is a result of ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "Poisson processes that are only dependent in that they don\
\[CloseCurlyQuote]t occur at the same time. Then ",
  StyleBox["y",
    FontSlant->"Italic"],
  " is a weighted sum of such Poissons, that might be approximated by the \
Poisson distribution again, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_yi\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@n\_\(\(i\)\(+\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_xj\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@n\_\(+j\)\)]],
  ". We then readily find ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(yi, xj\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(i, j\)\)]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(n\_\(+j\)\ \ n\_\(\(i\)\(+\)\)\)\)]],
  ". Now symmetry holds without a problem. This model hinges on the approach \
that either there are such Poisson processes or that, while perhaps the \
overall model might be a multinomial, the pairwise outcome while neglecting \
the rest might still be modelled as Poisson."
}], "ItemizedText"],

Cell["\<\
As said, the above only holds for the categories. This appendix however is \
targetted at the variables.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Variance for nominal variables", "Subsection"],

Cell[CellGroupData[{

Cell["Minimal and maximal dispersion", "Sub3section"],

Cell[TextData[{
  "Intuitively, we can choose between normal Variance and the Pearson \
measure, that are orderless measures, as fitting for nominal data. Of these, \
the Pearson measure might be best since it allows a quick connection to \
Cramer\[CloseCurlyQuote]s V ",
  "since both have the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " distribution so that their ratio is an F-distribution."
}], "Text"],

Cell[TextData[{
  "However, there arises a point that is counter-intuitive and that is both \
Variance and PearsonVariance are zero when all frequencies are equal, ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i\)]],
  ", while, for contingency tables, this actually means ",
  StyleBox["maximal ",
    FontSlant->"Italic"],
  "dispersion. Variance and PearsonVariance are maximal when all weight is in \
one cell, but for contingency tables this means ",
  StyleBox["minimal",
    FontSlant->"Italic"],
  " dispersion."
}], "Text"],

Cell["\<\
Hence, proper measures should at least be someting like 1 / (1 + Variance) or \
1 / (1 + Pearson). To better understand the issue it is useful to link up to \
ordinal data. We would like a smooth transition when nominal data suddenly \
can be seen as ordinal (when some hidden order is exposed).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ordered or orderless", "Sub3section"],

Cell["\<\
We can see the frequencies as orderless numbers as would be appropriate for \
nominal variables or adopt the alternative option to include the order of \
presentation. There always is an order of presentation, and we might \
caputilate for this and accept other ordinal methods. The two approaches are:\
\
\>", "Text"],

Cell[TextData[{
  "  ",
  StyleBox["1.",
    FontWeight->"Bold"],
  "  Use techniques from ordinal data, but maintain the interpretation of \
nominal data."
}], "ItemizedText"],

Cell[TextData[{
  "  ",
  StyleBox["2.",
    FontWeight->"Bold"],
  "  Use a measure of orderless variance, but interprete results while \
keeping in mind the order of presentation."
}], "ItemizedText"],

Cell[TextData[{
  "The correlation coefficients have been constructed without any notion of \
order. Yet, the determinant is sensitive to the presentation order. For \
example, Det[{{",
  StyleBox["a, b",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["c, d",
    FontSlant->"Italic"],
  "}}] = ",
  StyleBox["ad",
    FontSlant->"Italic"],
  " - ",
  StyleBox["bc",
    FontSlant->"Italic"],
  " while if we rearrange the rows then Det[{{",
  StyleBox["c, d",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["a, b",
    FontSlant->"Italic"],
  "}}] = ",
  StyleBox["bc - ad. ",
    FontSlant->"Italic"],
  "It may also be observed that the notion of regression has some suggestion \
of order. In the ",
  "hat shops example",
  ", using fitness as the variable to be explained and shops and colour as \
the explanatory variables, such that Fitness = \[Alpha] + \[Beta] Shop + \
\[Gamma] Colour, then the regression coefficient of \[Beta] of the shops \
would have the interpretation that a move from shop1 to shop2 would shift \
\[Beta] hats from fit to no-fit. The hat shops example only uses dichotomous \
variables and when we use the multinomial model then the interpretation would \
concern steps moving along the categories in their order of presentation. We \
can reason about this while maintaining strict nominality, yet why make life \
difficult, and why not allow for a variance measure that uses the order of \
presentation. "
}], "Text"],

Cell[TextData[{
  "The routine VariancePr is defined such that if we have a list of \
frequencies (e.g. the column sums) of length ",
  StyleBox["n",
    FontSlant->"Italic"],
  " then it assigns values {0, ...,  ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "-1",
  "} to the categories and then takes the normal variance of those values \
weighted by those frequencies. The technique is that of ordinal data but the \
interpretation remains nominal, since the only order used is the order of \
presentation. "
}], "Text"],

Cell["\<\
VariancePr is an important routine, since it helps us to see a key difference \
with orderless Variance.\
\>", "Text"],

Cell[TextData[{
  "  ",
  StyleBox["i.",
    FontWeight->"Bold"],
  "   Variance and Pearson take equal frequencies as the lowest dispersion."
}], "ItemizedText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance\  /@ \ {{1, \ 3, \ 5, \ 10}, \ {4, \ 4, \ 4, \ 4}}\  // \ 
      N\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(TraditionalForm\`{14.916666666666666`, 0.`}\)], "Output",
  CellLabel->"Out[128]="]
}, Open  ]],

Cell[TextData[{
  "  ",
  StyleBox["ii.",
    FontWeight->"Bold"],
  "   VariancePr takes equal frequencies as the case of highest dispersion. \
VariancePr still checks the mass distribution over the category values."
}], "ItemizedText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VariancePr\  /@ \ {{1, \ 3, \ 5, \ 10}, \ {4, \ 4, \ 4, \ 4}}\  // \ 
      N\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(TraditionalForm\`{0.8254847645429363`, 1.25`}\)], "Output",
  CellLabel->"Out[129]="]
}, Open  ]],

Cell["\<\
One might want to check the formal implementation of VariancePr:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VariancePr[{x1, \ x2}, \ {p1, \ p2}]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(TraditionalForm\`p1\ \((\(-p1\)\ x1 + x1 - p2\ x2)\)\^2 + 
      p2\ \((\(-p1\)\ x1 - p2\ x2 + x2)\)\^2\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VariancePr[{0, \ 1}, \ {f1, \ f2}\ /\ \((f1\  + \ f2)\)]\ \  // \ 
      Simplify\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(TraditionalForm\`\(f1\ f2\)\/\((f1 + f2)\)\^2\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VariancePr[{f1, \ f2}]\  // \ Simplify\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(TraditionalForm\`\(f1\ f2\)\/\((f1 + f2)\)\^2\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
Since we would like that the transition from nominal to ordinal data is as \
smooth as possible, let us stop to consider the argument why equal \
frequencies might mean maximal dispersion, also for nominal data. The \
rationale has already been expressed above. Indeed, with all data in one \
cell, if the data are just meaningless numbers, then the variance is maximal. \
But if the data represent observations on some nominal variable, then only \
that category is observed, and we have no dispersion at all.\
\>", "Text"],

Cell["\<\
Thus, the ordinal measure was very helpfull to enlighted the issue of \
dispersion for contingency tables. The next point however is whether we \
should use it or not. We can compare the ordinal measure with the measure for \
NominalVariance, that we shall discuss shortly.\
\>", "Text"],

Cell["\<\
The ordinal measure generates different values for the various arrangements \
of the data.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(VariancePr\  /@ \ Permutations[{1, \ 3, \ 20, \ 100}]\  // \ 
        N\)\ \  // \ Union\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(TraditionalForm\`{0.19426378772112382`, 0.20310874089490114`, 
      0.22548126951092612`, 0.2551378772112383`, 0.27594953173777315`, 
      0.3487903225806452`, 0.5626951092611863`, 0.5835067637877211`, 
      0.604318418314256`, 0.7083766909469302`, 1.2332856399583767`, 
      1.264503121748179`}\)], "Output",
  CellLabel->"Out[130]="]
}, Open  ]],

Cell["\<\
Instead, given that we are discussing nominal data, it would be better to \
maintain orderlessness.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NominalVariance\  /@ \ Permutations[{1, \ 3, \ 20, \ 100}]\  // \ 
        N\)\  // \ Union\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(TraditionalForm\`{40.04838709677419`}\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Orderless", "Sub3section"],

Cell[TextData[{
  "The design choice becomes clearer when we consider the variance measures \
that assume orderless data. For reference we keep including the plain \
variance of the frequencies, both division by ",
  StyleBox["n",
    FontSlant->"Italic"],
  " - 1 or by ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "(with the latter called Maximum Likelihood Estimation (MLE)),",
  StyleBox[" ",
    FontSlant->"Italic"],
  "and the Pearson or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " measure on the frequencies. The possibly less familiar options can best \
be explained using their formulas. Let ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "be the list of frequency data and let ",
  StyleBox["n",
    FontSlant->"Italic"],
  " be the number of categories, then ",
  StyleBox["N = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%n f\_i\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "and",
  StyleBox[" p = f / N, ",
    FontSlant->"Italic"],
  "so that ",
  Cell[BoxData[
      \(TraditionalForm\`f\&_\)]],
  " = ",
  StyleBox["N / n ",
    FontSlant->"Italic"],
  "is the average frequency and ",
  Cell[BoxData[
      \(TraditionalForm\`p\&^\)]],
  " = 1/ ",
  StyleBox["n",
    FontSlant->"Italic"],
  " would be theoretical probabilities under a uniform distribution. In the \
following \[OpenCurlyDoubleQuote].\[CloseCurlyDoubleQuote] stands for the \
improduct. The effective number of categories is included in this list though \
it is not a dispersion measure but it might be used to adjust ",
  StyleBox["n.",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "   \[FilledSmallSquare]  EffectiveNumberOfCategories[",
  StyleBox["f",
    FontSlant->"Italic"],
  "] = ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Sum]\+\(i = 1\)\%n f\_i)\)\^2\)]],
  " / (",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%n f\_i\^2\)]],
  ")"
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  VarianceFreq[Power, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "] = ",
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(\[Product]\+\(i = 1\)\%n f\_i\),
              "TraditionalForm"], ")"}], \(1/n\)], TraditionalForm]]],
  " / ",
  Cell[BoxData[
      \(TraditionalForm\`f\&_\)]],
  "  = the ratio between the geometric and the arithmetic average. It ranges \
between 0 and 1."
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  VarianceFreq[Times, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "] =  ",
  StyleBox["N",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      RowBox[{"(", 
        FormBox[\(\[Product]\+\(i = 1\)\%n p\_i\),
          "TraditionalForm"], ")"}]]],
  " = the product of the probabilities. For ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = 2 it gives the variance of the binomial distribution. See below for a \
discussion of the multinomial model. Note that the denominator of \
NominalCorrelation uses the product of the row and column sums. If those can \
be taken as the standarddeviations (of row-variable and column-variable \
separately) then the numerator becomes the covariance. See the discussion \
below."
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  VarianceFreq[Border, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "] =  ",
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " ",
  Cell[BoxData[
      RowBox[{"(", 
        FormBox[\(\[Product]\+\(i = 1\)\%n p\_i\),
          "TraditionalForm"], ")"}]]],
  " = the product of the probabilities, with a better correction. (The \
default.)"
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  VarianceFreq[Sum, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "] =  ",
  StyleBox["N  p . ",
    FontSlant->"Italic"],
  "(1 -",
  StyleBox[" p",
    FontSlant->"Italic"],
  ") = the sum of the pairwise variances. "
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  VarianceFreq[Average, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "] = ",
  " ",
  StyleBox["N  p . ",
    FontSlant->"Italic"],
  "(1 -",
  StyleBox[" p",
    FontSlant->"Italic"],
  ") / ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = the average of the latter"
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  VarianceFreq[N, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "] = ",
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"p", ".", 
              FormBox[\(\@\(f\ \((1 - p)\)\)\),
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]]],
  "  = the weighted average, weighing the pairwise standard deviations. It \
might be multiplied with ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "to scale it up to the level of the Sum measure."
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  VarianceFreq[\"Pearson\", ",
  StyleBox["f",
    FontSlant->"Italic"],
  "] = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%n\((f\_i\  - \ f\&_\ )\)\^2/\ 
          f\&_\)]],
  " ",
  " = ",
  StyleBox["N",
    FontSlant->"Italic"],
  " (",
  StyleBox["n p . p",
    FontSlant->"Italic"],
  " - 1) = PearsonVariance (for levels). Divide by ",
  StyleBox["N",
    FontSlant->"Italic"],
  " for the ",
  StyleBox["p ",
    FontSlant->"Italic"],
  "versus their theoretical value 1 / ",
  StyleBox["n. ",
    FontSlant->"Italic"],
  "The measure has been mentioned already but it is useful to see these two \
formats. "
}], "ItemizedText"],

Cell["\<\
In some cases a variance measure will generate a zero outcome. This is \
awkward when theoretically transforming a correlation matrix into a \
variance-covariance matrix. To allow for theoretical results, the routine \
NominalVariance puts out a symbolic value \[OpenCurlyDoubleQuote]Var\
\[CloseCurlyDoubleQuote] if the variance would be zero, otherwise it takes, \
by default, VarianceFreq[Border].\
\>", "Text"],

Cell[TextData[{
  "PM. The chosen default variance VarianceFreq[Border] ranges from 0 to 1 \
and thus lacks a scaling factor related to ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". This is not material since it affects all variables and thus does not \
affect the ratio of the standard deviations required for the regression \
coefficients."
}], "Text"],

Cell["\<\
PM. If a frequency is zero, then some measures find that the category should \
be dropped while Variance still generates a value. A zero value for one \
frequency of two categories however is a pathological case, for which neither \
a correlation coefficient is defined, so that this result is not problematic.\
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison", "Sub3section"],

Cell[TextData[{
  "The various possibilities are listed below using some examples that show \
the key properties. ",
  "Values {0, ..., ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "- 1} are assigned to the categories for the ordered measure only, and its \
effect can be seen from rearranging the frequencies {",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  "}. ",
  "The data-entries thus concern frequencies, not to be confused with the \
values assigned to the categories. The most important point to observe in \
these tables is that Variance and Pearson have opposite reactions to other \
measures when we compare the situations with equal frequencies to those with \
inequality. Under equality, Variance drops to zero while VariancePr takes its \
highest value. "
}], "Text"],

Cell[TextData[{
  "For the ",
  StyleBox["n ",
    FontSlant->"Italic"],
  " = 2 situation, the assignment of numerical values {",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  "} to the categories is symmetric. The measures are distinguished by their \
reaction to equal frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`f\_2\)]],
  ". ",
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalVariance[
        Table, {{1, 0}, {0, 1}, {1, \ 2}, \ {2, \ 1}, \ {0, 4}, {1, 
            4}, \ {4, \ 4}}] // N\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox[\({1.`, 0.`}\),
                "TraditionalForm"], 
              FormBox[\({0.`, 1.`}\),
                "TraditionalForm"], 
              FormBox[\({1.`, 2.`}\),
                "TraditionalForm"], 
              FormBox[\({2.`, 1.`}\),
                "TraditionalForm"], 
              FormBox[\({0.`, 4.`}\),
                "TraditionalForm"], 
              FormBox[\({1.`, 4.`}\),
                "TraditionalForm"], 
              FormBox[\({4.`, 4.`}\),
                "TraditionalForm"]},
            {
              FormBox["EffectiveNumberOfCategories",
                "TraditionalForm"], "1.`", "1.`", "1.8`", "1.8`", "1.`", 
              "1.4705882352941178`", "2.`"},
            {
              FormBox["NominalVariance",
                "TraditionalForm"], "\<\"Var\"\>", "\<\"Var\"\>", 
              "0.8888888888888888`", "0.8888888888888888`", "\<\"Var\"\>", 
              "0.64`", "1.`"},
            {
              FormBox["\<\"Order\"\>",
                
                "TraditionalForm"], "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>"},
            {
              FormBox["VariancePr",
                "TraditionalForm"], "0.`", "0.`", "0.2222222222222222`", 
              "0.2222222222222222`", "0.`", "0.16`", "0.25`"},
            {
              FormBox["\<\"Orderless\"\>",
                
                "TraditionalForm"], "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>"},
            {
              FormBox["VarianceMLE",
                "TraditionalForm"], "0.25`", "0.25`", "0.25`", "0.25`", "4.`",
               "2.25`", "0.`"},
            {
              FormBox["Variance",
                "TraditionalForm"], "0.5`", "0.5`", "0.5`", "0.5`", "8.`", 
              "4.5`", "0.`"},
            {
              FormBox["PearsonVariance",
                "TraditionalForm"], "1.`", "1.`", "0.3333333333333333`", 
              "0.3333333333333333`", "4.`", "1.8`", "0.`"},
            {
              FormBox[\(VarianceFreq(Power)\),
                "TraditionalForm"], "0.`", "0.`", "0.9428090415820634`", 
              "0.9428090415820634`", "0.`", "0.8`", "1.`"},
            {
              FormBox[\(VarianceFreq(Times)\),
                "TraditionalForm"], "0.`", "0.`", "0.6666666666666666`", 
              "0.6666666666666666`", "0.`", "0.8`", "2.`"},
            {
              FormBox[\(VarianceFreq(Border)\),
                "TraditionalForm"], "0.`", "0.`", "0.8888888888888888`", 
              "0.8888888888888888`", "0.`", "0.64`", "1.`"},
            {
              FormBox[\(VarianceFreq(Sum)\),
                "TraditionalForm"], "0.`", "0.`", "1.3333333333333333`", 
              "1.3333333333333333`", "0.`", "1.6`", "4.`"},
            {
              FormBox[\(VarianceFreq(Average)\),
                "TraditionalForm"], "0.`", "0.`", "0.6666666666666666`", 
              "0.6666666666666666`", "0.`", "0.8`", "2.`"},
            {
              FormBox[\(VarianceFreq(N)\),
                "TraditionalForm"], "0.`", "0.`", "0.6666666666666666`", 
              "0.6666666666666666`", "0.`", "0.8`", "2.`"}
            },
          RowSpacings->0.5,
          ColumnSpacings->1,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableSpacing -> {.5, 1.0}, TableHeadings -> {{
            EffectiveNumberOfCategories, NominalVariance, "Order", VariancePr,
             "Orderless", VarianceMLE, Variance, PearsonVariance, 
            VarianceFreq[ Power], 
            VarianceFreq[ Times], 
            VarianceFreq[ Border], 
            VarianceFreq[ Sum], 
            VarianceFreq[ Average], 
            VarianceFreq[ N]}, {{1.0, 0.0}, {0.0, 1.0}, {1.0, 2.0}, {2.0, 
            1.0}, {0.0, 4.0}, {1.0, 4.0}, {4.0, 4.0}}}]]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[49]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "For the ",
  StyleBox["n ",
    FontSlant->"Italic"],
  " = 4 situation, the assignment of numerical values {",
  "0, ..., 3}",
  " to the categories no longer is symmetric for VariancePr. ",
  "VariancePr no longer generates 0 when a (single) frequency is zero. ",
  "The ordered and orderless measures again are distinguished by their \
reaction to equal frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i\)]],
  ". The VarianceFreq[Times] measure generates very small numbers."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalVariance[
        Table, {{1, 3, 5, 10}, {10, 3, 5, 1}, {0, 4, 4, 4}, {4, 4, 4, 4}}] // 
      N\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox[\({1.`, 3.`, 5.`, 10.`}\),
                "TraditionalForm"], 
              FormBox[\({10.`, 3.`, 5.`, 1.`}\),
                "TraditionalForm"], 
              FormBox[\({0.`, 4.`, 4.`, 4.`}\),
                "TraditionalForm"], 
              FormBox[\({4.`, 4.`, 4.`, 4.`}\),
                "TraditionalForm"]},
            {
              FormBox["EffectiveNumberOfCategories",
                "TraditionalForm"], "2.674074074074074`", 
              "2.674074074074074`", "3.`", "4.`"},
            {
              FormBox["NominalVariance",
                "TraditionalForm"], "0.2946570391571581`", 
              "0.2946570391571581`", "\<\"Var\"\>", "1.`"},
            {
              FormBox["\<\"Order\"\>",
                
                "TraditionalForm"], "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", \
"\<\"-\"\>"},
            {
              FormBox["VariancePr",
                "TraditionalForm"], "0.8254847645429363`", 
              "0.9750692520775623`", "0.6666666666666666`", "1.25`"},
            {
              FormBox["\<\"Orderless\"\>",
                
                "TraditionalForm"], "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", \
"\<\"-\"\>"},
            {
              FormBox["VarianceMLE",
                "TraditionalForm"], "11.1875`", "11.1875`", "3.`", "0.`"},
            {
              FormBox["Variance",
                "TraditionalForm"], "14.916666666666666`", 
              "14.916666666666666`", "4.`", "0.`"},
            {
              FormBox["PearsonVariance",
                "TraditionalForm"], "9.421052631578947`", 
              "9.421052631578947`", "4.`", "0.`"},
            {
              FormBox[\(VarianceFreq(Power)\),
                "TraditionalForm"], "0.7367653708590702`", 
              "0.7367653708590702`", "0.`", "1.`"},
            {
              FormBox[\(VarianceFreq(Times)\),
                "TraditionalForm"], "0.021869077124945326`", 
              "0.021869077124945326`", "0.`", "0.0625`"},
            {
              FormBox[\(VarianceFreq(Border)\),
                "TraditionalForm"], "0.2946570391571581`", 
              "0.2946570391571581`", "0.`", "1.`"},
            {
              FormBox[\(VarianceFreq(Sum)\),
                "TraditionalForm"], "11.894736842105264`", 
              "11.894736842105264`", "8.`", "12.`"},
            {
              FormBox[\(VarianceFreq(Average)\),
                "TraditionalForm"], "2.973684210526316`", 
              "2.973684210526316`", "2.`", "3.`"},
            {
              FormBox[\(VarianceFreq(N)\),
                "TraditionalForm"], "3.813403422822567`", 
              "3.813403422822567`", "2.6666666666666665`", "3.`"}
            },
          RowSpacings->0.5,
          ColumnSpacings->1,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableSpacing -> {.5, 1.0}, TableHeadings -> {{
            EffectiveNumberOfCategories, NominalVariance, "Order", VariancePr,
             "Orderless", VarianceMLE, Variance, PearsonVariance, 
            VarianceFreq[ Power], 
            VarianceFreq[ Times], 
            VarianceFreq[ Border], 
            VarianceFreq[ Sum], 
            VarianceFreq[ Average], 
            VarianceFreq[ N]}, {{1.0, 3.0, 5.0, .1*^2}, {.1*^2, 3.0, 5.0, 
            1.0}, {0.0, 4.0, 4.0, 4.0}, {4.0, 4.0, 4.0, 4.0}}}]]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[50]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusions", "Sub3section"],

Cell["Conclusions are:", "Text"],

Cell[TextData[{
  "  ",
  StyleBox["1.",
    FontWeight->"Bold"],
  " For contingency tables orderless measures Variance and Pearson cannot be \
used (directly) since they measure the inverse of dispersion for contingency \
tables."
}], "ItemizedText"],

Cell[TextData[{
  "  ",
  StyleBox["2.",
    FontWeight->"Bold"],
  " For contingency tables it is often important that all frequencies are \
equal, as this is sometimes a requirement for balanced observations. \
Orderless measures Variance and Pearson then break down with zero values as \
well. Other VarianceFreq measures then would be more appropriate. This adds \
to the problem of the direction of measuring dispersion."
}], "ItemizedText"],

Cell[TextData[{
  "  ",
  StyleBox["3.",
    FontWeight->"Bold"],
  " The latter thus holds in general. Henceforth, we better not use Variance \
or Pearson. Of the alternative measures, Power and Times have low values and \
generate zeros when a category has zero frequency. Only VarianceFreq[Sum] \
generates values such that the square root is in the range of the frequencies \
themselves. It is definitely an interesting measure when choosing for \
orderlessness. It may be noted that it is most sensitive to the length of the \
list and a bit less sensitive to its contents, but it does show sufficient \
variation. However, from alternative considerations the measure \
VarianceFreq[Border] has been chosen as the default nominal variance."
}], "ItemizedText"],

Cell[TextData[{
  "  ",
  StyleBox["4.",
    FontWeight->"Bold"],
  " If we didn\[CloseCurlyQuote]t have VarianceFreq[Sum] or \
VarianceFreq[Border] then the ordered approach with VariancePr would be \
preferable above using Variance or Pearson, for the mentioned reasons."
}], "ItemizedText"],

Cell[TextData[{
  "  ",
  StyleBox["5.",
    FontWeight->"Bold"],
  " In anticipation of the discussion below: the VarianceFreq[Border] has the \
advantages: (a) it links up to the volume ratio measure, (b) there may be a \
scaling factor related to ",
  StyleBox["N",
    FontSlant->"Italic"],
  ", but this holds for all variances in a contingency table, and hence is \
immaterial for the transformation of correlation coefficients to regression \
coefficients."
}], "ItemizedText"],

Cell["\<\
PM. Perhaps we need not worry much about zero values. We already have a \
correlation matrix, so we don\[CloseCurlyQuote]t have to divide by zero but \
we multiply with it in order to create the variance-covariance matrix. Zero\
\[CloseCurlyQuote]s are only a problem for the calculation of the regression \
coefficients, when we divide by the standard deviations. Here it holds: (a) \
When one row or column has no observations then it might be deleted. (b) When \
we have balanced observations (equal frequencies), we could use symbolic \
values and see how these work out. It turns out, however, that such cases \
occur in a non-negligible number of situation, and it is awkward to judge \
each individual case. Thus when we can avoid zero values then this is \
advisable. \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Correction of the product of the marginals", "Subsection"],

Cell[TextData[{
  "The routine VariancePr2By2 copies the approach of CorrelationPr2By2, i.e. \
assigns values {i, j} to the categories (both row and column), and uses \
VariancePr[",
  StyleBox["x, p",
    FontSlant->"Italic"],
  "] to calculate the implied variances. There are two main conclusions: (i) \
It appears that the values of ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["j ",
    FontSlant->"Italic"],
  "only disappear when ",
  StyleBox["i",
    FontSlant->"Italic"],
  " = ",
  StyleBox["j",
    FontSlant->"Italic"],
  " +/- 1, for example {0, 1}. Thus an assignment {-1, 1} would introduce a \
perhaps arbitrary value of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^2\)]],
  ". (ii) The variance would be the product of the marginal probabilities. \
This gives the idea to see nominal correlation or the volume ratio measure as \
a fraction with numerator and denominator, with the numerator (determinant) \
as the covariance, and the denominator as the product of the standard \
deviations. This implies that a closer look at the denominator would generate \
a concept of variance."
}], "Text"],

Cell[TextData[{
  "This routine gives separately the variances of the column sums and the row \
sums of a 2 \[Times] 2 matrix, when the categories get values ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[VariancePr2By2[Definition, {{a, b}, {c, d}}, {i, j}], 
      Assumptions \[Rule] {Thread[{a, b, c, d} \[GreaterEqual] 
              0]}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(\((a + c)\)\ \((b + d)\)\ \((i - j)\)\^2\)\/\((a + \
b + c + d)\)\^2, \(\((a + b)\)\ \((c + d)\)\ \((i - j)\)\^2\)\/\((a + b + c + \
d)\)\^2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In above discussion, this idea has been implemented with \
VarianceFreq[Times], such that for example the variance of the column \
variable is given as the product of the marginal probabilities of the columns \
(times ",
  StyleBox["N",
    FontSlant->"Italic"],
  "). However, a product of probabilities causes small numbers and possibly \
problems with numerical conditioning. To reduce this, the measure already \
includes a multiplication by ",
  StyleBox["N",
    FontSlant->"Italic"],
  ". For a 2 \[Times] 2 the measure then is equal to the variance of the \
binomial distribution, which was the inspiration for this adjustment, and \
indeed reasonable numerical values are gotten. However, for larger dimensions \
this does not help. "
}], "Text"],

Cell[TextData[{
  "In itself, a measure with a product of the frequencies is attractive, \
given it relation to the volume ratio. The following is an exercise to look \
for a way to condition the outcome to reasonable values. Let ",
  StyleBox["N",
    FontSlant->"Italic"],
  "  be the total number of observations and ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "the number of categories. An approach might be to compare a marginal \
probability with the theoretical value 1 /",
  StyleBox[" n, ",
    FontSlant->"Italic"],
  "and in particular take the ratio. While the Pearson measure takes the sum \
of the squared deviations, or weighs the differences from 1 for the ratios, \
we might take: ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i\)]],
  " / ",
  StyleBox["N",
    FontSlant->"Italic"],
  ",  ",
  StyleBox["P",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Product]\+\(i = 1\)\%n p\_i\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`q\_i\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  " / (1 / ",
  StyleBox["n",
    FontSlant->"Italic"],
  ") , Var = ",
  Cell[BoxData[
      \(TraditionalForm\`q\_1\)]],
  " ... ",
  Cell[BoxData[
      \(TraditionalForm\`q\_n\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`p\_1\)]],
  " ... ",
  Cell[BoxData[
      \(TraditionalForm\`p\_n\)]],
  ". Indeed, the factor ",
  Cell[BoxData[
      \(TraditionalForm\`2\^2\)]],
  " mentioned above would have a rationale, and might be a better correction \
factor than the implemented multiplication with ",
  StyleBox["N. ",
    FontSlant->"Italic"],
  "This has been implemented in VarianceFreq[Border]."
}], "Text"],

Cell[TextData[{
  "This compares ",
  StyleBox["N",
    FontSlant->"Italic"],
  " ",
  StyleBox["P",
    FontSlant->"Italic"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " ",
  StyleBox["N",
    FontSlant->"Italic"],
  " ",
  StyleBox["P,",
    FontSlant->"Italic"],
  " ",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " ",
  StyleBox["P",
    FontSlant->"Italic"],
  " and the inverse 1 / (",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " ",
  StyleBox["P",
    FontSlant->"Italic"],
  ")."
}], "MathCaption"],

Cell[BoxData[
    \(testcor[lis_List]\  := \ 
      Module[{n, \ v, \ vn, \ \ w}, \ 
        n\  = \ Length[lis]; \ \ v\  = \ VarianceFreq[Times, \ lis]; \ 
        vn\  = \ \ v\ \ n^n; \ 
        w\  = \ vn\ /\ Add[lis]; \ \ \[IndentingNewLine]{v, \ vn, \ w, \ 
            1/w}\  // \ N]\)], "Input",
  CellLabel->"In[124]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(testcor\  /@ \ {{1, 3, 5, 10}, \ {4, \ 4, \ 4, \ 4}, \ \ {100, \ 100, \ 
          100, \ 100}}\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.021869077124945326`", "5.598483743986003`", 
              "0.2946570391571581`", "3.3937760416666665`"},
            {"0.0625`", "16.`", "1.`", "1.`"},
            {"1.5625`", "400.`", "1.`", "1.`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[126]="]
}, Open  ]],

Cell[TextData[{
  "The difference between 16 and 400 observations pays itself back in a more \
accurate estimate of the ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  " but if the distribution does not change then ",
  StyleBox["P ",
    FontSlant->"Italic"],
  "would not change. We again must choose between ",
  StyleBox["P ",
    FontSlant->"Italic"],
  "and 1 / ",
  StyleBox["P. ",
    FontSlant->"Italic"],
  "The latter 1 / ",
  StyleBox["P ",
    FontSlant->"Italic"],
  "(or 1 / ",
  StyleBox["P",
    FontSlant->"Italic"],
  " - 1) has the advantage that it suits the normal idea of the variance, \
that equality of frequencies gives the lowest dispersion. (The choice of 1 / \
",
  StyleBox["P",
    FontSlant->"Italic"],
  " - 1 would cause awkward zero values.) But as discussed, the variance and \
thus 1 / ",
  StyleBox["P ",
    FontSlant->"Italic"],
  "give the inverse dispersion for contingency data. But sticking with ",
  StyleBox["P,",
    FontSlant->"Italic"],
  " these examples show that a proper conditioning is not found yet. Perhaps \
",
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\@N\)]],
  " is better, but, this begs the question why. Quite possibly the correction \
",
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " is sufficient, since variance values of 1 mean that the regression \
coefficients would only depend upon the correlation coefficients, which might \
be very acceptable. "
}], "Text"],

Cell["\<\
The volume ratio is based upon a normalized matrix, whence the appearance of \
the row and column sums. It does not quite follow that such sums \
\[OpenCurlyDoubleQuote]thus\[CloseCurlyDoubleQuote] should appear in a \
measure for the variance. \
\>", "Text"],

Cell["\<\
This discussion is no longer pursued. However, given all consideration, the \
conclusion that the VarianceFreq[Border] measure serves as the best measure \
for nominal correlation seems warranted.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PearsonVariance", "Subsection"],

Cell[TextData[{
  "The Pearson variance is \[CapitalSigma] ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox["f",
                FontSlant->"Italic"], "-", 
              StyleBox["t",
                FontSlant->"Italic"]}], ")"}], "2"], TraditionalForm]]],
  " / ",
  StyleBox["t, ",
    FontSlant->"Italic"],
  "where the theoretical frequency now is the mean. It is attractive to use \
this measure. For association matrices made on NominalCorrelation and similar \
matrices made with Cramer\[CloseCurlyQuote]s V we would want to use the same \
variance, and since the Pearson variance and Cramer\[CloseCurlyQuote]s V both \
have a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " distribution then their ratio is F. "
}], "Text"],

Cell["\<\
This leaves some questions to ask, though. \
\>", "Text"],

Cell[TextData[{
  "   \[FilledSmallSquare]  Cramer\[CloseCurlyQuote]s V had a limit value if \
1, and thus was interpreted as a correlation and not as a covariance. Thus, \
in this case we would ",
  StyleBox["multiply ",
    FontSlant->"Italic"],
  "with the standarddeviations and not ",
  StyleBox["divide. ",
    FontSlant->"Italic"],
  "Conversely, Cramer\[CloseCurlyQuote]s V uses the degrees of freedom but \
rather we should use an alternative measure with a standarddeviation, that \
would have a limit in the degrees of freedom."
}], "ItemizedText"],

Cell[TextData[{
  "   \[FilledSmallSquare]  ",
  "We would multiply (or divide) with a product of standarddeviations - \
getting products of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  " or square roots of those."
}], "ItemizedText"],

Cell["\<\
   \[FilledSmallSquare]  The Pearson measure has an inverted sense of \
dispersion.\
\>", "ItemizedText"],

Cell["\<\
We need not resolve those questions and can maintain the earlier conclusions.\
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multinomial", "Subsection"],

Cell[TextData[{
  "Taking the border sums for a variable in a contingency table gives us in \
fact a multinomial distribution. Standardly available are variances and \
covariances of a such a distribution. The \[OpenCurlyDoubleQuote]Generalized \
Variance\[CloseCurlyDoubleQuote] has been defined as the determinant of the \
variance-covariance matrix. This approach runs dead since that determinant \
for the multinomial distribution appears to be zero. It should be. The events \
are fully correlated, in the sense that if something happens in some category \
then this can only be since nothing happens in the other ones. For ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = 3, for example, observations are  {1, 0, 0}, {0, 1, 0}, {0, 0, 1} and \
then repeated in arbitrary number. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mnd\  = \ MultinomialDistribution[n, \ {p1, \ p2, \ p3}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"MultinomialDistribution", "(", 
        RowBox[{"n", ",", 
          TagBox[\({p1, p2, p3}\),
            Short]}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{n\ \((1 - p1)\)\ p1, n\ \((1 - p2)\)\ p2, 
      n\ \((1 - p3)\)\ p3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cvm\  = \ CovarianceMatrix[mnd]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(n\ \((p1 - 
                    p1\^2)\)\), \(\(-n\)\ p1\ p2\), \(\(-n\)\ p1\ p3\)},
            {\(\(-n\)\ p1\ p2\), \(n\ \((p2 - 
                    p2\^2)\)\), \(\(-n\)\ p2\ p3\)},
            {\(\(-n\)\ p1\ p3\), \(\(-n\)\ p2\ p3\), \(n\ \((p3 - p3\^2)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?GeneralizedVariance\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"GeneralizedVariance[{{x11, ..., x1p}, ..., {xn1, ..., xnp}}] \
gives the generalized variance of the n p-dimensional vectors.  This is \
equivalent to the determinant of the covariance matrix, or the product of the \
variances of the principal components of the data.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Statistics`MultiDescriptiveStatistics`",
        Active->True,
        ButtonStyle->"AddOnsLink"]}]], "Print",
  CellTags->"Info3388089028-2566563"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[cvm]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-p1\)\ p2\ p3\^2\ n\^3 - p1\ p2\^2\ p3\ n\^3 - 
      p1\^2\ p2\ p3\ n\^3 + p1\ p2\ p3\ n\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-n\^3\)\ p1\ p2\ p3\ \((p1 + p2 + p3 - 
          1)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix L: Two more practical examples", "Section"],

Cell[CellGroupData[{

Cell["An example from Losh (2004a)", "Subsubsection"],

Cell["\<\
The following example for nominal data concerning (1) sex, (2) email use and \
(3) education have been taken from Losh (2004a):\
\>", "Text"],

Cell[TextData[{
  "\[OpenCurlyDoubleQuote]Consider the following example from the August 2000 \
Current Population Survey that examines the bivariate association between \
education and the use of email at home for job or money-making purposes (for \
example, someone who has an online business or who places auction items on \
eBay). Here I am ",
  StyleBox["only",
    FontSlant->"Italic"],
  " considering the 31,576 valid (weighted) cases who are persons with online \
access at home. The more education a person has, the more likely they are to \
use email for commercial purposes at home. However, because men are more \
likely to be self-employed than women (and more likely to be employed at \
all), men may use home email for commercial purposes more than women do, so \
both education and gender may be independent variables. In fact, men are \
about 3 percent more likely than women to use home email for commercial \
purposes in this sample.\[CloseCurlyDoubleQuote]"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ "\<Email study\>"]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Yes\"\>",
                "TraditionalForm"], 
              FormBox["\<\"No\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Male\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"< Highschool\"\>",
                      "TraditionalForm"], "130"},
                  {
                    FormBox["\<\"Highschool\"\>",
                      "TraditionalForm"], "344"},
                  {
                    FormBox["\<\"Some college\"\>",
                      "TraditionalForm"], "736"},
                  {
                    FormBox["\<\"Bachelor\"\>",
                      "TraditionalForm"], "790"},
                  {
                    FormBox["\<\"Advanced\"\>",
                      "TraditionalForm"], "533"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1510"},
                  {"2605"},
                  {"3849"},
                  {"3049"},
                  {"1788"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Female\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"< Highschool\"\>",
                      "TraditionalForm"], "99"},
                  {
                    FormBox["\<\"Highschool\"\>",
                      "TraditionalForm"], "338"},
                  {
                    FormBox["\<\"Some college\"\>",
                      "TraditionalForm"], "725"},
                  {
                    FormBox["\<\"Bachelor\"\>",
                      "TraditionalForm"], "673"},
                  {
                    FormBox["\<\"Advanced\"\>",
                      "TraditionalForm"], "330"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1477"},
                  {"3246"},
                  {"4515"},
                  {"3358"},
                  {"1481"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{130, 344, 736, 790, 533}, {1510, 2605, 3849, 3049, 
          1788}}, {{99, 338, 725, 673, 330}, {1477, 3246, 4515, 3358, 1481}}},
           TableHeadings -> {{"Male", "Female"}, {"Yes", "No"}, {
          "< Highschool", "Highschool", "Some college", "Bachelor", 
          "Advanced"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[51]//TableForm="]
}, Open  ]],

Cell["\<\
The key result of this paper is that correlation and regression coefficients \
are made available, based upon a determinant or volume ratio measure of \
association. Regression coefficiencts follow from both the correlation matrix \
and the variances. Though the nominal data have no order, there is an order \
of presentation. For these tables, \[OpenCurlyDoubleQuote]not using email\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]becoming female\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]getting more education\
\[CloseCurlyDoubleQuote] are positive steps in the right direction.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NominalStatistics[CT["\<Email study\>", \ Data]\ ]\  // \ 
      Chop\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(ContingencyTableQ \[Rule] True\), 
          ",", \(OverallCorrelation \[Rule] 0.13361793733549576`\), 
          ",", \(Length \[Rule] {2, 2, 5}\), 
          ",", \(EffectiveNumberOfCategories \[Rule] {1.998347549371849`, 
              1.3392160330168639`, 4.362214131873455`}\), 
          ",", \(Variance \[Rule] {0.9991730914731671`, 0.5065889664607865`, 
              0.6682835289137784`}\), 
          ",", \(BorderTotals \[Rule] {{15334, 16242}, {4698, 26878}, {3216, 
                6533, 9825, 7870, 4132}}\), ",", 
          RowBox[{"BorderMatrices", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{\({1, 2}\), "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"2533", "12801"},
                        {"2165", "14077"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{\({1, 3}\), "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1640", "2949", "4585", "3839", "2321"},
                        {"1576", "3584", "5240", "4031", "1811"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
                RowBox[{\({2, 3}\), "\[Rule]", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"229", "682", "1461", "1463", "863"},
                        {"2987", "5851", "8364", "6407", "3269"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], 
              "}"}]}], ",", 
          RowBox[{"NominalCorrelationMatrix", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.`", "0.04045910069554973`", \(-0.06614671872612932`\)},
                  {"0.04045910069554973`", "1.`", \(-0.11867753640538585`\)},
                  {\(-0.06614671872612932`\), \(-0.11867753640538585`\), 
                    "1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarMat", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0.999173091473167`", 
                    "0.02878488199446805`", \(-0.05405166157120658`\)},
                  {"0.02878488199446805`", 
                    "0.5065889664607864`", \(-0.06905207988141937`\)},
                  {\(-0.05405166157120658`\), \(-0.06905207988141937`\), 
                    "0.6682835289137784`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarRegress", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0", "0.046450440831712556`", \(-0.07608172253326313`\)},
                  {"0.02332109673073415`", "0", \(-0.10144127891891645`\)},
                  {\(-0.0502517994005127`\), \(-0.13345254682111024`\), "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[TextData[{
  "For the matrix of regression coefficients \
(\[OpenCurlyDoubleQuote]CovarRegress\[CloseCurlyDoubleQuote]) ",
  StyleBox["C",
    FontSlant->"Italic"],
  " and variables ",
  StyleBox["x = ",
    FontSlant->"Italic"],
  "{",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\)]],
  "}, the relation is ",
  StyleBox["x = ",
    FontSlant->"Italic"],
  StyleBox["C.x",
    FontSlant->"Italic"],
  " + \[Epsilon].. The matrix ",
  StyleBox["C ",
    FontSlant->"Italic"],
  "is not symmetric since it matters in regression what the explained \
variable is."
}], "Text"],

Cell["\<\
For these data, some of the conclusions are as follows: Sex and email use \
have a correlation coefficient of 4%, and if one male in the study were \
replaced by one woman then not using email (second row) would rise by 0.02 \
(the {2, 1} cell). Education and email use have a correlation coefficient of \
-11.9%. If education rises one step then not using email rises by -0.10 (the \
{2, 3} cell). The latter might be confounded by the larger percentage of \
women in the study who use less email.\
\>", "Text"],

Cell["\<\
These coefficients would gain in interpretative value if they could be \
transformed into percentages.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["An example by Linacre (2005)", "Subsubsection"],

Cell[TextData[{
  "Linacre (2005) gives some data referring to Uebersax (2000), with a \
Pearson product moment correlation of 61% and a Polychoric correlation of \
67%. The important point of these data are that they are ",
  StyleBox["real",
    FontSlant->"Italic"],
  " data, i.e. that these are counts from a grid where the values 1, 2, \
etcetera are the mean values of the cells in the grid. For such data the \
Pearson product moment measure would be allowable. If we treat these data as \
mere counts then there is no correlation. PM. The CT routine requires that \
all categories are uniquely labelled. The labels A to E actually would be \
values 1 to 5 as well."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ "\<Uebersax (2000)\>"]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"A\"\>",
                "TraditionalForm"], 
              FormBox["\<\"B\"\>",
                "TraditionalForm"], 
              FormBox["\<\"C\"\>",
                "TraditionalForm"], 
              FormBox["\<\"D\"\>",
                "TraditionalForm"], 
              FormBox["\<\"E\"\>",
                "TraditionalForm"]},
            {
              FormBox["1",
                "TraditionalForm"], "0", "0", "12", "32", "40"},
            {
              FormBox["2",
                "TraditionalForm"], "0", "4", "23", "66", "23"},
            {
              FormBox["3",
                "TraditionalForm"], "1", "10", "67", "77", "15"},
            {
              FormBox["4",
                "TraditionalForm"], "1", "22", "133", "40", "3"},
            {
              FormBox["5",
                "TraditionalForm"], "8", "71", "125", "21", "2"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{1, 2, 3, 4, 5}, {"A", "B", "C", "D", 
            "E"}}]]], TraditionalForm]], "Output",
  CellLabel->"Out[55]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(NominalStatistics[%\ ]\)\(\ \)\)\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(ContingencyTableQ \[Rule] True\), 
          ",", \(OverallCorrelation \[Rule] 0.0004453836485637076`\), 
          ",", \(Length \[Rule] {5, 5}\), 
          ",", \(EffectiveNumberOfCategories \[Rule] {4.508374720724054`, 
              3.1100160012565405`}\), 
          ",", \(Variance \[Rule] {0.7317282348330674`, 
              0.07378380651836094`}\), ",", 
          RowBox[{"BorderTotals", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"84", "116", "170", "199", "227"},
                  {"10", "107", "360", "236", "83"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"BorderMatrices", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{\({1, 2}\), "\[Rule]", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "0", "12", "32", "40"},
                      {"0", "4", "23", "66", "23"},
                      {"1", "10", "67", "77", "15"},
                      {"1", "22", "133", "40", "3"},
                      {"8", "71", "125", "21", "2"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], "}"}]}],
           ",", 
          RowBox[{"NominalCorrelationMatrix", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.`", \(-0.0004453836485637076`\)},
                  {\(-0.0004453836485637076`\), "1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarMat", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0.7317282348330674`", \(-0.00010348793085028405`\)},
                  {\(-0.00010348793085028405`\), "0.07378380651836094`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"CovarRegress", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0.`", \(-0.0014025832460206739`\)},
                  {\(-0.0001414294623657556`\), "0.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT["\<Uebersax (2000)\>", \ Source]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(TraditionalForm\`"http://www.rasch.org/rmt/rmt193c.htm\nPearson \
correlation = 0.61\n Polychoric correlation = 0.67"\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["\<\
PM. For completeness we mention Cramer\[CloseCurlyQuote]s V.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CramersV[CT["\<Uebersax (2000)\>", \ Data]]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(TraditionalForm\`0.3525730589063106`\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix M: Manipulating a contingency table", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection"],

Cell["\<\
Above discussion occasionally uses the routine CT \
(\[OpenCurlyDoubleQuote]contingency table\[CloseCurlyDoubleQuote]) for input. \
The following clarifies its use. The routine CT allows you to order, sum and \
take elements from a contingency matrix with a bit more ease. The routine \
requires that you give labels for the variables and their categories, and \
then it gives you the benefit to communicate in terms of those labels instead \
of numbers. For example, when you would sum a variable, so that it \
effectively disappears from the table, the numbers would change but the \
labels remain the same. Obviously, typing some numbers, say the 8 numbers in \
the 2 \[Times] 2 \[Times] 2 case, is probably quicker, but some control \
appears useful, also for subsequent routines, and also for presentation.\
\>", "Text"],

Cell["\<\
The routine dbCT is a databank that allows to to store contingency tables and \
use labels to find them. The dimensions of a table contain the labels for the \
variables and their categories. The databank also contains a source label \
that allows you to record where the data came from. \
\>", "Text"],

Cell["\<\
The routine CT allows you to take a contingency table from the database and \
set it as a default, meaning that its identifying label is available as CT[] \
and that routines will call this CT[] if no other label is specified.\
\>", "Text"],

Cell["\<\
The options of CT already contain an example crosstable. The Dimensions \
specify the variable and its categories. In this example it so happens that \
the Dimensions have all equal length but this need not be so in general. The \
options of CT also specify what the default Databank is.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[CT]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Label \[Rule] "Arthritis"\), ",", 
          RowBox[{"Dimensions", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"\<\"Effect\"\>", "\<\"Some\"\>", "\<\"None\"\>"},
                  {"\<\"Treatment\"\>", "\<\"Active\"\>", "\<\"Placebo\"\>"},
                  {"\<\"Sex\"\>", "\<\"F\"\>", "\<\"M\"\>"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ",", 
          RowBox[{"Data", "\[Rule]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\({21, 7}\), \({13, 1}\)},
                  {\({6, 7}\), \({19, 10}\)}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
          ",", \(Source \[Rule] 
            "http://www.math.yorku.ca/SCS/Courses/grcat/grc6.html and Koch & \
Stokes (1991), Reordered"\), ",", \(Databank \[Rule] dbCT\)}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell[TextData[{
  "When the routine CT sets a database up for use, it first checks whether \
the dimensions fit the datastructure. When all checks are OK then the table \
components are allocated to standard locations such as CT[",
  StyleBox["label",
    FontSlant->"Italic"],
  ", Data], CT[",
  StyleBox["label",
    FontSlant->"Italic"],
  ", Dimensions] and so on. This means that you and the routines can trust \
that these locations form a well-defined working space."
}], "Text"],

Cell["\<\
This sets the default crosstable using the options. This also prints the \
table using TableForm. As one can see in the options, the Effect variable is \
the second one, and due to TableForm printing it appears as the main column, \
which is easiest for our understanding. Sex and Treatment are the explanatory \
variables around that main column.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ Default]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Active\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Placebo\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Some\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "21"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"13"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"None\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "6"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"19"},
                  {"10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{21, 7}, {13, 1}}, {{6, 7}, {19, 10}}}, 
          TableHeadings -> {{"Some", "None"}, {"Active", "Placebo"}, {"F", 
          "M"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[106]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic handling", "Subsubsection"],

Cell["The table is available as default.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(TraditionalForm\`"Arthritis"\)], "Output",
  CellLabel->"Out[107]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Data]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({21, 7}\), \({13, 1}\)},
            {\({6, 7}\), \({19, 10}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Variables]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(TraditionalForm\`{"Effect", "Treatment", "Sex"}\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[TableHeadings]\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Some\"\>", "\<\"None\"\>"},
            {"\<\"Active\"\>", "\<\"Placebo\"\>"},
            {"\<\"F\"\>", "\<\"M\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[110]="]
}, Open  ]],

Cell[TextData[{
  "Elements in the table now are available by naming them. Admittedly, it is \
quicker to simply type 13 than this long identifier, yet, for programming it \
can be handy, it may reduce typing errors, and it may be more convenient when \
the table has more dimensions and larger numbers, where the layout on the \
screen might sometimes be confusing. In this case, the variables are defined \
in the order ",
  StyleBox["effect, cause, confounder",
    FontSlant->"Italic"],
  ", and selecting values should be in that order."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Take, \ "\<F\>", \ "\<Some\>", \ "\<Placebo\>"]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    FormBox[
      RowBox[{\(CT::"mis"\), \(\(:\)\(\ \)\), "\<\"Unknown query keys or \
wrong order: \\!\\(TraditionalForm\\`\\({\\\"F\\\", \\\"Some\\\", \\\"Placebo\
\\\"}\\)\\)\"\>"}], TraditionalForm]], "Message",
  CellLabel->"From In[111]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Take, \ \ "\<Some\>", \ "\<Placebo\>", \ "\<F\>"]\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(TraditionalForm\`13\)], "Output",
  CellLabel->"Out[112]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summing", "Subsubsection"],

Cell["\<\
When we sum Treatment then it disappears from the table. The original table \
remains the default unless we also specify that the new result should become \
the default.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Sum, \ "\<Treatment\>"]\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"F\"\>",
                "TraditionalForm"], 
              FormBox["\<\"M\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Some\"\>",
                "TraditionalForm"], "34", "8"},
            {
              FormBox["\<\"None\"\>",
                "TraditionalForm"], "25", "17"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{"Some", "None"}, {"F", "M"}}]]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[113]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(TraditionalForm\`"Arthritis"\)], "Output",
  CellLabel->"Out[114]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Sum, \ Default, \ "\<Treatment\>"]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"F\"\>",
                "TraditionalForm"], 
              FormBox["\<\"M\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Some\"\>",
                "TraditionalForm"], "34", "8"},
            {
              FormBox["\<\"None\"\>",
                "TraditionalForm"], "25", "17"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{"Some", "None"}, {"F", "M"}}]]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[115]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(TraditionalForm\`"Arthritis-Treatment"\)], "Output",
  CellLabel->"Out[116]="]
}, Open  ]],

Cell["CT[Set, ...] keeps a list of the labels that are set. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[List]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(TraditionalForm\`{"Arthritis", "Arthritis-Treatment"}\)], "Output",
  CellLabel->"Out[117]="]
}, Open  ]],

Cell["\<\
This gets us back to the original table. Use CT[Default, ...] for contingency \
tables that have already been Set. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Default, \ "\<Arthritis\>"]\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Active\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Placebo\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Some\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "21"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"13"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"None\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "6"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"19"},
                  {"10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{21, 7}, {13, 1}}, {{6, 7}, {19, 10}}}, 
          TableHeadings -> {{"Some", "None"}, {"Active", "Placebo"}, {"F", 
          "M"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[118]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ordering", "Subsubsection"],

Cell["Sometimes another look at the table can be helpful.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Order, \ \ \ "\<Treatment\>"]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Some\"\>",
                "TraditionalForm"], 
              FormBox["\<\"None\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Active\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "21"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"6"},
                  {"7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"Placebo\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"F\"\>",
                      "TraditionalForm"], "13"},
                  {
                    FormBox["\<\"M\"\>",
                      "TraditionalForm"], "1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"19"},
                  {"10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{21, 7}, {6, 7}}, {{13, 1}, {19, 10}}}, 
          TableHeadings -> {{"Active", "Placebo"}, {"Some", "None"}, {"F", 
          "M"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[119]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Order, \ {"\<Sex\>", \ "\<Treatment\>"}]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Active\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Placebo\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"F\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Some\"\>",
                      "TraditionalForm"], "21"},
                  {
                    FormBox["\<\"None\"\>",
                      "TraditionalForm"], "6"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"13"},
                  {"19"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"M\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Some\"\>",
                      "TraditionalForm"], "7"},
                  {
                    FormBox["\<\"None\"\>",
                      "TraditionalForm"], "7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"1"},
                  {"10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{21, 6}, {13, 19}}, {{7, 7}, {1, 10}}}, 
          TableHeadings -> {{"F", "M"}, {"Active", "Placebo"}, {"Some", 
          "None"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[120]//TableForm="]
}, Open  ]],

Cell["\<\
The list of contingency tables that have been set now also includes these \
reordered tables. The dash - means a summation (or a minus, because of \
removal) while -1- means a reordering.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[List]\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(TraditionalForm\`{"Arthritis", "Arthritis-Treatment", 
      "Arthritis-1-Treatment", "Arthritis-1-Treatment-1-Sex"}\)], "Output",
  CellLabel->"Out[121]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Working with the databank", "Sub3section"],

Cell["\<\
Since other packages may have been loaded that also set the SetDatabank \
default databank, we set it now. Once we do this, the various Databank \
routines apply to the default dbCT.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[SetDatabank, \ Databank\  \[Rule] \ dbCT]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(TraditionalForm\`{Databank \[Rule] dbCT}\)], "Output",
  CellLabel->"Out[122]="]
}, Open  ]],

Cell["\<\
This query tells us what contingency tables are available, identified by \
their short labels.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Databank[Query, \ Label]\)\(\ \)\)\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Hat shops\"\>"},
            {"\<\"Arthritis-Original\"\>"},
            {"\<\"Arthritis2\"\>"},
            {"\<\"Arthritis\"\>"},
            {"\<\"Email study\"\>"},
            {"\<\"Uebersax (2000)\"\>"},
            {"\<\"Cornfield\"\>"},
            {"\<\"Fisher Male Twins\"\>"},
            {"\<\"Fisher Female Twins\"\>"},
            {"\<\"Fisher Twins\"\>"},
            {"\<\"Arthritis-Original-Sex-1-Treatment\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[123]="]
}, Open  ]],

Cell["\<\
The following gives an explanation of the contents of the first contingency \
table. Note that the Dimensions and Data elements are put in Hold. The reason \
is that Databank only accepts lists of one level.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Explain[\(dbCT[Data]\)[\([1]\)]]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Label \[Rule] "Hat shops"\), ",", 
          RowBox[{"Dimensions", "\[Rule]", 
            RowBox[{"Hold", "[", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"Shop\"\>", "\<\"Shop1\"\>", "\<\"Shop2\"\>"},
                    {"\<\"Colour\"\>", "\<\"Green\"\>", "\<\"Blue\"\>"},
                    {"\<\"Fitness\"\>", "\<\"Fit\"\>", "\<\"No fit\"\>"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}]}], 
          ",", 
          RowBox[{"Data", "\[Rule]", 
            RowBox[{"Hold", "[", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\({5, 1}\), \({8, 2}\)},
                    {\({2, 8}\), \({1, 5}\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}]}], 
          ",", \(Source \[Rule] 
            "Kleinbaum et al. (2003), \"ActivEpi Companion texbook\", \
Springer"\)}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[124]="]
}, Open  ]],

Cell["This gives all records of the databank.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(ShowData[Transpose]\)\(\ \)\)\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["Label",
                "TraditionalForm"], 
              FormBox["Dimensions",
                "TraditionalForm"], 
              FormBox["Data",
                "TraditionalForm"], 
              FormBox["Source",
                "TraditionalForm"]},
            {
              FormBox["1",
                "TraditionalForm"], "\<\"Hat shops\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Shop\"\>", "\<\"Shop1\"\>", "\<\"Shop2\"\>"},
                      {"\<\"Colour\"\>", "\<\"Green\"\>", "\<\"Blue\"\>"},
                      {"\<\"Fitness\"\>", "\<\"Fit\"\>", "\<\"No fit\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({5, 1}\), \({8, 2}\)},
                      {\({2, 8}\), \({1, 5}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Kleinbaum et al. (2003), \\\"ActivEpi Companion \
texbook\\\", Springer\"\>"},
            {
              FormBox["2",
                "TraditionalForm"], "\<\"Arthritis-Original\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Sex\"\>", "\<\"F\"\>", "\<\"M\"\>"},
                      {"\<\"Effect\"\>", "\<\"None\"\>", "\<\"Some\"\>"},
                      {"\<\"Treatment\"\>", "\<\"Active\"\>", \
"\<\"Placebo\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({6, 19}\), \({21, 13}\)},
                      {\({7, 10}\), \({7, 1}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991)\"\>"},
            {
              FormBox["3",
                
                "TraditionalForm"], "\<\"Arthritis2\"\>", \(Hold[{{"Sex", 
                    "F", "M"}, {"Effect", "None", "OnlySome", 
                    "Marked"}, {"Treatment", "Active", "Placebo"}}]\), 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({6, 19}\), \({5, 7}\), \({16, 6}\)},
                      {\({7, 10}\), \({2, 0}\), \({5, 1}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991)\"\>"},
            {
              FormBox["4",
                "TraditionalForm"], "\<\"Arthritis\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Effect\"\>", "\<\"Some\"\>", "\<\"None\"\>"},
                      {"\<\"Treatment\"\>", "\<\"Active\"\>", \
"\<\"Placebo\"\>"},
                      {"\<\"Sex\"\>", "\<\"F\"\>", "\<\"M\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({21, 7}\), \({13, 1}\)},
                      {\({6, 7}\), \({19, 10}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991), Reordered\"\>"},
            {
              FormBox["5",
                
                "TraditionalForm"], "\<\"Email study\"\>", \(Hold[{{"Sex", 
                    "Male", "Female"}, {"Email use", "Yes", 
                    "No"}, {"Education", "< Highschool", "Highschool", 
                    "Some college", "Bachelor", "Advanced"}}]\), 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({130, 344, 736, 790, 533}\), \({1510, 2605, 3849, 
                          3049, 1788}\)},
                      {\({99, 338, 725, 673, 330}\), \({1477, 3246, 4515, 
                          3358, 1481}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Losh, S.C. (2004a), \\\"Guide 6: Multivariate \
Crosstabulations and Causal Issues\\\",  \
http://edf5400-01.fa04.fsu.edu/Guide6.html\"\>"},
            {
              FormBox["6",
                "TraditionalForm"], "\<\"Uebersax (2000)\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Row\"\>", "1", "2", "3", "4", "5"},
                      {"\<\"Column\"\>", "\<\"A\"\>", "\<\"B\"\>", \
"\<\"C\"\>", "\<\"D\"\>", "\<\"E\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "0", "12", "32", "40"},
                      {"0", "4", "23", "66", "23"},
                      {"1", "10", "67", "77", "15"},
                      {"1", "22", "133", "40", "3"},
                      {"8", "71", "125", "21", "2"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], \("http://www.rasch.org/rmt/rmt193c.htm\nPearson \
correlation = 0.61\n Polychoric correlation = 0.67"\)},
            {
              FormBox["7",
                "TraditionalForm"], "\<\"Cornfield\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Effect\"\>", "\<\"Disease\"\>", \(\[Not] \
"Disease"\)},
                      {"\<\"Truth\"\>", "\<\"Cause\"\>", \(\[Not] "Cause"\)},
                      {"\<\"Confounding\"\>", "\<\"Confounder\"\>", \(\[Not] \
"Confouder"\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({10, 4}\), \({4, 5}\)},
                      {\({75, 20}\), \({110, 781}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Pure theoretical example\"\>"},
            {
              FormBox["8",
                "TraditionalForm"], "\<\"Fisher Male Twins\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Smoking habits\"\>", "\<\"Alike\"\>", "\<\"Unlike\
\"\>"},
                      {"\<\"Twins\"\>", "\<\"Fraternal\"\>", "\<\"Identical\"\
\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"15", "39"},
                      {"16", "12"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Fisher, R.A. (1958a), \\\"Lung Cancer and \
Cigarettes?  Letter to the editor\\\", Nature, vol. 182, p. 108, 12 July 1958 \
[Collected Papers 275], \
http://www.york.ac.uk/depts/maths/histstat/fisher275.pdf, Retrieved from \
source\"\>"},
            {
              FormBox["9",
                "TraditionalForm"], "\<\"Fisher Female Twins\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Smoking habits\"\>", "\<\"Alike\"\>", "\<\"Unlike\
\"\>"},
                      {"\<\"Twins\"\>", "\<\"Fraternal\"\>", "\<\"Identical\"\
\>"},
                      {"\<\"Separated at birth\"\>", "\<\"Separated\"\>", \(\
\[Not] "Separated"\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({"x", 9 - "x"}\), \({23, 21}\)},
                      {\({"z", 9 - "z"}\), \({4, 5}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Fisher, R.A. (1958b), \\\"Cancer and Smoking? \
Letter to the editor\\\", Nature, vol. 182, p. 596, 30 August 1958 [Collected \
Papers 276], http://www.york.ac.uk/depts/maths/histstat/fisher276.pdf, \
Retrieved from source\"\>"},
            {
              FormBox["10",
                "TraditionalForm"], "\<\"Fisher Twins\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Smoking habits\"\>", "\<\"Alike\"\>", "\<\"Unlike\
\"\>"},
                      {"\<\"Twins\"\>", "\<\"Fraternal\"\>", "\<\"Identical\"\
\>"},
                      {"\<\"Sex\"\>", "\<\"Male\"\>", "\<\"Female\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({15, 9}\), \({39, 44}\)},
                      {\({16, 9}\), \({12, 9}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"See other Fisher tables\"\>"},
            {
              FormBox["11",
                
                "TraditionalForm"], "\<\"Arthritis-Original-Sex-1-Treatment\"\
\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Treatment\"\>", "\<\"Active\"\>", \
"\<\"Placebo\"\>"},
                      {"\<\"Effect\"\>", "\<\"None\"\>", "\<\"Some\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"13", "28"},
                      {"29", "14"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991), Reordered\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {Automatic, {Label, Dimensions, Data, 
            Source}}]]], TraditionalForm]], "Output",
  CellLabel->"Out[125]//TableForm="]
}, Open  ]],

Cell["\<\
CT has access to the databank and we might set the default to the Arthritis2 \
table.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ Default, \ "\<Arthritis2\>"]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"None\"\>",
                "TraditionalForm"], 
              FormBox["\<\"OnlySome\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Marked\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"F\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Active\"\>",
                      "TraditionalForm"], "6"},
                  {
                    FormBox["\<\"Placebo\"\>",
                      "TraditionalForm"], "19"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"5"},
                  {"7"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"16"},
                  {"6"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"M\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Active\"\>",
                      "TraditionalForm"], "7"},
                  {
                    FormBox["\<\"Placebo\"\>",
                      "TraditionalForm"], "10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"2"},
                  {"0"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"5"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{6, 19}, {5, 7}, {16, 6}}, {{7, 10}, {2, 0}, {5, 1}}}, 
          TableHeadings -> {{"F", "M"}, {"None", "OnlySome", "Marked"}, {
          "Active", "Placebo"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[126]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "Thus, in setting or declaring something to become the default, CT[Set, \
(Default,) Label \[Rule] ...., Dimensions \[Rule] ...., ...]  works from the \
options, CT[Set, (Default,) ",
  StyleBox["label",
    FontSlant->"Italic"],
  "] works from the databank, and CT[Default, ",
  StyleBox["label",
    FontSlant->"Italic"],
  "] works from tables that have already been set. Having set a crosstable, \
the following key data are available, for example for above new default:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Information]\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"Length", "3"},
            {"Levels", \({2, 3, 2}\)},
            {
              "Dimensions", \({{"Sex", "F", "M"}, {"Effect", "None", 
                  "OnlySome", "Marked"}, {"Treatment", "Active", 
                  "Placebo"}}\)},
            {"Variables", \({"Sex", "Effect", "Treatment"}\)},
            {
              "TableHeadings", \({{"F", "M"}, {"None", "OnlySome", 
                  "Marked"}, {"Active", "Placebo"}}\)},
            {"Data", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\({6, 19}\), \({5, 7}\), \({16, 6}\)},
                    {\({7, 10}\), \({2, 0}\), \({5, 1}\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]},
            {
              "Source", \
"\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.html and Koch & Stokes \
(1991)\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[127]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dumping to the databank", "Subsubsection"],

Cell["\<\
When a contingency table has been created via various elaborations, then it \
can be dumped to the databank, that hence might be stored on a medium and \
retrieved for later use.\
\>", "Text"],

Cell["\<\
This creates a new default table. The entry number refers to the database. \
These are the original Arthritis data, in a different order.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Set, \ Default, \ 2]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"None\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Some\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"F\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Active\"\>",
                      "TraditionalForm"], "6"},
                  {
                    FormBox["\<\"Placebo\"\>",
                      "TraditionalForm"], "19"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"21"},
                  {"13"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]},
            {
              FormBox["\<\"M\"\>",
                "TraditionalForm"], GridBox[{
                  {
                    FormBox["\<\"Active\"\>",
                      "TraditionalForm"], "7"},
                  {
                    FormBox["\<\"Placebo\"\>",
                      "TraditionalForm"], "10"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}], GridBox[{
                  {"7"},
                  {"1"}
                  },
                RowSpacings->0.25,
                ColumnSpacings->1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Center}],
        TableForm[ {{{6, 19}, {21, 13}}, {{7, 10}, {7, 1}}}, 
          TableHeadings -> {{"F", "M"}, {"None", "Some"}, {"Active", 
          "Placebo"}}]], TraditionalForm]], "Output",
  CellLabel->"Out[128]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Sum, \ Default, \ "\<Sex\>"]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Active\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Placebo\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"None\"\>",
                "TraditionalForm"], "13", "29"},
            {
              FormBox["\<\"Some\"\>",
                "TraditionalForm"], "28", "14"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{"None", "Some"}, {"Active", 
            "Placebo"}}]]], TraditionalForm]], "Output",
  CellLabel->"Out[129]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[Order, \ Default, \ "\<Treatment\>"]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"None\"\>",
                "TraditionalForm"], 
              FormBox["\<\"Some\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"Active\"\>",
                "TraditionalForm"], "13", "28"},
            {
              FormBox["\<\"Placebo\"\>",
                "TraditionalForm"], "29", "14"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableHeadings -> {{"Active", "Placebo"}, {"None", 
            "Some"}}]]], TraditionalForm]], "Output",
  CellLabel->"Out[130]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(TraditionalForm\`"Arthritis-Original-Sex-1-Treatment"\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell["\<\
The CT[AppendTo] command appends the default table to the default databank. \
If you want to adapt some information, you can first directly edit them such \
as CT[CT[], Source] = .... The label can be adjusted by CT[CopyData, new (, \
old)].\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CT[AppendTo]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"Hat shops\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Shop\"\>", "\<\"Shop1\"\>", "\<\"Shop2\"\>"},
                      {"\<\"Colour\"\>", "\<\"Green\"\>", "\<\"Blue\"\>"},
                      {"\<\"Fitness\"\>", "\<\"Fit\"\>", "\<\"No fit\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({5, 1}\), \({8, 2}\)},
                      {\({2, 8}\), \({1, 5}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Kleinbaum et al. (2003), \\\"ActivEpi Companion \
texbook\\\", Springer\"\>"},
            {"\<\"Arthritis-Original\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Sex\"\>", "\<\"F\"\>", "\<\"M\"\>"},
                      {"\<\"Effect\"\>", "\<\"None\"\>", "\<\"Some\"\>"},
                      {"\<\"Treatment\"\>", "\<\"Active\"\>", \
"\<\"Placebo\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({6, 19}\), \({21, 13}\)},
                      {\({7, 10}\), \({7, 1}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991)\"\>"},
            {"\<\"Arthritis2\"\>", \(Hold[{{"Sex", "F", "M"}, {"Effect", 
                    "None", "OnlySome", "Marked"}, {"Treatment", "Active", 
                    "Placebo"}}]\), 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({6, 19}\), \({5, 7}\), \({16, 6}\)},
                      {\({7, 10}\), \({2, 0}\), \({5, 1}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991)\"\>"},
            {"\<\"Arthritis\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Effect\"\>", "\<\"Some\"\>", "\<\"None\"\>"},
                      {"\<\"Treatment\"\>", "\<\"Active\"\>", \
"\<\"Placebo\"\>"},
                      {"\<\"Sex\"\>", "\<\"F\"\>", "\<\"M\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({21, 7}\), \({13, 1}\)},
                      {\({6, 7}\), \({19, 10}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991), Reordered\"\>"},
            {"\<\"Email study\"\>", \(Hold[{{"Sex", "Male", 
                    "Female"}, {"Email use", "Yes", "No"}, {"Education", 
                    "< Highschool", "Highschool", "Some college", "Bachelor", 
                    "Advanced"}}]\), 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({130, 344, 736, 790, 533}\), \({1510, 2605, 3849, 
                          3049, 1788}\)},
                      {\({99, 338, 725, 673, 330}\), \({1477, 3246, 4515, 
                          3358, 1481}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Losh, S.C. (2004a), \\\"Guide 6: Multivariate \
Crosstabulations and Causal Issues\\\",  \
http://edf5400-01.fa04.fsu.edu/Guide6.html\"\>"},
            {"\<\"Uebersax (2000)\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Row\"\>", "1", "2", "3", "4", "5"},
                      {"\<\"Column\"\>", "\<\"A\"\>", "\<\"B\"\>", \
"\<\"C\"\>", "\<\"D\"\>", "\<\"E\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "0", "12", "32", "40"},
                      {"0", "4", "23", "66", "23"},
                      {"1", "10", "67", "77", "15"},
                      {"1", "22", "133", "40", "3"},
                      {"8", "71", "125", "21", "2"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], \("http://www.rasch.org/rmt/rmt193c.htm\nPearson \
correlation = 0.61\n Polychoric correlation = 0.67"\)},
            {"\<\"Cornfield\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Effect\"\>", "\<\"Disease\"\>", \(\[Not] \
"Disease"\)},
                      {"\<\"Truth\"\>", "\<\"Cause\"\>", \(\[Not] "Cause"\)},
                      {"\<\"Confounding\"\>", "\<\"Confounder\"\>", \(\[Not] \
"Confouder"\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({10, 4}\), \({4, 5}\)},
                      {\({75, 20}\), \({110, 781}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Pure theoretical example\"\>"},
            {"\<\"Fisher Male Twins\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Smoking habits\"\>", "\<\"Alike\"\>", "\<\"Unlike\
\"\>"},
                      {"\<\"Twins\"\>", "\<\"Fraternal\"\>", "\<\"Identical\"\
\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"15", "39"},
                      {"16", "12"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Fisher, R.A. (1958a), \\\"Lung Cancer and \
Cigarettes?  Letter to the editor\\\", Nature, vol. 182, p. 108, 12 July 1958 \
[Collected Papers 275], \
http://www.york.ac.uk/depts/maths/histstat/fisher275.pdf, Retrieved from \
source\"\>"},
            {"\<\"Fisher Female Twins\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Smoking habits\"\>", "\<\"Alike\"\>", "\<\"Unlike\
\"\>"},
                      {"\<\"Twins\"\>", "\<\"Fraternal\"\>", "\<\"Identical\"\
\>"},
                      {"\<\"Separated at birth\"\>", "\<\"Separated\"\>", \(\
\[Not] "Separated"\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({"x", 9 - "x"}\), \({23, 21}\)},
                      {\({"z", 9 - "z"}\), \({4, 5}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"Fisher, R.A. (1958b), \\\"Cancer and Smoking? \
Letter to the editor\\\", Nature, vol. 182, p. 596, 30 August 1958 [Collected \
Papers 276], http://www.york.ac.uk/depts/maths/histstat/fisher276.pdf, \
Retrieved from source\"\>"},
            {"\<\"Fisher Twins\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Smoking habits\"\>", "\<\"Alike\"\>", "\<\"Unlike\
\"\>"},
                      {"\<\"Twins\"\>", "\<\"Fraternal\"\>", "\<\"Identical\"\
\>"},
                      {"\<\"Sex\"\>", "\<\"Male\"\>", "\<\"Female\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\({15, 9}\), \({39, 44}\)},
                      {\({16, 9}\), \({12, 9}\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"See other Fisher tables\"\>"},
            {"\<\"Arthritis-Original-Sex-1-Treatment\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Treatment\"\>", "\<\"Active\"\>", \
"\<\"Placebo\"\>"},
                      {"\<\"Effect\"\>", "\<\"None\"\>", "\<\"Some\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"13", "28"},
                      {"29", "14"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991), Reordered\"\>"},
            {"\<\"Arthritis-Original-Sex-1-Treatment\"\>", 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"Treatment\"\>", "\<\"Active\"\>", \
"\<\"Placebo\"\>"},
                      {"\<\"Effect\"\>", "\<\"None\"\>", "\<\"Some\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], "]"}], 
              RowBox[{"Hold", "[", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"13", "28"},
                      {"29", "14"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                "]"}], "\<\"http://www.math.yorku.ca/SCS/Courses/grcat/grc6.\
html and Koch & Stokes (1991), Reordered\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[132]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["More information", "Subsubsection"],

Cell["\<\
The Databank package may have some standard routines available that might be \
of use as well.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Economics[Databank]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[GridBox[{
        {
          StyleBox["Cool`Databank`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AfterSum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389965867-3079002", 
                    "Cool`Databank`AfterSum"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"], 
                ButtonBox[
                  StyleBox["BeforeSum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389965867-3079002", 
                    "Cool`Databank`BeforeSum"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"], 
                ButtonBox[
                  StyleBox["Databank",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389965867-3079002", 
                    "Cool`Databank`Databank"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"], 
                ButtonBox[
                  StyleBox["DataMold",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389965867-3079002", 
                    "Cool`Databank`DataMold"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"], 
                ButtonBox[
                  StyleBox["Explain",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389965867-3079002", 
                    "Cool`Databank`Explain"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"], 
                ButtonBox[
                  StyleBox["SetDatabank",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389965867-3079002", 
                    "Cool`Databank`SetDatabank"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"], 
                ButtonBox[
                  StyleBox["ShowData",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3389965867-3079002", 
                    "Cool`Databank`ShowData"},
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"], 
                ButtonBox[
                  StyleBox["Upd",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3389965867-3079002", "Cool`Databank`Upd"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Cool`Databank`"]}
              },
            RowMinHeight->1.05]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix N: Routines", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
This discussion uses The Economics Pack, Cool (2001). The basic routines are \
all defined with the more technical term \[OpenCurlyDoubleQuote]VolumeRatio\
\[CloseCurlyDoubleQuote] and the routine \
\[OpenCurlyDoubleQuote]NominalCorrelation\[CloseCurlyDoubleQuote] builds on \
those.\
\>", "Text"],

Cell["\<\
Note the distinction between OverallCorrelation and NominalCorrelation. I \
have considered to replace the subtitle of this paper \
\[OpenCurlyDoubleQuote]A measure of association or correlation\
\[CloseCurlyDoubleQuote] with the more extensive \
\[OpenCurlyDoubleQuote]Measures of association and correlation\
\[CloseCurlyDoubleQuote], to indicate that this paper discusses more angles. \
Yet, the focus is on the proposal for nominal correlation.\
\>", "Text"],

Cell[TextData[{
  "This analysis started out with a small case, clarified and simplified by \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The subsequent steps in generalization benefitted from that testing and \
prototyping environment as well. The availability of linear algebra routines \
and matrix manipulations was essential. The routines rely on symbolic \
operations. The environment also allowed the quick creation of user friendly \
routines, that not only have a clear logical structure but also come with \
help support and all. Finally, these routines also form building blocks that \
can be used immediately within other routines. All in all, there is yet \
another reason to thank the makers of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["For real or nominal data", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?CovarRegress\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \("CovarRegress[vcm] with vcm a variance-covariance matrix gives the \
coefficients of OLS (of the first variable on the other ones) as - s1 R1i / \
(si R11), where si is the standarddeviation of variable i (Sqrt diagonal) and \
where Rij is the (i, j) cofactor of the correlation matrix\nCovarRegress[cor, \
s] with cor a correlation matrix and s a vector of standard deviations, gives \
the same\nCovarRegress[All, cor, s] gives the matrix of OLS regression \
coefficients C, where each row has a 0 for the explained variable, while the \
off-diagonal coefficients are taken on the right hand side. Thus if x is the \
list of variables {x1, ..., xn} then x == C.x + eps\nCovarRegress[All, s] \
gives an explanation in terms of the cofactors of a correlation matrix, use a \
symbolic s"\)], "Print",
  CellTags->"Info3389963783-4703339"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?AssociationMatrixQ\)\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \("AssociationMatrixQ[m] is CORAMatrixQ[m, Full -> False]"\)], "Print",
  CellTags->"Info3389963783-2444450"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?CorrelationMatrixQ\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \("CorrelationMatrixQ[m] is CORAMatrixQ[m, Full -> True], which is \
AssociationMatrixQ[m] && PSD"\)], "Print",
  CellTags->"Info3389963783-2202456"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?CORAMatrixQ\)\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \("CORAMatrixQ[m] is True if m is a square symmetric matrix with 1 on the \
diagonal and elements -1 <= # <= 1, and otherwise False. If this is satisfied \
then the elements can be called pairwise associations. When the option Full \
-> True, then the routine also tests 0 <= Det[m] <= 1. If true the matrix is \
positive semi-definite (PSD) and is a full correlation matrix. Default Full \
-> Indeterminate since a call should be done with AssociationMatrixQ or \
CorrelationMatrixQ that set this option. Option MessagesQ -> (default True) \
controls printing of diagnostic messages"\)], "Print",
  CellTags->"Info3389963783-7322274"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?OverallCorrelation\)\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \("OverallCorrelation[mat] gives the overall correlation in correlation \
matrix mat. Options are:\n(1) Mode -> MultipleRSquared (default) | Det\n(1a) \
If Det is selected then the routine returns Sqrt[1 - Det[mat]]\n(1b) If \
MultipleRSquared is selected, then this routine is applied for i = 1, ..., \
Length[m]; such results can be found in lis = MultipleRSquared[List]. Then \
option Function -> f (default Max) is applied to that lis; output is \
Sqrt[f[lis]]. Results[OverallCorrelation] helps to identify the variable with \
the highest correlation\n(2) Check -> True | Return | False. False is \
default, does no test, since you would only apply this routine to a true \
positive semi-definite correlation matrix. Values True | Return tests mat on \
being a correlation matrix, while Return quits the routine if the test fails. \
See also the options of CorrelationMatrixQ. PM 1. This option would be \
relevant if you run the mistake to apply this routine to a square contingency \
table, where you should use NominalCorrelation. PM 2. Since Det[mat] is \
always computed, there is a default test on 0 <= Det[Mat] <= 1. Suppress a \
message by MessagesQ -> False, e.g. in CorrelationMatrixQ"\)], "Print",
  CellTags->"Info3389963783-3830953"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?MultipleRSquared\)\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \("MultipleRSquared[mat, i] = 1 - Det[mat] /  CoFactor[mat, i, i], and \
gives R^2[i; 2, ..., i-1, i+1, ..., n] or the squared multiple correlation \
coefficient from the OLS regression of ith (dependent) variable upon the \
other (independent) variables, provided that mat is the CorrelationMatrix \
between all variables\nOption Range with value False (default) does no test, \
with values True | Return tests mat on being a correlation matrix, while \
Return  quits the routine when the test fails\nMultipleRSquared[mat] takes i \
= 1\nSee OverallCorrelation, and note the difference between R and R^2\nSee \
the Estimate package where the MultipleRSquared is simply called \
RSquared"\)], "Print",
  CellTags->"Info3389963783-9661964"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ToPSDCorrelationMatrix\)\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \("ToPSDCorrelationMatrix[m] for association matrix m gives the closest \
approximation R such that R can be called a correlation matrix (in the \
conventional strong sense): symmetric, diagonal ones, -1 <= R[i, j] <= 1, and \
0 <= Det[R] <= 1. Given the first conditions the last implies positive \
semi-definiteness (PSD-ness). The approximation works best when m is already \
close to being a correlation matrix. Option Do -> ... gives the manner how \
this is done: \n(1) Default {\"NonnegEV\", UnitDiagonalMatrix} first adjusts \
the eigenvalues (all nonnegative) and then applies UnitDiagonalMatrix, see \
ToPSDMatrix\n(2) {\"HighamF\", UnitDiagonalMatrix} uses Higham's method, see \
ToPSDMatrix\n(3) \"Proportional\" uses m x with uniform scalar x for \
off-diagonal elements\n(4) \"Power\" uses m^x for off-diagonal elements\n(5) \
\"Gradual\" uses m^x x for off-diagonal elements (works best)\n\
ToPSDCorrelationMatrix[{a, b, x}, m] for a and b Symbols or 1 or 0 and x a \
Symbol explains these numerical adjustments (3), (4) and (5)"\)], "Print",
  CellTags->"Info3389963783-1309459"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ToPSDMatrix\)\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \("ToPSDMatrix[m] gives the closest positive semi-definite PSD \
approximation to square matrix m. Option Apply -> ... gives the manner. \n(1) \
Default \"NonnegEV\" sets negative eigenvalues to zero and updates the \
positive values proportionally so that sum again gives the dimension\n(2) \
\"HighamF\" uses the Frobenius norm for \"closeness\" and applies the formula \
from N. J. Higham (1989), \"Matrix nearness problems and applications\". In \
M. J. C. Gover and S. Barnett (eds), Applications of Matrix Theory, pages 1\
\[Dash]27. Oxford University Press. Real values only. Thus A = (m + \
Transpose[m])/2; {U, H} = PolarDecomposition[A], i.e. A = U.H or U = \
A.Inverse[H]; higham = (A + H) / 2; but warrant symmetry by S = (H + \
Transpose[H])/2; higham2 = (A + S) / 2\nNB. These manners do not guarantee \
that the diagonal is 1. If you are working on a correlation matrix then also \
consider UnitDiagonalMatrix after applying ToPSDMatrix"\)], "Print",
  CellTags->"Info3389963783-1444548"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?EigenChop\)\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \("EigenChop[m] chops the square matrix m's eigensystem with delta, \
default option Chop -> 10^(-6). Value Automatic gives the system delta, False \
doesn't chop and thus allows you to check that, with mat = Transpose[ev] we \
get m = mat . DiagonalMatrix[v] . Inverse[mat]. For a symmetric matrix the \
Inverse is the same as the Transpose. The eigensystem is in \
Results[EigenChop], with Mat = Transpose[ev] the eigenvectors in the columns. \
Output is the reassembled matrix. You may check the difference m - \
EigenChop[m]"\)], "Print",
  CellTags->"Info3389963784-8391200"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["For nominal data", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NominalStatistics\)\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \("NominalStatistics[c] with c a contingency table gives various \
statistics. From the NominalCorrelationMatrix and Variance, a CovarMat is \
determined, which allows a call to CovarRegress. Option N controls \
application of N[.] to results, values N (default) or Identity, and \
NominalVariance -> Automatic uses the default setting of NominalVariance with \
formal replacement of zeros\nNominalStatistics[Results, f_Symbol, \
heading_List (, heading2)] can be run afterwards with appropriate \
tableheadings (only once for square matrices"\)], "Print",
  CellTags->"Info3389963786-3160652"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?EffectiveNumberOfCategories\)\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \("EffectiveNumberOfCategories[f] for f a list of frequencies per \
category gives Add[f]^2/ Add[f^2]"\)], "Print",
  CellTags->"Info3389963786-6005471"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ContingencyTableQ\)\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \("ContingencyTableQ[x] is True when x is a contingency table and False \
otherwise. A vector is not a contingency table; this at least requires a \
matrix with one row. All sublists must be of equal length, see ArrayQ. Option \
Element -> ... has values (1) Automatic, means that all elements must be \
natural numbers (nonnegative integers) or Symbol. An alternative value is \
e.g. IntegerQ. (2) None, no test done on the elements, input as a whole must \
only be an Array, (3) your own test on the elements. E.g. the None effect is \
also got with Element -> ((#; True) &)"\)], "Print",
  CellTags->"Info3389963786-1547483"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?CorrelationPr2By2\)\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \("CorrelationPr2By2[{{n11, n12}, {n21, n22}}] gives the measure of \
correlation for a contingency table of two binary nominal variables \
(correlation and not just association)\nCorrelationPr2By2[mat] may also take \
a 3x3 matrix but then the borders are seen as sum totals, and dropped\n\
CorrelationPr2By2[Definition, mat (, {i, j})] gives the original definition \
without simplification based upon the nonnegative values (using binary values \
i and j)\nLet C (cause) be the column variable and E (effect) the row \
variable. In logic, the variables take values {1, 0}. Here it is better to \
take {1, -1} so that equal numbers of observations give a zero mean. Output \
then is the normal Pearson CorrelationPr[{1, 1, -1, -1}, {1, -1, 1, -1}, \
{n11, n21, n12, n22}].\nSee SquareMatrixNormedDet for larger {n, n} and \
VolumeRatio and CramersV for {n, m} contingency tables\nSee \
NominalCorrelation for n1 by n2 by ... by nm in general\n        *** \
AddedUsage by Cool`Survival`Epidemiology`: *** \nCorrelationPr2By2[] takes \
default DiseaseTestMatrix[]. Note that this measure has already been \
presented by Matthews 1975 but see NominalCorrelation too"\)], "Print",
  CellTags->"Info3389963786-6168920"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SquareMatrixNormedDet\)\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \("SquareMatrixNormedDet[mat] gives InDet[NormalizedMatrix[mat]] for \
square contingency table mat. This routine retains the sign of the direction \
of the association (ordinal or presentation order). See VolumeRatio and \
NominalCorrelation. For 2 by 2 matrices, see CorrelationPr2By2. InDet returns \
Indeterminate if its input has such element"\)], "Print",
  CellTags->"Info3389963787-5162220"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NormalizedMatrix\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \("NormalizedMatrix[mat] divides the elements of a n by m matrix by the \
square roots of their appropriate row and column sums. Note that repeated \
application doesn't generate the same result. Is primarily used in \
VolumeRatio and NominalCorrelation"\)], "Print",
  CellTags->"Info3389963787-9421809"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NominalCorrelation\)\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \("NominalCorrelation[mat] translates into VolumeRatio[mat] for n bij m \
dimensional contingency table mat (just a pairwise correlation number), and \
OverallCorrelation[NominalCorrelationMatrix[mat]] for n1 x n2 x .... x nk \
dimensions and k > 2 (a correlation score based upon a full correlation \
matrix). Options are passed on to the appropriate subroutines. PM. For square \
mat you might add the option NaturalNumberQ -> True to test on the use of \
natural numbers (nonnegative integers) for contingency tables (for possible \
confusion with OverallCorrelation on a square correlation matrix). The latter \
gives a warning test only, and the option is not used in VolumeRatio \
itself"\)], "Print",
  CellTags->"Info3389963787-4595655"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NominalCorrelationMatrix\)\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \("NominalCorrelationMatrix[mat] basically gives f[R] = R[w] = (1 - w) \
VR[B] + w VR[meth], where VR = VolumeRatioMatrix, B = BorderMatrices and meth \
is the chosen BordersOrAll -> meth option. Selected is the w such that the \
desired method is retained as much as possible but with a positive \
semi-definite (PSD) outcome. There are the following aspects to consider: \n\
(1) If the intermediate result R[w] appears to be non-PSD, then \
ToPSDCorrelationMatrix[R[w]] is put out \n(2) If meth = BorderMatrices, then \
of course w = 0 \n(3) If meth = Show then this only shows like in VR \n(4) \
See Options[NominalCorrelationMatrix] for the allowed BordersOrAll options in \
VR \n(5) Factor w is determined when Bounds -> True (default). Use Bounds -> \
False if you just want the results of VR without any tampering. Note that \
this also means that no PSD approximation is used \n(6) Factor w is found \
with SolveDetIn0To1, using FindRoot. A possible call to \
ToPSDCorrelationMatrix may cause a repeated call of SolveDetIn0To1 e.g. if \
the Gradual way is used \n(7) When both VR[B] and VR[meth] are non-PSD, then \
VR[meth] is directly adjusted towards PSD-ness, instead of first moving to \
VR[B] and only then adjusting; find the latter by directly calling \
BordersOrAll -> BorderMatrices \n(8) Results[NominalCorrelationMatrix, ...] \
contain the relevant details, check these by ??Results"\)], "Print",
  CellTags->"Info3389963787-1842802"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?VolumeRatio\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \("VolumeRatio[mat] gives a measure of association or correlation in a \
contingency matrix of size n by m. There are three approaches, indicated by \
the option VolumeRatioMethod: \n(i) \"Weak\" (default): (1) M = \
NormalizedMatrix[mat], (2) ma = M.M' or ma = M'.M whichever has smaller \
dimensions (potentially nonzero determinant), (3) output Sqrt[Det[ma]] \n(ii) \
Automatic (default): the same as (i) but using a faster algorithm which can \
be important for large multidimensional matrices and simulations \n(iii) \
\"Strong\": (1) ma = mat.mat' or ma = mat'.mat whichever has smaller \
dimensions (potentially nonzero determinant), (2) output \
Sqrt[SquareMatrixNormedDet[ma]]. This method is not preferable since (a) the \
2 x 2 case differs from the theoretical notion discussed below, (b) in fact, \
VolumeRatio[mat] and SquareMatrixNormedDet[mat] should gives similar outcomes \
for any square matrix, (c) in the standard case still 5% cases with a \
determinant out of range, (d) also the method of only using border matrices \
still gives 1% of cases out of the range. \nTheory: The absolute value of the \
determinant of real vectors gives the volume of the parallelepipedum created \
by those vectors. Let f: Rn -> Rm be defined by matrix A, so that f[x] = A x, \
and let S be a subset of Rn, then volume[f[S]] = Sqrt[Det[A'.A]]* volume[S]. \
Hence Sqrt[Det[m]] gives a normalized volume ratio.\nPM. If mat is a \
contingency table with nonnegative numbers, for nominal variables, then \
VolumeRatio gives a measure of association comparable to a correlation \
coefficient\nPM. Since the squares destroy the sign it is recovered with \
PairwiseSign\nPM. The routine uses InDet for Det\nVolumeRatio[mat] gives \
OverallCorrelation[VolumeRatioMatrix[mat]] if mat is more-dimensional \
(MatrixQ[mat] is false). In that latter case the BordersOrAll option is \
passed on to VolumeRatioMatrix, and the Mode, Function and Check options \
passed on to OverallCorrelation. This call thus basically generates a number \
of association since it is not warranted that the matrix is positive \
semi-definite (PSD). Use NominalCorrelation[mat] for that"\)], "Print",
  CellTags->"Info3389963787-1670301"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?PairwiseSign\)\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \("PairwiseSign[mat] gives 1 or -1 as the sign of association between \
rows and columns. Mat is aggregated to a 2 by 2 matrix m, then Sign[Det[m]]. \
Option ForceSign has default value False; if True then other values than 1 or \
-1 are set to 1. If the value is 1 then the sign is forced to be 1"\)], \
"Print",
  CellTags->"Info3389963787-7879889"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ForceSign\)\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \("ForceSign is an option of PairwiseSign"\)], "Print",
  CellTags->"Info3389963787-1951870"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?VolumeRatioMatrix\)\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \("VolumeRatioMatrix[mat] for a {n1, ..., nk} matrix gives a k by k \
assocation matrix, containing the VolumeRatio[m[ni, nj]] measures of \
association. There are three major ways to obtain that latter individual \
measure:\nBordersOrAll -> BorderMatrices sums the other dimensions\n\
BordersOrAll -> All (default) determines all individual m[p][ni, nj] matrices \
in the lower dimensions, determines their association, and (in default) gives \
the sum, weighted by total numbers in those submatrices\nBordersOrAll -> Show \
shows that latter method\nNB. The BordersOrAll -> All may be refined by \
non-default application by the option Inner -> Automatic | Min | Max | {f1, \
f2}, where the default is Automatic and uses {f1, f2} = \
VolumeRatioMatrix[Split], VolumeRatioMatrix[Average]} (weighted average), \
where choice Min uses {f1, f2} = {VolumeRatio, Min}, Max uses {VolumeRatio, \
Max}, and where f1 and f2 in general are functions that work on lists"\)], \
"Print",
  CellTags->"Info3389963787-2144332"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?PairwiseMeasure\)\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \("PairwiseMeasure is an option to indicate a measure for nominal \
variables that can be used to create a matrix of pairwise correlations. \
Examples are PairwiseMeasure -> VolumeRatio | CramersV"\)], "Print",
  CellTags->"Info3389963788-4054695"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?PairwiseMeasureMatrix\)\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \("PairwiseMeasureMatrix[mat] for a {n1, ..., nk} contingency table gives \
a k by k assocation matrix. Option PairwiseMeasure -> f gives the measure \
such that f[m[ni, nj]] are the measures of association, that then become the \
elements of the matrix. The default is VolumeRatio, and this routine is \
modelled after VolumeRatioMatrix (so that it should have the same outcomes). \
There are three major ways to obtain that latter individual measure:\n\
BordersOrAll -> BorderMatrices sums the other dimensions\nBordersOrAll -> All \
(default) determines all individual m[p][ni, nj] matrices in the lower \
dimensions, determines their association, and (in default) gives the sum, \
weighted by total numbers in those submatrices\nBordersOrAll -> Show shows \
that latter method\nNB. The BordersOrAll -> All may be refined by non-default \
application by the option Inner -> Automatic | Min | Max | {f1, f2}, where \
the default is Automatic and uses {f1, f2} = PairwiseMeasureMatrix[Split], \
PairwiseMeasureMatrix[Average]} (weighted average), where choice Min uses \
{f1, f2} = {VolumeRatio, Min}, Max uses {VolumeRatio, Max}, and where f1 and \
f2 in general are functions that work on lists\nNB. UsedPairwiseMeasure -> \
{VolumeRatio, CramersV} determines the pairwise measures that are allowed for \
this routine. The reason for being so strict is that a pairwise measure must \
be properly defined, and you would not want to see lots of confusing output \
when you would enter a insufficiently defined measure, or just a typing \
error. Adjust this option only when you feel confident about it"\)], "Print",
  CellTags->"Info3389963788-8282604"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NominalVariance\)\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \("NominalVariance[f] with f a list of frequency per category, uses \
default (VarianceFreq[Border, #]&). Option NominalVariance -> ... also \
accepts Variance, VarianceMLE, PearsonVariance, (VarianceFreq[Sum, #]&) and \
VariancePr without message; puts out a message if another routine is used\n\
NominalVariance[Table, {f1, ..., fn}] puts out all measures for lists f1, \
..., fn\nOption Replace -> ... replaces a zero outcome by a symbolic \
expression, default \"Var\", but no replacement if False\nOptions \
\"KnownVarMeasure\" states the variance measures that the routine tests upon \
(spelling errors)"\)], "Print",
  CellTags->"Info3389963788-4900215"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?VariancePr\)\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \("VariancePr[x_List, p_List] gives the variance of a list of values x \
using the list of associated probabilities p \nVariancePr[f] with p = f / \
Add[f] for frequencies f, assigns values 0, ..., k-1 to the categories. For \
Length k = 2, this is the binomial variance. See VarianceFreq if k > 2 and \
you want averages of pairwise variances\n        *** AddedUsage by \
Cool`Probability`: *** \nVariancePr[q_Prospect] gives the variance"\)], \
"Print",
  CellTags->"Info3389963788-2312096"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?VarianceFreq\)\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \("VarianceFreq[method, f] for a list of frequencies f, neglects the \
influence of the categories and just considers dispersion in those \
frequencies seen as orderless numbers. Here n = Add[f], p = f / n, and k = \
Length[f]. See VariancePr when the scores of the categories matter. See \
EffectiveNumberOfCategories as well. \nVarianceFreq[Times, f] gives n (Times \
@@ p). For Length k = 2, this is the binomial variance as well \n\
VarianceFreq[Border, f] gives k^k (Times @@ p) \nVarianceFreq[Sum, f] gives n \
p.(1 - p), the sum of pairwise variances \nVarianceFreq[Average, f] gives the \
arithmetic average (n p.(1 - p)) / k \nVarianceFreq[N, f] gives the weighted \
average (p . Sqrt[x (1-p)])^2 where the pairwise standard deviations are \
weighted \nVarianceFreq[Power, f] is (Times @@ f)^(1/k) / Average[f], thus \
the ratio between the geometric and arithmetic average; its outcome lies \
between 0 and 1 \nVarianceFreq[\"Pearson\", f] gives n (k * p.p - 1); see the \
Chi2 package "\)], "Print",
  CellTags->"Info3389963788-1844059"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TabledBorderMatrix\)\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \("TabledBorderMatrix[mat, {i, j}] decomposes the {i, j} border matrix \
into the submatrices that cause its sum value. These submatrices are \
indicated with label Mat. PM Check the same outcome as BorderMatrix by using \
(% // Add) /. Mat -> Identity"\)], "Print",
  CellTags->"Info3389963788-6521224"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NominalCorrelationReview\)\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \("NominalCorrelationReview[mat] applies the various standardly defined \
volume ratio measures to mat and determines the overall correlation. Defined \
are: (1) Option BordersOrAll takes values BorderMatrices and All, with the \
latter split to the inner methods Automatic, Min, Max. (2) Option Mode has \
values MultipleRSquared or Det. (3) The overall correlations are calculated \
either with or without adjustment for PSD-ness. PM. This is only defined for \
higher dimensional matrices since a m x n matrix just has the \
VolumeRatio[mat] for which all these distinctions don't apply"\)], "Print",
  CellTags->"Info3389963788-9745965"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Literature", "Section"],

Cell["Colignatus is the name of Thomas Cool in science.", "Text"],

Cell["\<\
Becker, L.A. (1999), \[OpenCurlyDoubleQuote]Measures of Effect Size (Strength \
of Association)\[CloseCurlyDoubleQuote], \
http://web.uccs.edu/lbecker/SPSS/glm_effectsize.htm, Retrieved from source\
\>", "Text"],

Cell[TextData[{
  "Cool, Th. (1999, 2001), \[OpenCurlyDoubleQuote]The Economics Pack, \
Applications for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyDoubleQuote], ",
  "http://www.dataweb.nl/~cool",
  ", ISBN 90-804774-1-9, JEL-99-0820"
}], "Text"],

Cell["\<\
Colignatus, Th. (2006), \[OpenCurlyDoubleQuote]On the sample distribution of \
the adjusted coefficient of determination (R2Adj) in OLS\
\[CloseCurlyDoubleQuote], \
http://library.wolfram.com/infocenter/MathSource/6269/\
\>", "Text"],

Cell["\<\
Colignatus, Th. (2007a), \[OpenCurlyDoubleQuote]A logic of exceptions\
\[CloseCurlyDoubleQuote], http://www.dataweb.nl/~cool, ISBN 978-90-804774-4-5\
\
\>", "Text"],

Cell["\<\
Colignatus, Th. (2007b), \[OpenCurlyDoubleQuote]Voting theory for democracy\
\[CloseCurlyDoubleQuote], 2nd edition, http://www.dataweb.nl/~cool, ISBN \
978-90-804774-5-2\
\>", "Text"],

Cell["\<\
Colignatus, Th. (2007c), \[OpenCurlyDoubleQuote]A measure of association \
(correlation) in nominal data (contingency tables), using determinants\
\[CloseCurlyDoubleQuote], a earlier version of this paper (3rd publishable \
draft), http://ideas.repec.org/p/pra/mprapa/2662.html\
\>", "Text"],

Cell["\<\
Colignatus, Th. (2007d), \[OpenCurlyDoubleQuote]Correlation in contingency \
tables. A measure of association or correlation in nominal data (contingency \
tables), using determinants\[CloseCurlyDoubleQuote], this paper, to be put at \
MPRA as well, as the improved version of Colignatus, Th. (2007c), but useful \
to mention in this list of references if only an abridged version of this \
paper is eventually published, http://mpra.ub.uni-muenchen.de/3044/ \
\>", "Text"],

Cell["\<\
Colignatus, Th. (2007e), \[OpenCurlyDoubleQuote]Elementary statistics and \
causality\[CloseCurlyDoubleQuote], work in progress, \
http://www.dataweb.nl/~cool\
\>", "Text"],

Cell["\<\
Colignatus, Th. (2007f), \[OpenCurlyDoubleQuote]The 2 \[Times] 2 \[Times] 2 \
case in causality, of an effect, a cause and a confounder\
\[CloseCurlyDoubleQuote], http://mpra.ub.uni-muenchen.de/3351/, Retrieved \
from source\
\>", "Text"],

Cell[TextData[{
  StyleBox["Friendly, M. (2007), \[OpenCurlyDoubleQuote]",
    FontSize->12],
  "Categorical Data Analysis with Graphics\[CloseCurlyDoubleQuote], Retrieved \
from http://www.math.yorku.ca/SCS/Courses/grcat/grc6.html (citing the data \
from Koch & Stokes (1991))"
}], "Text"],

Cell["\<\
Garson, D. (2007), \[OpenCurlyDoubleQuote]Nominal Association: Phi, \
Contingency Coefficient, Tschuprow's T, Cramer's V, Lambda, Uncertainty \
Coefficient\[CloseCurlyDoubleQuote], \
http://www2.chass.ncsu.edu/garson/pa765/assocnominal.htm, Retrieved from \
source \
\>", "Text"],

Cell["\<\
Higham, N. J. (1989), \[OpenCurlyDoubleQuote]Matrix nearness problems and \
applications\[CloseCurlyDoubleQuote]. In M. J. C. Gover and S. Barnett (eds), \
\[OpenCurlyDoubleQuote]Applications of Matrix Theory\[CloseCurlyDoubleQuote], \
pages 1\[Dash]27. Oxford University Press\
\>", "Text"],

Cell["\<\
Johnston J. (1972), \[OpenCurlyDoubleQuote]Econometric methods\
\[CloseCurlyDoubleQuote], McGraw-Hill\
\>", "Text"],

Cell["\<\
Kleinbaum, D.G., K.M. Sullivan and N.D. Barker (2003), \
\[OpenCurlyDoubleQuote]ActivEpi Companion texbook\[CloseCurlyDoubleQuote], \
Springer\
\>", "Text"],

Cell["\<\
Linacre J. M, (2005), \[OpenCurlyDoubleQuote]Correlation Coefficients: \
Describing Relationships\[CloseCurlyDoubleQuote], Rasch Measurement \
Transactions, 19:3 p. 1028-9, retrieved from \
http://www.rasch.org/rmt/rmt193c.htm (citing the data from Uebersax (2000))\
\>", "Text"],

Cell["\<\
Losh, S.C. (2004), \[OpenCurlyDoubleQuote]Guide 5: Bivariate Associations and \
Correlation Coefficient Properties\[CloseCurlyDoubleQuote], \
http://edf5400-01.fa04.fsu.edu/Guide5.html, Retrieved from Source\
\>", "Text"],

Cell["\<\
Losh, S.C. (2004a), \[OpenCurlyDoubleQuote]Guide 6: Multivariate \
Crosstabulations and Causal Issues\[CloseCurlyDoubleQuote], \
http://edf5400-01.fa04.fsu.edu/Guide6.html, Retrieved from Source\
\>", "Text"],

Cell["\<\
Mood, A.M. and F.A. Graybill (1963), \[OpenCurlyDoubleQuote]Introduction to \
the theory of statistics\[CloseCurlyDoubleQuote], McGraw-Hill\
\>", "Text"],

Cell["\<\
Pearl, J. (2000), \[OpenCurlyDoubleQuote]Causality. Models, reasoning and \
inference\[CloseCurlyDoubleQuote], Cambridge\
\>", "Text"],

Cell["\<\
Schield, M. (1999), \[OpenCurlyDoubleQuote]Simpson\[CloseCurlyQuote]s paradox \
and Cornfield\[CloseCurlyQuote]s conditions\[CloseCurlyDoubleQuote], Augsburg \
College ASA-JSM\
\>", "Text"],

Cell["\<\
Simon, R. (2007), \[OpenCurlyDoubleQuote]Lecture Notes and Exercises 2006/07\
\[CloseCurlyDoubleQuote], http://www.maths.lse.ac.uk/Courses/MA201/, \
Retrieved from source\
\>", "Text"],

Cell["\<\
Takayama A. (1974), \[OpenCurlyDoubleQuote]Mathematical economics\
\[CloseCurlyDoubleQuote], The Dryden Press\
\>", "Text"],

Cell["\<\
Theil H. (1971), \[OpenCurlyDoubleQuote]Principles of econometrics\
\[CloseCurlyDoubleQuote], North-Holland\
\>", "Text"],

Cell["\<\
UCLA ATS (2007), \[OpenCurlyDoubleQuote]SAS Textbook Examples. Econometric \
Analysis, Fourth Edition by Greene. Chapter 16: Simultaneous Equations Models\
\[CloseCurlyDoubleQuote], \
http://www.ats.ucla.edu/stat/SAS/examples/greene/chapter16.htm, Retrieved \
from source \
\>", "Text"],

Cell["(Other) websites", "Text"],

Cell["\<\
http://en.wikipedia.org/wiki/Contingency_table
http://post.queensu.ca:8080/SASDoc/getDoc/en/procstat.hlp/corr_sect26.htm
http://en.wikipedia.org/wiki/Fisher%27s_exact_test\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
ScreenStyleEnvironment->"AllBrackets",
WindowSize->{734, 637},
WindowMargins->{{Automatic, 129}, {Automatic, -1}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
ShowCellLabel->False,
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.

NB. Itemized text cannot be justified because the Dot or Number will jump.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PrintingStyleEnvironment->"Printout",
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"PrintingMargins"->{{97, 97}, {180, 64}},
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "AllBrackets"],
    PageWidth->WindowWidth,
    ShowCellBracket->True,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "EnhancedPrintout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ScriptMinSize->5,
    FontFamily->"Palatino",
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakAbove->True,
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->30],
  
  Cell[StyleData["Title", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->28],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {25, 20}},
    FontSize->24],
  
  Cell[StyleData["Subtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {25, 20}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Futura",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, Inherited}, {8, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 35}},
    FontSize->16],
  
  Cell[StyleData["Section", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {6, 12}},
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{12, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 18}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {5, 15}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sub3section"],
    CellMargins->{{12, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Sub3section",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Sub3section", "Printout"],
    CellMargins->{{2, 0}, {7, 18}},
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["Sub3section", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {5, 15}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->11],
  
  Cell[StyleData["Text", "EnhancedPrintout"],
    CellMargins->{{30, 30}, {2, 6}},
    TextJustification->1,
    FontSize->10.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{10, 10}, {5, 5}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["SmallText", "EnhancedPrintout"],
    CellMargins->{{10, 10}, {5, 5}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Arial",
    FontSize->11,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9],
  
  Cell[StyleData["Input", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{46, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 2}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{75, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["Print", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9],
  
  Cell[StyleData["Graphics", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "EnhancedPrintout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Miscellaneous Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{46, 42}, {0, 14}},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{42, 42}, {0, 14}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "EnhancedPrintout"],
    CellMargins->{{42, 30}, {0, 8}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10.5,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10],
  
  Cell[StyleData["Commentary", "EnhancedPrintout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 4}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 4},
    ParagraphIndent->-21,
    CounterIncrements->"ItemizedText",
    FontSize->11],
  
  Cell[StyleData["ItemizedText", "Printout"],
    ParagraphIndent->-18,
    FontSize->11],
  
  Cell[StyleData["ItemizedText", "EnhancedPrintout"],
    CellMargins->{{30, 30}, {3, 3}},
    TextJustification->0,
    ParagraphIndent->-18,
    FontFamily->"Palatino",
    FontSize->10.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{41, 4}, {0, 4}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text",
    FontSize->11],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{38, 4}, {0, 4}},
    FontSize->11],
  
  Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
    CellMargins->{{38, 30}, {0, 4}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->11],
  
  Cell[StyleData["IndentedText", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CoolBullitItem"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{25, 4}, {0, 4}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text",
    FontSize->11],
  
  Cell[StyleData["CoolBullitItem", "Printout"],
    CellMargins->{{20, 20}, {0, 4}},
    TextJustification->1,
    FontSize->11],
  
  Cell[StyleData["CoolBullitItem", "EnhancedPrintout"],
    CellMargins->{{42, 30}, {0, 6}},
    TextJustification->1,
    FontSize->10.5]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 4}},
    FontSize->10,
    Background->GrayLevel[0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.2, 0.3, 0.5},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox3Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox4Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox5Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox6Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {-1, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TopBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-2, 4}},
    FontSize->10,
    Background->GrayLevel[0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -1}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {-1, -1}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["MiddleBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-4, -4}},
    FontSize->10,
    Background->GrayLevel[0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpacedBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -1}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left},
    RowMinHeight->1.2}],
  
  Cell[StyleData["MiddleSpacedBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    Background->GrayLevel[0.900008],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpacedBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontFamily->"Palatino",
    Background->GrayLevel[0.900008],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -3}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left},
    RowMinHeight->1.2}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[0.900008],
    GridBoxOptions->{RowMinHeight->2.2}],
  
  Cell[StyleData["BottomBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[0.949996],
    GridBoxOptions->{RowMinHeight->2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-4, 4}},
    FontSize->10,
    Background->GrayLevel[0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {-1, -3}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.949996, 0.900008],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left},
    RowMinHeight->1.2}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-1, -1}},
    FontSize->10,
    Background->GrayLevel[0.900008],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-4, -4}},
    FontSize->10,
    Background->GrayLevel[0.949996],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{12, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}],
  
  Cell[StyleData["Picture", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{12, 4}, {0, 2}},
    PageBreakAbove->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 4}, {2, 4}},
    FontSize->7],
  
  Cell[StyleData["Caption", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {2, 4}},
    FontSize->8]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SingleRowTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["SingleRowTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["SingleRowTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.49,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["2ColumnEvenTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["3ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.25,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["4ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["4ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.2,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["5ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["5ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.16,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["6ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["6ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["7ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.14,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["7ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["7ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["8ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.12,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["8ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["8ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{45, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{45, Inherited}, {7, 7}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"]],
  
  Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{45, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["DisplayMath", "EnhancedPrintout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"WRICourier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0}],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0}],
  
  Cell[StyleData["EquationNumber", "EnhancedPrintout"],
    LineSpacing->{1.7, 0},
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{12, Inherited}, {7, 7}},
    CellFrameMargins->{{0, 0}, {7, 5}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "EnhancedPrintout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontFamily->"WRICourier",
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->26,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18],
  
  Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "EnhancedPrintout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None,
    FontSize->11],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->11],
  
  Cell[StyleData["Contents", "EnhancedPrintout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontFamily->"Times New Roman",
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None,
    FontSize->11],
  
  Cell[StyleData["Outline", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->11],
  
  Cell[StyleData["Outline", "EnhancedPrintout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontFamily->"Times New Roman",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None,
    FontSize->11,
    FontWeight->"Bold"],
  
  Cell[StyleData["Outline2", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->11,
    FontWeight->"Bold"],
  
  Cell[StyleData["Outline2", "EnhancedPrintout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontFamily->"Times New Roman",
    FontSize->10,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{40, 2}, {0, 1}},
    StyleMenuListing->None,
    FontSize->11],
  
  Cell[StyleData["Outline3", "Printout"],
    CellMargins->{{30, 0}, {0, 2}},
    FontSize->11],
  
  Cell[StyleData["Outline3", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 2}},
    FontFamily->"Times New Roman",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{60, 2}, {0, 1}},
    StyleMenuListing->None,
    FontSize->11],
  
  Cell[StyleData["Outline4", "Printout"],
    CellMargins->{{50, 0}, {0, 2}},
    FontSize->11],
  
  Cell[StyleData["Outline4", "EnhancedPrintout"],
    CellMargins->{{50, 0}, {0, 2}},
    FontFamily->"Times New Roman",
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->10],
  
  Cell[StyleData["Index", "EnhancedPrintout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->10],
  
  Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Browser Emulation", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextNormal"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["TextNormal", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrowserEmulation"],
    CellMargins->{{12, 1}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 70},
    LineSpacing->{1, 3},
    FontFamily->"Helvetica",
    GridBoxOptions->{ColumnWidths->0.25,
    ColumnAlignments->{Left},
    GridFrame->True,
    GridFrameMargins->0.5,
    ColumnLines->True}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CategoryDefs"],
    CellMargins->{{300, 10}, {7, 7}},
    LineSpacing->{1, 3},
    FontFamily->"Helvetica",
    Background->RGBColor[1, 0.8, 0.6],
    GridBoxOptions->{ColumnAlignments->{Left},
    GridFrame->False,
    RowLines->True,
    ColumnLines->True}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category1"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Category1", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category2"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{85, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Category2", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category3"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{157, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.2, 0, 0.4]],
  
  Cell[StyleData["Category3", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category4"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{230, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.300008, 0.4]],
  
  Cell[StyleData["Category4", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "EnhancedPrintout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Plain"],
  
  Cell[StyleData["Footer", "Printout"]],
  
  Cell[StyleData["Footer", "EnhancedPrintout"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Printout"]],
  
  Cell[StyleData["PageNumber", "EnhancedPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "EnhancedPrintout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->11,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
    FontFamily->"WRICourier",
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->11,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->11,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3389988121-2727535"->{
    Cell[8704, 267, 141, 3, 56, "Print",
      CellTags->"Info3389988121-2727535"]},
  "Info3389988124-3165832"->{
    Cell[71231, 1846, 332, 5, 56, "Print",
      CellTags->"Info3389988124-3165832"]},
  "Info3389988126-2902430"->{
    Cell[161043, 4040, 641, 10, 56, "Print",
      CellTags->"Info3389988126-2902430"]},
  "Info3388089028-2566563"->{
    Cell[795840, 22508, 550, 11, 63, "Print",
      CellTags->"Info3388089028-2566563"]},
  "Info3389963783-4703339"->{
    Cell[876884, 24742, 856, 12, 158, "Print",
      CellTags->"Info3389963783-4703339"]},
  "Info3389963783-2444450"->{
    Cell[877861, 24763, 127, 2, 25, "Print",
      CellTags->"Info3389963783-2444450"]},
  "Info3389963783-2202456"->{
    Cell[878109, 24774, 167, 3, 25, "Print",
      CellTags->"Info3389963783-2202456"]},
  "Info3389963783-7322274"->{
    Cell[878390, 24786, 653, 9, 101, "Print",
      CellTags->"Info3389963783-7322274"]},
  "Info3389963783-3830953"->{
    Cell[879164, 24804, 1269, 17, 234, "Print",
      CellTags->"Info3389963783-3830953"]},
  "Info3389963783-9661964"->{
    Cell[880552, 24830, 757, 11, 158, "Print",
      CellTags->"Info3389963783-9661964"]},
  "Info3389963783-1309459"->{
    Cell[881434, 24850, 1113, 15, 234, "Print",
      CellTags->"Info3389963783-1309459"]},
  "Info3389963783-1444548"->{
    Cell[882661, 24874, 1021, 14, 215, "Print",
      CellTags->"Info3389963783-1444548"]},
  "Info3389963784-8391200"->{
    Cell[883794, 24897, 598, 9, 101, "Print",
      CellTags->"Info3389963784-8391200"]},
  "Info3389963786-3160652"->{
    Cell[884587, 24920, 612, 9, 120, "Print",
      CellTags->"Info3389963786-3160652"]},
  "Info3389963786-6005471"->{
    Cell[885329, 24938, 171, 3, 25, "Print",
      CellTags->"Info3389963786-6005471"]},
  "Info3389963786-1547483"->{
    Cell[885620, 24950, 646, 9, 101, "Print",
      CellTags->"Info3389963786-1547483"]},
  "Info3389963786-6168920"->{
    Cell[886386, 24968, 1234, 17, 253, "Print",
      CellTags->"Info3389963786-6168920"]},
  "Info3389963787-5162220"->{
    Cell[887744, 24994, 417, 6, 63, "Print",
      CellTags->"Info3389963787-5162220"]},
  "Info3389963787-9421809"->{
    Cell[888280, 25009, 323, 5, 63, "Print",
      CellTags->"Info3389963787-9421809"]},
  "Info3389963787-4595655"->{
    Cell[888724, 25023, 763, 11, 120, "Print",
      CellTags->"Info3389963787-4595655"]},
  "Info3389963787-1842802"->{
    Cell[889614, 25043, 1472, 20, 291, "Print",
      CellTags->"Info3389963787-1842802"]},
  "Info3389963787-1670301"->{
    Cell[891200, 25072, 2226, 30, 424, "Print",
      CellTags->"Info3389963787-1670301"]},
  "Info3389963787-7879889"->{
    Cell[893541, 25111, 369, 6, 63, "Print",
      CellTags->"Info3389963787-7879889"]},
  "Info3389963787-1951870"->{
    Cell[894022, 25126, 111, 2, 25, "Print",
      CellTags->"Info3389963787-1951870"]},
  "Info3389963787-2144332"->{
    Cell[894253, 25137, 1031, 15, 196, "Print",
      CellTags->"Info3389963787-2144332"]},
  "Info3389963788-4054695"->{
    Cell[895402, 25161, 266, 4, 44, "Print",
      CellTags->"Info3389963788-4054695"]},
  "Info3389963788-8282604"->{
    Cell[895792, 25174, 1672, 22, 310, "Print",
      CellTags->"Info3389963788-8282604"]},
  "Info3389963788-4900215"->{
    Cell[897582, 25205, 679, 10, 120, "Print",
      CellTags->"Info3389963788-4900215"]},
  "Info3389963788-2312096"->{
    Cell[898374, 25224, 511, 8, 101, "Print",
      CellTags->"Info3389963788-2312096"]},
  "Info3389963788-1844059"->{
    Cell[899000, 25241, 1066, 15, 234, "Print",
      CellTags->"Info3389963788-1844059"]},
  "Info3389963788-6521224"->{
    Cell[900187, 25265, 322, 5, 63, "Print",
      CellTags->"Info3389963788-6521224"]},
  "Info3389963788-9745965"->{
    Cell[900636, 25279, 659, 9, 101, "Print",
      CellTags->"Info3389963788-9745965"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3389988121-2727535", 958613, 27416},
  {"Info3389988124-3165832", 958728, 27419},
  {"Info3389988126-2902430", 958845, 27422},
  {"Info3388089028-2566563", 958964, 27425},
  {"Info3389963783-4703339", 959084, 27428},
  {"Info3389963783-2444450", 959205, 27431},
  {"Info3389963783-2202456", 959324, 27434},
  {"Info3389963783-7322274", 959443, 27437},
  {"Info3389963783-3830953", 959563, 27440},
  {"Info3389963783-9661964", 959685, 27443},
  {"Info3389963783-1309459", 959806, 27446},
  {"Info3389963783-1444548", 959928, 27449},
  {"Info3389963784-8391200", 960050, 27452},
  {"Info3389963786-3160652", 960170, 27455},
  {"Info3389963786-6005471", 960290, 27458},
  {"Info3389963786-1547483", 960409, 27461},
  {"Info3389963786-6168920", 960529, 27464},
  {"Info3389963787-5162220", 960651, 27467},
  {"Info3389963787-9421809", 960770, 27470},
  {"Info3389963787-4595655", 960889, 27473},
  {"Info3389963787-1842802", 961010, 27476},
  {"Info3389963787-1670301", 961132, 27479},
  {"Info3389963787-7879889", 961254, 27482},
  {"Info3389963787-1951870", 961373, 27485},
  {"Info3389963787-2144332", 961492, 27488},
  {"Info3389963788-4054695", 961614, 27491},
  {"Info3389963788-8282604", 961733, 27494},
  {"Info3389963788-4900215", 961855, 27497},
  {"Info3389963788-2312096", 961976, 27500},
  {"Info3389963788-1844059", 962096, 27503},
  {"Info3389963788-6521224", 962218, 27506},
  {"Info3389963788-9745965", 962337, 27509}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 65, 0, 150, "Title"],
Cell[1844, 55, 126, 3, 80, "Subtitle"],
Cell[1973, 60, 98, 4, 88, "Text"],
Cell[2074, 66, 269, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[2368, 75, 29, 0, 38, "Subsection"],
Cell[2400, 77, 3089, 97, 230, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5526, 179, 20, 0, 72, "Section"],
Cell[5549, 181, 85, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[5659, 187, 49, 1, 26, "Input"],
Cell[5711, 190, 504, 8, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6252, 203, 131, 3, 27, "Input"],
Cell[6386, 208, 1636, 33, 171, "Output"]
}, Open  ]],
Cell[8037, 244, 82, 2, 27, "Input"],
Cell[8122, 248, 108, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[8255, 254, 77, 2, 27, "Input"],
Cell[8335, 258, 366, 7, 56, "Message"],
Cell[8704, 267, 141, 3, 56, "Print",
  CellTags->"Info3389988121-2727535"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8882, 275, 90, 2, 27, "Input"],
Cell[8975, 279, 3175, 78, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12187, 362, 76, 2, 27, "Input"],
Cell[12266, 366, 14460, 359, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26763, 730, 74, 2, 27, "Input"],
Cell[26840, 734, 11061, 276, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37938, 1015, 91, 2, 27, "Input"],
Cell[38032, 1019, 4853, 114, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42922, 1138, 87, 2, 27, "Input"],
Cell[43012, 1142, 12734, 301, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55783, 1448, 73, 2, 27, "Input"],
Cell[55859, 1452, 7544, 187, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63440, 1644, 79, 2, 27, "Input"],
Cell[63522, 1648, 7592, 189, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71151, 1842, 77, 2, 27, "Input"],
Cell[71231, 1846, 332, 5, 56, "Print",
  CellTags->"Info3389988124-3165832"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71600, 1856, 76, 2, 27, "Input"],
Cell[71679, 1860, 1061, 16, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72777, 1881, 94, 2, 27, "Input"],
Cell[72874, 1885, 16807, 395, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89718, 2285, 90, 2, 27, "Input"],
Cell[89811, 2289, 32079, 757, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121927, 3051, 74, 2, 27, "Input"],
Cell[122004, 3055, 464, 8, 56, "Message"],
Cell[122471, 3065, 37737, 941, 56, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160245, 4011, 61, 2, 27, "Input"],
Cell[160309, 4015, 460, 8, 56, "Message"],
Cell[160772, 4025, 79, 2, 56, "Output"]
}, Open  ]],
Cell[160866, 4030, 82, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[160973, 4036, 67, 2, 27, "Input"],
Cell[161043, 4040, 641, 10, 56, "Print",
  CellTags->"Info3389988126-2902430"]
}, Open  ]],
Cell[161699, 4053, 115, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[161839, 4059, 96, 2, 27, "Input"],
Cell[161938, 4063, 646, 18, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162621, 4086, 70, 2, 27, "Input"],
Cell[162694, 4090, 2119, 60, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164850, 4155, 95, 2, 27, "Input"],
Cell[164948, 4159, 2124, 60, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167109, 4224, 76, 2, 27, "Input"],
Cell[167188, 4228, 333, 10, 56, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[167570, 4244, 60, 1, 46, "Section",
  PageBreakAbove->True],
Cell[167633, 4247, 27, 0, 17, "Outline3"],
Cell[167663, 4249, 32, 0, 23, "Outline2"],
Cell[167698, 4251, 48, 0, 17, "Outline3"],
Cell[167749, 4253, 38, 0, 17, "Outline3"],
Cell[167790, 4255, 52, 0, 17, "Outline3"],
Cell[167845, 4257, 55, 0, 17, "Outline3"],
Cell[167903, 4259, 48, 0, 23, "Outline2"],
Cell[167954, 4261, 33, 0, 23, "Outline2"],
Cell[167990, 4263, 41, 0, 17, "Outline3"],
Cell[168034, 4265, 36, 0, 17, "Outline3"],
Cell[168073, 4267, 43, 0, 17, "Outline3"],
Cell[168119, 4269, 53, 0, 17, "Outline3"],
Cell[168175, 4271, 47, 0, 17, "Outline3"],
Cell[168225, 4273, 47, 0, 17, "Outline3"],
Cell[168275, 4275, 57, 0, 17, "Outline3"],
Cell[168335, 4277, 55, 0, 17, "Outline3"],
Cell[168393, 4279, 43, 0, 17, "Outline3"],
Cell[168439, 4281, 66, 0, 17, "Outline3"],
Cell[168508, 4283, 41, 0, 23, "Outline2"],
Cell[168552, 4285, 30, 0, 17, "Outline3"],
Cell[168585, 4287, 64, 0, 17, "Outline3"],
Cell[168652, 4289, 67, 0, 17, "Outline3"],
Cell[168722, 4291, 46, 0, 23, "Outline2"],
Cell[168771, 4293, 169, 9, 24, "Outline2"],
Cell[168943, 4304, 26, 0, 17, "Outline3"],
Cell[168972, 4306, 34, 0, 17, "Outline3"],
Cell[169009, 4308, 38, 0, 17, "Outline4"],
Cell[169050, 4310, 58, 0, 17, "Outline4"],
Cell[169111, 4312, 47, 0, 17, "Outline4"],
Cell[169161, 4314, 242, 10, 23, "Outline2"],
Cell[169406, 4326, 30, 0, 17, "Outline3"],
Cell[169439, 4328, 36, 0, 17, "Outline3"],
Cell[169478, 4330, 43, 0, 17, "Outline3"],
Cell[169524, 4332, 26, 0, 17, "Outline3"],
Cell[169553, 4334, 31, 0, 17, "Outline3"],
Cell[169587, 4336, 30, 0, 23, "Outline2"],
Cell[169620, 4338, 93, 2, 23, "Outline2"],
Cell[169716, 4342, 134, 5, 23, "Outline2"],
Cell[169853, 4349, 30, 0, 17, "Outline3"],
Cell[169886, 4351, 41, 0, 17, "Outline3"],
Cell[169930, 4353, 39, 0, 17, "Outline3"],
Cell[169972, 4355, 41, 0, 17, "Outline3"],
Cell[170016, 4357, 33, 0, 17, "Outline4"],
Cell[170052, 4359, 35, 0, 17, "Outline4"],
Cell[170090, 4361, 39, 0, 17, "Outline4"],
Cell[170132, 4363, 31, 0, 17, "Outline4"],
Cell[170166, 4365, 33, 0, 17, "Outline4"],
Cell[170202, 4367, 29, 0, 17, "Outline4"],
Cell[170234, 4369, 50, 0, 17, "Outline3"],
Cell[170287, 4371, 45, 0, 17, "Outline3"],
Cell[170335, 4373, 60, 0, 17, "Outline3"],
Cell[170398, 4375, 74, 0, 23, "Outline2"],
Cell[170475, 4377, 53, 0, 17, "Outline3"],
Cell[170531, 4379, 71, 0, 17, "Outline3"],
Cell[170605, 4381, 52, 0, 17, "Outline3"],
Cell[170660, 4383, 96, 5, 17, "Outline3"],
Cell[170759, 4390, 52, 0, 17, "Outline3"],
Cell[170814, 4392, 73, 0, 23, "Outline2"],
Cell[170890, 4394, 49, 0, 17, "Outline3"],
Cell[170942, 4396, 34, 0, 17, "Outline3"],
Cell[170979, 4398, 49, 0, 17, "Outline3"],
Cell[171031, 4400, 45, 0, 17, "Outline3"],
Cell[171079, 4402, 67, 0, 17, "Outline3"],
Cell[171149, 4404, 64, 0, 23, "Outline2"],
Cell[171216, 4406, 64, 0, 23, "Outline2"],
Cell[171283, 4408, 58, 0, 23, "Outline2"],
Cell[171344, 4410, 89, 2, 23, "Outline2"],
Cell[171436, 4414, 31, 0, 17, "Outline3"],
Cell[171470, 4416, 30, 0, 17, "Outline3"],
Cell[171503, 4418, 28, 0, 17, "Outline3"],
Cell[171534, 4420, 40, 0, 17, "Outline4"],
Cell[171577, 4422, 113, 5, 17, "Outline3"],
Cell[171693, 4429, 103, 5, 17, "Outline3"],
Cell[171799, 4436, 32, 0, 17, "Outline4"],
Cell[171834, 4438, 137, 5, 17, "Outline4"],
Cell[171974, 4445, 131, 5, 17, "Outline4"],
Cell[172108, 4452, 131, 5, 17, "Outline4"],
Cell[172242, 4459, 123, 5, 17, "Outline4"],
Cell[172368, 4466, 26, 0, 17, "Outline4"],
Cell[172397, 4468, 38, 0, 17, "Outline3"],
Cell[172438, 4470, 152, 5, 17, "Outline3"],
Cell[172593, 4477, 32, 0, 17, "Outline4"],
Cell[172628, 4479, 42, 0, 17, "Outline4"],
Cell[172673, 4481, 137, 5, 17, "Outline4"],
Cell[172813, 4488, 131, 5, 17, "Outline4"],
Cell[172947, 4495, 131, 5, 17, "Outline4"],
Cell[173081, 4502, 123, 5, 17, "Outline4"],
Cell[173207, 4509, 26, 0, 17, "Outline4"],
Cell[173236, 4511, 36, 0, 17, "Outline3"],
Cell[173275, 4513, 52, 0, 23, "Outline2"],
Cell[173330, 4515, 32, 0, 17, "Outline3"],
Cell[173365, 4517, 56, 0, 17, "Outline3"],
Cell[173424, 4519, 57, 0, 17, "Outline3"],
Cell[173484, 4521, 75, 0, 17, "Outline3"],
Cell[173562, 4523, 82, 1, 17, "Outline3"],
Cell[173647, 4526, 30, 0, 17, "Outline3"],
Cell[173680, 4528, 74, 0, 23, "Outline2"],
Cell[173757, 4530, 32, 0, 17, "Outline3"],
Cell[173792, 4532, 34, 0, 17, "Outline3"],
Cell[173829, 4534, 43, 0, 17, "Outline3"],
Cell[173875, 4536, 40, 0, 17, "Outline3"],
Cell[173918, 4538, 26, 0, 17, "Outline3"],
Cell[173947, 4540, 69, 0, 23, "Outline2"],
Cell[174019, 4542, 32, 0, 17, "Outline3"],
Cell[174054, 4544, 54, 0, 17, "Outline3"],
Cell[174111, 4546, 50, 0, 17, "Outline3"],
Cell[174164, 4548, 30, 0, 17, "Outline3"],
Cell[174197, 4550, 35, 0, 17, "Outline3"],
Cell[174235, 4552, 35, 0, 17, "Outline3"],
Cell[174273, 4554, 59, 0, 23, "Outline2"],
Cell[174335, 4556, 64, 0, 23, "Outline2"],
Cell[174402, 4558, 40, 0, 23, "Outline2"],
Cell[174445, 4560, 32, 0, 17, "Outline3"],
Cell[174480, 4562, 44, 0, 17, "Outline3"],
Cell[174527, 4564, 36, 0, 17, "Outline3"],
Cell[174566, 4566, 30, 0, 23, "Outline2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174633, 4571, 55, 1, 72, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[174713, 4576, 50, 0, 38, "Subsection"],
Cell[174766, 4578, 654, 10, 104, "Text"],

Cell[CellGroupData[{
Cell[175445, 4592, 235, 5, 46, "Input"],
Cell[175683, 4599, 94, 2, 29, "Output"]
}, Open  ]],
Cell[175792, 4604, 1242, 18, 140, "Text"],
Cell[177037, 4624, 75, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[177137, 4628, 95, 2, 28, "Input"],
Cell[177235, 4632, 2124, 60, 91, "Output"]
}, Open  ]],
Cell[179374, 4695, 1082, 16, 140, "Text"],
Cell[180459, 4713, 1479, 23, 194, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181975, 4741, 40, 0, 38, "Subsection"],
Cell[182018, 4743, 2260, 48, 212, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184315, 4796, 55, 0, 38, "Subsection"],
Cell[184373, 4798, 426, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[184824, 4809, 107, 2, 28, "Input"],
Cell[184934, 4813, 95, 2, 29, "Output"]
}, Open  ]],
Cell[185044, 4818, 507, 8, 86, "Text"],
Cell[185554, 4828, 602, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[186181, 4841, 107, 2, 28, "Input"],
Cell[186291, 4845, 96, 2, 45, "Output"]
}, Open  ]],
Cell[186402, 4850, 204, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[186631, 4858, 102, 2, 28, "Input"],
Cell[186736, 4862, 87, 2, 29, "Output"]
}, Open  ]],
Cell[186838, 4867, 1098, 16, 158, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[187973, 4888, 57, 0, 38, "Subsection"],
Cell[188033, 4890, 490, 8, 86, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[188572, 4904, 47, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[188644, 4908, 38, 0, 49, "Subsubsection"],
Cell[188685, 4910, 711, 10, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[189433, 4925, 31, 0, 49, "Subsubsection"],
Cell[189467, 4927, 1812, 63, 104, "Text"],
Cell[191282, 4992, 2162, 74, 140, "Text"],
Cell[193447, 5068, 1240, 40, 86, "Text"],
Cell[194690, 5110, 1789, 55, 122, "Text"],

Cell[CellGroupData[{
Cell[196504, 5169, 108, 2, 28, "Input"],
Cell[196615, 5173, 535, 12, 75, "Output"]
}, Open  ]],
Cell[197165, 5188, 1572, 55, 86, "Text"],
Cell[198740, 5245, 2783, 105, 140, "Text"],
Cell[201526, 5352, 1230, 30, 140, "Text"],
Cell[202759, 5384, 55, 0, 32, "Text"],
Cell[202817, 5386, 1304, 39, 76, "ItemizedText"],
Cell[204124, 5427, 1105, 40, 76, "ItemizedText"],
Cell[205232, 5469, 1160, 29, 122, "Text"],
Cell[206395, 5500, 532, 14, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206964, 5519, 46, 0, 49, "Subsubsection"],
Cell[207013, 5521, 623, 11, 86, "Text"],

Cell[CellGroupData[{
Cell[207661, 5536, 80, 2, 28, "Input"],
Cell[207744, 5540, 3415, 73, 249, "Output"]
}, Open  ]],
Cell[211174, 5616, 156, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[211355, 5625, 119, 3, 28, "Input"],
Cell[211477, 5630, 1226, 33, 81, "Output"]
}, Open  ]],
Cell[212718, 5666, 893, 30, 68, "Text"],
Cell[213614, 5698, 549, 8, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214200, 5711, 95, 2, 49, "Subsubsection"],
Cell[214298, 5715, 487, 7, 86, "Text"],

Cell[CellGroupData[{
Cell[214810, 5726, 81, 2, 28, "Input"],
Cell[214894, 5730, 842, 25, 63, "Output"]
}, Open  ]],
Cell[215751, 5758, 168, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[215944, 5765, 88, 2, 28, "Input"],
Cell[216035, 5769, 82, 2, 29, "Output"]
}, Open  ]],
Cell[216132, 5774, 576, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[216733, 5787, 99, 2, 28, "Input"],
Cell[216835, 5791, 1091, 26, 91, "Output"]
}, Open  ]],
Cell[217941, 5820, 260, 5, 50, "Text"],
Cell[218204, 5827, 157, 4, 28, "Input"],

Cell[CellGroupData[{
Cell[218386, 5835, 131, 3, 28, "Input"],
Cell[218520, 5840, 3446, 78, 216, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[222015, 5924, 78, 0, 49, "Subsubsection"],
Cell[222096, 5926, 1318, 55, 68, "Text"],

Cell[CellGroupData[{
Cell[223439, 5985, 99, 2, 28, "Input"],
Cell[223541, 5989, 1159, 32, 81, "Output"]
}, Open  ]],
Cell[224715, 6024, 529, 12, 68, "Text"],
Cell[225247, 6038, 883, 43, 32, "Text"],
Cell[226133, 6083, 410, 18, 32, "Text"],
Cell[226546, 6103, 388, 13, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226971, 6121, 56, 0, 49, "Subsubsection"],
Cell[227030, 6123, 1453, 24, 158, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228520, 6152, 64, 0, 49, "Subsubsection"],
Cell[228587, 6154, 441, 7, 68, "Text"],
Cell[229031, 6163, 737, 11, 104, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[229817, 6180, 32, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[229874, 6184, 43, 0, 38, "Subsection"],
Cell[229920, 6186, 1349, 19, 176, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231306, 6210, 38, 0, 38, "Subsection"],
Cell[231347, 6212, 3256, 63, 320, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[234640, 6280, 45, 0, 38, "Subsection"],
Cell[234688, 6282, 1002, 19, 104, "Text"],

Cell[CellGroupData[{
Cell[235715, 6305, 119, 2, 28, "Input"],
Cell[235837, 6309, 120, 2, 25, "Print"],
Cell[235960, 6313, 409, 10, 63, "Output"]
}, Open  ]],
Cell[236384, 6326, 474, 7, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236895, 6338, 55, 0, 38, "Subsection"],
Cell[236953, 6340, 3118, 106, 177, "Text"],
Cell[240074, 6448, 654, 14, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240765, 6467, 49, 0, 38, "Subsection"],
Cell[240817, 6469, 1238, 29, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242092, 6503, 49, 0, 38, "Subsection"],
Cell[242144, 6505, 2617, 44, 248, "Text"],
Cell[244764, 6551, 482, 18, 50, "Text"],
Cell[245249, 6571, 1095, 21, 140, "Text"],
Cell[246347, 6594, 540, 16, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246924, 6615, 59, 0, 38, "Subsection"],
Cell[246986, 6617, 3243, 77, 248, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[250266, 6699, 57, 0, 38, "Subsection"],
Cell[250326, 6701, 1574, 34, 158, "Text"],
Cell[251903, 6737, 680, 10, 104, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252620, 6752, 45, 0, 38, "Subsection"],
Cell[252668, 6754, 442, 9, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[253147, 6768, 68, 0, 38, "Subsection"],
Cell[253218, 6770, 440, 7, 68, "Text"],
Cell[253661, 6779, 309, 7, 50, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[254019, 6792, 40, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[254084, 6796, 32, 0, 38, "Subsection"],
Cell[254119, 6798, 478, 11, 68, "Text"],
Cell[254600, 6811, 393, 8, 57, "Input"],

Cell[CellGroupData[{
Cell[255018, 6823, 108, 2, 28, "Input"],
Cell[255129, 6827, 1071, 29, 81, "Output"]
}, Open  ]],
Cell[256215, 6859, 63, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[256303, 6863, 61, 1, 28, "Input"],
Cell[256367, 6866, 280, 9, 45, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[256696, 6881, 66, 0, 38, "Subsection"],
Cell[256765, 6883, 813, 29, 68, "Text"],

Cell[CellGroupData[{
Cell[257603, 6916, 70, 1, 28, "Input"],
Cell[257676, 6919, 22854, 466, 149, 5257, 244, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[280545, 7388, 974, 43, 54, "Text"],

Cell[CellGroupData[{
Cell[281544, 7435, 1406, 45, 42, "Input"],
Cell[282953, 7482, 62, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[283052, 7488, 307, 9, 28, "Input"],
Cell[283362, 7499, 62, 1, 29, "Output"]
}, Open  ]],
Cell[283439, 7503, 424, 20, 32, "Text"],
Cell[283866, 7525, 218, 7, 32, "Text"],
Cell[284087, 7534, 1037, 43, 50, "Text"],

Cell[CellGroupData[{
Cell[285149, 7581, 233, 4, 28, "Input"],
Cell[285385, 7587, 126, 2, 50, "Output"]
}, Open  ]],
Cell[285526, 7592, 477, 16, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[286040, 7613, 69, 0, 38, "Subsection"],
Cell[286112, 7615, 354, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[286491, 7627, 64, 1, 28, "Input"],
Cell[286558, 7630, 352, 9, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[286947, 7644, 168, 3, 28, "Input"],
Cell[287118, 7649, 52, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[287231, 7657, 45, 0, 72, "Section"],
Cell[287279, 7659, 426, 11, 50, "Text"],
Cell[287708, 7672, 1358, 46, 104, "Text"],
Cell[289069, 7720, 701, 16, 68, "Text"],
Cell[289773, 7738, 427, 9, 73, "Input"],

Cell[CellGroupData[{
Cell[290225, 7751, 102, 2, 28, "Input"],
Cell[290330, 7755, 77, 1, 29, "Output"]
}, Open  ]],
Cell[290422, 7759, 324, 10, 50, "Text"],

Cell[CellGroupData[{
Cell[290771, 7773, 165, 4, 28, "Input"],
Cell[290939, 7779, 468, 11, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[291444, 7795, 102, 2, 28, "Input"],
Cell[291549, 7799, 303, 5, 25, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[291901, 7810, 168, 9, 72, "Section"],

Cell[CellGroupData[{
Cell[292094, 7823, 28, 0, 38, "Subsection"],
Cell[292125, 7825, 1924, 72, 122, "Text"],
Cell[294052, 7899, 860, 22, 104, "Text"],
Cell[294915, 7923, 411, 17, 32, "Text"],
Cell[295329, 7942, 407, 22, 32, "Text"],
Cell[295739, 7966, 2142, 61, 183, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[297918, 8032, 36, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[297979, 8036, 43, 0, 49, "Subsubsection"],
Cell[298025, 8038, 236, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[298286, 8046, 92, 1, 28, "Input"],
Cell[298381, 8049, 77, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[298495, 8055, 92, 1, 28, "Input"],
Cell[298590, 8058, 76, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[298715, 8065, 63, 0, 49, "Subsubsection"],
Cell[298781, 8067, 188, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[298994, 8075, 91, 1, 28, "Input"],
Cell[299088, 8078, 157, 2, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[299294, 8086, 52, 0, 49, "Subsubsection"],
Cell[299349, 8088, 356, 10, 50, "Text"],

Cell[CellGroupData[{
Cell[299730, 8102, 151, 3, 28, "Input"],
Cell[299884, 8107, 470, 11, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[300391, 8123, 51, 1, 28, "Input"],
Cell[300445, 8126, 57, 1, 29, "Output"]
}, Open  ]],
Cell[300517, 8130, 729, 15, 104, "Text"],

Cell[CellGroupData[{
Cell[301271, 8149, 131, 2, 28, "Input"],
Cell[301405, 8153, 362, 9, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[301804, 8167, 76, 1, 28, "Input"],
Cell[301883, 8170, 284, 9, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[302204, 8184, 45, 1, 28, "Input"],
Cell[302252, 8187, 57, 1, 28, "Output"]
}, Open  ]],
Cell[302324, 8191, 163, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[302512, 8198, 78, 1, 28, "Input"],
Cell[302593, 8201, 52, 1, 28, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[302718, 8210, 241, 10, 72, "Section"],

Cell[CellGroupData[{
Cell[302984, 8224, 32, 0, 38, "Subsection"],
Cell[303019, 8226, 1406, 54, 86, "Text"],
Cell[304428, 8282, 2540, 89, 144, "Text"],
Cell[306971, 8373, 592, 13, 86, "Text"],
Cell[307566, 8388, 556, 9, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[308159, 8402, 38, 0, 38, "Subsection"],
Cell[308200, 8404, 272, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[308497, 8413, 269, 5, 46, "Input"],
Cell[308769, 8420, 2124, 60, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[310930, 8485, 77, 2, 28, "Input"],
Cell[311010, 8489, 1061, 29, 45, "Output"]
}, Open  ]],
Cell[312086, 8521, 300, 5, 50, "Text"],
Cell[312389, 8528, 88, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[312502, 8534, 168, 4, 28, "Input"],
Cell[312673, 8540, 394, 11, 89, "Output"]
}, Open  ]],
Cell[313082, 8554, 230, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[313337, 8562, 113, 2, 28, "Input"],
Cell[313453, 8566, 52, 1, 29, "Output"]
}, Open  ]],
Cell[313520, 8570, 237, 4, 50, "Text"],
Cell[313760, 8576, 65, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[313850, 8581, 162, 3, 28, "Input"],
Cell[314015, 8586, 92, 1, 29, "Output"]
}, Open  ]],
Cell[314122, 8590, 307, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[314454, 8599, 157, 3, 28, "Input"],
Cell[314614, 8604, 70, 1, 29, "Output"]
}, Open  ]],
Cell[314699, 8608, 152, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[314876, 8615, 193, 4, 28, "Input"],
Cell[315072, 8621, 92, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[315213, 8628, 45, 0, 38, "Subsection"],
Cell[315261, 8630, 993, 16, 122, "Text"],

Cell[CellGroupData[{
Cell[316279, 8650, 102, 2, 28, "Input"],
Cell[316384, 8654, 5923, 136, 117, "Output"]
}, Open  ]],
Cell[322322, 8793, 85, 2, 32, "Text"],
Cell[322410, 8797, 52, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[322487, 8802, 190, 4, 28, "Input"],
Cell[322680, 8808, 443, 10, 63, "Output"]
}, Open  ]],
Cell[323138, 8821, 281, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[323444, 8830, 162, 3, 28, "Input"],
Cell[323609, 8835, 92, 1, 29, "Output"]
}, Open  ]],
Cell[323716, 8839, 70, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[323811, 8843, 193, 4, 28, "Input"],
Cell[324007, 8849, 92, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[324148, 8856, 28, 0, 38, "Subsection"],
Cell[324179, 8858, 235, 4, 50, "Text"],
Cell[324417, 8864, 94, 2, 28, "Input"],
Cell[324514, 8868, 47, 0, 28, "Input"],

Cell[CellGroupData[{
Cell[324586, 8872, 47, 0, 28, "Input"],
Cell[324636, 8874, 900, 26, 63, "Output"]
}, Open  ]],
Cell[325551, 8903, 127, 3, 32, "Text"],
Cell[325681, 8908, 67, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[325773, 8912, 116, 2, 28, "Input"],
Cell[325892, 8916, 447, 10, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[326388, 8932, 33, 0, 38, "Subsection"],
Cell[326424, 8934, 333, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[326782, 8944, 65, 1, 28, "Input"],
Cell[326850, 8947, 70, 1, 29, "Output"]
}, Open  ]],
Cell[326935, 8951, 1413, 37, 140, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[328397, 8994, 29, 0, 72, "Section"],
Cell[328429, 8996, 1003, 23, 104, "Text"],
Cell[329435, 9021, 1481, 34, 158, "Text"],
Cell[330919, 9057, 361, 6, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[331317, 9068, 116, 3, 72, "Section",
  PageBreakAbove->True],
Cell[331436, 9073, 838, 14, 122, "Text"],
Cell[332277, 9089, 261, 5, 50, "Text"],
Cell[332541, 9096, 207, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[332773, 9104, 44, 1, 28, "Input"],
Cell[332820, 9107, 69, 1, 46, "Output"]
}, Open  ]],
Cell[332904, 9111, 321, 5, 50, "Text"],
Cell[333228, 9118, 388, 6, 50, "Text"],
Cell[333619, 9126, 390, 6, 68, "Text"],
Cell[334012, 9134, 568, 19, 50, "Text"],
Cell[334583, 9155, 363, 7, 50, "Text"],
Cell[334949, 9164, 892, 35, 54, "Text"],
Cell[335844, 9201, 339, 7, 50, "Text"],
Cell[336186, 9210, 117, 5, 32, "Text"],
Cell[336306, 9217, 553, 12, 68, "Text"],
Cell[336862, 9231, 116, 3, 32, "Text"],
Cell[336981, 9236, 99, 2, 32, "Text"],
Cell[337083, 9240, 128, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[337248, 9248, 133, 5, 72, "Section"],

Cell[CellGroupData[{
Cell[337406, 9257, 32, 0, 38, "Subsection"],
Cell[337441, 9259, 1555, 28, 176, "Text"],
Cell[338999, 9289, 953, 36, 72, "Text"],
Cell[339955, 9327, 827, 14, 104, "Text"],
Cell[340785, 9343, 304, 5, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[341126, 9353, 43, 0, 38, "Subsection"],
Cell[341172, 9355, 876, 20, 104, "Text"],

Cell[CellGroupData[{
Cell[342073, 9379, 205, 5, 28, "Input"],
Cell[342281, 9386, 60, 1, 25, "Print"],
Cell[342344, 9389, 333, 11, 41, "Print"],
Cell[342680, 9402, 63, 1, 25, "Print"],
Cell[342746, 9405, 609, 15, 61, "Print"],
Cell[343358, 9422, 73, 1, 25, "Print"],
Cell[343434, 9425, 925, 19, 87, "Print"],
Cell[344362, 9446, 2853, 60, 250, "Output"]
}, Open  ]],
Cell[347230, 9509, 202, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[347457, 9517, 110, 2, 28, "Input"],
Cell[347570, 9521, 154, 2, 49, "Output"]
}, Open  ]],
Cell[347739, 9526, 88, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[347852, 9532, 86, 1, 28, "Input"],
Cell[347941, 9535, 135, 2, 63, "Output"]
}, Open  ]],
Cell[348091, 9540, 438, 9, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[348566, 9554, 41, 0, 38, "Subsection"],
Cell[348610, 9556, 129, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[348764, 9563, 73, 1, 28, "Input"],
Cell[348840, 9566, 71, 1, 29, "Output"]
}, Open  ]],
Cell[348926, 9570, 354, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[349305, 9582, 60, 1, 28, "Input"],
Cell[349368, 9585, 57, 1, 29, "Output"]
}, Open  ]],
Cell[349440, 9589, 730, 14, 86, "Text"],
Cell[350173, 9605, 576, 10, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350786, 9620, 43, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[350854, 9624, 38, 0, 49, "Subsubsection"],
Cell[350895, 9626, 911, 17, 122, "Text"],
Cell[351809, 9645, 160, 4, 28, "Input"],

Cell[CellGroupData[{
Cell[351994, 9653, 67, 1, 28, "Input"],
Cell[352064, 9656, 197, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[352298, 9664, 54, 1, 28, "Input"],
Cell[352355, 9667, 556, 8, 29, "Output"]
}, Open  ]],
Cell[352926, 9678, 104, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[353067, 9686, 40, 0, 49, "Subsubsection"],
Cell[353110, 9688, 387, 6, 68, "Text"],
Cell[353500, 9696, 176, 3, 28, "Input"],

Cell[CellGroupData[{
Cell[353701, 9703, 212, 4, 46, "Input"],
Cell[353916, 9709, 2410, 59, 97, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[356363, 9773, 131, 2, 28, "Input"],
Cell[356497, 9777, 424, 10, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[356970, 9793, 44, 0, 49, "Subsubsection"],
Cell[357017, 9795, 723, 11, 86, "Text"],

Cell[CellGroupData[{
Cell[357765, 9810, 561, 9, 100, "Input"],
Cell[358329, 9821, 1510, 39, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[359876, 9865, 156, 3, 28, "Input"],
Cell[360035, 9870, 447, 11, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[360531, 9887, 36, 0, 49, "Subsubsection"],
Cell[360570, 9889, 812, 16, 104, "Text"],

Cell[CellGroupData[{
Cell[361407, 9909, 263, 4, 46, "Input"],
Cell[361673, 9915, 1076, 31, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[362786, 9951, 145, 3, 28, "Input"],
Cell[362934, 9956, 445, 11, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[363416, 9972, 48, 1, 28, "Input"],
Cell[363467, 9975, 426, 11, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[363942, 9992, 38, 0, 49, "Subsubsection"],
Cell[363983, 9994, 463, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[364471, 10005, 272, 5, 28, "Input"],
Cell[364746, 10012, 1508, 39, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[366291, 10056, 125, 2, 28, "Input"],
Cell[366419, 10060, 405, 10, 29, "Output"]
}, Open  ]],
Cell[366839, 10073, 263, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[367127, 10082, 254, 4, 46, "Input"],
Cell[367384, 10088, 1074, 31, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368495, 10124, 125, 2, 28, "Input"],
Cell[368623, 10128, 413, 10, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[369085, 10144, 34, 0, 49, "Subsubsection"],
Cell[369122, 10146, 336, 6, 68, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[369507, 10158, 52, 0, 38, "Subsection"],
Cell[369562, 10160, 587, 10, 86, "Text"],

Cell[CellGroupData[{
Cell[370174, 10174, 106, 2, 28, "Input"],
Cell[370283, 10178, 319, 10, 63, "Output"]
}, Open  ]],
Cell[370617, 10191, 165, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[370807, 10198, 108, 2, 28, "Input"],
Cell[370918, 10202, 143, 2, 50, "Output"]
}, Open  ]],
Cell[371076, 10207, 167, 4, 28, "Input"],

Cell[CellGroupData[{
Cell[371268, 10215, 108, 2, 28, "Input"],
Cell[371379, 10219, 114, 2, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[371530, 10226, 104, 2, 28, "Input"],
Cell[371637, 10230, 480, 7, 53, "Output"]
}, Open  ]],
Cell[372132, 10240, 578, 13, 68, "Text"],

Cell[CellGroupData[{
Cell[372735, 10257, 223, 4, 28, "Input"],
Cell[372961, 10263, 190, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[373188, 10271, 256, 4, 46, "Input"],
Cell[373447, 10277, 1301, 35, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[374785, 10317, 144, 2, 28, "Input"],
Cell[374932, 10321, 30276, 913, 186, 16040, 733, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[405223, 11237, 1204, 26, 140, "Text"],
Cell[406430, 11265, 968, 14, 140, "Text"],
Cell[407401, 11281, 1093, 19, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[408531, 11305, 47, 0, 38, "Subsection"],
Cell[408581, 11307, 752, 24, 68, "Text"],

Cell[CellGroupData[{
Cell[409358, 11335, 109, 2, 28, "Input"],
Cell[409470, 11339, 60, 1, 25, "Print"],
Cell[409533, 11342, 1259, 39, 69, "Print"],
Cell[410795, 11383, 63, 1, 25, "Print"],
Cell[410861, 11386, 1291, 39, 69, "Print"],
Cell[412155, 11427, 73, 1, 25, "Print"],
Cell[412231, 11430, 1301, 39, 69, "Print"],
Cell[413535, 11471, 1482, 32, 147, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[415066, 11509, 62, 0, 38, "Subsection"],
Cell[415131, 11511, 1415, 27, 158, "Text"],

Cell[CellGroupData[{
Cell[416571, 11542, 228, 5, 60, "Input"],
Cell[416802, 11549, 1794, 41, 73, "Output"]
}, Open  ]],
Cell[418611, 11593, 276, 5, 50, "Text"],
Cell[418890, 11600, 69, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[418984, 11605, 232, 5, 60, "Input"],
Cell[419219, 11612, 1738, 40, 73, "Output"]
}, Open  ]],
Cell[420972, 11655, 225, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[421222, 11663, 63, 1, 28, "Input"],
Cell[421288, 11666, 1268, 32, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[422593, 11703, 307, 6, 60, "Input"],
Cell[422903, 11711, 1854, 44, 73, "Output"]
}, Open  ]],
Cell[424772, 11758, 557, 9, 86, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[425378, 11773, 73, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[425476, 11777, 55, 0, 38, "Subsection"],
Cell[425534, 11779, 1093, 40, 68, "Text"],
Cell[426630, 11821, 4897, 130, 358, "Text"],
Cell[431530, 11953, 723, 21, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[432290, 11979, 73, 0, 38, "Subsection"],
Cell[432366, 11981, 581, 17, 50, "Text"],
Cell[432950, 12000, 1394, 35, 122, "Text"],
Cell[434347, 12037, 1581, 56, 104, "Text"],

Cell[CellGroupData[{
Cell[435953, 12097, 60, 1, 28, "Input"],
Cell[436016, 12100, 59, 1, 30, "Output"]
}, Open  ]],
Cell[436090, 12104, 116, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[436231, 12111, 106, 2, 28, "Input"],
Cell[436340, 12115, 57, 1, 36, "Output"]
}, Open  ]],
Cell[436412, 12119, 2535, 93, 122, "Text"],
Cell[438950, 12214, 731, 20, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[439718, 12239, 54, 0, 38, "Subsection"],
Cell[439775, 12241, 237, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[440037, 12249, 89, 1, 28, "Input"],
Cell[440129, 12252, 319, 10, 63, "Output"]
}, Open  ]],
Cell[440463, 12265, 137, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[440625, 12272, 63, 1, 28, "Input"],
Cell[440691, 12275, 258, 4, 52, "Output"]
}, Open  ]],
Cell[440964, 12282, 132, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[441121, 12291, 62, 1, 28, "Input"],
Cell[441186, 12294, 329, 5, 41, "Message"],
Cell[441518, 12301, 348, 6, 25, "Message"],
Cell[441869, 12309, 181, 3, 63, "Output"]
}, Open  ]],
Cell[442065, 12315, 299, 12, 32, "Text"],

Cell[CellGroupData[{
Cell[442389, 12331, 248, 4, 28, "Input"],
Cell[442640, 12337, 123, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[442800, 12344, 77, 1, 28, "Input"],
Cell[442880, 12347, 139, 2, 63, "Output"]
}, Open  ]],
Cell[443034, 12352, 124, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[443183, 12359, 62, 1, 28, "Input"],
Cell[443248, 12362, 69, 1, 36, "Output"]
}, Open  ]],
Cell[443332, 12366, 195, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[443552, 12374, 81, 1, 28, "Input"],
Cell[443636, 12377, 88, 1, 36, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[443773, 12384, 98, 5, 38, "Subsection"],
Cell[443874, 12391, 701, 19, 86, "Text"],

Cell[CellGroupData[{
Cell[444600, 12414, 144, 2, 30, "Input"],
Cell[444747, 12418, 367, 10, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[445151, 12433, 225, 4, 30, "Input"],
Cell[445379, 12439, 275, 4, 33, "Output"]
}, Open  ]],
Cell[445669, 12446, 227, 4, 50, "Text"],
Cell[445899, 12452, 356, 6, 47, "Input"],
Cell[446258, 12460, 241, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[446524, 12468, 102, 2, 30, "Input"],
Cell[446629, 12472, 625, 11, 104, "Output"]
}, Open  ]],
Cell[447269, 12486, 198, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[447492, 12498, 83, 1, 30, "Input"],
Cell[447578, 12501, 119, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[447746, 12509, 54, 0, 38, "Subsection"],
Cell[447803, 12511, 239, 4, 50, "Text"],
Cell[448045, 12517, 1152, 25, 333, "Input"],
Cell[449200, 12544, 161, 2, 28, "Input"],
Cell[449364, 12548, 287, 5, 50, "Text"],
Cell[449654, 12555, 147, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[449826, 12561, 64, 1, 28, "Input"],
Cell[449893, 12564, 694, 15, 81, "Output"]
}, Open  ]],
Cell[450602, 12582, 532, 14, 68, "Text"],

Cell[CellGroupData[{
Cell[451159, 12600, 58, 1, 28, "Input"],
Cell[451220, 12603, 70, 1, 29, "Output"]
}, Open  ]],
Cell[451305, 12607, 170, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[451500, 12614, 48, 1, 28, "Input"],
Cell[451551, 12617, 70, 1, 29, "Output"]
}, Open  ]],
Cell[451636, 12621, 371, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[452032, 12631, 55, 1, 28, "Input"],
Cell[452090, 12634, 70, 1, 29, "Output"]
}, Open  ]],
Cell[452175, 12638, 161, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[452361, 12645, 60, 1, 28, "Input"],
Cell[452424, 12648, 700, 16, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[453185, 12671, 72, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[453282, 12675, 51, 0, 38, "Subsection"],
Cell[453336, 12677, 519, 8, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[453892, 12690, 36, 0, 38, "Subsection"],
Cell[453931, 12692, 154, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454122, 12700, 51, 0, 38, "Subsection"],
Cell[454176, 12702, 1030, 46, 68, "Text"],
Cell[455209, 12750, 277, 4, 64, "Input"],

Cell[CellGroupData[{
Cell[455511, 12758, 211, 4, 28, "Input"],
Cell[455725, 12764, 149, 2, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[455923, 12772, 67, 0, 38, "Subsection"],
Cell[455993, 12774, 230, 4, 50, "Text"],
Cell[456226, 12780, 194, 4, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[456457, 12789, 69, 0, 38, "Subsection"],
Cell[456529, 12791, 415, 11, 50, "Text"],

Cell[CellGroupData[{
Cell[456969, 12806, 186, 3, 28, "Input"],
Cell[457158, 12811, 164, 2, 57, "Output"]
}, Open  ]],
Cell[457337, 12816, 400, 6, 68, "Text"],
Cell[457740, 12824, 483, 17, 50, "Text"],
Cell[458226, 12843, 294, 11, 32, "Text"],
Cell[458523, 12856, 320, 7, 50, "Text"],
Cell[458846, 12865, 892, 29, 68, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[459787, 12900, 63, 0, 72, "Section"],
Cell[459853, 12902, 282, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[460160, 12911, 157, 3, 28, "Input"],
Cell[460320, 12916, 2438, 63, 153, "Output"]
}, Open  ]],
Cell[462773, 12982, 227, 10, 32, "Text"],

Cell[CellGroupData[{
Cell[463025, 12996, 63, 1, 28, "Input"],
Cell[463091, 12999, 356, 11, 81, "Output"]
}, Open  ]],
Cell[463462, 13013, 102, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[463589, 13020, 69, 1, 28, "Input"],
Cell[463661, 13023, 2812, 70, 225, "Output"]
}, Open  ]],
Cell[466488, 13096, 35, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[466548, 13100, 83, 1, 28, "Input"],
Cell[466634, 13103, 356, 11, 81, "Output"]
}, Open  ]],
Cell[467005, 13117, 46, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[467076, 13121, 89, 1, 28, "Input"],
Cell[467168, 13124, 48061, 960, 801, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[515266, 14089, 72, 1, 28, "Input"],
Cell[515341, 14092, 673, 16, 87, "Output"]
}, Open  ]],
Cell[516029, 14111, 111, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[516165, 14118, 54, 1, 28, "Input"],
Cell[516222, 14121, 72, 1, 29, "Output"]
}, Open  ]],
Cell[516309, 14125, 28, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[516362, 14129, 66, 1, 28, "Input"],
Cell[516431, 14132, 72, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[516552, 14139, 63, 0, 72, "Section"],
Cell[516618, 14141, 94, 2, 32, "Text"],
Cell[516715, 14145, 1170, 35, 104, "Text"],
Cell[517888, 14182, 2236, 101, 86, "Text"],
Cell[520127, 14285, 575, 21, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520739, 14311, 57, 0, 72, "Section"],
Cell[520799, 14313, 299, 5, 50, "Text"],
Cell[521101, 14320, 487, 9, 73, "Input"],

Cell[CellGroupData[{
Cell[521613, 14333, 64, 1, 28, "Input"],
Cell[521680, 14336, 519, 12, 81, "Output"]
}, Open  ]],
Cell[522214, 14351, 511, 8, 68, "Text"],
Cell[522728, 14361, 319, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[523072, 14370, 90, 1, 28, "Input"],
Cell[523165, 14373, 70, 1, 29, "Output"]
}, Open  ]],
Cell[523250, 14377, 291, 5, 50, "Text"],
Cell[523544, 14384, 737, 12, 104, "Text"],
Cell[524284, 14398, 1420, 55, 86, "Text"],
Cell[525707, 14455, 1536, 49, 104, "Text"],
Cell[527246, 14506, 635, 18, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[527918, 14529, 88, 2, 72, "Section"],

Cell[CellGroupData[{
Cell[528031, 14535, 33, 0, 38, "Subsection"],
Cell[528067, 14537, 434, 7, 68, "Text"],
Cell[528504, 14546, 89, 1, 28, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[528630, 14552, 32, 0, 38, "Subsection"],
Cell[528665, 14554, 2257, 68, 158, "Text"],
Cell[530925, 14624, 1730, 49, 140, "Text"],
Cell[532658, 14675, 449, 7, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[533144, 14687, 30, 0, 38, "Subsection"],
Cell[533177, 14689, 372, 17, 32, "Text"],
Cell[533552, 14708, 516, 23, 50, "Text"],

Cell[CellGroupData[{
Cell[534093, 14735, 416, 13, 28, "Input"],
Cell[534512, 14750, 416, 13, 45, "Output"]
}, Open  ]],
Cell[534943, 14766, 823, 30, 50, "Text"],
Cell[535769, 14798, 529, 22, 50, "Text"],
Cell[536301, 14822, 531, 21, 32, "Text"],
Cell[536835, 14845, 1689, 60, 69, "Text"],
Cell[538527, 14907, 3859, 160, 104, "Text"],
Cell[542389, 15069, 70, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[542484, 15073, 45, 0, 49, "Subsubsection"],
Cell[542532, 15075, 185, 4, 50, "Text"],
Cell[542720, 15081, 1077, 47, 50, "Text"],
Cell[543800, 15130, 308, 14, 32, "Text"],
Cell[544111, 15146, 2597, 75, 43, "Text"],
Cell[546711, 15223, 90, 2, 32, "Text"],
Cell[546804, 15227, 1598, 49, 39, "Text"],
Cell[548405, 15278, 6309, 295, 140, "Text"],

Cell[CellGroupData[{
Cell[554739, 15577, 149, 3, 28, "Input"],
Cell[554891, 15582, 181, 3, 49, "Output"]
}, Open  ]],
Cell[555087, 15588, 543, 16, 50, "Text"],
Cell[555633, 15606, 1138, 44, 68, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[556820, 15656, 115, 5, 38, "Subsection"],
Cell[556938, 15663, 264, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[557227, 15674, 244, 4, 46, "Input"],
Cell[557474, 15680, 2088, 59, 91, "Output"]
}, Open  ]],
Cell[559577, 15742, 63, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[559665, 15747, 168, 4, 28, "Input"],
Cell[559836, 15753, 145, 2, 25, "Message"],
Cell[559984, 15757, 1625, 28, 135, "Output"]
}, Open  ]],
Cell[561624, 15788, 159, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[561808, 15795, 209, 5, 28, "Input",
  Evaluatable->False],
Cell[562020, 15802, 59, 1, 29, "Output"]
}, Open  ]],
Cell[562094, 15806, 530, 16, 68, "Text"],

Cell[CellGroupData[{
Cell[562649, 15826, 297, 6, 30, "Input"],
Cell[562949, 15834, 23024, 304, 6920, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[586010, 16143, 195, 5, 25, "Input",
  Evaluatable->False],
Cell[586208, 16150, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[586316, 16157, 105, 5, 38, "Subsection"],

Cell[CellGroupData[{
Cell[586446, 16166, 37, 0, 49, "Subsubsection"],
Cell[586486, 16168, 437, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[586948, 16184, 244, 4, 46, "Input"],
Cell[587195, 16190, 2088, 59, 91, "Output"]
}, Open  ]],
Cell[589298, 16252, 274, 7, 50, "Text"],
Cell[589575, 16261, 85, 1, 28, "Input"],
Cell[589663, 16264, 87, 1, 28, "Input"],
Cell[589753, 16267, 82, 1, 28, "Input"],
Cell[589838, 16270, 255, 5, 50, "Text"],
Cell[590096, 16277, 152, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[590285, 16285, 142, 5, 49, "Subsubsection"],

Cell[CellGroupData[{
Cell[590452, 16294, 47, 1, 28, "Input"],
Cell[590502, 16297, 54, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[590593, 16303, 179, 3, 48, "Input"],
Cell[590775, 16308, 145, 2, 21, "Message"],
Cell[590923, 16312, 2086, 33, 177, "Output"]
}, Open  ]],
Cell[593024, 16348, 168, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[593217, 16354, 135, 3, 28, "Input"],
Cell[593355, 16359, 73, 1, 28, "Output"]
}, Open  ]],
Cell[593443, 16363, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[593575, 16369, 78, 1, 28, "Input"],
Cell[593656, 16372, 64, 1, 28, "Output"]
}, Open  ]],
Cell[593735, 16376, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[593864, 16382, 132, 3, 28, "Input"],
Cell[593999, 16387, 72, 1, 28, "Output"]
}, Open  ]],
Cell[594086, 16391, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[594204, 16396, 130, 3, 28, "Input"],
Cell[594337, 16401, 73, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[594447, 16407, 66, 1, 28, "Input"],
Cell[594516, 16410, 75, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[594628, 16416, 103, 2, 28, "Input"],
Cell[594734, 16420, 87, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[594858, 16426, 172, 2, 28, "Input"],
Cell[595033, 16430, 320, 9, 44, "Output"]
}, Open  ]],
Cell[595368, 16442, 359, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[595752, 16452, 73, 1, 28, "Input"],
Cell[595828, 16455, 220, 4, 21, "Message"],
Cell[596051, 16461, 69, 1, 28, "Output"]
}, Open  ]],
Cell[596135, 16465, 73, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[596233, 16469, 104, 2, 28, "Input"],
Cell[596340, 16473, 437, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596814, 16488, 39, 1, 28, "Input"],
Cell[596856, 16491, 76, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596969, 16497, 126, 2, 28, "Input"],
Cell[597098, 16501, 441, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[597576, 16516, 39, 1, 28, "Input"],
Cell[597618, 16519, 72, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[597739, 16526, 136, 5, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[597900, 16535, 50, 1, 28, "Input"],
Cell[597953, 16538, 57, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[598047, 16544, 173, 3, 48, "Input"],
Cell[598223, 16549, 1405, 24, 145, "Output"]
}, Open  ]],
Cell[599643, 16576, 168, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[599836, 16582, 135, 3, 28, "Input"],
Cell[599974, 16587, 73, 1, 28, "Output"]
}, Open  ]],
Cell[600062, 16591, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[600194, 16597, 78, 1, 28, "Input"],
Cell[600275, 16600, 57, 1, 28, "Output"]
}, Open  ]],
Cell[600347, 16604, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[600476, 16610, 132, 3, 28, "Input"],
Cell[600611, 16615, 69, 1, 28, "Output"]
}, Open  ]],
Cell[600695, 16619, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[600813, 16624, 130, 3, 28, "Input"],
Cell[600946, 16629, 73, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[601068, 16636, 136, 5, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[601229, 16645, 50, 1, 28, "Input"],
Cell[601282, 16648, 57, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[601376, 16654, 173, 3, 48, "Input"],
Cell[601552, 16659, 1405, 24, 145, "Output"]
}, Open  ]],
Cell[602972, 16686, 168, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[603165, 16692, 135, 3, 28, "Input"],
Cell[603303, 16697, 73, 1, 28, "Output"]
}, Open  ]],
Cell[603391, 16701, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[603523, 16707, 78, 1, 28, "Input"],
Cell[603604, 16710, 64, 1, 28, "Output"]
}, Open  ]],
Cell[603683, 16714, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[603812, 16720, 132, 3, 28, "Input"],
Cell[603947, 16725, 73, 1, 28, "Output"]
}, Open  ]],
Cell[604035, 16729, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[604153, 16734, 130, 3, 28, "Input"],
Cell[604286, 16739, 73, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[604396, 16745, 66, 1, 28, "Input"],
Cell[604465, 16748, 75, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[604577, 16754, 103, 2, 28, "Input"],
Cell[604683, 16758, 83, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[604803, 16764, 172, 2, 28, "Input"],
Cell[604978, 16768, 316, 9, 44, "Output"]
}, Open  ]],
Cell[605309, 16780, 212, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[605546, 16788, 75, 1, 28, "Input"],
Cell[605624, 16791, 70, 1, 28, "Output"]
}, Open  ]],
Cell[605709, 16795, 73, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[605807, 16799, 140, 2, 48, "Input"],
Cell[605950, 16803, 433, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[606420, 16818, 39, 1, 28, "Input"],
Cell[606462, 16821, 76, 1, 28, "Output"]
}, Open  ]],
Cell[606553, 16825, 99, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[606677, 16831, 113, 2, 28, "Input"],
Cell[606793, 16835, 433, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607263, 16850, 39, 1, 28, "Input"],
Cell[607305, 16853, 69, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607411, 16859, 126, 2, 48, "Input"],
Cell[607540, 16863, 401, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607978, 16878, 39, 1, 28, "Input"],
Cell[608020, 16881, 70, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[608139, 16888, 128, 5, 29, "Subsubsection"],
Cell[608270, 16895, 63, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[608358, 16900, 168, 4, 28, "Input"],
Cell[608529, 16906, 145, 2, 21, "Message"],
Cell[608677, 16910, 1625, 28, 133, "Output"]
}, Open  ]],
Cell[610317, 16941, 168, 2, 28, "Input"],
Cell[610488, 16945, 85, 1, 28, "Input"],
Cell[610576, 16948, 87, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[610688, 16953, 135, 3, 28, "Input"],
Cell[610826, 16958, 73, 1, 28, "Output"]
}, Open  ]],
Cell[610914, 16962, 82, 1, 28, "Input"],
Cell[610999, 16965, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[611131, 16971, 78, 1, 28, "Input"],
Cell[611212, 16974, 57, 1, 28, "Output"]
}, Open  ]],
Cell[611284, 16978, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[611413, 16984, 132, 3, 28, "Input"],
Cell[611548, 16989, 69, 1, 28, "Output"]
}, Open  ]],
Cell[611632, 16993, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[611750, 16998, 130, 3, 28, "Input"],
Cell[611883, 17003, 73, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[612005, 17010, 31, 0, 29, "Subsubsection"],
Cell[612039, 17012, 386, 10, 50, "Text"],
Cell[612428, 17024, 119, 3, 28, "Input"],
Cell[612550, 17029, 53, 0, 28, "Input"],

Cell[CellGroupData[{
Cell[612628, 17033, 42, 0, 28, "Input"],
Cell[612673, 17035, 1096, 31, 81, "Output"]
}, Open  ]],
Cell[613784, 17069, 636, 10, 104, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[614469, 17085, 40, 0, 38, "Subsection"],
Cell[614512, 17087, 379, 6, 68, "Text"],
Cell[614894, 17095, 447, 20, 32, "Text"],
Cell[615344, 17117, 288, 13, 32, "Text"],

Cell[CellGroupData[{
Cell[615657, 17134, 153, 3, 28, "Input"],
Cell[615813, 17139, 163, 2, 63, "Output"]
}, Open  ]],
Cell[615991, 17144, 274, 8, 50, "Text"],
Cell[616268, 17154, 240, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[616533, 17164, 234, 4, 46, "Input"],
Cell[616770, 17170, 134, 2, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[616941, 17177, 143, 2, 28, "Input"],
Cell[617087, 17181, 29563, 848, 186, 14742, 661, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[646665, 18032, 287, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[646977, 18043, 130, 3, 28, "Input"],
Cell[647110, 18048, 134, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[647281, 18056, 254, 4, 46, "Input"],
Cell[647538, 18062, 1622, 45, 153, "Output"]
}, Open  ]],
Cell[649175, 18110, 938, 13, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[650150, 18128, 154, 5, 38, "Subsection"],

Cell[CellGroupData[{
Cell[650329, 18137, 37, 0, 49, "Subsubsection"],
Cell[650369, 18139, 250, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[650644, 18147, 109, 2, 28, "Input"],
Cell[650756, 18151, 87, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[650892, 18158, 47, 0, 49, "Subsubsection"],
Cell[650942, 18160, 437, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[651404, 18176, 244, 4, 46, "Input"],
Cell[651651, 18182, 2088, 59, 91, "Output"]
}, Open  ]],
Cell[653754, 18244, 274, 7, 50, "Text"],
Cell[654031, 18253, 85, 1, 28, "Input"],
Cell[654119, 18256, 87, 1, 28, "Input"],
Cell[654209, 18259, 82, 1, 28, "Input"],
Cell[654294, 18262, 152, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[654483, 18270, 142, 5, 49, "Subsubsection"],

Cell[CellGroupData[{
Cell[654650, 18279, 47, 1, 28, "Input"],
Cell[654700, 18282, 54, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[654791, 18288, 179, 3, 48, "Input"],
Cell[654973, 18293, 145, 2, 21, "Message"],
Cell[655121, 18297, 2695, 44, 205, "Output"]
}, Open  ]],
Cell[657831, 18344, 168, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[658024, 18350, 135, 3, 28, "Input"],
Cell[658162, 18355, 73, 1, 28, "Output"]
}, Open  ]],
Cell[658250, 18359, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[658382, 18365, 78, 1, 28, "Input"],
Cell[658463, 18368, 64, 1, 28, "Output"]
}, Open  ]],
Cell[658542, 18372, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[658671, 18378, 132, 3, 28, "Input"],
Cell[658806, 18383, 72, 1, 28, "Output"]
}, Open  ]],
Cell[658893, 18387, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[659011, 18392, 130, 3, 28, "Input"],
Cell[659144, 18397, 73, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[659254, 18403, 66, 1, 28, "Input"],
Cell[659323, 18406, 75, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[659435, 18412, 103, 2, 28, "Input"],
Cell[659541, 18416, 87, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[659665, 18422, 172, 2, 28, "Input"],
Cell[659840, 18426, 320, 9, 44, "Output"]
}, Open  ]],
Cell[660175, 18438, 212, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[660412, 18446, 71, 1, 28, "Input"],
Cell[660486, 18449, 220, 4, 21, "Message"],
Cell[660709, 18455, 69, 1, 28, "Output"]
}, Open  ]],
Cell[660793, 18459, 65, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[660883, 18463, 82, 1, 28, "Input"],
Cell[660968, 18466, 70, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[661087, 18473, 136, 5, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[661248, 18482, 50, 1, 28, "Input"],
Cell[661301, 18485, 57, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[661395, 18491, 173, 3, 28, "Input"],
Cell[661571, 18496, 145, 2, 21, "Message"],
Cell[661719, 18500, 1753, 30, 196, "Output"]
}, Open  ]],
Cell[663487, 18533, 168, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[663680, 18539, 135, 3, 28, "Input"],
Cell[663818, 18544, 73, 1, 28, "Output"]
}, Open  ]],
Cell[663906, 18548, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[664038, 18554, 78, 1, 28, "Input"],
Cell[664119, 18557, 64, 1, 28, "Output"]
}, Open  ]],
Cell[664198, 18561, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[664327, 18567, 132, 3, 28, "Input"],
Cell[664462, 18572, 71, 1, 28, "Output"]
}, Open  ]],
Cell[664548, 18576, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[664666, 18581, 130, 3, 28, "Input"],
Cell[664799, 18586, 73, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[664921, 18593, 136, 5, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[665082, 18602, 50, 1, 28, "Input"],
Cell[665135, 18605, 57, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[665229, 18611, 173, 3, 28, "Input"],
Cell[665405, 18616, 145, 2, 21, "Message"],
Cell[665553, 18620, 1753, 30, 196, "Output"]
}, Open  ]],
Cell[667321, 18653, 168, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[667514, 18659, 135, 3, 28, "Input"],
Cell[667652, 18664, 73, 1, 28, "Output"]
}, Open  ]],
Cell[667740, 18668, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[667872, 18674, 78, 1, 28, "Input"],
Cell[667953, 18677, 64, 1, 28, "Output"]
}, Open  ]],
Cell[668032, 18681, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[668161, 18687, 132, 3, 28, "Input"],
Cell[668296, 18692, 73, 1, 28, "Output"]
}, Open  ]],
Cell[668384, 18696, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[668502, 18701, 130, 3, 28, "Input"],
Cell[668635, 18706, 73, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668745, 18712, 66, 1, 28, "Input"],
Cell[668814, 18715, 75, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668926, 18721, 103, 2, 28, "Input"],
Cell[669032, 18725, 87, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[669156, 18731, 172, 2, 28, "Input"],
Cell[669331, 18735, 320, 9, 44, "Output"]
}, Open  ]],
Cell[669666, 18747, 212, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[669903, 18755, 75, 1, 28, "Input"],
Cell[669981, 18758, 70, 1, 28, "Output"]
}, Open  ]],
Cell[670066, 18762, 73, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[670164, 18766, 140, 2, 28, "Input"],
Cell[670307, 18770, 435, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[670779, 18785, 39, 1, 28, "Input"],
Cell[670821, 18788, 75, 1, 28, "Output"]
}, Open  ]],
Cell[670911, 18792, 99, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[671035, 18798, 113, 2, 28, "Input"],
Cell[671151, 18802, 439, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[671627, 18817, 39, 1, 28, "Input"],
Cell[671669, 18820, 73, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[671779, 18826, 126, 2, 28, "Input"],
Cell[671908, 18830, 439, 10, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[672384, 18845, 39, 1, 28, "Input"],
Cell[672426, 18848, 71, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[672546, 18855, 128, 5, 29, "Subsubsection"],
Cell[672677, 18862, 63, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[672765, 18867, 168, 4, 28, "Input"],
Cell[672936, 18873, 145, 2, 21, "Message"],
Cell[673084, 18877, 2023, 32, 169, "Output"]
}, Open  ]],
Cell[675122, 18912, 168, 2, 28, "Input"],
Cell[675293, 18916, 85, 1, 28, "Input"],
Cell[675381, 18919, 87, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[675493, 18924, 135, 3, 28, "Input"],
Cell[675631, 18929, 73, 1, 28, "Output"]
}, Open  ]],
Cell[675719, 18933, 82, 1, 28, "Input"],
Cell[675804, 18936, 107, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[675936, 18942, 78, 1, 28, "Input"],
Cell[676017, 18945, 64, 1, 28, "Output"]
}, Open  ]],
Cell[676096, 18949, 104, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[676225, 18955, 132, 3, 28, "Input"],
Cell[676360, 18960, 71, 1, 28, "Output"]
}, Open  ]],
Cell[676446, 18964, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[676564, 18969, 130, 3, 28, "Input"],
Cell[676697, 18974, 73, 1, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[676819, 18981, 31, 0, 29, "Subsubsection"],
Cell[676853, 18983, 386, 10, 50, "Text"],
Cell[677242, 18995, 119, 3, 28, "Input"],
Cell[677364, 19000, 53, 0, 28, "Input"],
Cell[677420, 19002, 106, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[677551, 19009, 42, 0, 28, "Input"],
Cell[677596, 19011, 1100, 31, 81, "Output"]
}, Open  ]],
Cell[678711, 19045, 322, 5, 68, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[679082, 19056, 38, 0, 38, "Subsection"],
Cell[679123, 19058, 138, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[679286, 19065, 106, 2, 28, "Input"],
Cell[679395, 19069, 88, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[679520, 19075, 84, 1, 28, "Input"],
Cell[679607, 19078, 135, 2, 63, "Output"]
}, Open  ]],
Cell[679757, 19083, 93, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[679875, 19088, 84, 1, 28, "Input"],
Cell[679962, 19091, 157, 2, 63, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[680180, 19100, 51, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[680256, 19104, 34, 0, 38, "Subsection"],
Cell[680293, 19106, 1328, 41, 86, "Text"],
Cell[681624, 19149, 560, 9, 86, "Text"],
Cell[682187, 19160, 336, 6, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[682560, 19171, 58, 0, 38, "Subsection"],
Cell[682621, 19173, 230, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[682876, 19181, 244, 4, 46, "Input"],
Cell[683123, 19187, 2088, 59, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[685248, 19251, 52, 1, 28, "Input"],
Cell[685303, 19254, 1036, 28, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[686376, 19287, 73, 1, 28, "Input"],
Cell[686452, 19290, 4688, 98, 252, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[691177, 19393, 126, 3, 28, "Input"],
Cell[691306, 19398, 52, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[691407, 19405, 59, 0, 38, "Subsection"],
Cell[691469, 19407, 136, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[691630, 19414, 307, 5, 46, "Input"],
Cell[691940, 19421, 2088, 59, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[694065, 19485, 52, 1, 28, "Input"],
Cell[694120, 19488, 1044, 28, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[695201, 19521, 71, 1, 28, "Input"],
Cell[695275, 19524, 4275, 89, 252, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[699587, 19618, 126, 3, 28, "Input"],
Cell[699716, 19623, 52, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[699817, 19630, 77, 0, 38, "Subsection"],
Cell[699897, 19632, 226, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[700148, 19640, 235, 3, 46, "Input"],
Cell[700386, 19645, 2116, 59, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[702539, 19709, 52, 1, 28, "Input"],
Cell[702594, 19712, 1064, 28, 45, "Output"]
}, Open  ]],
Cell[703673, 19743, 443, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[704141, 19754, 71, 1, 28, "Input"],
Cell[704215, 19757, 220, 4, 25, "Message"],
Cell[704438, 19763, 221, 4, 25, "Message"],
Cell[704662, 19769, 220, 4, 25, "Message"],
Cell[704885, 19775, 405, 7, 25, "Message"],
Cell[705293, 19784, 7232, 152, 492, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[712562, 19941, 126, 3, 28, "Input"],
Cell[712691, 19946, 71, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[712811, 19953, 84, 1, 38, "Subsection"],
Cell[712898, 19956, 124, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[713047, 19963, 231, 3, 46, "Input"],
Cell[713281, 19968, 2108, 59, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[715426, 20032, 52, 1, 28, "Input"],
Cell[715481, 20035, 1052, 28, 45, "Output"]
}, Open  ]],
Cell[716548, 20066, 434, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[717007, 20077, 73, 1, 28, "Input"],
Cell[717083, 20080, 219, 4, 25, "Message"],
Cell[717305, 20086, 219, 4, 25, "Message"],
Cell[717527, 20092, 6996, 149, 372, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[724560, 20246, 126, 3, 28, "Input"],
Cell[724689, 20251, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[724778, 20257, 111, 2, 28, "Input"],
Cell[724892, 20261, 71, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[725012, 20268, 32, 0, 38, "Subsection"],
Cell[725047, 20270, 1410, 39, 104, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[726506, 20315, 73, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[726604, 20319, 34, 0, 38, "Subsection"],
Cell[726641, 20321, 1974, 34, 230, "Text"],
Cell[728618, 20357, 113, 3, 32, "Text"],
Cell[728734, 20362, 113, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[728872, 20368, 85, 1, 28, "Input"],
Cell[728960, 20371, 447, 10, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[729444, 20386, 54, 1, 28, "Input"],
Cell[729501, 20389, 219, 4, 25, "Message"],
Cell[729723, 20395, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[729828, 20402, 36, 0, 38, "Subsection"],
Cell[729867, 20404, 160, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[730052, 20411, 86, 1, 28, "Input"],
Cell[730141, 20414, 537, 13, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[730715, 20432, 49, 1, 28, "Input"],
Cell[730767, 20435, 81, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[730885, 20441, 55, 1, 28, "Input"],
Cell[730943, 20444, 139, 2, 25, "Message"],
Cell[731085, 20448, 56, 1, 29, "Output"]
}, Open  ]],
Cell[731156, 20452, 185, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[731366, 20460, 155, 3, 28, "Input"],
Cell[731524, 20465, 507, 12, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[732068, 20482, 71, 1, 28, "Input"],
Cell[732142, 20485, 530, 13, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[732709, 20503, 77, 1, 28, "Input"],
Cell[732789, 20506, 104, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[732942, 20514, 45, 0, 38, "Subsection"],
Cell[732990, 20516, 256, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[733271, 20525, 93, 1, 28, "Input"],
Cell[733367, 20528, 540, 13, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[733944, 20546, 57, 1, 28, "Input"],
Cell[734004, 20549, 81, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[734122, 20555, 63, 1, 28, "Input"],
Cell[734188, 20558, 139, 2, 25, "Message"],
Cell[734330, 20562, 56, 1, 29, "Output"]
}, Open  ]],
Cell[734401, 20566, 225, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[734651, 20574, 156, 3, 28, "Input"],
Cell[734810, 20579, 509, 12, 63, "Output"]
}, Open  ]],
Cell[735334, 20594, 282, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[735641, 20604, 59, 1, 28, "Input"],
Cell[735703, 20607, 529, 12, 69, "Output"]
}, Open  ]],
Cell[736247, 20622, 135, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[736407, 20629, 58, 1, 28, "Input"],
Cell[736468, 20632, 319, 10, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[736836, 20648, 42, 0, 38, "Subsection"],
Cell[736881, 20650, 634, 16, 68, "Text"],

Cell[CellGroupData[{
Cell[737540, 20670, 127, 3, 28, "Input"],
Cell[737670, 20675, 929, 20, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[738636, 20700, 91, 1, 28, "Input"],
Cell[738730, 20703, 531, 14, 65, "Output"]
}, Open  ]],
Cell[739276, 20720, 112, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[739413, 20727, 70, 1, 28, "Input"],
Cell[739486, 20730, 443, 10, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[739966, 20745, 56, 1, 28, "Input"],
Cell[740025, 20748, 82, 1, 29, "Output"]
}, Open  ]],
Cell[740122, 20752, 59, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[740206, 20756, 131, 3, 28, "Input"],
Cell[740340, 20761, 443, 10, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[740820, 20776, 58, 1, 28, "Input"],
Cell[740881, 20779, 55, 1, 29, "Output"]
}, Open  ]],
Cell[740951, 20783, 222, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[741198, 20793, 91, 1, 28, "Input"],
Cell[741292, 20796, 70, 1, 29, "Output"]
}, Open  ]],
Cell[741377, 20800, 256, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[741658, 20809, 59, 1, 28, "Input"],
Cell[741720, 20812, 455, 10, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[742212, 20827, 77, 1, 28, "Input"],
Cell[742292, 20830, 102, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[742431, 20837, 59, 1, 28, "Input"],
Cell[742493, 20840, 457, 10, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[742999, 20856, 28, 0, 38, "Subsection"],
Cell[743030, 20858, 375, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[743430, 20868, 47, 1, 28, "Input"],
Cell[743480, 20871, 447, 10, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[743964, 20886, 134, 2, 28, "Input"],
Cell[744101, 20890, 507, 12, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[744645, 20907, 156, 3, 28, "Input"],
Cell[744804, 20912, 509, 12, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[745350, 20929, 110, 2, 28, "Input"],
Cell[745463, 20933, 443, 10, 63, "Output"]
}, Open  ]],
Cell[745921, 20946, 406, 7, 68, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[746376, 20959, 68, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[746469, 20963, 34, 0, 38, "Subsection"],
Cell[746506, 20965, 713, 19, 86, "Text"],

Cell[CellGroupData[{
Cell[747244, 20988, 95, 2, 28, "Input"],
Cell[747342, 20992, 701, 16, 99, "Output"]
}, Open  ]],
Cell[748058, 21011, 598, 17, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[748693, 21033, 52, 0, 38, "Subsection"],
Cell[748748, 21035, 939, 26, 86, "Text"],
Cell[749690, 21063, 1227, 45, 86, "Text"],
Cell[750920, 21110, 2859, 93, 123, "ItemizedText"],
Cell[753782, 21205, 1288, 40, 99, "ItemizedText"],
Cell[755073, 21247, 128, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[755238, 21255, 52, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[755315, 21259, 53, 0, 49, "Sub3section"],
Cell[755371, 21261, 425, 9, 68, "Text"],
Cell[755799, 21272, 593, 16, 68, "Text"],
Cell[756395, 21290, 319, 5, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[756751, 21300, 43, 0, 49, "Sub3section"],
Cell[756797, 21302, 328, 6, 68, "Text"],
Cell[757128, 21310, 176, 6, 22, "ItemizedText"],
Cell[757307, 21318, 202, 6, 22, "ItemizedText"],
Cell[757512, 21326, 1450, 37, 158, "Text"],
Cell[758965, 21365, 525, 13, 68, "Text"],
Cell[759493, 21380, 128, 3, 32, "Text"],
Cell[759624, 21385, 162, 5, 22, "ItemizedText"],

Cell[CellGroupData[{
Cell[759811, 21394, 134, 3, 28, "Input"],
Cell[759948, 21399, 103, 2, 29, "Output"]
}, Open  ]],
Cell[760066, 21404, 237, 6, 40, "ItemizedText"],

Cell[CellGroupData[{
Cell[760328, 21414, 136, 3, 28, "Input"],
Cell[760467, 21419, 105, 2, 29, "Output"]
}, Open  ]],
Cell[760587, 21424, 88, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[760700, 21430, 94, 2, 28, "Input"],
Cell[760797, 21434, 162, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[760996, 21442, 139, 3, 28, "Input"],
Cell[761138, 21447, 104, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[761279, 21454, 96, 2, 28, "Input"],
Cell[761378, 21458, 104, 2, 47, "Output"]
}, Open  ]],
Cell[761497, 21463, 534, 8, 86, "Text"],
Cell[762034, 21473, 297, 5, 50, "Text"],
Cell[762334, 21480, 121, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[762480, 21487, 149, 3, 28, "Input"],
Cell[762632, 21492, 359, 6, 29, "Output"]
}, Open  ]],
Cell[763006, 21501, 130, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[763161, 21508, 152, 3, 28, "Input"],
Cell[763316, 21513, 97, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[763462, 21521, 32, 0, 49, "Sub3section"],
Cell[763497, 21523, 1631, 50, 122, "Text"],
Cell[765131, 21575, 318, 11, 24, "ItemizedText"],
Cell[765452, 21588, 507, 17, 22, "ItemizedText"],
Cell[765962, 21607, 786, 21, 76, "ItemizedText"],
Cell[766751, 21630, 408, 14, 22, "ItemizedText"],
Cell[767162, 21646, 282, 11, 22, "ItemizedText"],
Cell[767447, 21659, 333, 15, 22, "ItemizedText"],
Cell[767783, 21676, 570, 18, 40, "ItemizedText"],
Cell[768356, 21696, 697, 26, 42, "ItemizedText"],
Cell[769056, 21724, 424, 7, 68, "Text"],
Cell[769483, 21733, 358, 8, 50, "Text"],
Cell[769844, 21743, 336, 6, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[770217, 21754, 33, 0, 49, "Sub3section"],
Cell[770253, 21756, 857, 20, 104, "Text"],
Cell[771113, 21778, 496, 19, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[771634, 21801, 177, 4, 28, "Input"],
Cell[771814, 21807, 4131, 97, 237, "Output"]
}, Open  ]],
Cell[775960, 21907, 588, 16, 82, "MathCaption"],

Cell[CellGroupData[{
Cell[776573, 21927, 161, 4, 28, "Input"],
Cell[776737, 21933, 3642, 89, 237, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[780428, 22028, 34, 0, 49, "Sub3section"],
Cell[780465, 22030, 32, 0, 32, "Text"],
Cell[780500, 22032, 252, 7, 40, "ItemizedText"],
Cell[780755, 22041, 446, 9, 58, "ItemizedText"],
Cell[781204, 22052, 765, 13, 94, "ItemizedText"],
Cell[781972, 22067, 293, 7, 40, "ItemizedText"],
Cell[782268, 22076, 484, 12, 58, "ItemizedText"],
Cell[782755, 22090, 800, 12, 122, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[783604, 22108, 64, 0, 38, "Subsection"],
Cell[783671, 22110, 1136, 29, 122, "Text"],
Cell[784810, 22141, 281, 9, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[785116, 22154, 183, 3, 28, "Input"],
Cell[785302, 22159, 195, 3, 49, "Output"]
}, Open  ]],
Cell[785512, 22165, 774, 16, 104, "Text"],
Cell[786289, 22183, 1806, 62, 122, "Text"],
Cell[788098, 22247, 630, 33, 31, "MathCaption"],
Cell[788731, 22282, 328, 7, 64, "Input"],

Cell[CellGroupData[{
Cell[789084, 22293, 154, 3, 28, "Input"],
Cell[789241, 22298, 475, 12, 63, "Output"]
}, Open  ]],
Cell[789731, 22313, 1504, 46, 140, "Text"],
Cell[791238, 22361, 269, 5, 50, "Text"],
Cell[791510, 22368, 220, 4, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[791767, 22377, 37, 0, 38, "Subsection"],
Cell[791807, 22379, 824, 22, 68, "Text"],
Cell[792634, 22403, 67, 2, 32, "Text"],
Cell[792704, 22407, 559, 12, 58, "ItemizedText"],
Cell[793266, 22421, 250, 7, 22, "ItemizedText"],
Cell[793519, 22430, 115, 3, 22, "ItemizedText"],
Cell[793637, 22435, 103, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[793777, 22443, 33, 0, 38, "Subsection"],
Cell[793813, 22445, 800, 13, 104, "Text"],

Cell[CellGroupData[{
Cell[794638, 22462, 89, 1, 28, "Input"],
Cell[794730, 22465, 193, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[794960, 22475, 44, 1, 28, "Input"],
Cell[795007, 22478, 121, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[795165, 22485, 64, 1, 28, "Input"],
Cell[795232, 22488, 511, 12, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[795780, 22505, 57, 1, 28, "Input"],
Cell[795840, 22508, 550, 11, 63, "Print",
  CellTags->"Info3388089028-2566563"]
}, Open  ]],

Cell[CellGroupData[{
Cell[796427, 22524, 41, 1, 28, "Input"],
Cell[796471, 22527, 145, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[796653, 22534, 50, 1, 28, "Input"],
Cell[796706, 22537, 107, 2, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[796874, 22546, 58, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[796957, 22550, 53, 0, 49, "Subsubsection"],
Cell[797013, 22552, 151, 3, 32, "Text"],
Cell[797167, 22557, 1037, 18, 140, "Text"],

Cell[CellGroupData[{
Cell[798229, 22579, 86, 2, 28, "Input"],
Cell[798318, 22583, 3209, 86, 175, "Output"]
}, Open  ]],
Cell[801542, 22672, 621, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[802188, 22685, 127, 3, 28, "Input"],
Cell[802318, 22690, 3591, 72, 226, "Output"]
}, Open  ]],
Cell[805924, 22765, 699, 27, 50, "Text"],
Cell[806626, 22794, 522, 8, 86, "Text"],
Cell[807151, 22804, 126, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[807314, 22812, 53, 0, 49, "Subsubsection"],
Cell[807370, 22814, 686, 12, 104, "Text"],

Cell[CellGroupData[{
Cell[808081, 22830, 90, 2, 28, "Input"],
Cell[808174, 22834, 1387, 40, 117, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[809598, 22879, 94, 2, 28, "Input"],
Cell[809695, 22883, 2626, 57, 232, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[812358, 22945, 93, 2, 28, "Input"],
Cell[812454, 22949, 176, 3, 67, "Output"]
}, Open  ]],
Cell[812645, 22955, 84, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[812754, 22961, 101, 2, 28, "Input"],
Cell[812858, 22965, 95, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[813014, 22974, 63, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[813102, 22978, 37, 0, 49, "Subsubsection"],
Cell[813142, 22980, 835, 12, 122, "Text"],
Cell[813980, 22994, 312, 5, 50, "Text"],
Cell[814295, 23001, 250, 4, 50, "Text"],
Cell[814548, 23007, 318, 5, 65, "MathCaption"],

Cell[CellGroupData[{
Cell[814891, 23016, 70, 2, 28, "Input"],
Cell[814964, 23020, 1137, 25, 91, "Output"]
}, Open  ]],
Cell[816116, 23048, 487, 11, 68, "Text"],
Cell[816606, 23061, 378, 6, 65, "MathCaption"],

Cell[CellGroupData[{
Cell[817009, 23071, 77, 2, 28, "Input"],
Cell[817089, 23075, 2120, 60, 91, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[819258, 23141, 39, 0, 49, "Subsubsection"],
Cell[819300, 23143, 57, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[819382, 23147, 63, 2, 28, "Input"],
Cell[819448, 23151, 88, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[819573, 23158, 67, 2, 28, "Input"],
Cell[819643, 23162, 338, 10, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[820018, 23177, 72, 2, 28, "Input"],
Cell[820093, 23181, 107, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[820237, 23188, 76, 2, 28, "Input"],
Cell[820316, 23192, 395, 11, 63, "Output"]
}, Open  ]],
Cell[820726, 23206, 561, 10, 82, "MathCaption"],

Cell[CellGroupData[{
Cell[821312, 23220, 109, 2, 28, "Input"],
Cell[821424, 23224, 261, 5, 25, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[821722, 23234, 111, 2, 28, "Input"],
Cell[821836, 23238, 79, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[821964, 23246, 32, 0, 49, "Subsubsection"],
Cell[821999, 23248, 200, 4, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[822224, 23256, 85, 2, 28, "Input"],
Cell[822312, 23260, 820, 25, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[823169, 23290, 63, 2, 28, "Input"],
Cell[823235, 23294, 88, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[823360, 23301, 96, 2, 28, "Input"],
Cell[823459, 23305, 820, 25, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[824316, 23335, 63, 2, 28, "Input"],
Cell[824382, 23339, 98, 2, 29, "Output"]
}, Open  ]],
Cell[824495, 23344, 77, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[824597, 23348, 67, 2, 28, "Input"],
Cell[824667, 23352, 113, 2, 29, "Output"]
}, Open  ]],
Cell[824795, 23357, 146, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[824966, 23364, 89, 2, 28, "Input"],
Cell[825058, 23368, 2120, 60, 91, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[827227, 23434, 33, 0, 49, "Subsubsection"],
Cell[827263, 23436, 74, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[827362, 23440, 91, 2, 28, "Input"],
Cell[827456, 23444, 2120, 60, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[829613, 23509, 102, 2, 28, "Input"],
Cell[829718, 23513, 2126, 60, 91, "Output"]
}, Open  ]],
Cell[831859, 23576, 218, 4, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[832102, 23584, 67, 2, 28, "Input"],
Cell[832172, 23588, 176, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[832385, 23596, 48, 0, 49, "Sub3section"],
Cell[832436, 23598, 213, 4, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[832674, 23606, 111, 2, 28, "Input"],
Cell[832788, 23610, 100, 2, 29, "Output"]
}, Open  ]],
Cell[832903, 23615, 125, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[833053, 23622, 97, 2, 28, "Input"],
Cell[833153, 23626, 707, 19, 207, "Output"]
}, Open  ]],
Cell[833875, 23648, 238, 4, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[834138, 23656, 91, 2, 28, "Input"],
Cell[834232, 23660, 1198, 27, 103, "Output"]
}, Open  ]],
Cell[835445, 23690, 62, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[835532, 23694, 92, 2, 28, "Input"],
Cell[835627, 23698, 12414, 275, 587, "Output"]
}, Open  ]],
Cell[848056, 23976, 116, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[848197, 23983, 97, 2, 28, "Input"],
Cell[848297, 23987, 2708, 76, 91, "Output"]
}, Open  ]],
Cell[851020, 24066, 506, 11, 68, "Text"],

Cell[CellGroupData[{
Cell[851551, 24081, 74, 2, 28, "Input"],
Cell[851628, 24085, 1195, 30, 153, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[852884, 24122, 48, 0, 49, "Subsubsection"],
Cell[852935, 24124, 202, 4, 50, "Text"],
Cell[853140, 24130, 168, 3, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[853333, 24137, 82, 2, 28, "Input"],
Cell[853418, 24141, 2131, 60, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[855586, 24206, 90, 2, 28, "Input"],
Cell[855679, 24210, 849, 25, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[856565, 24240, 98, 2, 28, "Input"],
Cell[856666, 24244, 849, 25, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[857552, 24274, 63, 2, 28, "Input"],
Cell[857618, 24278, 113, 2, 29, "Output"]
}, Open  ]],
Cell[857746, 24283, 272, 5, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[858043, 24292, 71, 2, 28, "Input"],
Cell[858117, 24296, 12074, 254, 605, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[870240, 24556, 41, 0, 49, "Subsubsection"],
Cell[870284, 24558, 118, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[870427, 24565, 78, 2, 28, "Input"],
Cell[870508, 24569, 4446, 113, 77, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[875015, 24689, 39, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[875079, 24693, 34, 0, 38, "Subsection"],
Cell[875116, 24695, 307, 6, 50, "Text"],
Cell[875426, 24703, 472, 8, 68, "Text"],
Cell[875901, 24713, 797, 16, 104, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[876735, 24734, 46, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[876806, 24738, 75, 2, 28, "Input"],
Cell[876884, 24742, 856, 12, 158, "Print",
  CellTags->"Info3389963783-4703339"]
}, Open  ]],

Cell[CellGroupData[{
Cell[877777, 24759, 81, 2, 28, "Input"],
Cell[877861, 24763, 127, 2, 25, "Print",
  CellTags->"Info3389963783-2444450"]
}, Open  ]],

Cell[CellGroupData[{
Cell[878025, 24770, 81, 2, 28, "Input"],
Cell[878109, 24774, 167, 3, 25, "Print",
  CellTags->"Info3389963783-2202456"]
}, Open  ]],

Cell[CellGroupData[{
Cell[878313, 24782, 74, 2, 28, "Input"],
Cell[878390, 24786, 653, 9, 101, "Print",
  CellTags->"Info3389963783-7322274"]
}, Open  ]],

Cell[CellGroupData[{
Cell[879080, 24800, 81, 2, 28, "Input"],
Cell[879164, 24804, 1269, 17, 234, "Print",
  CellTags->"Info3389963783-3830953"]
}, Open  ]],

Cell[CellGroupData[{
Cell[880470, 24826, 79, 2, 28, "Input"],
Cell[880552, 24830, 757, 11, 158, "Print",
  CellTags->"Info3389963783-9661964"]
}, Open  ]],

Cell[CellGroupData[{
Cell[881346, 24846, 85, 2, 28, "Input"],
Cell[881434, 24850, 1113, 15, 234, "Print",
  CellTags->"Info3389963783-1309459"]
}, Open  ]],

Cell[CellGroupData[{
Cell[882584, 24870, 74, 2, 28, "Input"],
Cell[882661, 24874, 1021, 14, 215, "Print",
  CellTags->"Info3389963783-1444548"]
}, Open  ]],

Cell[CellGroupData[{
Cell[883719, 24893, 72, 2, 28, "Input"],
Cell[883794, 24897, 598, 9, 101, "Print",
  CellTags->"Info3389963784-8391200"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[884441, 24912, 38, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[884504, 24916, 80, 2, 28, "Input"],
Cell[884587, 24920, 612, 9, 120, "Print",
  CellTags->"Info3389963786-3160652"]
}, Open  ]],

Cell[CellGroupData[{
Cell[885236, 24934, 90, 2, 28, "Input"],
Cell[885329, 24938, 171, 3, 25, "Print",
  CellTags->"Info3389963786-6005471"]
}, Open  ]],

Cell[CellGroupData[{
Cell[885537, 24946, 80, 2, 28, "Input"],
Cell[885620, 24950, 646, 9, 101, "Print",
  CellTags->"Info3389963786-1547483"]
}, Open  ]],

Cell[CellGroupData[{
Cell[886303, 24964, 80, 2, 28, "Input"],
Cell[886386, 24968, 1234, 17, 253, "Print",
  CellTags->"Info3389963786-6168920"]
}, Open  ]],

Cell[CellGroupData[{
Cell[887657, 24990, 84, 2, 28, "Input"],
Cell[887744, 24994, 417, 6, 63, "Print",
  CellTags->"Info3389963787-5162220"]
}, Open  ]],

Cell[CellGroupData[{
Cell[888198, 25005, 79, 2, 28, "Input"],
Cell[888280, 25009, 323, 5, 63, "Print",
  CellTags->"Info3389963787-9421809"]
}, Open  ]],

Cell[CellGroupData[{
Cell[888640, 25019, 81, 2, 28, "Input"],
Cell[888724, 25023, 763, 11, 120, "Print",
  CellTags->"Info3389963787-4595655"]
}, Open  ]],

Cell[CellGroupData[{
Cell[889524, 25039, 87, 2, 28, "Input"],
Cell[889614, 25043, 1472, 20, 291, "Print",
  CellTags->"Info3389963787-1842802"]
}, Open  ]],

Cell[CellGroupData[{
Cell[891123, 25068, 74, 2, 28, "Input"],
Cell[891200, 25072, 2226, 30, 424, "Print",
  CellTags->"Info3389963787-1670301"]
}, Open  ]],

Cell[CellGroupData[{
Cell[893463, 25107, 75, 2, 28, "Input"],
Cell[893541, 25111, 369, 6, 63, "Print",
  CellTags->"Info3389963787-7879889"]
}, Open  ]],

Cell[CellGroupData[{
Cell[893947, 25122, 72, 2, 28, "Input"],
Cell[894022, 25126, 111, 2, 25, "Print",
  CellTags->"Info3389963787-1951870"]
}, Open  ]],

Cell[CellGroupData[{
Cell[894170, 25133, 80, 2, 28, "Input"],
Cell[894253, 25137, 1031, 15, 196, "Print",
  CellTags->"Info3389963787-2144332"]
}, Open  ]],

Cell[CellGroupData[{
Cell[895321, 25157, 78, 2, 28, "Input"],
Cell[895402, 25161, 266, 4, 44, "Print",
  CellTags->"Info3389963788-4054695"]
}, Open  ]],

Cell[CellGroupData[{
Cell[895705, 25170, 84, 2, 28, "Input"],
Cell[895792, 25174, 1672, 22, 310, "Print",
  CellTags->"Info3389963788-8282604"]
}, Open  ]],

Cell[CellGroupData[{
Cell[897501, 25201, 78, 2, 28, "Input"],
Cell[897582, 25205, 679, 10, 120, "Print",
  CellTags->"Info3389963788-4900215"]
}, Open  ]],

Cell[CellGroupData[{
Cell[898298, 25220, 73, 2, 28, "Input"],
Cell[898374, 25224, 511, 8, 101, "Print",
  CellTags->"Info3389963788-2312096"]
}, Open  ]],

Cell[CellGroupData[{
Cell[898922, 25237, 75, 2, 28, "Input"],
Cell[899000, 25241, 1066, 15, 234, "Print",
  CellTags->"Info3389963788-1844059"]
}, Open  ]],

Cell[CellGroupData[{
Cell[900103, 25261, 81, 2, 28, "Input"],
Cell[900187, 25265, 322, 5, 63, "Print",
  CellTags->"Info3389963788-6521224"]
}, Open  ]],

Cell[CellGroupData[{
Cell[900546, 25275, 87, 2, 28, "Input"],
Cell[900636, 25279, 659, 9, 101, "Print",
  CellTags->"Info3389963788-9745965"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[901356, 25295, 29, 0, 72, "Section"],
Cell[901388, 25297, 65, 0, 32, "Text"],
Cell[901456, 25299, 221, 4, 50, "Text"],
Cell[901680, 25305, 274, 8, 50, "Text"],
Cell[901957, 25315, 243, 5, 50, "Text"],
Cell[902203, 25322, 174, 4, 32, "Text"],
Cell[902380, 25328, 193, 4, 32, "Text"],
Cell[902576, 25334, 301, 5, 50, "Text"],
Cell[902880, 25341, 483, 7, 68, "Text"],
Cell[903366, 25350, 182, 4, 32, "Text"],
Cell[903551, 25356, 248, 5, 50, "Text"],
Cell[903802, 25363, 290, 6, 51, "Text"],
Cell[904095, 25371, 289, 6, 50, "Text"],
Cell[904387, 25379, 301, 5, 50, "Text"],
Cell[904691, 25386, 125, 3, 32, "Text"],
Cell[904819, 25391, 166, 4, 32, "Text"],
Cell[904988, 25397, 289, 5, 50, "Text"],
Cell[905280, 25404, 231, 4, 50, "Text"],
Cell[905514, 25410, 218, 4, 50, "Text"],
Cell[905735, 25416, 163, 3, 32, "Text"],
Cell[905901, 25421, 144, 3, 32, "Text"],
Cell[906048, 25426, 199, 4, 32, "Text"],
Cell[906250, 25432, 194, 4, 32, "Text"],
Cell[906447, 25438, 133, 3, 32, "Text"],
Cell[906583, 25443, 131, 3, 32, "Text"],
Cell[906717, 25448, 296, 6, 50, "Text"],
Cell[907016, 25456, 32, 0, 32, "Text"],
Cell[907051, 25458, 195, 4, 88, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

